      SUBROUTINE ATMGRA
C
C VERSION
C     01JAN15 AD Simplified to use INTGRA
C                Also allow for TVib profiles
C     26DEC99 AD Original
C
C DESCRIPTION
C     Interpolate to fill 2-D atmospheric profile field.
C     Called once by INPATM after all profiles are loaded if GRA flag enabled
C     For each species (including pressure and temperature) the procedure is
C     to establish the psi locations at which profile values have been supplied
C     and interpolate values for any missing internal locations, and duplicate
C     end values for any missing external locations.
C     Horizontal interpolation is linear for T, log for p (linear if p small),
C     and depends upon LIN flag for VMR as in ATMLAY. 
C     The end result should be that full profiles for p, T and VMR are set at
C     all specified psi values, and any TVib profiles loaded via .atm files
C     Also loads reference profile (psi=0) into atmcom.inc
C
      IMPLICIT NONE
C
      EXTERNAL
     &  INTGRA ! Interpolate to fill 2-D atmospheric profile field.
     &, MOVGRA ! Exchange profiles between /ATMCOM/ and /GRACOM/ arrays.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
      INCLUDE 'ntecom.inc' ! Non-LTE data 
C
C LOCAL VARIABLES
      INTEGER IGAS ! Counter for absorbing species
      INTEGER INTE ! Counter for vibrational temperature profiles
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      CALL INTGRA ( NGRA, NATM, MAXATM, FLTGRA, .TRUE., PSIGRA, TEMGRA ) 
      CALL INTGRA ( NGRA, NATM, MAXATM, FLPGRA, .FALSE., PSIGRA, 
     &              PREGRA )
      DO IGAS = 1, NGAS
        CALL INTGRA ( NGRA, NATM, MAXATM, FLVGRA(1,IGAS), LINFLG, 
     &                PSIGRA, VMRGRA(1,1,IGAS) )
      END DO
      DO INTE = 1, NNTE
        CALL INTGRA ( NGRA, NATM, MAXATM, FLNGRA(1,INTE), .FALSE., 
     &                PSIGRA, TVBGRA(1,1,INTE) ) 
      END DO
C
      CALL MOVGRA ( NOMGRA, 0 )
C
      END                     
