      SUBROUTINE ATMLAY ( FAIL, ERRMSG )
C
C VERSION
C     01JAN15 AD New version - simplified.
C     31DEC99 AD Insert extra layers into horiz.gradient profiles as well
C     24JAN99 AD Replace OFMFLG by LINFLG.
C                    Remove GL2FLG and module LAYGL2
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Subdivide atmospheric profile layers.
C     Called once by ATMFIL if LAY flag enabled.
C     Adds extra altitude grid points half-way between user-supplied profile.
C
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  RFMLOG ! Write text message to RFM log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes      
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
C
C LOCAL VARIABLES
      INTEGER      IATM    ! Original profile level
      INTEGER      INEW    ! New profile level
      INTEGER      NNEW    ! No. of new levels in profile
      CHARACTER*80 MESSGE  ! Text message sent to Log file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Calculate the number of new profile levels
      NNEW = 2 * NATM - 1
C
      IF ( NNEW .GT. MAXATM ) THEN
        WRITE ( ERRMSG, '(A,I6,A,I6,A)' )
     &    'F-ATMLAY: LAY flag requires', NATM, 
     &    ' levels, > MAXATM parameter=', MAXATM, ' in rfmsiz.inc'
        FAIL = .TRUE.
      ELSE
        WRITE ( MESSGE, '(A,I6,A,I6)' ) 
     &    'I-ATMLAY: Number of atmos.profile levels increased from ', 
     &    NATM, ' to ', NNEW
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
      END IF
      IF ( FAIL ) RETURN
C
C Eg If NATM=5, INEW = 9,8,7..2, IATM=4,4,3...1, 
      DO INEW = 2 * NATM - 1, 2, -1
        IATM = INEW/2                      ! integer division assumed
        IF ( IATM .EQ. 2 * INEW ) THEN     ! INEW even: interpolated level
          HGTATM(INEW) = 0.5 * ( HGTATM(IATM) + HGTATM(IATM+1) ) 
        ELSE                               ! INEW odd: replicated level
          HGTATM(INEW) = HGTATM(IATM+1)    
        END IF
      END DO
C
      NATM = NNEW                        
C
      END
