      SUBROUTINE ATMNTE ( IDXVIB, VIBATM, FAIL, ERRMSG )
C
C VERSION
C     01JAN15 AD Use IDXNTE. Remove QFNNTE from /NTECOM/ 
C     13AUG13 AD Remove redundant variable IPRF
C     06JAN11 AD Explicitly set QFNNTE = 0 
C                    Fix bug: actually *load* TEMNTE
C     09JAN07 AD Original. Based on MORSE routine VIBNTE
C
C DESCRIPTION
C     Load vibrational temperature profile from .atm file
C     Called by FILPRF if NTE flag enabled and VT profile found in .atm file.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      IDXVIB  !  I  Encoded details of Vibrational level
      REAL      VIBATM(*)  !  I  Vib.Tem profile interpolated to *ATM levels
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  IDXNTE ! Index of Vib.Temp data in /NTECOM/ arrays
     &, RFMLOG ! Write text message to RFM log file.
      INTEGER IDXNTE
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! Dimensions for common arrays
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'ntecom.inc' ! Non-LTE data
C
C LOCAL CONSTANTS
      INTEGER      NVIB    ! No. of Vib.Temps with locally listed Energies
        PARAMETER  ( NVIB = 2 ) 
C
C LOCAL VARIABLES
      INTEGER      IATM    ! Counter for atmospheric profile levels
      INTEGER      IGAS    ! Index in *GAS arrays of molecule
      INTEGER      IGQ     ! Global Quantum Index of vibrational level
      INTEGER      IMOL    ! HITRAN ID for VT molecule 
      INTEGER      INTE    ! Counter for stored NTE datasets
      INTEGER      ISO     ! Isotope# (or 0=apply to all isotopes)
      INTEGER      IVIB    ! Counter for locally stored Energy levels info
      INTEGER      LSTVIB(NVIB) ! List of VT indices for Energy levels
      REAL         ENGVIB(NVIB) ! Energy for each Vib.level
      CHARACTER*80 MESSGE  ! Text message for log file
C
C DATA STATEMENTS
C Copy data from .nte files if other levels are required
      DATA LSTVIB / 5000002,   5001002 /
      DATA ENGVIB / 2143.2711, 2143.2711 /
      SAVE LSTVIB, ENGVIB
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      IMOL = IDXVIB/1000000     ! Extract Molecule ID, Isotope#, GQ#
      ISO  = MOD ( IDXVIB, 1000000 ) / 1000
      IGQ  = MOD ( IDXVIB, 1000 )
C
      IGAS = IGSMOL(IMOL)
C
      INTE = IDXNTE ( IMOL, ISO, IGQ )
C Check if a VT profile has already been loaded for this mol/iso/igq
      IF ( INTE .GT. 0 ) THEN
        DO IATM = 1, NATM
          TEMNTE(IATM,INTE) = VIBATM(IATM)
        END DO
        MESSGE = 'W-ATMNTE: VT profile superseded'
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        RETURN  ! Normal exit with VT profile replaced
      END IF
C
C If not already loaded this VT, add to list
      IF ( NNTE .GT. MAXNTE ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-ATMNTE: MAXNTE in rfmsiz.inc too small'
        RETURN
      END IF
C
      NNTE = NNTE + 1
      MNTE = NNTE
      IDGNTE(NNTE) = IMOL
      ISONTE(NNTE) = ISO
      IGQNTE(NNTE) = IGQ
      IQFNTE(NNTE) = 0
C Load new profile 
      DO IATM = 1, NATM
        TEMNTE(IATM,NNTE) = VIBATM(IATM)
      END DO
C
C Check that Gas/IGQ VTs are either marked for all isotopes or individual iso.
      DO INTE = 1, NNTE-1
        IF ( IDGNTE(INTE) .EQ. IDGNTE(NNTE) .AND.
     &       IGQNTE(INTE) .EQ. IGQNTE(NNTE) ) THEN
          IF ( ISONTE(INTE) .EQ. 0 .OR. ISONTE(NNTE) .EQ. 0 ) THEN
            FAIL = .TRUE.
            WRITE ( ERRMSG, '(A,A,A,I3,A)' ) 'F-ATMNTE: Gas ', 
     &        CODGAS(IGAS), ' GQIdx#', IGQNTE(NNTE),
     &        ' has VT flagged for both * and specific isotps.'
            RETURN
          ENDIF
        ENDIF 
      ENDDO
C
C Check that the energy level for this VT is stored here 
      DO IVIB = 1, NVIB
        IF ( IDXVIB .EQ. LSTVIB(IVIB) ) THEN
          ENGNTE(NNTE) = ENGVIB(IVIB)
          FAIL = .FALSE.
          RETURN                       ! Normal exit for new VT profile
        ENDIF
      END DO
C
      FAIL = .TRUE.
      WRITE ( ERRMSG, '(A,A,A,I1,A,I3)' ) 
     &  'F-ATMNTE: No Energy level listed for Gas=', CODGAS(IGAS), 
     &  ' Iso=', ISONTE(INTE), ' GQ#=', IGQNTE(INTE)
      RETURN
C
      END
