      SUBROUTINE ATMPSI ( NAMATM, IGRA, FAIL, ERRMSG )
C
C VERSION
C     01JAN15 AD Changed arguments. Perform more functions internally
C     03JAN08 AD Original.
C
C DESCRIPTION
C     Extract Psi angle from brackets following .atm filename
C     Called by ATMFIL, NTEFIL for each file 
C     If called with GRA flag this returns the index IGRA for the Psi angle.
C     If called without GRA flag this returns IGRA=0
C     Also strips off '(...)' from NAMATM leaving just the filename.
C
      IMPLICIT NONE
C
C ARGUMENTS
      CHARACTER*(*) NAMATM ! I/O Name of file 
      INTEGER       IGRA   !  O  Index of horizontal angle location
      REAL          PSI    !  O  Horizontal angle
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  IDXGRA ! Index of PSI angle in horizontal gradient /GRACOM/ arrays
     &, NEWPSI ! Create new horizontal location in horiz.gradient data
     &, RFMLOG ! Write text message to RFM log file.
      INTEGER IDXGRA
C
C LOCAL CONSTANTS
      REAL PSIMAX                   ! Max magnitude of horizontal angle [deg]
        PARAMETER ( PSIMAX = 90.0 ) ! STRGRA in MAKNAM limits PSI to <100deg.
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
C
C LOCAL VARIABLES
      INTEGER      IEND    ! Location of end of text field in RECORD 
      INTEGER      IOS     ! Saved value of IOSTAT for error message
      INTEGER      ISTA    ! Location of start of text field in RECORD 
      CHARACTER*9  ERRSTR  ! Piece of error message
      CHARACTER*80 MESSGE  ! Text message for LOG file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      IGRA = 0
C Establish if there is any qualifier string appended to filename containing
C the horizontal angle
      ISTA = INDEX (  NAMATM, '(' )
      IF ( ISTA .EQ. 0 ) THEN
        IF ( GRAFLG ) IGRA = IDXGRA ( 0.0 )  ! Assume angle psi=0
        FAIL = .FALSE.
        RETURN               ! Normal exit if no appended angle
      END IF
C      
C If there is a qualifier string but GRA flag not enabled, simply strip off
C this string and return with warning message that angle is ignored
      IF ( .NOT. GRAFLG ) THEN
        NAMATM = NAMATM(1:ISTA-1)   ! strip off qualifier string
        MESSGE = 'W-ATMPSI: GRA flag disabled so '//
     &             'profile Horiz.angles ignored.'
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        RETURN
      END IF
C
C Read Psi angle from qualifier string and check valid range
      IEND = INDEX ( NAMATM, ')' )
      IF ( IEND .LE. ISTA ) THEN
        ERRSTR = NAMATM(ISTA:MIN(LEN(NAMATM),ISTA+8))
        ERRMSG= 'F-ATMPSI: No '')'' character '//
     &          'following ''('' for hor.angle of file: '
     &          //ERRSTR
        FAIL = .TRUE.
        RETURN
      END IF
      READ ( NAMATM(ISTA+1:IEND-1), *, IOSTAT=IOS ) PSI
      IF ( IOS .NE. 0 ) THEN
        ERRSTR = NAMATM(ISTA:MIN(ISTA+8,IEND))
        WRITE ( ERRMSG, '(A,I11)' ) 
     &    'F-ATMPSI: Unable to read horiz.angle from '''//
     &    ERRSTR//'''. IOSTAT=', IOS
        FAIL = .TRUE.
        RETURN
      ELSE IF ( ABS(PSI) .GT. PSIMAX ) THEN
        WRITE ( ERRMSG, '(A,F7.3,A)' )
     &    'F-ATMPSI: |Psi angle| > allowed maximum magnitude=',
     &     PSIMAX, ' [deg]'
        FAIL = .TRUE.
        RETURN
      END IF
C
      NAMATM = NAMATM(1:ISTA-1)   ! strip off qualifier string
      WRITE ( MESSGE, '(A,F7.3)' ) 
     &  'I-ATMPSI: Loading horizontal gradient profiles at PSI=', 
     &  PSI
      CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
C Find if PSI already a defined location
      IGRA = IDXGRA ( PSI ) 
      IF ( IGRA .EQ. 0 ) THEN             ! not yet defined, so add it
        CALL NEWPSI ( PSI, IGRA, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
      END
