      SUBROUTINE BRAKET ( ARRAY, N, X, I )
C
C VERSION
C     18JUN15 AD Partly rewritten - use WHILE instead of GOTO
C     03JAN14 AD Ensure that I is defined if N=1
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Return lower index I of the two points in array ARRAY(N)
C     whose values bracket X.  
C     i.e. L:  ARRAY(I)>X>ARRAY(I+1)  or  ARRAY(I)<X<ARRAY(I+1)
C     Special cases:
C         If X<ARRAY(1)<ARRAY(N)  or  X>ARRAY(1)>ARRAY(N), then I = 0
C         If X<ARRAY(N)<ARRAY(1)  or  X>ARRAY(N)>ARRAY(1), then I = N
C         If N=1 then I=0
C    Routine does not check parameters or if the array is monotonic
C    On input, I is initial guess of position.
C    Note: there is also a DP version of this subroutine: dbrakt.for
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER N          !  I  Array length
      REAL    ARRAY(N)   !  I  Data Array
      REAL    X          !  I  Value to be bracketted
      INTEGER I          ! I/O  Index of array element below X
C
C LOCAL VARIABLES
      INTEGER ISTEP      ! Step size, in array indices
      INTEGER J,M        ! High, Mid indices
      LOGICAL ASCEND     ! TRUE=ascending array, FALSE=descending (assumed)
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C Ensure I is well-defined if N=1
      IF ( N .EQ. 1 ) THEN
        I = 0
        RETURN
      END IF
C
C Determine if ascending or descending array (based on two end values only)
      ASCEND = ARRAY(1) .LT. ARRAY(N)
C
C If initials guess outside array index range, set to mid-point
      IF ( I .LE. 0 .OR. I .GT. N ) I = N / 2
C
C Starting with an initial step size of one, find pair of indices I,J
C where J = I + ISTEP, which bracket the required X value I < X < J (asc.array)
      ISTEP = 1
      J = I
      IF ( X .GE. ARRAY(I) .EQV. ASCEND ) THEN     ! I < X in ascend.array
        DO WHILE ( X .GE. ARRAY(J) .EQV. ASCEND )  ! I < J < X
          I = J  
          J = I + ISTEP
          ISTEP = ISTEP * 2
          IF ( J .GT. N ) THEN
            J = N + 1
            GOTO 100
          END IF
        END DO
      ELSE                                          ! X < I in ascend.array 
        DO WHILE ( X .LT. ARRAY(I) .EQV. ASCEND )   ! X < I < J
          J = I
          I = J - ISTEP 
          ISTEP = ISTEP * 2
          IF ( I .LT. 1 ) THEN
            I = 0
            GOTO 100
          END IF
        END DO
      END IF
 100  CONTINUE
C
C Then progressively divide interval by 2 until J=I+1 with I .LE. X .LE. J 
      DO WHILE ( J - I .GT. 1 ) 
        M =  ( J + I ) / 2 
        IF ( X .GT. ARRAY(M) .EQV. ASCEND ) THEN
          I = M
        ELSE
          J = M
        END IF
      END DO
C
      END
