      SUBROUTINE CHICO2 ( IPTH, NWNO, DWNO, CHIFAC )
C
C VERSION
C     10DEC14 AD Fix Bug#95, and rewritten for faster CPU
C     22JAN98 AD (Standard F77) Put DATA statements *after* declarations
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Calculate Chi-Factor for CO2 sub-Lorentzian lineshape.
C     Called by CHISHP for CO2 lines.
C     Note that this is a CPU-intensive routine.
C
C REFERENCES
C     C.Cousin,R.Le Doucen,C.Boulet and A.Henry, (1985)
C     Temperature dependence of the absorption in the region beyond the 4.3 
C     mic band head of CO2. 2: N2 and O2 broadening.
C     Appl.Opt. 24 (22) 3899-3907
C
C     Pure CO2 chi factor: Appl.Opt. 24 (6) 897-906 (1985)
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER IPTH         !  I  Index of path
      INTEGER NWNO         !  I  No. wavenumber points to be evaluted
      DOUBLE PRECISION DWNO(NWNO) !  I  Array of Wavenumbers [/cm]
      REAL    CHIFAC(NWNO) !  O  Chi-factor
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants      
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'adjcom.inc' ! Path-Adjusted line data
      INCLUDE 'pthcom.inc' ! RFM path data
C
C LOCAL CONSTANTS
      REAL          DFRQ         ! Wavenumber increment [cm-1] for chi table
        PARAMETER ( DFRQ = 0.5 )
      INTEGER       NFRQ         ! No.wavenumber points in chi tabulation
        PARAMETER ( NFRQ = 503 )
      REAL          TEMF1        ! Temperature tabulation points
        PARAMETER ( TEMF1 = 193.0 ) 
      REAL          TEMF2
        PARAMETER ( TEMF2 = 238.0 ) 
      REAL          TEMF3
        PARAMETER ( TEMF3 = 296.0 ) 
      REAL          TEMS4
        PARAMETER ( TEMS4 = 218.0 ) 
      REAL          TEMS5
        PARAMETER ( TEMS5 = 296.0 ) 
      INTEGER       NTEM         ! No.temperatures in chi tabulation
        PARAMETER ( NTEM = 5 )
C
C LOCAL VARIABLES
      INTEGER  IFRQ,JFRQ   ! Lower,upper indices for wavenumber interpolation
      INTEGER  ITEM        ! Temperature counter (for initialising DATA)
      INTEGER  IWNO        ! Wavenumber array counter
      REAL     DFOR,DSLF   ! Weights for foreign-,self-broadening terms
      REAL     FFI,FFJ     ! Weights for lower,upper wavenumber interpolation
      REAL     RFRQ        ! Distance from line centre as a multiple of DFRQ
      REAL     TEM         ! Temperature [K] used for interpolation
      REAL     TF1,TF2,TF3 ! Weights for lower,upper for.broadened temperatures
      REAL     TS4, TS5    ! Weights for lower,upper self broadened temperatures
      REAL     CHI(NFRQ,NTEM) ! Chi tabulation for CO2
C
C DATA STATEMENTS
      INCLUDE 'chidat.inc' ! Data statements for CHI values
      SAVE   CHI
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C Foreign and self broadening fractions 
      DSLF = PPAPTH(IPTH) / PREPTH(IPTH)
      DFOR = 1.0 - DSLF
C
      TEM = TEMPTH(IPTH)
C
C Temperature interpolation (foreign broadened)
      IF ( TEM .LT. TEMF1 ) THEN
        TF1 = DFOR
        TF2 = 0.0
        TF3 = 0.0
      ELSE IF ( TEM .LT. TEMF2 ) THEN
        TF1 = ( TEMF2 - TEM ) / ( TEMF2 - TEMF1 ) 
        TF2 = ( 1.0 - TF1 ) * DFOR
        TF1 = TF1 * DFOR
        TF3 = 0.0
      ELSE IF ( TEM .LT. TEMF3 ) THEN
        TF1 = 0.0
        TF2 = ( TEMF3 - TEM ) / ( TEMF3 - TEMF2 )
        TF3 = ( 1.0 - TF2 ) * DFOR
        TF2 = TF2 * DFOR
      ELSE 
        TF1 = 0.0
        TF2 = 0.0
        TF3 = DFOR
      END IF
C
C Temperature interpolation (self broadened)
      IF ( TEM .LT. TEMS4 ) THEN
        TS4 = DSLF
        TS5 = 0.0
      ELSE IF ( TEM .LT. TEMS5 ) THEN
        TS4 = ( TEMS5 - TEM ) / ( TEMS5 - TEMS4 )
        TS5 = ( 1.0 - TS4 ) * DSLF
        TS4 = TS4 * DSLF
      ELSE
        TS4 = 0.0
        TS5 = DSLF
      END IF
C
      DO IWNO = 1, NWNO 
C
C Frequency interpolation
        RFRQ = 1.0 + ABS ( DWNO(IWNO) - WNOADJ ) / DFRQ 
        IF ( RFRQ .LT. NFRQ ) THEN 
          IFRQ = INT ( RFRQ ) 
          FFJ = ( RFRQ - IFRQ ) / DFRQ
        ELSE
          IFRQ = NFRQ - 1
          FFJ = 1.0
        END IF
        JFRQ = 1 + IFRQ
        FFI = ( 1.0 - FFJ ) 
C     
        CHIFAC(IWNO) = 
     &      TF1 * ( FFI * CHI(IFRQ,1) + FFJ * CHI(JFRQ,1) )
     &    + TF2 * ( FFI * CHI(IFRQ,2) + FFJ * CHI(JFRQ,2) )
     &    + TF3 * ( FFI * CHI(IFRQ,3) + FFJ * CHI(JFRQ,3) )
     &    + TS4 * ( FFI * CHI(IFRQ,4) + FFJ * CHI(JFRQ,4) )
     &    + TS5 * ( FFI * CHI(IFRQ,5) + FFJ * CHI(JFRQ,5) )
       END DO
C
       END
