      SUBROUTINE CHKLIM ( TANTST, USRELE, USRGEO, FAIL, ERRMSG )
C
C VERSION
C     02APR15 AD Use C9FLT. Change logic.
C     12FEB14 AD Remove crvcom.inc, add phycom.inc (containing RADCRV)
C     03SEP03 AD Add SFCTAN 
C     18MAR01 AD Remove GETOBS
C     06JAN00 AD Add GRACNV if GRAFLG enabled
C     18JUL98 AD Original.
C
C DESCRIPTION
C     Check path for Limb-viewing mode
C     Called by TANHGT and FOVTAN for each limb path
C
      IMPLICIT NONE 
C
C ARGUMENTS
      REAL         TANTST  !  I  Value of sec(theta) or elev. to be checked
      LOGICAL      USRELE  !  I  T=TANTST is elevation angle, F=actual
      LOGICAL      USRGEO  !  I  T=TANTST is geom.tangent height, F=actual.
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  C9FLT  ! Write real number as C*9 string up to 3 s.f.
     &, GRACNV ! Convert tangent point specifications for 2D atmosphere
     &, TANCNV ! Convert tangent point specifications
      CHARACTER*9 C9FLT
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'obscom.inc' ! Observer Position
      INCLUDE 'phycom.inc' ! Adjustable physical constants (RADCRV)
C
C LOCAL VARIABLES
      LOGICAL SFCTAN       ! T=intersects surface, F=doesn't (dummy here)
      REAL    ELETAN       ! Elevation angle [deg]
      REAL    GEOTAN       ! Geometric (projected) tangent height [km]
      REAL    HGTTAN       ! Refracted (actual) tangent height [km]
      REAL    PSITAN       ! Horizontal angle of Refracted tangent pt [deg]
      DOUBLE PRECISION SZNTAN ! Sine(Zenith Angle) at tangent pt or surface
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      FAIL = .TRUE.
C
      IF ( USRGEO ) THEN 
        GEOTAN = TANTST
        IF ( GEOTAN .GT. HGTATM(NATM) ) THEN
          ERRMSG = 'F-CHKLIM: Tangent Height=' // C9FLT ( GEOTAN ) // 
     &      '[km] > Top of Atmosphere=' // C9FLT ( HGTATM(NATM) ) //
     &      '[km]'
        ELSE IF ( SFCFLG .AND. GEOTAN .LT. -RADCRV ) THEN
          ERRMSG = 'F-CHKLIM: Tangent Height=' // C9FLT ( GEOTAN ) // 
     &      '[km] < Centre of Earth=' // C9FLT ( SNGL ( -RADCRV ) ) //
     &      '[km]'
        ELSE IF ( .NOT. SFCFLG .AND. GEOTAN .LT. HGTATM(1) ) THEN
          ERRMSG = 'F-CHKLIM: Tangent Height=' // C9FLT ( GEOTAN ) // 
     &      '[km] < Base of Atmosphere=' // C9FLT ( HGTATM(1) ) // 
     &      '[km]'
        ELSE
          IF ( GRAFLG ) THEN
            CALL GRACNV ( 2, ELETAN, GEOTAN, HGTTAN, 
     &                       SZNTAN, PSITAN, SFCTAN )
          ELSE
            CALL TANCNV ( 2, ELETAN, GEOTAN, HGTTAN, SZNTAN, SFCTAN )
          END IF
          IF ( ABS(SZNTAN) .LT. 1.0D0 .AND. .NOT. SFCFLG ) THEN
            ERRMSG = 'F-CHKLIM: Tan.Ht.=' // C9FLT ( GEOTAN ) //
     &        ' [km] < atmos. after refraction, alt=' // 
     &        C9FLT ( HGTTAN ) // ' [km]' 
          ELSE
            FAIL = .FALSE.
          END IF
        END IF
C
      ELSE IF ( USRELE ) THEN
        ELETAN = TANTST
        IF ( ABS ( ELETAN ) .GT. 90.0 ) THEN
          ERRMSG = 'F-CHKLIM: Specified Elev.  angle outside range'//
     &       ' +/-90deg, value=' // C9FLT ( ELETAN ) 
        ELSE IF ( ELETAN .GT. 0.0 .AND.
     &            ALTOBS .GE. HGTATM(NATM) ) THEN
          ERRMSG = 'F-CHKLIM: Positive Elev.Angles not allowed '//
     &               'if OBServer above atmosphere'
        ELSE
          IF ( GRAFLG ) THEN
            CALL GRACNV ( 1, ELETAN, GEOTAN, HGTTAN, 
     &                       SZNTAN, PSITAN, SFCTAN )
          ELSE
            CALL TANCNV ( 1, ELETAN, GEOTAN, HGTTAN, SZNTAN, SFCTAN )
          END IF
          IF ( GEOTAN .GT. HGTATM(NATM) ) THEN
            GEOTAN = MIN ( GEOTAN, 999999. )
            ERRMSG = 'F-CHKLIM: Elev.Ang=' // C9FLT ( ELETAN ) //
     &        ' [deg] has geom.tan.pt. > atmos., alt=' // 
     &        C9FLT ( GEOTAN ) // ' [km]'
          ELSE IF ( .NOT. SFCFLG .AND. GEOTAN .LE. HGTATM(1) ) THEN
            ERRMSG = 'F-CHKLIM: Elev.Ang=' // C9FLT ( ELETAN ) //
     &        ' [deg] has geom.tan.pt. < atmos., alt=' // 
     &        C9FLT ( GEOTAN ) // ' [km]'
          ELSE IF ( .NOT. SFCFLG .AND. HGTTAN .LE. HGTATM(1) ) THEN
            ERRMSG = 'F-CHKLIM: Elev.Ang=' // C9FLT ( ELETAN ) //
     &        ' [deg] has refr.tan.pt. < atmos., alt=' //
     &        C9FLT ( HGTTAN ) // ' [km]'
          ELSE
            FAIL = .FALSE.
          END IF
        END IF
C
      ELSE        
        HGTTAN = TANTST
        IF ( HGTTAN .GT. HGTATM(NATM) ) THEN
          ERRMSG = 'F-CHKLIM: Tangent Height=' // C9FLT ( HGTTAN ) //
     &      '[km] > Top of Atmosphere=' // C9FLT ( HGTATM(NATM) ) // 
     &      '[km]'
        ELSE IF ( HGTTAN .LT. HGTATM(1) ) THEN
          ERRMSG = 'F-CHKLIM: Tangent Height=' // C9FLT ( HGTTAN ) //
     &      '[km] < Base of Atmosphere=' // C9FLT ( HGTATM(1) ) //
     &      '[km]'
        ELSE
          FAIL = .FALSE.
        END IF
      END IF
C
      END
