      SUBROUTINE CHKRES ( WNRMAX, FAIL, ERRMSG )
C
C VERSION
C     10FEB15 AD Remove local variable WIDVOI
C     29JAN15 AD Replace WIDGL2 with WIDVOI
C     07AUG13 AD Change FORMAT descriptors to avoid ifort warnings
C     18MAR91 AD Original. Replaces CHKWID
C
C DESCRIPTION
C     Check tangent pt line-widths compatible with spectral resln.
C     Called by FINCHK for highest tangent height or hom.path
C     NB should only be called if IATTAN(NTAN) is defined and non-zero.
C
      IMPLICIT NONE
C
C ARGUMENTS
      REAL         WNRMAX  !  I  Maximum spacing of fine mesh resolution
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  RFMLOG ! Write text message to RFM log file.
     &, WIDVOI ! Estimate Voigt half-width of line.
      REAL  WIDVOI
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
      INCLUDE 'tancom.inc' ! Tangent heights
C
C LOCAL CONSTANTS
      REAL          WIDLIM ! Min No. calc.pts/half width for adequate resoln
        PARAMETER ( WIDLIM = 1.5 )
      REAL          TCOTYP        ! Typical temperature coeff for Press.Broad
        PARAMETER ( TCOTYP = 0.5 )
      REAL          WGTTYP        ! Typical molecular weight [g]
        PARAMETER ( WGTTYP = 36.0 )
      REAL          WIDTYP        ! Typical standard line width [/cm]
        PARAMETER ( WIDTYP = 0.1 )
C
C LOCAL VARIABLES
      INTEGER      IATM    ! Index of Atmospheric layer with highest tan.pt.
      REAL         PRE     ! Pressure [mb] corresponding to bottom of layer
      REAL         TEM     ! Temperature [K] corresponding to bottom of layer
      REAL         WID     ! Typical line half-width [cm-1] 
      REAL         WIDDOP  ! Doppler-broadended linewidth
      REAL         WIDLOR  ! Pressure-broadened linewidth
      CHARACTER*80 MESSGE  ! Warning message sent to runlog file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      FAIL = .FALSE.
C
      IF ( NTAN .EQ. 0 ) STOP 'F-CHKRES: Logical Error#1'
      IF ( IATTAN(NTAN) .EQ. 0 ) STOP 'F-CHKRES: Logical Error#2'
C
      IATM = IATTAN(NTAN)
      TEM = TEMATM(IATM)
      PRE = PREATM(IATM)
C
      WIDLOR = WIDTYP * PRE / ATMB * ( TEMREF / TEM )**TCOTYP
      WIDDOP = SNGL ( WMDSPC / VLIGHT ) * SQRT ( R2 * TEM / WGTTYP )
      WID = WIDVOI ( WIDLOR, WIDDOP )
      IF ( WID * WIDLIM .LT. WNRMAX ) THEN
        IF ( NATM .GT. 1 ) THEN
          WRITE ( MESSGE, '(A,F7.3,A,F7.4,A)' ) 
     &      'W-CHKRES: linewidth at Tan.Ht=', HGTATM(IATM),
     &      ' is ~', WID, ' cm-1 - will not be resolved'
        ELSE 
          WRITE ( MESSGE, '(A,F7.4,A)' ) 
     &      'W-CHKRES: linewidth is ~', WID, 
     &      ' cm-1 - will not be resolved'
        END IF
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG ) 
      END IF    
C
      END
