      SUBROUTINE CIADEF ( LUNCIA, NAMDEF, FAIL, ERRMSG )
C
C VERSION
C     08JUL15 AD Original.
C
C DESCRIPTION
C     Use default .cia filename to find any missing files.
C     Called once by INPCIA if filename template found in *CIA section of 
C     driver table.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNCIA !  I  LUN for CIA File
      CHARACTER*(*) NAMDEF !  I  Default name of CIA file
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CHKFIL ! Check if argument represents an existing filename
     &, CIAFIL ! Open X-Section data file read from RFM driver table.
     &, CIAMOL ! Identify molecules from .cia file header record
     &, EXPNAM ! Replace '*' in filename with given string
     &, NAMLOG ! Send text plus variable length filename to log file
     &, RFMLOG ! Write text message to RFM log file.
      LOGICAL CHKFIL
      CHARACTER*200 EXPNAM
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'ciacom.inc' ! Coll.Ind.Absorption data
C
C LOCAL CONSTANTS          
      INTEGER  NLST        ! No. of CIA molecule pairs 
        PARAMETER ( NLST = 7 ) 
C
C LOCAL VARIABLES
      INTEGER       ICIA   ! Counter for stored CIA datasets
      INTEGER   ID1,ID2    ! RFM/HITRAN indices for molecule pairs
      INTEGER       ILST   ! Counter for listed pairs
      CHARACTER*200 NAMCIA ! Name of CIA file
      CHARACTER*20  CIALST(NLST) ! List of CIA molecule pairs
C
C DATA STATEMENTS
C These molecules should be consistent with those in CIAMOL
      DATA CIALST / 'N2-N2', 'O2-CO2', 'O2-N2', 'O2-O2', 'CH4-CH4', 
     &              'CO2-CO2', 'N2-CH4' /
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      CALL RFMLOG ( 'I-CIADEF: Checking default .cia files',
     &              FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      DO ILST = 1, NLST
        CALL CIAMOL ( CIALST(ILST), ID1, ID2, FAIL, ERRMSG ) 
C Only error should be if CIAMOL list inconsistent with those in CIALST
        IF ( FAIL ) STOP 'F-CIADEF: Logical Error'
        IF ( IGSMOL(ID1) .GT. 0 .AND. IGSMOL(ID2) .GT. 0 ) THEN ! using pair
          DO ICIA = 1, NCIA
            IF ( ID1CIA(ICIA) .EQ. ID1 .AND.             ! data already loaded
     &           ID2CIA(ICIA) .EQ. ID2        ) GOTO 100
          END DO
          NAMCIA = EXPNAM ( NAMDEF, CIALST(ILST) )       ! expand filename
          CALL NAMLOG ( 'I-CIADEF: looking for file: ', NAMCIA,
     &                  FAIL, ERRMSG )
          IF ( FAIL ) RETURN
          IF ( CHKFIL ( NAMCIA ) ) THEN                  ! file exists
C Check file is useful, and read in data
            CALL CIAFIL ( LUNCIA, NAMCIA, FAIL, ERRMSG ) 
            IF ( FAIL ) RETURN
          END IF
        END IF
 100    CONTINUE
      END DO
C
C Normal exit
      FAIL = .FALSE.
C
      END
