      SUBROUTINE CIAMOL ( MOLSTR, IDX1, IDX2, FAIL, ERRMSG ) 
C
C VERSION
C     08JUL15 AD Original. 
C 
C DESCRIPTION    
C     Identify molecules from .cia file header record
C     Called multiply by REACIA.
C     The .cia header record contains a C*20 right-justified string containing
C     the pair of molecules, eg: '     O2-N2'
C     This will return IDX1 or IDX2 if molecule is not one of the list of
C     currently recognised CIA molecules: CO2, CH4, O2 or N2.
C                  
      IMPLICIT NONE
C
C ARGUMENTS      
      CHARACTER*20 MOLSTR  !  I  String containing molecules
      INTEGER      IDX1    !  O  HITRAN/RFM index of first molecule
      INTEGER      IDX2    !  O  HITRAN/RFM index of second molecule
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
C GLOBAL CONSTANTS
      INCLUDE 'idxcon.inc' ! HITRAN molecular indices
C
C LOCAL VARIABLES
      INTEGER I  ! Location of first non-blank character in MOLSTR
      INTEGER J  ! Location of '-' in MOLSTR
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      FAIL = .TRUE.
C Locate first non-blank character in MOLSTR
      I = 1
      DO WHILE ( MOLSTR(I:I) .EQ. ' ' ) 
        I = I + 1
        IF ( I .EQ. 20 ) THEN
          ERRMSG = 'F-CIAMOL: No molec. identification in .cia header'
          RETURN
        END IF
      END DO
C Locate '-' character in MOLSTR
      J = INDEX ( MOLSTR, '-' ) 
      IF ( J .LE. I .OR. J .EQ. 20 ) THEN
        ERRMSG = 'F-CIAMOL: Unable to read molecules from .cia header:'
     &           //MOLSTR
        RETURN
      END IF
C
C These molecules should be consistent with those in ciadef.for
      IDX1 = 0
      IF ( MOLSTR(I:J-1) .EQ. 'CO2' ) IDX1 = IDXCO2
      IF ( MOLSTR(I:J-1) .EQ. 'CH4' ) IDX1 = IDXCH4
      IF ( MOLSTR(I:J-1) .EQ. 'O2' )  IDX1 = IDXO2
      IF ( MOLSTR(I:J-1) .EQ. 'N2' )  IDX1 = IDXN2
C
      IDX2 = 0
      IF ( MOLSTR(J+1:) .EQ. 'CO2' ) IDX2 = IDXCO2
      IF ( MOLSTR(J+1:) .EQ. 'CH4' ) IDX2 = IDXCH4
      IF ( MOLSTR(J+1:) .EQ. 'O2' )  IDX2 = IDXO2
      IF ( MOLSTR(J+1:) .EQ. 'N2' )  IDX2 = IDXN2
C
C Normal exit
      FAIL = .FALSE.
C 
      END
