      SUBROUTINE CIAPTH ( MAXAM2, NAM2, IPTAM2, ID2AM2, AM2 )
C
C VERSION
C     23SEP15 AD Original.
C 
C DESCRIPTION    
C     Calculate absorber amounts for CIA paths.
C     Called one by RFMCIA if CIA flag enabled.
C                  
      IMPLICIT NONE
C
C ARGUMENTS      
      INTEGER   MAXAM2     !  I  Externally declared Size of *AM2 arrays
      INTEGER   NAM2       !  O  No.elements filled of *AM2 arrays
      INTEGER   IPTAM2(*)  !  O  list of /PTHCOM/ indices matched
      INTEGER   ID2AM2(*)  !  O  list of coll.molec#2 for each 
      REAL      AM2(*)     !  O  Absorber^2.amounts [kmole^2/cm^5]
C
      EXTERNAL 
     &  IDXPTH ! Indexing function for Pth# from Tan.pt#, Atm.Layer# and Gas#
      INTEGER IDXPTH
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'pthcom.inc' ! RFM path data
      INCLUDE 'ciacom.inc' ! Coll.Ind.Absorption data 
C
C LOCAL CONSTANTS
      INTEGER MAXCG1       ! Max.no different molecs. as 1st of collision pair
        PARAMETER ( MAXCG1 = 4 ) ! 4 allows for O2,N2,CO2 and CH4
      INTEGER MAXCG2
        PARAMETER ( MAXCG2 = 3 ) ! 3 allows for O2-O2, O2-N2 and O2-CO2
C
C LOCAL VARIABLES
      INTEGER CG1LST(MAXCG1) ! List of HITRAN/RFM indices of coll. molec#1
      INTEGER CG2LST(MAXCG2,MAXCG1) ! List of molec#2 for each molec#1
      INTEGER I            ! General counter
      INTEGER IC1GAS(MAXGAS) ! CG1 index of molec in /GASCOM/ arrays (or 0)
      INTEGER ICG1,ICG2    ! Counter for coll.molec#1,#2
      INTEGER ICIA         ! Counter for CIA datasets
      INTEGER ID1,ID2      ! HITRAN/RFM indices of collision pairs
      INTEGER IDGAS        ! HITRAN/RFM index of molec in /GASCOM/ arrays
      INTEGER IGAS         ! Gas counter
      INTEGER IPTH         ! Path counter
      INTEGER JGAS         ! Index in /GASCOM/ of molec#2
      INTEGER JPTH         ! Path index associated with 2nd molecule
      INTEGER NCG1         ! No.different first collision molecules
      INTEGER NCG2(MAXCG1) ! No.diff second collision molec.for each 1st molec.
C
C DATA STATEMENTS
      DATA NCG1 / 0 /
      DATA NCG2 / MAXCG1 * 0 / 
      DATA IC1GAS / MAXGAS * 0 /
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C First set up list of collision pairs
      DO ICIA = 1, NCIA
        ID1 = ID1CIA(ICIA)
        ID2 = ID2CIA(ICIA)
        DO I = 1, NCG1
          ICG1 = I
          IF ( ID1 .EQ. CG1LST(I) ) GOTO 100   ! already listed as ICG1
        END DO
        IF ( NCG1 .GE. MAXCG1 ) 
     &    STOP 'F-CIAPTH: local array dim MAXCG1 too small'
        NCG1 = NCG1 + 1
        ICG1 = NCG1
        CG1LST(ICG1) = ID1
        NCG2(ICG1) = 0
 100    CONTINUE
C Index of ID1 in CG1LST, CG2LST, NCG2 arrays list now established as ICG1
        DO I = 1, NCG2(ICG1) 
          IF ( ID2 .EQ. CG2LST(I,ICG1) ) GOTO 200     ! already listed 
        END DO
        IF ( NCG2(ICG1) .EQ. MAXCG2 ) 
     &    STOP 'F-CIAPTH: local array sim MAXCG2 too small'
        NCG2(ICG1) = NCG2(ICG1) + 1
        ICG2 = NCG2(ICG1)
        CG2LST(ICG2,ICG1) = ID2
 200    CONTINUE
      END DO 
C
C Next identify which gases are associated with first molec. in collision pairs
      DO IGAS = 1, NGAS
        IDGAS = IDXGAS(IGAS)
        DO ICG1 = 1, NCG1
          IF ( IDGAS .EQ. CG1LST(ICG1) ) IC1GAS(IGAS) = ICG1
        END DO
      END DO
C
C Loop through all calculated paths identifying those for which absorber is
C first molec in a collision pair
      NAM2 = 0
      DO IPTH = 1, NCLC
        IGAS = IGSPTH(IPTH)
        IF ( IC1GAS(IGAS) .GT. 0 ) THEN
          ICG1 = IC1GAS(IGAS)
          ID1 = CG1LST(ICG1)
          DO ICG2 = 1, NCG2(ICG1)
            ID2 = CG2LST(ICG2,ICG1) 
            IF ( ID2 .EQ. ID1 ) THEN
              JPTH = IPTH
            ELSE
              JGAS = IGSMOL(ID2)
              JPTH = IDXPTH ( ITNPTH(IPTH), IATPTH(IPTH), JGAS, 
     &                        IDRPTH(IPTH) )
            END IF
            IF ( NAM2 .EQ. MAXAM2 ) STOP 'F-CIAPTH: MAXAM2 too small'
            NAM2 = NAM2 + 1
C Factor 100 to convert from mb to Pa, 1E-6 to convert from /m3 to /cm3
            AM2(NAM2) = PPAPTH(IPTH) * ATMB * 100.0 * 1.0E-6
     &                  / RGAS / TEMPTH(IPTH) * AMTPTH(JPTH)
            IPTAM2(NAM2) = IPTH
            ID2AM2(NAM2) = ID2
          END DO
        END IF
      END DO
C      
      END
