      SUBROUTINE DIMFIL ( LUNDIM, AXTYP, FILDIM, MAXTAB, 
     &                    NTAB, AXTAB, FAIL, ERRMSG )
C
C VERSION
C     13DEC13 AD Original.
C
C DESCRIPTION
C     Read list of TAB axis values from file.
C     Called by INPDIM for p, T and q-axis files.
C     Also checks that at least one value is contained in file and that
C     array values are monotonic.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNDIM   !  I  LUN for axis value File
      CHARACTER*1   AXTYP    !  I  Tabulation axis 'P', 'T' or 'Q'
      CHARACTER*(*) FILDIM   !  I  Name of file containing axis values
      INTEGER       MAXTAB   !  I  Externally declared size of array AXTAB
      INTEGER       NTAB     !  O  No elements of AXTAB written
      REAL          AXTAB(*) !  O  Array for axis values
      LOGICAL       FAIL     !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG   !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  ACCLOG ! Accumulate and send text record to log file.
     &, NXTFL2 ! Load next field from secondary input file.
     &, OPNFIL ! Open ASCII input file, and skip/Log any initial comments.
     &, RFMLOG ! Write text message to RFM log file.
     &, SGNARR ! Determine if array is ascending, descending or not monotonic
      INTEGER SGNARR
C
C LOCAL VARIABLES
      INTEGER      IOS     ! Saved value of IOSTAT for error message
      INTEGER      LENGTH  ! Length of field read from driver table
      CHARACTER*80 FIELD   ! Tangent height or Tan.Hgt filename
      CHARACTER*80 LOGMSG  ! Message sent to RFM log file
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      LOGMSG = 'I-DIMFIL: Reading ' // AXTYP //'-axis values from file'
      CALL RFMLOG ( LOGMSG, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
C
C Open file containing axis values
      CALL OPNFIL ( LUNDIM, FILDIM, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
C
C Read in each field from file
      NTAB = 0
      LENGTH = 1
      CALL ACCLOG ( AXTYP//'-axis values:', FAIL, ERRMSG )
      IF ( FAIL ) RETURN
      DO WHILE ( LENGTH .GT. 0 ) 
        CALL NXTFL2 ( LUNDIM, FIELD, LENGTH, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        IF ( LENGTH .GT. 0 ) THEN     ! LENGTH=0 denotes end of file
          NTAB = NTAB + 1 
          IF ( NTAB .GT. MAXTAB ) THEN
            FAIL = .TRUE.
            ERRMSG = 'F-DIMFIL: Array dimension MAXTAB'//
     &                 ' in rfmsiz.inc too small'
            RETURN
          END IF
          READ ( FIELD, *, IOSTAT=IOS, ERR=900 ) AXTAB(NTAB) 
          CALL ACCLOG ( FIELD, FAIL, ERRMSG ) 
          IF ( FAIL ) RETURN
        END IF
      END DO
      CLOSE ( LUNDIM, IOSTAT=IOS, ERR=900 )
      CALL ACCLOG ( ' ', FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      FAIL = .TRUE.
      IF ( NTAB .EQ. 0 ) THEN
        ERRMSG = 'F-DIMFIL: No values found in file'
C NTAB=1 is valid but SGNARR will return 0 for this case, so exclude
      ELSE IF ( NTAB .GE. 2 .AND. SGNARR ( NTAB, AXTAB ) .EQ. 0 ) THEN
        ERRMSG = 'F-DIMFIL: axis values are not monotonic'
C P,Q axes must all be positive numbers
      ELSE IF ( MIN ( AXTAB(1), AXTAB(NTAB) ) .LE. 0.0 .AND. 
     &     ( AXTYP .EQ. 'P' .OR. AXTYP .EQ. 'Q' ) ) THEN
        ERRMSG = 'F-DIMFIL: '//AXTYP//'-axis values must all be +ve'
      ELSE IF ( MAX ( AXTAB(1), AXTAB(NTAB) ) .LT. 0.0 .AND.
     &          AXTYP .EQ. 'T' ) THEN
        ERRMSG = 'F-DIMFIL: Some T-axis values must be 0 or +ve'
      ELSE
        FAIL = .FALSE.
      END IF
C Normal exit
      RETURN
C
 900  WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-DIMFIL: I/O error on '//AXTYP//'-axis file. IOSTAT=', IOS
      FAIL = .TRUE.
C
      END
