      SUBROUTINE DIMGRD ( LUNDRV, AXTYP, IFLD, FIELD, MAXTAB,
     &                    NTAB, AXTAB, FAIL, ERRMSG ) 
C
C VERSION
C     13DEC13 AD Original.
C
C DESCRIPTION
C     Read TAB axis grid parameters from driver file.
C     Called by INPDIM for p, T and q-axis values.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNDRV   !  I  LUN for RFM driver file
      CHARACTER*1   AXTYP    !  I  Axis type ('P', 'T' or 'Q')
      INTEGER       IFLD     ! I/O Counter for field# in *DIM section
      CHARACTER*(*) FIELD    ! I/O Current field read from *DIM section
      INTEGER       MAXTAB   !  I  Externally declared size of array AXTAB
      INTEGER       NTAB     !  O  No elements of AXTAB written
      REAL          AXTAB(*) !  O  Array for axis values
      LOGICAL       FAIL     !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG   !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  ACCLOG ! Accumulate and send text record to log file.
     &, NXTFLD ! Load next field from section of RFM driver file
C
C LOCAL VARIABLES
      INTEGER      IOS     ! Saved value of IOSTAT for error message
      INTEGER      ITAB    ! Counter for axis points
      INTEGER      LENGTH  ! Length of field read from driver table
      REAL         AX1     ! 1st axis value
      REAL         AX2     ! last axis value
      REAL         DX      ! Axis increment
      REAL         LOGAX1  ! Ln(AX1)
      REAL         RDUM    ! Real variable
      CHARACTER*12 FSTR    ! Field counter/contents for error message
C
C EXECUTABLE CODE --------------------------------------------------------------
C                  123456789012
      FSTR = 'Field#x (xx)'
      WRITE ( FSTR(7:7), '(I1)' ) IFLD
      WRITE ( FSTR(10:11), '(2A1)' ) 'N', AXTYP
C
      CALL ACCLOG ( AXTYP//'-axis parameters: ', FAIL, ERRMSG )
      IF ( FAIL ) RETURN
      READ ( FIELD, *, IOSTAT=IOS, ERR=901 ) RDUM
      NTAB = NINT ( RDUM )
      FAIL = .TRUE.
      IF ( RDUM - NTAB .NE. 0.0 ) THEN
        ERRMSG = 'F-DIMGRD: ' // FSTR // 
     &    ' was not an integer, actual value=' // FIELD
      ELSE IF ( NTAB .EQ. 0 .AND. AXTYP .EQ. 'P' ) THEN
        ERRMSG = 'F-DIMGRD: At least one value required for P-axis'
      ELSE IF ( NTAB .LE. 0 .AND. AXTYP .EQ. 'T' ) THEN
        ERRMSG = 'F-DIMGRD: NPts for T-axis must be +ve'
      ELSE IF ( ABS ( NTAB ) .GT. MAXTAB ) THEN
        WRITE ( ERRMSG, '(A,A,A,I11,A,I6)' ) 
     &    'F-DIMGRD: NPts for ', AXTYP, '-axis =', ABS(NTAB), 
     &    ' > MAXTAB in rfmsiz.inc, =', MAXTAB 
      ELSE
        FAIL = .FALSE.
      END IF
      IF ( FAIL ) RETURN
      CALL ACCLOG ( FIELD, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      IFLD = IFLD + 1
      WRITE ( FSTR(7:7), '(I1)' ) IFLD
      WRITE ( FSTR(10:11), '(2A1)' ) AXTYP, '1'
      CALL NXTFLD ( LUNDRV, FIELD, LENGTH, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      IF ( LENGTH .EQ. 0 ) GOTO 900 
      READ ( FIELD, *, IOSTAT=IOS, ERR=901 ) AX1 
      CALL ACCLOG ( FIELD, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
      IF ( ABS ( NTAB ) .EQ. 1 ) THEN                       ! Single axis value
        AX2 = AX1
      ELSE 
        IFLD = IFLD + 1
        WRITE ( FSTR(7:7), '(I1)' ) IFLD
        WRITE ( FSTR(10:11), '(2A1)' ) AXTYP, '2'
        CALL NXTFLD ( LUNDRV, FIELD, LENGTH, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        IF ( LENGTH .EQ. 0 ) GOTO 900 
        CALL ACCLOG ( FIELD, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        READ ( FIELD, *, IOSTAT=IOS, ERR=901 ) AX2 
      END IF
      CALL ACCLOG ( ' ', FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      FAIL = .TRUE.
      IF ( MIN ( AX1, AX2 ) .LE. 0.0 .AND. 
     &     ( AXTYP .EQ. 'P' .OR. AXTYP .EQ. 'Q' ) ) THEN
        ERRMSG = 'F-DIMGRD: '//AXTYP//'-axis values must all be +ve'
      ELSE IF ( MAX ( AX1, AX2 ) .LT. 0.0 .AND. AXTYP .EQ. 'T' ) THEN
        ERRMSG = 'F-DIMGRD: Some T-axis values must be 0 or +ve'
      ELSE
        FAIL = .FALSE.
      END IF
      IF ( FAIL ) RETURN
C
C Calculate axis values
      IF ( NTAB .EQ. 1 ) THEN
        AXTAB(1) = AX1
      ELSE IF ( NTAB .LT. 0 ) THEN
        NTAB = ABS ( NTAB )
        LOGAX1 = LOG ( AX1 )
        DX = ( LOG ( AX2 ) - LOGAX1 ) / ( NTAB - 1 )
        DO ITAB = 1, NTAB 
          AXTAB(ITAB) = EXP ( LOGAX1 + ( ITAB - 1 ) * DX ) 
        END DO
      ELSE
        DX = ( AX2 - AX1 ) / ( NTAB - 1 )
        DO ITAB = 1, NTAB
          AXTAB(ITAB) = AX1 + ( ITAB - 1 ) * DX 
        END DO
      END IF
C Normal exit
      RETURN
C
 900  ERRMSG = 'F-DIMGRD: No value for '//FSTR
      FAIL = .TRUE.
      RETURN
C
 901  WRITE ( ERRMSG, '(A,A,A,I11)' ) 
     &  'F-DIMGRD: I/O error reading ', FSTR, '. IOSTAT=', IOS
      FAIL = .TRUE.
C
      END
