      SUBROUTINE DIMPRE ( USEPCG, FAIL, ERRMSG ) 
C
C VERSION
C     15JUN15 AD Use C9FLT to construct log message.
C     25SEP14 AD Original.
C
C DESCRIPTION
C     Set TAB p-axis values according to internal ATM profile.
C     Called by INPDIM if first field in *DIM section is 'PCG' or 'PLV'
C     The CG pressure calculation is extracted from subroutine RFMNAD
C
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL      USEPCG  !  I  T='PCG', F='PLV' in *DIM section
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  ACCLOG ! Accumulate and send text record to log file.
     &, C9FLT  ! Write real number as C*9 string up to 3 s.f.
     &, RFMLOG ! Write text message to RFM log file.
      CHARACTER*9 C9FLT
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C LOCAL CONSTANTS
      REAL     DLPMIN      ! Minimum value for dlnp for explicit differencing
        PARAMETER ( DLPMIN = 1.0E-3 ) ! 0.1%, about 7m min layer thickness
C Note: thin layers can cause problems in evaluating DPV etc, so avoid
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data  
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'tabcom.inc' ! Table axes for tabulated absorb.coeffs.
C
C LOCAL VARIABLES
      INTEGER  IATM        ! Atmos. layer# for path
      INTEGER  JATM        ! Index of profile point at top of segment
      REAL     B           ! VMR profile parameter: VMR = VMR1*(P/P1)^X
      REAL     DLNP        ! ln(p_l/p_u)
      REAL     DP          ! p_l - p_u
      REAL     DP2         ! p_l^2 - p_u^2
      REAL     DP2V        ! p_l^2 v_l - p_u^2 v_u
      REAL     DP2V2       ! p_l^2 v_l^2 - p_u^2 v_u^2
      REAL     DPV         ! p_l v_l - p_u v_l
      REAL     DV          ! v_l - v_u
      REAL     PCG         ! Curtis-Godson pressure [mb]
      REAL     PRE1, PRE2  ! Pressure [mb] at upp,low segment bounds
      REAL     USUM        ! Absorber Amount in layer [10^5*kmole/m^2]
      REAL     VMR1, VMR2  ! Vmr [ppv] at upp,low seg.bounds
      CHARACTER*9  PSTR9   ! Field containing each p-value for log file
      CHARACTER*80 LOGMSG  ! Message sent to RFM log file
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C Determine no.of p-axis grid points that will be set
      IF ( USEPCG ) THEN 
        LOGMSG = 'I-DIMPRE: Setting TAB p-axis to CG pressure '//
     &           'values of internal .atm profile'
        NPTAB = NATM + 1       ! NATM-1 layer values plus max+min level values
      ELSE
        LOGMSG = 'I-DIMPRE: Setting TAB p-axis to pressure levels '//
     &           'of internal .atm profile'
        NPTAB = NATM           ! NATM level values
      END IF
      IF ( NPTAB .GT. MAXTAB ) THEN
        WRITE ( ERRMSG, '(A,I11,A,I6)' ) 
     &    'F-DIMPRE: NPts reqd for p-axis =', NPTAB, 
     &    ' > MAXTAB in rfmsiz.inc, =', MAXTAB 
        FAIL = .TRUE.
      ELSE
        CALL RFMLOG ( LOGMSG, FAIL, ERRMSG )
      END IF
      IF ( FAIL ) RETURN         
C
      IF ( USEPCG ) THEN      
        PAXTAB(1) = PREATM(1)    ! Set first value at max pressure level
        VMR2 = VMRATM(1,1)
        PRE2 = PREATM(1)
        DO IATM = 1, NATM-1
          JATM = IATM + 1
C Copy previous segment upper value to current segment lower values
          VMR1 = VMR2
          PRE1 = PRE2
C Set current segment upper values from profile layer values
          VMR2 = VMRATM(JATM,1) 
          PRE2 = PREATM(JATM)
C Calculate summation terms for CG integrals (allow for VMR1=0 and/or VMR2=0)
          DLNP  = LOG(PRE1/PRE2)
          DP2V  = PRE1*PRE1*VMR1 - PRE2*PRE2*VMR2
          DP2V2 = PRE1*PRE1*VMR1*VMR1 - PRE2*PRE2*VMR2*VMR2
          DPV   = PRE1*VMR1 - PRE2*VMR2
          IF ( LINFLG .OR. VMR1 .LT. ARGMIN 
     &                .OR. VMR2 .LT. ARGMIN ) THEN
            DP    = PRE1 - PRE2
            DP2   = PRE1*PRE1 - PRE2*PRE2
            DV    = VMR1 - VMR2
            USUM  = DPV - DP * DV / DLNP
            IF ( USUM .NE. 0.0 .AND. DLNP .GE. DLPMIN ) THEN
              PCG = 0.5 * ( DP2V - 0.5*DP2*DV/DLNP ) / USUM
            ELSE 
              PCG = SQRT ( PRE1 * PRE2 )
            END IF
          ELSE
            B = LOG(VMR1/VMR2) / DLNP
            IF ( ABS ( 1.0 + B ) .LE. 1.0E-3 
     &                .OR. DLNP .LT. DLPMIN ) THEN
              USUM = PRE1*VMR1*DLNP
              PCG  = DP2V / ( 2.0 + B ) / USUM
            ELSE 
              USUM = DPV / ( 1.0 + B )
              IF ( ABS ( 2.0 + B ) .LE. 1.0E-3 ) THEN
                PCG = PRE1*PRE1*VMR1*DLNP
              ELSE
                PCG = DP2V / ( 2.0 + B ) / USUM
              END IF
            END IF
          END IF
          PAXTAB(JATM) = PCG
        END DO
        PAXTAB(NATM+1) = PREATM(NATM)   ! Set last point at min pressure level
      ELSE
        DO IATM = 1, NATM
          PAXTAB(IATM) = PREATM(IATM)
        END DO
      END IF
C
C Print values to log file
      CALL ACCLOG ( 'p-axis values: ', FAIL, ERRMSG )
      IF ( FAIL ) RETURN
      DO IATM = 1, NPTAB
        PSTR9 = C9FLT ( PAXTAB(IATM) )
        CALL ACCLOG ( PSTR9, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END DO
      CALL ACCLOG ( ' ', FAIL, ERRMSG )
C
      END
