      SUBROUTINE FOVFIL ( LUNFOV, NAMFOV, FAIL, ERRMSG )
C
C VERSION
C     22JAN15 AD Tidied up
C     26MAY00 AD Convert FNCFOV from SP to DP
C     18JUL98 AD Interpret -ve NFOV as angular FOV data
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Open, read FOV data file and close.
C     Called by INPFOV if filename listed in *FOV section of Driver Table.
C
      IMPLICIT NONE 
C
C ARGUMENTS
      INTEGER       LUNFOV !  I  LUN for FOV data file
      CHARACTER*(*) NAMFOV !  I  Name of FOV data file
      LOGICAL       FAIL   !  O  T=A fatal error was detected
      CHARACTER*80  ERRMSG !  O  Error message written if FAIL is TRUE
C      
      EXTERNAL
     &  OPNFIL ! Open ASCII input file, and skip/Log any initial comments.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'fovcom.inc' ! FOV Data
C
C LOCAL VARIABLES      
      INTEGER IFOV         ! Counter for FOV tabulation points
      INTEGER IOS          ! Saved value of IOSTAT for error message
      REAL  TABFOV(MAXFOV) ! Tabulated FOV response function
      DOUBLE PRECISION SUM ! Summation for normalising FOV function
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      CALL OPNFIL ( LUNFOV, NAMFOV, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C      
      READ ( LUNFOV, *, IOSTAT=IOS, ERR=900 ) NFOV
      ELEFOV = NFOV .LT. 0
      NFOV = ABS ( NFOV )
C
      FAIL = .TRUE.
      IF ( NFOV .LE. 2 ) THEN
        WRITE ( ERRMSG, '(A,I2,A)' )
     &    'F-FOVFIL: No.tabulated FOV pts=', NFOV,
     &    ' - should be at least 3'
      ELSE IF ( NFOV .GT. MAXFOV ) THEN
        WRITE ( ERRMSG, '(A,I11,A,I11,A)' )
     &    'F-FOVFIL: No.tabulated FOV pts=', NFOV,
     &    ' > MAXFOV=', MAXFOV, ' in rfmsiz.inc'
      ELSE IF ( ELEFOV .AND. .NOT. OBSFLG ) THEN
        ERRMSG = 'F-FOVFIL: Require Observation altitude (OBS Flag)'//
     &           ' to use angular FOV tabulation'
      ELSE IF ( .NOT. ELEFOV .AND. OBSFLG ) THEN
        ERRMSG ='F-FOVFIL: Require angular FOV tabulation with OBS flag'
      ELSE
        FAIL = .FALSE.
      END IF
      IF ( FAIL ) RETURN
C
      READ ( LUNFOV, *, IOSTAT=IOS, ERR=900 ) 
     &  ( ALTFOV(IFOV), IFOV = 1, NFOV )
      READ ( LUNFOV, *, IOSTAT=IOS, ERR=900 ) 
     &  ( TABFOV(IFOV), IFOV = 1, NFOV )
C
      CLOSE ( LUNFOV, IOSTAT=IOS, ERR=900 )
C
      IF ( TABFOV(1) .NE. 0.0 .OR. TABFOV(NFOV) .NE. 0.0 ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-FOVFIL: FOV Function non-zero at one or both ends'
        RETURN
      END IF
C
      FNCFOV(1) = DBLE ( ( ALTFOV(2) - ALTFOV(1) ) * TABFOV(2) )
      FNCFOV(NFOV) = DBLE ( ( ALTFOV(NFOV) - ALTFOV(NFOV-1) ) 
     &                      * TABFOV(NFOV-1) )
      SUM = FNCFOV(1) + FNCFOV(NFOV)
      DO IFOV = 2, NFOV - 1
        FNCFOV(IFOV) = 
     &    DBLE (   ( ALTFOV(IFOV) - ALTFOV(IFOV-1) ) 
     &           * ( TABFOV(IFOV-1) + 2 * TABFOV(IFOV) ) 
     &           + ( ALTFOV(IFOV+1) - ALTFOV(IFOV) ) 
     &           * ( TABFOV(IFOV+1) + 2 * TABFOV(IFOV) ) )
        SUM = SUM + FNCFOV(IFOV)
      END DO
C
C Normalise
      DO IFOV = 1, NFOV
        FNCFOV(IFOV) = FNCFOV(IFOV) / SUM
      END DO
C
C Normal exit
      FAIL = .FALSE.
      RETURN
C
  900 FAIL = .TRUE.
      WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-FOVFIL: I/O failure on FOV file. IOSTAT=', IOS
      END
