      SUBROUTINE GASALL ( IMIN, FAIL, ERRMSG )
C
C VERSION
C     05FEB15 AD Call LSTABS with WNLSPC,WNUSPC DP arguments 
C     05DEC14 AD Rewritten, and simplified with qualifier string checked
C                externally and value IMIN passed via argument list
C     15OCT13 AD SAVE IMIN
C     14AUG13 AD Add IMIN argument to LSTABS
C                    Use MOLIDX rather than local array of molecule names
C                    Remove checks for clono2/q sf6/q etc
C                    Write CODMOL without any leading blanks
C     23JUL09 AD Additional molecules (as in chkgas.for)
C     06MAY05 AD Save IMIN
C     06MAR02 AD Add SF6 as molecule#64, and HDO as molecule#39
C     14DEC01 AD Ensure JABS initialised
C     07FEB01 AD Add extra CFCs/HFCs ID=70-81, plus molecules 40-45
C     21DEC98 AD Original.
C
C DESCRIPTION
C     Add wildcard gases to list of absorbers
C     Called once by INPGAS if a wildcard symbol '*' is present in *GAS 
C     section.
C
      IMPLICIT NONE
C
C ARGUMENTS 
      INTEGER       IMIN   !  I  Limit for including absorbers
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  ACCLOG ! Accumulate and send text record to log file.
     &, GASCHK ! Check Gas name and set indices.
     &, LSTABS ! Construct ordered list of absorbers for given spec.range
     &, MOLIDX ! Give molecule name for HITRAN/RFM index, or vice-versa
     &, RFMLOG ! Write text message to RFM log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
C
C LOCAL CONSTANTS
      INTEGER       MAXLST ! Max.no. molecules returned by LSTABS
        PARAMETER ( MAXLST = 45 )  ! warning issued if this is limiting
C
C LOCAL VARIABLES
      INTEGER       IABS   ! Absorber counter
      INTEGER       IMOL   ! HITRAN index of each molecule from LSTABS
      INTEGER       ISPC   ! Spectral range counter
      INTEGER       MOLLST(MAXLST) ! List of molecule IDs
      INTEGER       NABS   ! No. of molecules required/found by LSTABS
      REAL          OPTLST(MAXLST) ! List of "optical strengths"
      CHARACTER*7   CODMOL ! Molecules name or index
      CHARACTER*80  LOGMSG ! Information message for log file
      LOGICAL       NOTGAS ! TRUE=string supplied to GASCHK not recognised gas
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      IF ( IMIN .LT. 0 ) THEN
        ERRMSG = 'F-GASALL: -ve qualifier not allowed for wildcard '//
     &           ' in *GAS section'
        FAIL = .TRUE.
        RETURN
      ELSE IF ( IMIN .GT. 99 ) THEN
        ERRMSG = 'F-GASALL: qualifier >99 not allowed for wildcard '//
     &           ' in *GAS section'
        FAIL = .TRUE.
        RETURN
      ELSE IF ( IMIN .EQ. 0 ) THEN
        LOGMSG = 'I-GASALL: Adding extra absorbers '
      ELSE
        WRITE ( LOGMSG, '(A,I3)' ) 'I-GASALL: Adding extra '//
     &    'absorbers with ''optical strength'' >=', IMIN
      END IF
      CALL RFMLOG ( LOGMSG, FAIL, ERRMSG )
        IF ( FAIL ) RETURN         
C
      DO ISPC = 1, NSPC
        NABS = MAXLST
        LOGMSG = 'I-GASALL: Spec.Range'//LABSPC(ISPC)//' add: '
        CALL ACCLOG ( LOGMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        CALL LSTABS ( WNLSPC(ISPC), WNUSPC(ISPC), IMIN, NABS, MOLLST, 
     &                OPTLST )
C
C Check if no.absorbers returned by LSTABS limited by MAXLST array size
        IF ( NABS .EQ. MAXLST ) THEN
          WRITE ( LOGMSG, '(A,I3,A)' ) 
     &      'W-GASALL: No.absorbers found limited to ',  MAXLST,
     &      '.Increase local parameter MAXLST?'
          CALL RFMLOG ( LOGMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
C
        DO IABS = 1, NABS
          IMOL = MOLLST(IABS)
          CALL MOLIDX ( IMOL, CODMOL, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
          CALL ACCLOG ( CODMOL, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
C
          IF ( IGSMOL(IMOL) .EQ. 0 ) THEN    ! Not already specified by user
            CALL GASCHK ( CODMOL, NOTGAS, FAIL, ERRMSG )
C Since the only molecule indices sent from this routine to GASCHK are from the
C LSTABS module, they should all be recognised, so NOTGAS=T shouldn't happen.
            IF ( NOTGAS ) STOP 'F-GASALL: Logical Error'
            IF ( FAIL ) RETURN
          END IF
        END DO           ! End loop over potential new absorbers
        CALL ACCLOG ( ' ', FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END DO             ! End loop over spectral ranges
C
      END
