      SUBROUTINE GASCHK ( GASSTR, NOTGAS, FAIL, ERRMSG )
C
C VERSION
C     15JUL15 AD Remove CTMFLG argument to GASCTM
C     02APR15 AD New arguments for GASQAL. Remove local qalcom.inc
C     05DEC14 AD Set Voigt lineshape for all line molecules, even if SHPFLG=T
C     03FEB14 AD Bug#90: Remove qualifier string from input argument to CHKGAS
C                Other related minor changes
C     14AUG13 AD Avoid modifying GASSTR
C     07AUG13 AD Remove redundant local variable IGAS
C     04JAN08 AD Add CHKGAS to identify molecules
C                    Set NISGAS, GASISO locally for all molecules
C     10FEB03 AD Set IDIGAS(NGAS) = 0
C     23FEB03 AD Add BrO as ID=40, move GeH4 (was ID=40) to new ID=46
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Check Gas name and set indices.
C     Called by INPGAS for each field in *GAS section, or by GASALL.
C     Note that all strings are converted to lower case for internal use.
C
      IMPLICIT NONE
C
C ARGUMENTS
      CHARACTER*(*) GASSTR !  I  Gas name to be tested (assumed non-blank)
      LOGICAL       NOTGAS !  O  Set TRUE if gas not recognised
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CHKGAS ! Check if GAS is valid molecule and get Hitran/RFM index
     &, GASCTM ! Initialise for Continuum data
     &, GASISO ! Load isotopic data for required gases.
     &, GASQAL ! Check & load isotope/band qualifiers for each molecule.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'shpcon.inc' ! Line-shape codes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'qalcom.inc' ! List of band/isotope qualifiers for line data.
C
C LOCAL VARIABLES
      INTEGER      IDUMMY  ! Dummy argument for CHKGAS
      INTEGER      IMOL    ! HITRAN index of molecule
      INTEGER      ISO     ! Isotope#
      INTEGER      LGS     ! Length of GAS part of GASSTR without qualifiers
      INTEGER      LPT     ! Length of non-blank part of GASSTR
      INTEGER      LQS     ! Length of QALSTR written
      LOGICAL      ANYQAL  ! Set TRUE if any qualifiers added
      CHARACTER*7  GAS     ! Gas name read from GASSTR
      CHARACTER*80 QALSTR  ! Qualifier data associated with molecule
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      FAIL   = .FALSE.
      NOTGAS = .TRUE.
C
C Set LPT to last non-blank character in GASSTR
      LPT = INDEX ( GASSTR, ' ' ) - 1
      IF ( LPT .EQ. -1 ) LPT = LEN ( GASSTR )
C
C Check for any qualifier data associated with molecule -look for '(' in string
      ANYQAL = INDEX ( GASSTR, '(' ) .GT. 1   ! Cannot start with '('
      IF ( ANYQAL ) THEN
        LGS = INDEX ( GASSTR, '(' ) - 1       
        LQS = LPT - LGS
        QALSTR(1:LQS) = GASSTR(LGS+1:LPT)
      ELSE
        LGS = LPT 
        LQS = 0
      END IF
C
C From this routine, call CHKGAS removing any qualifiers
      CALL CHKGAS ( GASSTR(1:LGS), GAS, IMOL, ISO, IDUMMY, 
     &              FAIL, ERRMSG )
      IF ( FAIL ) RETURN
      NOTGAS = ( IMOL .EQ. 0 ) 
      IF ( NOTGAS ) RETURN     ! Exit with no molecule identified
C
C Normally CHKGAS will also read any '(...)' and return Isotope#, but in the
C *GAS section of the driver table the qualifiers can be more complicated so
C these are removed earlier. However if gas is a recognised isotopomeric 
C abbreviation ('hdo' or 'ch3d') CHKGAS could still return isotope numbers, 
C in which case pretend these were part of the original qualifier string
      IF ( ISO .GT. 0 ) THEN   ! Identified isotopomeric abbreviation
        IF ( ANYQAL ) QALSTR(4:LQS+3) = QALSTR(1:LQS)
        WRITE ( QALSTR(1:3), '(A,I1,A)' ) '(', ISO, ')'
        LQS = LQS + 3
        ANYQAL = .TRUE.
      END IF
C
C Check molecule isn't already loaded
      IF ( IGSMOL(IMOL) .NE. 0 ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-GASCHK: Repeated Gas='//GAS
        RETURN
      END IF
C Check enough space to add new molecule
      IF ( NGAS .EQ. MAXGAS ) THEN  ! Not enough space for another gas
        FAIL = .TRUE.
        WRITE ( ERRMSG, '(A,I3)' )
     &  'F-GASCHK: No.gases reqd > MAXGAS in rfmsiz.inc,=', MAXGAS
        RETURN
      END IF
C Everything OK so add to list in gascom.inc
      NGAS = NGAS + 1
      IDIGAS(NGAS) = 0              ! default isotope profile
      IDXGAS(NGAS) = IMOL
      IGSMOL(IMOL) = NGAS
      ISOGAS(0,NGAS) = NGAS
      NISGAS(NGAS) = 0              ! could be changed by GASISO
      ISOMOL(IMOL) = .FALSE.
      NTEGAS(NGAS) = .FALSE.  
      CODGAS(NGAS) = GAS
      IF ( IMOL .LE. MAXHLN ) THEN           ! HITRAN Line molecule
        CALL GASISO ( FAIL, ERRMSG )         ! Load isotope,line params
        IF ( FAIL ) RETURN
        SHPGAS(NGAS) = SHPVOI          
        CALL GASCTM ( ANYQAL, LQS,         ! May reset ANYQAL=F
     &                QALSTR(1:LQS), FAIL, ERRMSG ) ! and set SHPGAS = SHPCTM
        IF ( FAIL ) RETURN
        IF ( ANYQAL ) THEN
          USEQAL(NGAS) = .TRUE.
          CALL GASQAL ( QALSTR(1:LQS), NGAS, GAS, NISGAS(NGAS), 
     &                  FAIL, ERRMSG )            ! Check qualifier info
          IF ( FAIL ) RETURN
        ELSE
          USEQAL(NGAS) = .FALSE.
        END IF
      ELSE                                    ! Cross-section molecule
        SHPGAS(NGAS) = SHPXSC         
        IF ( ANYQAL ) THEN
          FAIL = .TRUE.
          ERRMSG = 'F-GASCHK: qualifier data not applicable '//
     &      'to X/S molecules: '//GAS
          RETURN
        END IF
      END IF
      FAIL = .FALSE.                      ! Normal exit with new molecule added 
C
      END
