      SUBROUTINE GRDDEF ( LUNGRD, NAMDEF, FAIL, ERRMSG )
C
C VERSION
C     09DEC14 AD Add Warning message if file not found
C     12NOV14 AD Rewritten
C     23JUL03 AD Original.
C
C DESCRIPTION
C     Use default .GRD filename to find any missing files.
C     Called once by INPGRD if filename template found in *GRD section of 
C     driver table.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNGRD !  I  LUN for .grd file
      CHARACTER*(*) NAMDEF !  I  Default name of GRD file
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CHKFIL ! Check if argument represents an existing filename
     &, EXPNAM ! Replace '*' in filename with given string
     &, GRDFIL ! Open GRD file and check contents
     &, NAMLOG ! Send text plus variable length filename to log file
     &, RFMLOG ! Write text message to RFM log file.
      LOGICAL CHKFIL
      CHARACTER*200 EXPNAM
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gflcom.inc' ! Grid file data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
C
C LOCAL VARIABLES
      INTEGER       ISPC   ! Spectral range counter
      CHARACTER*200 NAMGRD ! Name of GRD file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Send message to LOG file saying which file is about to be opened
C
      CALL RFMLOG ( 'I-GRDDEF: Checking default .grd files',
     &              FAIL, ERRMSG )
        IF ( FAIL ) RETURN
C
      DO ISPC = 1, NSPC                            ! Loop over spectral ranges
        IF ( IDXGFL(ISPC) .EQ. 0 ) THEN            ! No .grd file assigned yet
          NAMGRD = EXPNAM ( NAMDEF, LABSPC(ISPC) ) 
          CALL NAMLOG ( 'I-GRDDEF: looking for file: ', NAMGRD,
     &                  FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          IF ( CHKFIL ( NAMGRD ) ) THEN
C Read file contents and load if useful
            CALL GRDFIL ( LUNGRD, NAMGRD, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          ELSE
            CALL RFMLOG ( 'W-GRDDEF: File not found', FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          END IF
        END IF
      END DO
C
      FAIL = .FALSE.
C
      END
