      INTEGER FUNCTION IDXINT ( ARRAY, N, X, A )
C
C VERSION
C     01JAN15 AD Original.
C
C DESCRIPTION
C     Index of array element below given value, and interp. fraction.
C     General purpose function
C
C     Returns IDXINT where ARRAY(IDXINT)>=X>ARRAY(IDXINT+1) 
c                       or ARRAY(IDXINT)<=X<ARRAY(IDXINT+1)
C     Also returns interpolation fraction A
C         A = ( X - ARRAY(IDXINT) ) / ( ARRAY(IDXINT+1) - ARRAY(IDXINT) ) 
C     If X outside range of array, then this returns the end values of the
C     array, i.e.
C         If X<ARRAY(1)<ARRAY(N)  or  X>ARRAY(1)>ARRAY(N), then I = 1, A=0
C         If X<=ARRAY(N)<ARRAY(1) or X>=ARRAY(N)>ARRAY(1), then I = N-1, A=1
C         If N=1 then I=1
C    Routine does not check parameters or if the array is monotonic
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER N          !  I  Array length
      REAL    ARRAY(N)   !  I  Data Array
      REAL    X          !  I  Value to be bracketted
      REAL    A          !  O  Interpolation fraction
C
C LOCAL VARIABLES
      INTEGER I          ! Local value of array index
      LOGICAL LINCRS     ! T=increasing array, F=decreasing
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      LINCRS = ARRAY(1) .LT. ARRAY(N)
C
C If X outside range of array values, set to end values
      IF ( X .LE. ARRAY(1) .EQV. LINCRS .OR. N .EQ. 1) THEN
        IDXINT = 1
        A = 0.0
      ELSE IF ( X .GE. ARRAY(N) .EQV. LINCRS ) THEN
        IDXINT = N-1
        A = 1.0
      ELSE
C X within ARRAY so find level
        I = 1
        DO WHILE ( X .GE. ARRAY(I+1) .EQV. LINCRS ) 
          I = I + 1
          IF ( I .GE. N ) STOP 'F-IDXINT: Logical error'
        END DO
        IDXINT = I
        A = ( X - ARRAY(I) ) / ( ARRAY(I+1) - ARRAY(I) )
      ENDIF
C
      END
