      SUBROUTINE INPATM ( LUNDRV, LUNATM, FAIL, ERRMSG )
C
C VERSION
C     01JAN15 AD Initialise /GRACOM/ with angle PSI=0.0
C                Remove ATMLAY - moved to ATMFIL
C     15DEC14 AD Add ATMAIR. Slight restructuring of loop
C                Assume FIRST set to .FALSE. by ATMFIL
C     19SEP12 AD Change NAMATM from C*80 to C*200
C     26DEC99 AD Add call to ATMGRA      
C     22JAN98 AD Remove redundant EXTERNAL declarations: RFMLOG, INPFIL
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     28SEP96 AD Remover NGAS argument to ATMAUX
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Read atm.profile files from driver table following *ATM marker
C     Called by RFMINP once.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNDRV  !  I  LUN for Driver File
      INTEGER      LUNATM  !  I  LUN for Atmospheric profiles 
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  ATMAIR ! Set VMR profile values for air
     &, ATMAUX ! Set up auxiliary profiles of atmospheric parameters
     &, ATMFIL ! Read file containing atmospheric profiles.
     &, ATMGRA ! Interpolate to fill 2-D atmospheric profile field.
     &, NXTFLD ! Load next field from section of RFM driver file
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
C
C LOCAL VARIABLES
      INTEGER  IGAS            ! Gas profile counter (1:NGAS)
      INTEGER  LENGTH          ! Length of filename read from driver file
      LOGICAL  GOTPRE          ! TRUE if a pressure profile has been stored
      LOGICAL  GOTTEM          ! TRUE if a temperature profile has been stored
      LOGICAL  GOTGAS(MAXGAS)  ! TRUE if a vmr profile has been stored
      LOGICAL  FIRST           ! TRUE until first profile of first file read in
      CHARACTER*200 NAMATM     ! Name of ATM file read from Driver Table
C
C DATA STATEMENTS
      DATA FIRST / .TRUE. /
      DATA GOTTEM / .FALSE. /
      DATA GOTGAS / MAXGAS*.FALSE. /
      DATA GOTPRE / .FALSE. /
      SAVE FIRST, GOTTEM, GOTGAS, GOTPRE
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Initialise horizontal location data and establish location at PSI=0
      IF ( GRAFLG ) THEN
        NGRA = 1
        PSIGRA(1) = 0.0
        NOMGRA = 1
      END IF
C
      CALL NXTFLD ( LUNDRV, NAMATM, LENGTH, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
C Jump here for each new field in *ATM section. 
      DO WHILE ( LENGTH .NE. 0 ) 
        CALL ATMFIL ( LUNATM, NAMATM(1:LENGTH), FIRST, GOTPRE, 
     &                GOTTEM, GOTGAS, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        CALL NXTFLD ( LUNDRV, NAMATM, LENGTH, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
      END DO
C
C If Rayleigh extinction is modelled, set VMR profile=1ppv for 'air'
      IF ( REXFLG ) CALL ATMAIR ( GOTGAS ) 
C
C Check all required profiles have been loaded
      FAIL = .TRUE.
      IF ( .NOT. GOTPRE ) THEN
        ERRMSG = 'F-INPATM: No Pressure profile specified'
        RETURN
      ELSE IF ( .NOT. GOTTEM ) THEN
        ERRMSG = 'F-INPATM: No Temperature profile specified'
        RETURN
      ELSE
        DO IGAS = 1, NGAS
          IF ( .NOT. GOTGAS(IGAS) ) THEN
            ERRMSG = 'F-INPATM: No '//CODGAS(IGAS)//
     &               ' profile specified'
            RETURN
          END IF
        END DO
      END IF
      FAIL = .FALSE.      
C
C If horizontal gradients used, interpolate to fill 2-D field
      IF ( GRAFLG ) CALL ATMGRA
C
C Calculate auxiliary profiles
      CALL ATMAUX 
C
C Normal exit
      FAIL = .FALSE.
C
      END
