      SUBROUTINE INPCHK ( FAIL, ERRMSG )
C
C VERSION
C     28NOV14 AD Add SFCCHK
C     17NOV14 AD Add LUTGRD, GRDCHK
C     10JAN14 AD Add LUTCHK
C     07AUG13 AD Remove redundant SPCFIN and RFMLOG from EXTERNAL list
C     03APR05 AD Add CHKVTJ
C     01JAN04 AD Add LEVTAN
C     13JUN02 AD Add ABSCHK
C     16JUN01 AD Set FAIL=FALSE if TAB flag
C     18MAR01 AD Original.
C
C DECSRIPTION
C     Cross-check inputs from more than one drv table section
C     Called once by RFMINP after all driver table info is loaded.
C     This is used to perform checks where inputs come from sections which 
C     can be in arbitrary order, so only meaningful after all driver table
C     data has been loaded.
C
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  ABSCHK ! Check information available for all absorbers.
     &, CHKVTJ ! Check vibrational temperature Jacobians
     &, FINCHK ! Check fine mesh resolution
     &, FLXPTH ! Set up paths for flux calculations.
     &, FOVTAN ! Add tangent heights to allow FOV convolution
     &, GRDCHK ! Check GRD files span ILS convolved spectral ranges
     &, HOMPTH ! Set up homogeneous paths for RFM calculations.
     &, ILSCHK ! Assign ILS Functions to each spectral range 
     &, LEVTAN ! Set up tangent paths for intermediate output levels
     &, LUTCHK ! Check Look-Up Table file data. 
     &, LUTGRD ! Use LUT files to set irregular grid.
     &, NADPTH ! Set up nadir paths for RFM calculations.
     &, SFCCHK ! Set default surface parameters if no *SFC data in driver file
     &, TANHGT ! Calculate actual (refracted) tangent heights
     &, TANPTH ! Construct list of RFM paths from tang.hts and atmos.profiles.
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Check spectral information is available for all absorbers
      CALL ABSCHK ( FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
C Set up paths
      IF ( HOMFLG ) THEN
        CALL HOMPTH ( FAIL, ERRMSG )
      ELSE IF ( FLXFLG ) THEN       ! must be tested before NAD/ZEN flags
        CALL FLXPTH ( FAIL, ERRMSG )
      ELSE IF ( NADFLG .OR. ZENFLG ) THEN
        CALL NADPTH ( FAIL, ERRMSG )
      ELSE IF ( .NOT. TABFLG ) THEN      ! limb-viewing calculation
        CALL TANHGT ( FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        IF ( FOVFLG ) THEN
          CALL FOVTAN ( FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
        CALL TANPTH ( FAIL, ERRMSG )
      ELSE                               ! TAB calculation - no checks here
        FAIL = .FALSE. 
      END IF
      IF ( FAIL ) RETURN
C
C If convolving, check ILS defined for all spectral ranges
      IF ( ILSFLG ) THEN
        CALL ILSCHK ( FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
C If spectral outputs at intermediate levels, set up paths
      IF ( LEVFLG ) THEN
        CALL LEVTAN ( FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
C Check that fine resolution is not coarser than any requested output grid
      CALL FINCHK ( FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
C Check if ILS convolution extends beyond irreg.grids
      IF ( GRDFLG .AND. ( ILSFLG .OR. AVGFLG) ) THEN
        CALL GRDCHK ( FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
C If Vib.Temp Jacobians required, check VT profiles loaded
      IF ( JACFLG .AND. NTEFLG ) THEN
        CALL CHKVTJ ( FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
C If using LUTs, check array sizes and spectral ranges
      IF ( LUTFLG ) THEN
        CALL LUTCHK ( FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        IF ( GRDFLG ) THEN          ! See if irreg.grids to be derived from LUTs
          CALL LUTGRD ( 0, FAIL, ERRMSG ) 
          IF ( FAIL ) RETURN
        END IF
      END IF
C
C If intersecting surface, set default values if no explicit surface data loaded
      IF ( SFCFLG ) THEN
        CALL SFCCHK ( FAIL, ERRMSG )
      END IF
C
      END
