      SUBROUTINE INPCIA ( LUNDRV, LUNCIA, FAIL, ERRMSG )
C
C VERSION
C     08JUL15 AD Original.
C
C DESCRIPTION
C     Read Collision-Induced Abs. filenames from RFM driver table.
C     Called by RFMINP once if CIA flag enabled and *CIA section in driver table
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNDRV  !  I  LUN for Driver File
      INTEGER      LUNCIA  !  I  LUN for reading CIA files (temporary)
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CIACHK ! Check CIA data consistent with other RFM options.
     &, CIADEF ! Use default .cia filename to find any missing files.
     &, CIAFIL ! Read Collision-Induced Abs. data file
     &, NXTFLD ! Load next field from section of RFM driver file
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'ciacom.inc' ! Coll.Ind.Absorption data 
C
C LOCAL VARIABLES
      INTEGER       LENGTH ! Length of field read from driver file
      CHARACTER*200 NAMDEF ! CIA filename template
      CHARACTER*200 NAMCIA ! Name of CIA file
      LOGICAL       GOTDEF ! True if filename template loaded
C
C DATA STATEMENTS
      DATA GOTDEF / .FALSE. /
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      NCIA = 0
C
C Read first field in driver table
      CALL NXTFLD ( LUNDRV, NAMCIA, LENGTH, FAIL, ERRMSG ) 
      IF ( FAIL ) RETURN
      IF ( LENGTH .EQ. 0 ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-INPCIA: No data in *CIA section'
        RETURN
      END IF
C
C Jump here for each subsequent field in Driver Table
      DO WHILE ( LENGTH .NE. 0 ) 
        IF ( INDEX ( NAMCIA(1:LENGTH), '*' ) .NE. 0 ) THEN
          IF ( GOTDEF ) THEN
            ERRMSG = 'F-INPCIA: *CIA section contains more than '//
     &               'one filename template'
            FAIL = .TRUE.
            RETURN
          ELSE
            GOTDEF = .TRUE.
            NAMDEF = NAMCIA(1:LENGTH)
          ENDIF
        ELSE
          CALL CIAFIL ( LUNCIA, NAMCIA(1:LENGTH), FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
        CALL NXTFLD ( LUNDRV, NAMCIA, LENGTH, FAIL, ERRMSG ) 
        IF ( FAIL ) RETURN
      END DO
C
      IF ( GOTDEF ) THEN
        CALL CIADEF ( LUNCIA, NAMDEF, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      ENDIF
C
C Check CIA data consistent with any molecules also represented by continua
      CALL CIACHK ( FAIL, ERRMSG )            
C
      END
