      SUBROUTINE INPDIM ( LUNDRV, LUNDIM, KEY, FAIL, ERRMSG )
C
C VERSION
C     25SEP14 AD Allow 'PCG' and 'PLV' for p-axis determination
C     05SEP14 AD Remove LUNDIM argument from CHKFIL
C     13DEC13 AD Original. Extracted from INPTAN
C
C DESCRIPTION
C     Read TAB dims from driver table *TAN or *DIM section
C     Called by RFMINP once if TABFLG set.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNDRV  !  I  LUN for Driver File
      INTEGER      LUNDIM  !  I  LUN for p,T or q tabulation axis file
      CHARACTER*4  KEY     !  I  Key actually used for *TAN section
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CHKFIL ! Check if argument represents an existing filename
     &, DIMGRD ! Read TAB axis grid parameters from driver file.
     &, DIMFIL ! Read list of TAB axis values from file.
     &, DIMPRE ! Set TAB p-axis values according to internal ATM profile.
     &, ENDCHK ! Check end of Driver Table section has been reached.
     &, NXTFLD ! Load next field from section of RFM driver file
     &, TABPTH ! Set up paths RFM TABulated abs.coeff. calculations.
     &, UPCASE ! Convert text string to upper case.
C
      LOGICAL CHKFIL
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'tabcom.inc' ! Table axes for tabulated absorb.coeffs.
C
C LOCAL VARIABLES
      INTEGER      IFLD    ! Counter for fields in Driver Table section
      INTEGER      LENGTH  ! Length of field read from driver table
      CHARACTER*80 FIELD   ! Tangent height or Tan.Hgt filename
      CHARACTER*80 UFIELD  ! Upper case version of FIELD
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C Check if valid Key has been used for Driver table section
      IF ( KEY .NE. '*TAN' .AND. KEY .NE. '*DIM' ) THEN
        ERRMSG = 
     &    'F-INPDIM: Only *DIM or *TAN section valid with TAB flag'
        FAIL = .TRUE.
        RETURN
      END IF
C
C First field is either NP or name of file containing list of pressures or
C one of 'PCG' or 'PLV' (case insensitive)
      IFLD = 1
      CALL NXTFLD ( LUNDRV, FIELD, LENGTH, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      CALL UPCASE ( FIELD, UFIELD )       ! should still work if LENGTH=0
      IF ( LENGTH .EQ. 0 ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-INPDIM: No data in *DIM/*TAN section'
      ELSE IF ( UFIELD .EQ. 'PCG' ) THEN
        CALL DIMPRE ( .TRUE., FAIL, ERRMSG )
      ELSE IF ( UFIELD .EQ. 'PLV' ) THEN
        CALL DIMPRE ( .FALSE., FAIL, ERRMSG )
      ELSE IF ( CHKFIL ( FIELD ) ) THEN
        CALL DIMFIL ( LUNDIM, 'P', FIELD, MAXTAB, 
     &                NPTAB, PAXTAB, FAIL, ERRMSG )
        IFLD = IFLD + 1
      ELSE
C Read 2 more fields containing lower/upper pressures
        CALL DIMGRD ( LUNDRV, 'P', IFLD, FIELD, MAXTAB, 
     &                NPTAB, PAXTAB, FAIL, ERRMSG )
      END IF
      IF ( FAIL ) RETURN
C
C Next field is either NT or name of file containing list of temperatures
      CALL NXTFLD ( LUNDRV, FIELD, LENGTH, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      IF ( LENGTH .EQ. 0 ) THEN   ! No temperature data incl in tabulation axes
        NTTAB = 1
        TAXTAB(1) = 0.0
      ELSE IF ( CHKFIL ( FIELD ) ) THEN
        CALL DIMFIL ( LUNDIM, 'T', FIELD, MAXTAB,
     &                NTTAB, TAXTAB, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        IFLD = IFLD + 1
      ELSE
        CALL DIMGRD ( LUNDRV, 'T', IFLD, FIELD, MAXTAB,
     &                NTTAB, TAXTAB, FAIL, ERRMSG )
      END IF
      IF ( FAIL ) RETURN
C
C Next field is either NQ or name of file containing list of VMR values
      CALL NXTFLD ( LUNDRV, FIELD, LENGTH, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      IF ( LENGTH .EQ. 0 ) THEN      ! No VMR data included in tabulation axes
        NQTAB = 1
        QAXTAB(1) = 100.0
      ELSE IF ( CHKFIL ( FIELD ) ) THEN
        IF ( FAIL ) RETURN
        CALL DIMFIL ( LUNDIM, 'Q', FIELD, MAXTAB,
     &                NQTAB, QAXTAB, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        IFLD = IFLD + 1
      ELSE
        CALL DIMGRD ( LUNDRV, 'Q', IFLD, FIELD, MAXTAB,
     &                NQTAB, QAXTAB, FAIL, ERRMSG )
      END IF
      IF ( FAIL ) RETURN
C
C Check no more fields in *DIM section
      CALL ENDCHK ( LUNDRV, 'DIM', FAIL, ERRMSG )                   
      IF ( FAIL ) RETURN
C 
C Construct RFM 'paths' for p,T,q table entries
      CALL TABPTH ( FAIL, ERRMSG )
C
      END
