      SUBROUTINE INPFLG ( LUNDRV, FAIL, ERRMSG )
C
C VERSION
C     21JUL15 AD Add JTPFLG
C     02JUL15 AD Add CIAFLG
C     01JAN15 AD Add REXFLG
C     12DEC14 AD Add SHHFLG
C     08DEC14 AD Add CHIFLG
C                For BFXFLG: require at least one of (BBTFLG,RADFLG,RJTFLG) 
C                instead of just requiring RADFLG.
C     12FEB14 AD Add HYD flag
C     08JAN13 AD Allow combination of HOM + SFC flags
C     08AUG13 AD Add V42 flag
C                    Remove specific checks for obsolete flags: GL2,IQD,OFM,SCA
C     11SEP11 AD Add RJT flag
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Read RFM option flags data following *FLG marker
C     Called once by RFMINP.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNDRV  !  I  LUN for Driver File
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  LOCASE ! Convert text string to lower case
     &, NXTFLD ! Load next field from section of RFM driver file
     &, RFMLOG ! Write text message to RFM log file
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
C
C LOCAL CONSTANTS
      INTEGER       MAXFLG       ! No. Flags listed in /FLGCOM/
        PARAMETER ( MAXFLG = 56 )
C
C LOCAL VARIABLES
      INTEGER       IFLG    ! Flag counter (1:MAXFLG)
      INTEGER       IPT     ! Pointer to locations in MESSGE ENATXT strings
      INTEGER       LENGTH  ! Length of character field read from driver table
      LOGICAL       SETFLG(MAXFLG)
      CHARACTER*3   FLGLST(MAXFLG)
      CHARACTER*80  FIELD   ! Field read from driver table
      CHARACTER*3   FLG     ! Flag read from driver table
      CHARACTER*132 MESSGE  ! Message listing enabled flags for LOG file
        DATA SETFLG / MAXFLG * .FALSE. /
        DATA FLGLST / 'abs', 'avg', 'bbt', 'bfx', 'bin', 'chi',
     &                'cia', 'clc', 'coo', 'ctm', 'dbl', 'fin',
     &                'flx', 'fov', 'fvz', 'geo', 'ghz', 'gra',
     &                'grd', 'hom', 'hyd', 'ils', 'jac', 'jtp',
     &                'lay', 'lev', 'lin', 'los', 'lun', 'lut', 
     &                'mix', 'mtx', 'nad', 'new', 'nte', 'obs', 
     &                'opt', 'prf', 'pth', 'qad', 'rad', 'rej', 
     &                'rex', 'rjt', 'sfc', 'shh', 'shp', 'tab', 
     &                'tps', 'tra', 'v42', 'vrt', 'vvw', 'wid', 
     &                'wng', 'zen' /
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Read next field in *FLG section of driver table
C
  100 CALL NXTFLD ( LUNDRV, FIELD, LENGTH, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      IF ( LENGTH .NE. 0 ) THEN                ! Not yet reached end of section
        IF ( LENGTH .NE. 3 ) THEN
          FAIL = .TRUE.
          LENGTH = MIN ( LENGTH, 40 )
          ERRMSG = 'F-INPFLG: Not a C*3 string, field='//FIELD(1:LENGTH)
          RETURN
        END IF
        CALL LOCASE ( FIELD(1:3), FLG )
        DO IFLG = 1, MAXFLG
          IF ( FLG .EQ. FLGLST(IFLG) ) THEN
            SETFLG(IFLG) = .TRUE.
            GOTO 100
          END IF
        END DO
        FAIL = .TRUE.
        IF ( FLG .EQ. 'crv' ) THEN
          ERRMSG = 'F-INPFLG: CRV flag no longer used - '//
     &             'radius now specified in *PHY section'
        ELSE
          ERRMSG = 'F-INPFLG: Unrecognised flag='//FLG
        END IF
        RETURN
      END IF
C
      ABSFLG = SETFLG(1)
      AVGFLG = SETFLG(2)
      BBTFLG = SETFLG(3)
      BFXFLG = SETFLG(4)
      BINFLG = SETFLG(5)
      CHIFLG = SETFLG(6)
      CIAFLG = SETFLG(7)
      CLCFLG = SETFLG(8)
      COOFLG = SETFLG(9)
      CTMFLG = SETFLG(10)
      DBLFLG = SETFLG(11)
      FINFLG = SETFLG(12)
      FLXFLG = SETFLG(13)
      FOVFLG = SETFLG(14)
      FVZFLG = SETFLG(15)
      GEOFLG = SETFLG(16)
      GHZFLG = SETFLG(17)
      GRAFLG = SETFLG(18)
      GRDFLG = SETFLG(19)
      HOMFLG = SETFLG(20)
      HYDFLG = SETFLG(21)
      ILSFLG = SETFLG(22)
      JACFLG = SETFLG(23)
      JTPFLG = SETFLG(24)
      LAYFLG = SETFLG(25)
      LEVFLG = SETFLG(26)
      LINFLG = SETFLG(27)
      LOSFLG = SETFLG(28)
      LUNFLG = SETFLG(29)
      LUTFLG = SETFLG(30)
      MIXFLG = SETFLG(31)
      MTXFLG = SETFLG(32)
      NADFLG = SETFLG(33)
      NEWFLG = SETFLG(34)
      NTEFLG = SETFLG(35)
      OBSFLG = SETFLG(36)
      OPTFLG = SETFLG(37)
      PRFFLG = SETFLG(38)
      PTHFLG = SETFLG(39)
      QADFLG = SETFLG(40)
      RADFLG = SETFLG(41)
      REJFLG = SETFLG(42)
      REXFLG = SETFLG(43)
      RJTFLG = SETFLG(44)
      SFCFLG = SETFLG(45)
      SHHFLG = SETFLG(46)
      SHPFLG = SETFLG(47)
      TABFLG = SETFLG(48)
      TPSFLG = SETFLG(49)
      TRAFLG = SETFLG(50)
      V42FLG = SETFLG(51)
      VRTFLG = SETFLG(52)
      VVWFLG = SETFLG(53)
      WIDFLG = SETFLG(54)
      WNGFLG = SETFLG(55)
      ZENFLG = SETFLG(56)
C
C Check for inconsistent combinations of flags
C
      FAIL = .TRUE.
      IF ( ABSFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: ABS and TAB flags are incompatible'
C
      ELSE IF ( AVGFLG .AND. ILSFLG ) THEN
        ERRMSG = 'F-INPFLG: AVG and ILS flags are incompatible'
      ELSE IF ( AVGFLG .AND. OPTFLG ) THEN
        ERRMSG = 'F-INPFLG: AVG and OPT flags are incompatible'
      ELSE IF ( AVGFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: AVG and TAB flags are incompatible'
C
      ELSE IF ( BBTFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: BBT and TAB flags are incompatible'
C
      ELSE IF ( BFXFLG .AND. HOMFLG ) THEN
        ERRMSG = 'F-INPFLG: BFX and HOM flags are incompatible'
      ELSE IF ( BFXFLG .AND. NTEFLG ) THEN
        ERRMSG = 'F-INPFLG: BFX and NTE flags are incompatible'
      ELSE IF ( BFXFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: BFX and NTE flags are incompatible'
C
      ELSE IF ( CLCFLG .AND. FLXFLG ) THEN
        ERRMSG = 'F-INPFLG: CLC and FLX flags are incompatible'
      ELSE IF ( CLCFLG .AND. HOMFLG ) THEN
        ERRMSG = 'F-INPFLG: CLC and HOM flags are incompatible'
      ELSE IF ( CLCFLG .AND. NADFLG ) THEN
        ERRMSG = 'F-INPFLG: CLC and NAD flags are incompatible'
      ELSE IF ( CLCFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: CLC and TAB flags are incompatible'
      ELSE IF ( CLCFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: CLC and HOM flags are incompatible'
C
      ELSE IF ( COOFLG .AND. VRTFLG ) THEN
        ERRMSG = 'F-INPFLG: COO and VRT flags are incompatible'
C
      ELSE IF ( DBLFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: DBL and TAB flags are incompatible'
C
C NB: COO, VRT and MTX all require FLX so no need to test these options also
      ELSE IF ( FLXFLG .AND. FOVFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and FOV flags are incompatible'
      ELSE IF ( FLXFLG .AND. GEOFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and GEO flags are incompatible'
      ELSE IF ( FLXFLG .AND. GRAFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and GRA flags are incompatible'
      ELSE IF ( FLXFLG .AND. HOMFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and HOM flags are incompatible'
      ELSE IF ( FLXFLG .AND. LEVFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and LEV flags are incompatible'
      ELSE IF ( FLXFLG .AND. LOSFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and LOS flags are incompatible'
      ELSE IF ( FLXFLG .AND. OBSFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and OBS flags are incompatible'
      ELSE IF ( FLXFLG .AND. OPTFLG .AND. .NOT. VRTFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and OPT flags also require VRT flag'
      ELSE IF ( FLXFLG .AND. PTHFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and PTH flags are incompatible'
      ELSE IF ( FLXFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX and TAB flags are incompatible'
C
      ELSE IF ( FOVFLG .AND. HOMFLG ) THEN
        ERRMSG = 'F-INPFLG: FOV and HOM flags are incompatible'
      ELSE IF ( FOVFLG .AND. NADFLG ) THEN
        ERRMSG = 'F-INPFLG: FOV and NAD flags are incompatible'
      ELSE IF ( FOVFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: FOV and TAB flags are incompatible'
      ELSE IF ( FOVFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: FOV and ZEN flags are incompatible'
      ELSE IF ( FOVFLG .AND. OPTFLG ) THEN
        ERRMSG = 'F-INPFLG: FOV and OPT flags are incompatible'
C
      ELSE IF ( GEOFLG .AND. HOMFLG ) THEN
        ERRMSG = 'F-INPFLG: GEO and HOM flags are incompatible'
      ELSE IF ( GEOFLG .AND. NADFLG ) THEN
        ERRMSG = 'F-INPFLG: GEO and NAD flags are incompatible'
      ELSE IF ( GEOFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: GEO and TAB flags are incompatible'
      ELSE IF ( GEOFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: GEO and ZEN flags are incompatible'
C
      ELSE IF ( GRAFLG .AND. HOMFLG ) THEN
        ERRMSG = 'F-INPFLG: GRA and HOM flags are incompatible'
      ELSE IF ( GRAFLG .AND. NADFLG ) THEN
        ERRMSG = 'F-INPFLG: GRA and NAD flags are incompatible'
      ELSE IF ( GRAFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: GRA and TAB flags are incompatible'
      ELSE IF ( GRAFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: GRA and ZEN flags are incompatible'
C
      ELSE IF ( GRDFLG .AND. WNGFLG ) THEN
        ERRMSG = 'F-INPFLG: GRD and WNG flags are incompatible'
C
      ELSE IF ( HOMFLG .AND. JTPFLG ) THEN
        ERRMSG = 'F-INPFLG: HOM and JTP flags are incompatible'
      ELSE IF ( HOMFLG .AND. LAYFLG ) THEN
        ERRMSG = 'F-INPFLG: HOM and LAY flags are incompatible'
      ELSE IF ( HOMFLG .AND. LEVFLG ) THEN
        ERRMSG = 'F-INPFLG: HOM and LEV flags are incompatible'
      ELSE IF ( HOMFLG .AND. LOSFLG ) THEN
        ERRMSG = 'F-INPFLG: HOM and LOS flags are incompatible'
      ELSE IF ( HOMFLG .AND. NADFLG ) THEN
        ERRMSG = 'F-INPFLG: HOM and NAD flags are incompatible'
      ELSE IF ( HOMFLG .AND. OBSFLG ) THEN
        ERRMSG = 'F-INPFLG: HOM and OBS flags are incompatible'
c      ELSE IF ( HOMFLG .AND. SFCFLG ) THEN
c        ERRMSG = 'F-INPFLG: HOM and SFC flags are incompatible'
      ELSE IF ( HOMFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: HOM and ZEN flags are incompatible'
C
      ELSE IF ( ILSFLG .AND. OPTFLG ) THEN
        ERRMSG = 'F-INPFLG: ILS and OPT flags are incompatible'
      ELSE IF ( ILSFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: ILS and TAB flags are incompatible'
C
      ELSE IF ( JACFLG .AND. LEVFLG ) THEN
        ERRMSG = 'F-INPFLG: JAC and LEV flags are incompatible'
      ELSE IF ( JACFLG .AND. MTXFLG ) THEN
        ERRMSG = 'F-INPFLG: JAC and MTX flags are incompatible'
      ELSE IF ( JACFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: JAC and TAB flags are incompatible'
C
      ELSE IF ( JTPFLG .AND. NADFLG ) THEN
        ERRMSG = 'F-INPFLG: JTP and NAD flags are incompatible'
      ELSE IF ( JTPFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: JTP and ZEN flags are incompatible'
C
      ELSE IF ( LEVFLG .AND. LOSFLG ) THEN
        ERRMSG = 'F-INPFLG: LEV and LOS flags are incompatible'
      ELSE IF ( LEVFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: LEV and TAB flags are incompatible'
C 
      ELSE IF ( LOSFLG .AND. MTXFLG ) THEN
        ERRMSG = 'F-INPFLG: LOS and MTX flags are incompatible'
      ELSE IF ( LOSFLG .AND. NADFLG ) THEN
        ERRMSG = 'F-INPFLG: LOS and NAD flags are incompatible'
      ELSE IF ( LOSFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: LOS and TAB flags are incompatible'
      ELSE IF ( LOSFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: LOS and ZEN flags are incompatible'
C
      ELSE IF ( LUTFLG .AND. NTEFLG ) THEN
        ERRMSG = 'F-INPFLG: LUT and NTE flags are incompatible'
C
      ELSE IF ( MTXFLG .AND. NADFLG ) THEN
        ERRMSG = 'F-INPFLG: MTX and NAD flags are incompatible'
      ELSE IF ( MTXFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: MTX and ZEN flags are incompatible'
C
      ELSE IF ( NADFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: NAD and TAB flags are incompatible'
      ELSE IF ( NADFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: NAD and ZEN flags are incompatible'
C
      ELSE IF ( OBSFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: OBS and TAB flags are incompatible'
C
      ELSE IF ( OPTFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: OPT and TAB flags are incompatible'
C
      ELSE IF ( PTHFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: PTH and TAB flags are incompatible'
C
      ELSE IF ( RADFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: RAD and TAB flags are incompatible'
C
      ELSE IF ( REXFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: REX and TAB flags are incompatible'
C
      ELSE IF ( RJTFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: RJT and TAB flags are incompatible'
C
      ELSE IF ( SFCFLG .AND. TABFLG ) THEN
        ERRMSG = 'F-INPFLG: SFC and TAB flags are incompatible'
C
      ELSE IF ( SFCFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: SFC and ZEN flags are incompatible'
C
      ELSE IF ( TABFLG .AND. TRAFLG ) THEN
        ERRMSG = 'F-INPFLG: TAB and TRA flags are incompatible'
      ELSE IF ( TABFLG .AND. ZENFLG ) THEN
        ERRMSG = 'F-INPFLG: TAB and ZEN flags are incompatible'
C
      ELSE IF ( BFXFLG .AND. .NOT. 
     &         ( BBTFLG .OR. RADFLG .OR. RJTFLG ) ) THEN
        ERRMSG = 'F-INPFLG: BFX flag also requires RAD flag enabled'
      ELSE IF ( COOFLG .AND. .NOT. FLXFLG ) THEN
        ERRMSG = 'F-INPFLG: COO flag also requires FLX flag enabled'
      ELSE IF ( FINFLG .AND. .NOT. ( ILSFLG .OR. AVGFLG ) ) THEN
        ERRMSG = 'F-INPFLG: FIN flag also requires either '//
     &           'ILS or AVG flag enabled'
      ELSE IF ( FLXFLG .AND. TRAFLG .AND. .NOT. MTXFLG 
     &          .AND. .NOT. ( NADFLG .OR. ZENFLG ) ) THEN
        ERRMSG = 'F-INPFLG: TRA+FLX-MTX flags also requires ZEN or NAD'
      ELSE IF ( FLXFLG .AND. ABSFLG .AND. .NOT. MTXFLG 
     &          .AND. .NOT. ( NADFLG .OR. ZENFLG ) ) THEN
        ERRMSG = 'F-INPFLG: ABS+FLX-MTX flags also requires ZEN or NAD'
      ELSE IF ( FLXFLG .AND. .NOT. ZENFLG .AND. .NOT. SFCFLG ) THEN
        ERRMSG = 'F-INPFLG: FLX-ZEN flags also requires SFC flag'
      ELSE IF ( FVZFLG .AND. .NOT. FOVFLG ) THEN
        ERRMSG = 'F-INPFLG: FVZ flag also requires FOV flag enabled'
      ELSE IF ( HYDFLG .AND. .NOT. ( NADFLG .OR. ZENFLG ) ) THEN
        ERRMSG = 'F-INPFLG: HYD flag also requires NAD or ZEN flag'
      ELSE IF ( JTPFLG .AND. .NOT. JACFLG ) THEN
        ERRMSG = 'F-INPFLG: JTP flag also requires JAC flag'
      ELSE IF ( MTXFLG .AND. .NOT. FLXFLG ) THEN
        ERRMSG = 'F-INPFLG: MTX flag also requires FLX flag enabled'
      ELSE IF ( MTXFLG .AND. COOFLG .AND. .NOT. SFCFLG ) THEN
        ERRMSG = 'F-INPFLG: MTX+COO flags also requires SFC flag'
      ELSE IF ( MTXFLG .AND. RADFLG .AND. .NOT. SFCFLG ) THEN
        ERRMSG = 'F-INPFLG: MTX+RAD flags also requires SFC flag'
      ELSE IF ( NADFLG .AND. .NOT. SFCFLG ) THEN
        ERRMSG = 'F-INPFLG: NAD flag also requires SFC flag enabled'
      ELSE IF ( VRTFLG .AND. .NOT. FLXFLG ) THEN
        ERRMSG = 'F-INPFLG: VRT flag also requires FLX flag enabled'
      ELSE
        FAIL = .FALSE.
      END IF
      IF ( FAIL ) RETURN     
C
C V42 flag - also set HYD flag to reproduce RFM v4.2 behaviour
      IF ( V42FLG .AND. ( NADFLG .OR. ZENFLG ) .AND. .NOT. HYDFLG ) THEN
        HYDFLG = .TRUE.
        MESSGE = 'I-INPFLG: V42: enabling HYD flag to reproduce old RFM'
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF 
C
C Construct message for log file listing status of all flags
C
      MESSGE = 'I-INPFLG: Enabled flags: '      
      IPT = 22
      DO IFLG = 1, MAXFLG
        IF ( SETFLG(IFLG) ) THEN
          IPT = IPT + 4
          MESSGE(IPT:IPT+3) = FLGLST(IFLG)//' '
        END IF
      END DO
      CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
C
      END
