      SUBROUTINE INPGAS ( LUNDRV, LUNGAS, GETHIT, GETXSC, FAIL, ERRMSG )
C
C VERSION
C     04FEB15 AD Bug fix.
C     01JAN15 AD Add GASAIR
C     05DEC14 AD Rewritten and simplified
C     13JUN02 AD Use SHPGAS rather than IDXGAS to test line/XSC species
C     28MAR01 AD Add IAXGAS
C     21MAR01 AD Set CHGGAS = TRUE. 
C     20DEC98 AD Modified to include GASALL
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Read RFM absorbing gases from driver table following *GAS marker
C     Called by RFMINP once.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNDRV  !  I  LUN for Driver File
      INTEGER      LUNGAS  !  I  LUN for Gas file
      LOGICAL      GETHIT  !  O  Set TRUE if HITRAN line data required
      LOGICAL      GETXSC  !  O  Set TRUE if X-Section data required
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  ACCLOG ! Accumulate and send text record to log file.
     &, GASAIR ! Add 'air' to list of absorbing species.
     &, GASALL ! Add wildcard gases to list of absorbers
     &, GASCHK ! Check Gas name and set indices.
     &, NXTFFL ! Load next field from section of RFM drv, expanding filenames
     &, REAQAL ! Decode Qualifier strings '(I1)' or '(I1:I2)'
     &, RFMLOG ! Write text message to RFM log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'idxcon.inc' ! HITRAN molecular indices
      INCLUDE 'shpcon.inc' ! Line Shape codes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
C
C LOCAL VARIABLES
      INTEGER       IDUM   ! Dummy integer
      INTEGER       IGAS   ! Gas counter
      INTEGER       IMOL   ! HITRAN index of molecule
      INTEGER       IQAL   ! Qualifier string attached to '*'
      INTEGER       LENGTH ! Length of field read from Driver file
      LOGICAL       NOTGAS ! Set TRUE if gas not recognised
      LOGICAL       USEALL ! Set TRUE if wildcard found in section
      LOGICAL       USECO2 ! Set TRUE if CO2 among absorbers to be used
      CHARACTER*80  MESSGE ! Text message sent to LOG file
      CHARACTER*200 FIELD  ! Molecule or name of .gas file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      NGAS = 0 
      IAXGAS = 0
      USEALL = .FALSE.
      DO IMOL = 1, MAXMOL
        IGSMOL(IMOL) = 0
      END DO
C
C If modelling Rayleigh extinction, set up 'air' as the first absorbing species
      IF ( REXFLG ) CALL GASAIR
C
C Load first field (if the first field is a filename, also open file using
C LUNGAS and get the first field in the file)
      CALL NXTFFL ( LUNDRV, LUNGAS, .FALSE., 
     &              FIELD, LENGTH, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
C Loop here for each field in *GAS section of driver table 
      DO WHILE ( LENGTH .NE. 0 )
        IF ( FIELD(1:1) .EQ. '*' ) THEN
          IF ( USEALL ) THEN
            FAIL = .TRUE.
            ERRMSG = 'F-INPGAS: ''*'' appears twice in *GAS section'
            RETURN
          END IF
          USEALL = .TRUE.
          IF ( LENGTH .GT. 1 ) THEN
            CALL REAQAL ( FIELD(2:LENGTH), .TRUE., IQAL, IDUM, 
     &                    FAIL, ERRMSG ) 
              IF ( FAIL ) RETURN
          END IF
        ELSE
          CALL GASCHK ( FIELD(1:LENGTH), NOTGAS, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          IF ( NOTGAS ) THEN
            LENGTH = MIN ( LENGTH, 15 ) 
            FAIL = .TRUE.
            ERRMSG = 'F-INPGAS: *GAS section contains unrecognised '//
     &               'molecule or file: '//FIELD(1:LENGTH)
            RETURN
          END IF
        END IF
        CALL NXTFFL ( LUNDRV, LUNGAS, .FALSE., FIELD, 
     &                LENGTH, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END DO
C
C Add any gases included by wildcard 
      IF ( USEALL ) THEN
        CALL GASALL ( IQAL, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
C Construct message for log file listing all identified species
      GETHIT = .FALSE.
      GETXSC = .FALSE.
      IF ( NGAS .EQ. 0 ) THEN
        MESSGE = 'W-INPGAS: No gases specified'
      ELSE
        CALL ACCLOG ( 'I-INPGAS: Using gases:', FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        DO IGAS = 1, NGAS
          CALL ACCLOG ( CODGAS(IGAS), FAIL, ERRMSG )
          IF ( FAIL ) RETURN
          IF ( SHPGAS(IGAS) .EQ. SHPXSC ) THEN
            GETXSC = .TRUE.
          ELSE IF ( SHPGAS(IGAS) .NE. SHPCTM ) THEN
            GETHIT = .TRUE.
          END IF
          CHGGAS(IGAS) = .TRUE.                   ! Flag for new profile loaded
          IF ( IDXGAS(IGAS) .EQ. IDXAER ) IAXGAS = IGAS
        END DO
      END IF
      CALL ACCLOG ( ' ', FAIL, ERRMSG )        ! Output all gases so far
      IF ( FAIL ) RETURN
C
C Check if CO2 listed in case of MIX or CHI flags
      USECO2 = IGSMOL(IDXCO2) .GT. 0
      IF ( CHIFLG ) THEN
        IF ( USECO2 ) THEN
          MESSGE = 'I-INPGAS: Applying Chi-Factor to CO2 lines'
          SHPGAS(IGSMOL(IDXCO2)) = SHPCHI
        ELSE
          MESSGE = 'W-INPGAS: CHI flag selected but CO2 not used'
        END IF
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
      IF ( MIXFLG ) THEN
        IF ( USECO2 ) THEN
          MESSGE = 'I-INPGAS: Applying line-mixing for CO2 lines'
        ELSE
          MESSGE = 'W-INPGAS: MIX flag selected but CO2 not used'
        END IF
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF 
C
      END
