      SUBROUTINE INPNTE ( LUNDRV, LUNNTE, FAIL, ERRMSG )
C
C VERSION
C     01JAN15 AD Add ALLQFN, NTEGRA
C     05SEP14 AD Change NAMDEF,NAMNTE from C*80 to C*200
C     16OCT13 AD Simplified. Remove GETNTE argument and local GOTNTE check.
C     09JAN08 AD Don't initialise NNTE here - do it in RFMDEF
C     23JUL03 AD Add NTEDEF
C     14JUL98 AD Replace NXTREC by NXTFLD
C     04DEC97 AD Add GOTNTE to check for duplicate section
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     20SEP96 AD Original.
C
C DESCRIPTION
C     Read non-LTE files from driver table.
C     Called by RFMINP once if *NTE section found in Driver Table and NTEFLG=T
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNDRV  !  I  LUN for Driver File
      INTEGER      LUNNTE  !  I  Temporary LUN for non-LTE data
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  ALLQFN ! Allocate Vib.Partition Function data to Vib.Tem profiles.
     &, NTEDEF ! Use default .nte  filename to find any missing files.
     &, NTEFIL ! Read file containing non-LTE data
     &, NTEGRA ! Interpolate to fill 2-D atmospheric non-LTE profile field.
     &, NXTFLD ! Load next field from section of RFM driver file
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C GLOBAL VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
C
C LOCAL VARIABLES
      INTEGER       LENGTH ! Length of filename read from driver file
      CHARACTER*200 NAMDEF ! .nte filename template
      CHARACTER*200 NAMNTE ! Name of NTE file read from Driver Table
      LOGICAL       GOTDEF ! True if filename template loaded
C
C DATA STATEMENTS
      DATA GOTDEF / .FALSE. /
      SAVE GOTDEF
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      CALL NXTFLD ( LUNDRV, NAMNTE, LENGTH, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C Jump here for each new field in *NTE section. 
      DO WHILE ( LENGTH .NE. 0 )
        IF ( INDEX ( NAMNTE(1:LENGTH), '*' ) .NE. 0 ) THEN
          IF ( GOTDEF ) THEN
            ERRMSG = 'F-INPNTE: *NTE section contains more than '//
     &                 'one filename template'
            FAIL = .TRUE.
          ELSE
            GOTDEF = .TRUE.
            NAMDEF = NAMNTE(1:LENGTH)
          ENDIF
        ELSE
          CALL NTEFIL ( LUNNTE, NAMNTE(1:LENGTH), FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
        CALL NXTFLD ( LUNDRV, NAMNTE, LENGTH, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END DO
C
C Load any remaining files using filename template
      IF ( GOTDEF ) CALL NTEDEF ( LUNNTE, NAMDEF, FAIL, ERRMSG )
C
C Assign any Vib.Partition functions to Vib.Temperatures
      CALL ALLQFN ( FAIL, ERRMSG )
        IF ( FAIL ) RETURN
C
C Horizontally Interpolate non-LTE data to complete 2D field
      IF ( GRAFLG ) CALL NTEGRA
C
      END
