      SUBROUTINE INPPHY ( LUNDRV, FAIL, ERRMSG )
C
C VERSION
C     12FEB14 AD Original.
C
C DESCRIPTION
C     Read modified values of adjustable physical constants.
C     Called by RFMINP once if *PHY key listed in RFM Driver table.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNDRV  !  I  LUN for Driver File
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  NXTREC ! Load next record from RFM input file.
     &, PARVAL ! Extract Parameter and Value strings from record
     &, RFMLOG ! Write text message to RFM log file.
     &, UPCASE ! Convert text string to upper case.
C
C COMMON VARIABLES
      INCLUDE 'phycom.inc' ! Adjustable physical constants
C
C LOCAL VARIABLES
      INTEGER       IOS    ! Saved value of IOSTAT for error messages
      LOGICAL       ENDSEC ! T=reached end of driver file *PHY section
      CHARACTER*80  LOGMSG ! Message sent to log file
      CHARACTER*6   PARAM  ! Name of parameter to be adjusted
      CHARACTER*200 RECORD ! Record read from RFM Driver file
      CHARACTER*10  VALUE  ! Substring containing new value of parameter
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      FAIL = .FALSE.
      ENDSEC = .FALSE.
C
      DO WHILE ( .NOT. ENDSEC ) 
        CALL NXTREC ( LUNDRV, RECORD, ENDSEC, FAIL, ERRMSG ) 
        IF ( FAIL ) RETURN
        IF ( .NOT. ENDSEC ) THEN 
          CALL PARVAL ( RECORD, PARAM, VALUE, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
          CALL UPCASE ( PARAM, PARAM )
          IF ( PARAM .EQ. 'CPKMOL' ) THEN
            READ ( VALUE, *, IOSTAT=IOS, ERR=900 ) CPKMOL 
          ELSE IF ( PARAM .EQ. 'GRAVTY' ) THEN
            READ ( VALUE, *, IOSTAT=IOS, ERR=900 ) GRAVTY
          ELSE IF ( PARAM .EQ. 'WGTAIR' ) THEN
            READ ( VALUE, *, IOSTAT=IOS, ERR=900 ) WGTAIR
          ELSE IF ( PARAM .EQ. 'TEMSPA' ) THEN
            READ ( VALUE, *, IOSTAT=IOS, ERR=900 ) TEMSPA
          ELSE IF ( PARAM .EQ. 'RADCRV' ) THEN
            READ ( VALUE, *, IOSTAT=IOS, ERR=900 ) RADCRV
          ELSE
            FAIL = .TRUE.
            ERRMSG = 'F-INPPHY: Unrecognised adjustable parameter: '//
     &               PARAM
            RETURN
          END IF
          WRITE ( LOGMSG, '(A,A,A,A)' ) 
     &      'I-INPPHY: Setting new value for ', PARAM, '=', VALUE
          CALL RFMLOG ( LOGMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
      END DO
      RETURN
C
 900  CONTINUE
      WRITE ( ERRMSG, '(A,A,A,A,A,I11)' ) 'F-INPPHY: PARAM=', PARAM,
     &  ': error reading VALUE=', VALUE, '. IOSTAT=', IOS
      FAIL = .TRUE.
C
      END
