      SUBROUTINE INTCIA ( ID1, ID2, TEM, NWNO, WNOLST, CIALST )
C
C VERSION
C     09JUL15 AD Original
C
C DESCRIPTION
C     Interpolate CIA spectrum.
C     Called multiply by RFMCIA
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER    ID1       !  I  RFM/HITRAN index of 1st collision molecule
      INTEGER    ID2       !  I  RFM/HITRAN index of 2nd collision molecule
      REAL       TEM       !  I  Temperature [K]
      INTEGER    NWNO      !  I  No.spectral points
      DOUBLE PRECISION WNOLST(*)  !  I  Wavenumber axis [cm-1]
      REAL       CIALST(*) !  O  Spectrum of CIA values
C
      EXTERNAL
     &  VALCIA ! Spectral interpolation of CIA data.
      REAL VALCIA
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'ciacom.inc' ! Coll.Ind.Absorption data 
C
C LOCAL CONSTANTS
      INTEGER MAXSAV       ! Array size for saved data
        PARAMETER ( MAXSAV = 10 )  ! Ideally > No.diff ID1,ID2 combinations
C
C LOCAL VARIABLES
      INTEGER ICIA         ! Counter for CIA tabulations
      INTEGER ICL          ! Index of lower temperature CIA tabulation
      INTEGER ICU          ! Index of upper temperature CIA tabulation
      INTEGER ICLSAV(MAXSAV) ! Saved values of ICL
      INTEGER ICUSAV(MAXSAV) ! Saved values of ICU
      INTEGER ID1SAV(MAXSAV) ! Saved values of ID1
      INTEGER ID2SAV(MAXSAV) ! Saved values of ID2
      INTEGER ISAV         ! Counter for saved data values
      INTEGER IWNO         ! Counter for spectral points
      INTEGER JSAV         ! Index for saved data
      INTEGER NSAV         ! No.saved ID1,ID2 pairs
      LOGICAL FIRST        ! T=start new search for tabulations
      REAL    A            ! Interpolation fraction
      REAL    TEMLOW       ! Lower tabulated temperature [K]
      REAL    TEMUPP       ! Upper tabulated temperature [K]
      DOUBLE PRECISION WN1 ! Lower wavenumber required [cm-1]
      DOUBLE PRECISION WN2 ! Upper wavenumber required [cm-1]
      DOUBLE PRECISION WNO ! Wavenumber [cm-1]
C
C DATA STATEMENTS
      DATA NSAV / 0 /
      SAVE NSAV, ICLSAV, ICUSAV, ID1SAV, ID2SAV
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      WN1 = WNOLST(1)
      WN2 = WNOLST(NWNO)
C
C First check through list of saved indices
      JSAV = 0
      DO ISAV = 1, NSAV
        IF ( ID1 .EQ. ID1SAV(ISAV) .AND. ID2 .EQ. ID2SAV(ISAV) ) THEN
          JSAV = ISAV
          ICL = ICLSAV(ISAV)
          ICU = ICUSAV(ISAV)
          TEMLOW = TEMCIA(ICL)
          TEMUPP = TEMCIA(ICU)
C If saved data still fits WNO/TEM then move straight to interpolation
          IF ( WN1CIA(ICL) .LE. WN2 .AND. 
     &         WN2CIA(ICL) .GE. WN1 .AND.
     &              TEMLOW .LE. TEM .AND.
     &              TEMUPP .GE. TEM ) GOTO 200
C If it doesn't, search for new data tabulations
          GOTO 100
        END IF
      END DO
C If no data yet saved for ID1,ID2 and space to add more, set new index
      IF ( NSAV .LT. MAXSAV ) THEN
        NSAV = NSAV + 1
        JSAV = NSAV
      END IF
C
C Search all stored CIA data for pair of tabulations bracketing reqd WNO,TEM
 100  CONTINUE
      FIRST = .TRUE.
      DO ICIA = 1, NCIA
        IF ( ID1CIA(ICIA) .EQ. ID1 .AND. ID2CIA(ICIA) .EQ. ID2 .AND.
     &       WN1CIA(ICIA) .LE. WN2 .AND. WN2CIA(ICIA) .GE. WN1 ) THEN
C Found pair of molecules and wavenumber range, so check temperatures
          IF ( FIRST ) THEN      ! If first, use for both lower,upper TEM
            IF ( TEMCIA(ICIA) .GE. TEM ) THEN
              TEMLOW = -1.0
              TEMUPP = TEMCIA(ICIA)
            ELSE
              TEMLOW = TEMCIA(ICIA) 
              TEMUPP = 1.0E6
            END IF
            ICL = ICIA
            ICU = ICIA 
            FIRST = .FALSE.
          ELSE IF ( 
     &      ( TEMCIA(ICIA) .GT. TEMLOW .AND. TEMCIA(ICIA) .LE. TEM ).OR.
     &      ( TEMCIA(ICIA) .LT. TEMLOW .AND. TEMLOW .GT. TEM ) ) THEN
            TEMLOW = TEMCIA(ICIA)
            ICL = ICIA
          ELSE IF ( 
     &      ( TEMCIA(ICIA) .LT. TEMUPP .AND. TEMCIA(ICIA) .GE. TEM ).OR.
     &      ( TEMCIA(ICIA) .GT. TEMUPP .AND. TEMUPP .LT. TEM ) ) THEN
            TEMUPP = TEMCIA(ICIA)
            ICU = ICIA
          END IF
        END IF
      END DO
C
C If FIRST is still true, then no data has been found overlapping spectral
C range so set all CIA values to zero
      IF ( FIRST ) THEN
        DO IWNO = 1, NWNO
          CIALST(IWNO) = 0.0
        END DO
        RETURN                     ! Exit with CIA=0
      END IF
C
C Might reach this point with ICL=ICU if TEM outside range of tabulated values,
C or only one tabulated temperature
C
      IF ( JSAV .GT. 0 ) THEN
        ID1SAV(JSAV) = ID1
        ID2SAV(JSAV) = ID2
        ICLSAV(JSAV) = ICL
        ICUSAV(JSAV) = ICU
      END IF
C        
 200  CONTINUE
      IF ( ICU .EQ. ICL ) THEN    ! Temperature beyond tabulated values
        DO IWNO = 1, NWNO
          WNO = WNOLST(IWNO) 
          CIALST(IWNO) = VALCIA ( ICL, WNO ) 
        END DO
      ELSE                        ! Interpolate between tabulated values
        A = ( TEM - TEMLOW ) / ( TEMUPP - TEMLOW ) 
        DO IWNO = 1, NWNO
          WNO = WNOLST(IWNO)
          CIALST(IWNO) = ( 1.0 - A ) * VALCIA ( ICL, WNO ) + 
     &                             A * VALCIA ( ICU, WNO )
        END DO
      END IF
C
      END 
           
