      SUBROUTINE INTGRA ( NPSI, NATM, MAXATM, FLG, LIN, PSI, PRF )
C
C VERSION
C     01JAN15 AD Original.
C
C DESCRIPTION
C     Interpolate to fill 2-D atmospheric profile field.
C     General purpose routine.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER NPSI      !  I  Number of different locations to fill
      INTEGER NATM      !  I  Number of defined profile levels
      INTEGER MAXATM    !  I  Externally declared size of 1st dim. of PRF
      LOGICAL FLG(NPSI) !  I  T=location already filled, F=to be interpolated.
      LOGICAL LIN       !  I  T=linear interpolation in VMR, F=log interp.
      REAL    PSI(NPSI) !  I  Horizontal angle of each location
      REAL    PRF(MAXATM,NPSI)  ! I/O Profiles
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C LOCAL VARIABLES
      INTEGER IATM ! Profile level counter
      INTEGER INXT ! Index of next set location
      INTEGER IPRV ! Index of previous set location
      INTEGER IPSI ! Index of horizontal locations
      REAL    A    ! Interpolation weight
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      IPRV = 0
      INXT = 1
      DO WHILE ( .NOT. FLG(INXT) .AND. INXT .LT. NPSI ) 
        INXT = INXT + 1
      END DO
C There should always be at least one point with FLG=TRUE
      IF ( .NOT. FLG(INXT) ) STOP 'F-INTGRA: Logical error'
C
      DO IPSI = 1, NPSI 
C If a set location is found, set IPRV to this and look for new INXT
        IF ( FLG(IPSI) ) THEN
          IPRV = IPSI
          IF ( IPSI .LT. NPSI ) THEN
            INXT = IPRV + 1 
            DO WHILE ( .NOT. FLG(INXT) .AND. INXT .LT. NPSI )
              INXT = INXT + 1
            END DO
            IF ( .NOT. FLG(INXT) ) INXT = 0
          END IF
C If location not yet set...
        ELSE
          IF ( IPRV .EQ. 0 ) THEN   ! copy values from next set location
            DO IATM = 1, NATM
              PRF(IATM,IPSI) = PRF(IATM,INXT)
            END DO
          ELSE IF ( INXT .EQ. 0 ) THEN  ! copy values from prev set location
            DO IATM = 1, NATM
              PRF(IATM,IPSI) = PRF(IATM,IPRV)
            END DO
          ELSE                       ! interpolate using prev/next loc. values
            A = (PSI(IPSI) - PSI(IPRV)) / (PSI(INXT) - PSI(IPRV))
            DO IATM = 1, NATM
              IF ( LIN .OR. PRF(IATM,IPRV) .LT. ARGMIN .OR.
     &                      PRF(IATM,INXT) .LT. ARGMIN ) THEN ! linear interp.
                PRF(IATM,IPSI) = A * PRF(IATM,INXT) + 
     &                 ( 1.0 - A ) * PRF(IATM,IPRV) 
              ELSE                                            ! log interp.
                PRF(IATM,IPSI) = 
     &                       EXP ( A * LOG(PRF(IATM,INXT)) +
     &                   ( 1.0 - A ) * LOG(PRF(IATM,IPRV))   )
              END IF
            END DO
          END IF ! Interpolate/duplicate
        END IF   ! If FLG(PSI) 
      END DO     ! IPSI loop
C
      END                     
