      SUBROUTINE KEYCHK ( KEY, GETHIT, GETXSC, GETNTE, 
     &                    IGNORE, FAIL, ERRMSG )
C
C VERSION
C     02JUL15 AD Add *CIA section
C     01JAN15 AD Correction: don't write *NTE to OPTLST if required
C     09DEC14 AD Correction to *GRD flag if LUT+GRD flags enabled
C     28NOV14 AD Make *SFC section optional
C     12NOV14 AD Allow missing *GRD section if LUT flag enabled
C     12FEB14 AD Add '*PHY', remove '*CRV'
C     04DEC13 AD Original.
C
C DESCRIPTION
C     Check section headers read from RFM driver table
C     Called by RFMINP for each section header after primary sections
C
      IMPLICIT NONE
C
C ARGUMENTS
      CHARACTER*4  KEY     !  I  Section header
      LOGICAL      GETHIT  !  I  T=require *HIT section
      LOGICAL      GETXSC  !  I  T=require *XSC section
      LOGICAL      GETNTE  !  I  T=require *NTE section
      LOGICAL      IGNORE  !  O  T=this section can be skipped
      LOGICAL      FAIL    !  O  T = a fatal error has been detected
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
C
C LOCAL VARIABLES
      INTEGER       I      ! Pointer to location of KEY in *LST arrays
      INTEGER       NKEY   ! No. sections found so far 
      LOGICAL       FIRST  ! T=first call of this routine
      CHARACTER*132 KEYLST ! List of found sections (size=4*[6+opt+req]) 
      CHARACTER*68  OPTLST ! List of optional sections (size=4*no.opt sections)
      CHARACTER*60  REQLST ! List of required sections (size=4*no.req sections)
C
C DATA STATEMENTS
      DATA FIRST / .TRUE. /
      DATA KEYLST / '*HDR*FLG*SPC*GAS*ATM*TAN' /  ! Primary sections
      DATA NKEY / 6 / 
      DATA OPTLST / ' ' /
      DATA REQLST / ' ' /
      SAVE FIRST, KEYLST, NKEY, OPTLST, REQLST
C
C EXECTUABLE CODE -------------------------------------------------------------
C
      FAIL = .FALSE.
      IGNORE = .FALSE.
C
C If NTEFLG=TRUE then NTE data can be loaded via the *ATM and/or *NTE sections
C If GETNTE=TRUE no data was loaded in *ATM section so *NTE section required
C If GETNTE=FALSE some data was loaded in *ATM section so *NTE section optional 
      IF ( FIRST ) THEN
C 15 secondary sections
        IF ( CIAFLG ) REQLST(1:4) = '*CIA' 
        IF ( FINFLG ) REQLST(5:8) = '*FIN'
        IF ( FOVFLG ) REQLST(9:12) = '*FOV'
C GRD data can also be taken from files included in *LUT section
        IF ( GRDFLG .AND. .NOT. LUTFLG ) REQLST(13:16) = '*GRD'
        IF ( GETHIT .AND. .NOT. LUTFLG ) REQLST(17:20) = '*HIT'
        IF ( ILSFLG ) REQLST(21:24) = '*ILS'
        IF ( JACFLG ) REQLST(25:28) = '*JAC'
        IF ( LEVFLG ) REQLST(29:32) = '*LEV'
        IF ( LUTFLG ) REQLST(33:36) = '*LUT'
        IF ( GETNTE ) REQLST(37:40) = '*NTE'
        IF ( OBSFLG ) REQLST(41:44) = '*OBS'
        IF ( REJFLG ) REQLST(45:48) = '*REJ'
        IF ( SHPFLG ) REQLST(49:52) = '*SHP'
        IF ( TPSFLG ) REQLST(53:56) = '*TPS'
        IF ( GETXSC .AND. .NOT. LUTFLG ) REQLST(57:60) = '*XSC'
C 15 optional sections (11 modifying output filenames, 
C plus *GRD, *HIT,*NTE,*XSC,*PHY)
        OPTLST(1:4) = '*PHY'
        IF ( ABSFLG ) OPTLST(5:8)   = '*ABS'
        IF ( BBTFLG ) OPTLST(9:12)  = '*BBT'
        IF ( COOFLG ) OPTLST(13:16) = '*COO'
        IF ( OPTFLG ) OPTLST(17:20) = '*OPT'
        IF ( PRFFLG ) OPTLST(21:24) = '*PRF'
        IF ( PTHFLG ) OPTLST(25:28) = '*PTH'
        IF ( RADFLG ) OPTLST(29:32) = '*RAD'
        IF ( RJTFLG ) OPTLST(33:36) = '*RJT'
        IF ( TABFLG ) OPTLST(37:40) = '*TAB'
        IF ( TRAFLG ) OPTLST(41:44) = '*TRA'
        IF ( WIDFLG ) OPTLST(45:48) = '*WID'
C
        IF ( GETHIT .AND. LUTFLG ) OPTLST(49:52) = '*HIT'
        IF ( NTEFLG .AND. .NOT. GETNTE ) OPTLST(53:56) = '*NTE'
        IF ( GETXSC .AND. LUTFLG ) OPTLST(57:60) = '*XSC'
        IF ( SFCFLG ) OPTLST(61:64) = '*SFC'
        IF ( GRDFLG .AND. LUTFLG ) OPTLST(65:68) = '*GRD'
C 
        FIRST = .FALSE.
      END IF        
C
C Check for duplicate keys and add to list of section keys found so far
      IF ( INDEX ( KEYLST, KEY ) .GT. 0 ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-KEYCHK: repeated '//KEY//' section in Driver File'
        RETURN
      ELSE
        NKEY = NKEY + 1
        I = 4*NKEY - 3
        IF ( I+3 .GT. LEN ( KEYLST ) ) STOP 'F-KEYCHK: Logical Error'
        KEYLST(I:I+3) = KEY
      END IF
C
C If one of the optional sections then just exit
      IF ( INDEX ( OPTLST, KEY ) .GT. 0 ) RETURN
C
C If one of the required sections then delete from required list and exit
      I = INDEX ( REQLST, KEY ) 
      IF ( I .GT. 0 ) THEN
        REQLST(I:I+3) = '    '
        RETURN
      END IF
C
C At this point KEY is either *END or not a required section
C If *END then check for any remaining required sections
      IF ( KEY .EQ. '*END' ) THEN
        I = INDEX ( REQLST, '*' ) 
        IF ( I .GT. 0 ) THEN
          FAIL = .TRUE.
          ERRMSG = 'F-KEYCHK: '//REQLST(I:I+3)//
     &             ' section missing from Driver File'
        END IF
      ELSE
        IGNORE = .TRUE.
      END IF
C
      END
