      REAL FUNCTION KINGDF ( WNO, IATM )
C
C VERSION
C     01JAN15 AD Original.
C 
C DESCRIPTION    
C     Calculate the King Factor for depolarization.
C     This is a fairly constant function of wavenumber for 0:10000cm-1
C     (1 um and longer) but starts to vary at shorter wavelength.
C
C            WNO    F(N2)   F(O2)   F(CO2)   F(A)    F(AIR)
C     10um   1E3    1.0340  1.0960  1.1500  1.0000  1.04567
C     1um    1E4    1.0343  1.0975  1.1500  1.0000  1.04625
C     0.3um  3E4    1.0369  1.1202  1.1500  1.0000  1.05304
C     0.1um  1E5    1.0657  2.6825  1.1500  1.0000  1.40667
C
C REFERENCES
C     Bodhaine, B. A., N. B. Wood, E. G. Dutton, and J. R. Slusser,
C       On Rayleigh Optical Depth Calculations, J. Atm. Ocean. Tech.,
C       16(11), 1854--1861, 1999.
C                  
      IMPLICIT NONE
      SAVE
C
C ARGUMENTS      
      DOUBLE PRECISION WNO  !  I  Wavenumber [cm-1]
      INTEGER          IATM !  I  Profile level for evaluation 
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'idxcon.inc' ! HITRAN molecular indices
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'gascom.inc' ! Molecular and isotope data
C
C LOCAL VARIABLES
      INTEGER JATM         ! Counter for atmospheric profile levels
      INTEGER IGAS         ! Index of selected molecule in *GAS arrays
      LOGICAL FIRST        ! T=if first call of this function
      REAL    A0(MAXATM)   ! Constant coefficients
      REAL    A2(MAXATM)   ! Coefficients of (wno)^2
      REAL    A4(MAXATM)   ! Coefficients of (wno)^4
      REAL    VMRCO2       ! VMR of CO2 [ppv]
      REAL    VMRN2        ! VMR of N2 [ppv]
      REAL    VMRO2        ! VMR of O2 [ppv]
      REAL    VMRA         ! VMR of Argon [ppv]
      REAL    VMRSUM       ! Sum of VMR values
      DOUBLE PRECISION WNO2 ! Square of wavenumber [(cm-1)^2]
C
C DATA STATEMENTS
      DATA FIRST / .TRUE. /
      DATA A0 / MAXATM * 0.0 /
      DATA A2 / MAXATM * 0.0 /
      DATA A4 / MAXATM * 0.0 /
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C On first call of this routine evaluate vertical profile of spectral 
C coefficients A0,A2,A4 which depends on molecular composition
      IF ( FIRST ) THEN
        DO JATM = 1, NATM
          IF ( IGSMOL(IDXN2) .NE. 0 ) THEN
            IGAS = IGSMOL(IDXN2) 
            VMRN2 = VMRATM(JATM,IGAS)
          ELSE
            VMRN2 = 0.78
          END IF
          IF ( IGSMOL(IDXO2) .NE. 0 ) THEN
            IGAS = IGSMOL(IDXO2)
            VMRO2 = VMRATM(JATM,IGAS)
          ELSE 
            VMRO2 = 0.21
          END IF
          IF ( IGSMOL(IDXCO2) .NE. 0 ) THEN
            IGAS = IGSMOL(IDXCO2)
            VMRCO2 = VMRATM(JATM,IGAS)
          ELSE
            VMRCO2 = 0.0004
          ENDIF
          VMRA = 0.009
C
          VMRSUM = VMRN2 + VMRO2 + VMRCO2 + VMRA
          A0(JATM) = ( 1.034 * VMRN2 + 1.096 * VMRO2 + 
     &                 1.15 * VMRCO2 + 1.0 * VMRA ) / VMRSUM
          A2(JATM) = ( 3.17E-12 * VMRN2 + 1.385E-11 * VMRO2 ) / VMRSUM
          A4(JATM) = 1.448E-20 * VMRO2 / VMRSUM 
        END DO
        FIRST = .FALSE. 
      END IF
C     
      WNO2 = WNO**2
      KINGDF = A0(IATM) + WNO2 * ( A2(IATM) + WNO2 * A4(IATM) )
C
      END
