      SUBROUTINE LOOKUP ( X, Y, XTAB, YTAB, N, JGUESS, MORD )
C
C VERSION
C     09JAN15 AD Tidied up
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     General purpose interpolation routine.
C     General purpose
C     Given arrays of N corresponding values in arrays XTAB and YTAB the routine
C     will return the interpolated value (Y) at the point X using a polynomial
C     of order MORD.  XTAB must be monotonic.
C     If the routine is called with JGUESS such that X is approximately 
C     X(JGUESS) the routine will work faster but JGUESS can take any value on
C     input.  On output JGUESS is set to the highest of the MORD element indices
C     of the input table that was used for the interpolation; this is a
C     value appropriate for making another entry in the same part of the table.
C     Note: also a DP version of this subroutine: DLOOKP.FOR
C
      IMPLICIT NONE
C
C ARGUMENTS
      REAL    X       !  I  Point at which interpolation is required
      REAL    Y       !  O  Answer
      REAL    XTAB(*) !  I  Tabulation of N x coordinates
      REAL    YTAB(*) !  I  Tabulation of N y coordinates
      INTEGER N       !  I  Number of points in table
      INTEGER JGUESS  ! I/O Entry point to table
      INTEGER MORD    !  I  Order of interpolating polynomial
C
      EXTERNAL 
     &  BRAKET ! Return lower index I of the two points in array ARRAY(N)
C
C LOCAL VARIABLES
      INTEGER I, J, NN 
      REAL T
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      J = JGUESS
      CALL BRAKET ( XTAB, N, X, J ) 
      NN     = MAX ( 1, J-(MORD-1)/2 )
      JGUESS = MIN ( N, NN+MORD )
      NN     = JGUESS - MORD
C
      Y = 0.0
      DO J = NN, JGUESS
        T = YTAB(J)
        DO I = NN, JGUESS
         IF ( I .NE. J ) T = T * ( X - XTAB(I) ) / ( XTAB(J) - XTAB(I) )
        ENDDO
        Y = Y + T
      ENDDO
C
      END
