      SUBROUTINE LUTCHK ( FAIL, ERRMSG )
C
C VERSION
C     13JUL15 AD Add NAMGAS
C     15JAN14 AD Rewritten. Now called once from INPCHK.
C     06JUN00 AD Add IRRFIL argument, allow for irreg.grid files
C     31JUL99 AD Remove unused variable NYTOT
C     04JUN99 AD Add BINFIL, NHEAD arguments to allow for binary files
C     29APR99 AD Allow qualifier data appended to TAB files
C     23APR99 AD Change error messages to accommodate C*8 LABSPC
C     16AUG98 AD Correction to error message for >MAXLUL
C     19JUN98 AD Modify to handle uncompressed LUTs differently.
C     22JAN98 AD (Standard F77) Put DATA statements *after* declarations
C     04JUL97 AD Original.
C
C DESCRIPTION
C     Check Look-Up Table file data.
C     Called once by INPCHK after all driver table contents read.
C     This checks that the combined LUTs for each spectral range do not exceed
C     the declared array sizes, and also warns if the ILS-convolved widths of 
C     the spectral ranges exceed the LUT spectral widths.
C
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  ISZSVD ! Find max array space required for SVD-LUT data
     &, NAMGAS ! Return molecular name associated with /GASCOM/ index
     &, RFMLOG ! Write text message to RFM log file.
      INTEGER ISZSVD
      CHARACTER*7 NAMGAS
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'lflcom.inc' ! Look-Up Table file data
      INCLUDE 'lkpcom.inc' ! Look-Up Table interpolation coefficients
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
      INCLUDE 'svdcom.inc' ! SVD-compressed Look-Up Table data
C
C LOCAL VARIABLES
      INTEGER      I       ! Index of last character in LABSPC
      INTEGER      IL      ! Index of last character in GASSTR
      INTEGER      IGAS    ! Index of absorbed in /GASCOM/
      INTEGER      ILFL    ! Index of LUT file in /LFLCOM/
      INTEGER      ISPC    ! Index of spectral range in /SPCCOM/
      INTEGER      MAXN    ! Required array size
      INTEGER      NLUT    ! Counter for no.TAB-LUT files reqd in each spc.range
      CHARACTER*7  GASSTR  ! String containing molec.name plus isotopic ID
      CHARACTER*80 WRNMSG  ! Warning message 
      DOUBLE PRECISION WNOTOL ! Tolerance [cm-1] for matching spectral ranges
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      FAIL = .TRUE.
C
C The following checks are only for SVD-LUTs which combine data from different
C LUTs within the same spectral range into the same array
C
C Check no.wavenumber points (SVD files only) within MAXLUV
      MAXN = ISZSVD ( 'V', ISPC )
      IF ( MAXN .GT. MAXLUV ) THEN
        I = INDEX ( LABSPC(ISPC)//' ', ' ' ) - 1
        WRITE ( ERRMSG, '(A,A,A,I7,A,I7)' ) 'F-LUTCHK: Spc.Rng ', 
     &    LABSPC(ISPC)(1:I), ' reqs tot', MAXN, 
     &    ' WnoPts > MAXLUV in rfmsiz.inc=', MAXLUV
        RETURN
      END IF
C
C Check no.p*t*q axis points within MAXLUX
      MAXN = ISZSVD ( 'X', ISPC )
      IF ( MAXN .GT. MAXLUX ) THEN
        I = INDEX ( LABSPC(ISPC)//' ', ' ' ) - 1
        WRITE ( ERRMSG, '(A,A,A,I7,A,I7)' ) 'F-LUTCHK: Spc.Rng ', 
     &    LABSPC(ISPC)(1:I), ' reqs tot', MAXN, 
     &    ' pT Pts >MAXLUX in rfmsiz.inc=', MAXLUX
        RETURN
      END IF
C
C Check total number of LUTs for each spectral range         
      MAXN = ISZSVD ( 'T', ISPC )
      IF ( MAXN .GT. MAXSVD ) THEN
        I = INDEX ( LABSPC(ISPC)//' ', ' ' ) - 1
        WRITE ( ERRMSG, '(A,A,A,I7,A,I7)' ) 'F-LUTCHK: Spc.Rng ', 
     &    LABSPC(ISPC)(1:I), ' reqs tot', MAXN, 
     &    ' LUTs > MAXSVD in rfmsiz.inc=', MAXSVD
        RETURN
      END IF
C
C Now that ILS data has been assigned to each spectral range, check that the
C spectral ranges of LUTs also overlap the convolved ranges 
      MAXN = 0
      DO ISPC = 1, NSPC
        WNOTOL = 0.01 * WNRSPC(ISPC)
        NLUT = 0
        DO IGAS = 1, NGAS
          ILFL = IDXLFL(IGAS,ISPC)
          IF ( ILFL .GT. 0 ) THEN
            IF ( V1LFL(ILFL) .GT. WXLSPC(ISPC) + WNOTOL .OR.
     &           V2LFL(ILFL) .LT. WXUSPC(ISPC) - WNOTOL     ) THEN
              I = INDEX ( LABSPC(ISPC)//' ', ' ' ) - 1
              GASSTR = NAMGAS(IGAS,IL)
              WRNMSG = 'W-LUTCHK: ' // GASSTR(1:IL) //
     &          ' LUT for Spc.Range ' //LABSPC(ISPC)(1:I) //
     &          ' narrower than ILS convol width'
              CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
              IF ( FAIL ) RETURN
            END IF
            IF ( .NOT. SVDLFL(ILFL) ) NLUT = NLUT + 1
          END IF
        END DO
        MAXN = MAX ( MAXN, NLUT )
      END DO
C
      IF ( MAXN .GT. MAXLUT ) THEN
        WRITE ( ERRMSG, '(A,A,A,I7,A,I7)' ) 'F-LUTCHK: Spc.Rng ', 
     &    LABSPC(ISPC)(1:I), ' reqs tot', MAXN, 
     &    ' LUTs > MAXLUT in rfmsiz.inc=', MAXLUT
        FAIL = .TRUE.
      ELSE
        FAIL = .FALSE.
      END IF
C
      END
