      SUBROUTINE LUTDEF ( LUNLUT, NAMDEF, FAIL, ERRMSG )
C
C VERSION
C     13JUL15 AD Use NAMGAS to construct molec + iso string
C     01DEC14 AD Add message if file not found
C     17NOV14 AD Simplify by using function EXPNAM
C     05SEP14 AD Remove LUNLUT argument from CHKFIL
C     19DEC13 AD Use CHKFIL to test if file exists
C                Use ACCLOG to log filenames being tested
C                Increase NAMLUT from 80 to 200
C                Use IDXLFL to see which gas/spc ranges remain to be filled
C     25MAR04 AD Allow for isotopes in filenames
C     23JUL03 AD Original.
C
C DESCRIPTION
C     Use default LUT filename to find any missing files.
C     Called once by INPLUT if filename template found in *LUT section of 
C     driver table.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNLUT ! I/O LUN for LUT File/next free LUN
      CHARACTER*(*) NAMDEF !  I  Default name of LUT file
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CHKFIL ! Check if argument represents an existing filename
     &, EXPNAM ! Replace '*' in filename with given string
     &, IDGOLD ! Convert new RFM index for .xsc data to old value
     &, LUTFIL ! Open LUT file and check contents
     &, NAMGAS ! Return molecular name associated with /GASCOM/ index
     &, NAMLOG ! Send text plus variable length filename to log file.
     &, RFMLOG ! Write text message to RFM log file.
      INTEGER IDGOLD
      LOGICAL CHKFIL
      CHARACTER*200 EXPNAM
      CHARACTER*7 NAMGAS
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'lflcom.inc' ! Look-Up Table file data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
C
C LOCAL VARIABLES
      INTEGER       IGAS   ! Absorber counter
      INTEGER       ISPC   ! Spectral range counter
      INTEGER       JPT    ! Pointer to last character in spectral range label
      INTEGER       KPT    ! Pointer to last character in molecule name
      LOGICAL       SVDFIL ! T=SVD-compressed MIPAS LUT, F=RFM direct tab.
      CHARACTER*7   GASSTR ! Molecule name (+ iso id)
      CHARACTER*200 NAMLUT ! Name of LUT file
      CHARACTER*20  SUBSTR ! Combination of spectral range label and molecule
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      CALL RFMLOG ( 'I-LUTDEF: Checking default LUT files', FAIL,ERRMSG)
        IF ( FAIL ) RETURN
C
      SVDFIL = INDEX ( NAMDEF, 'CS_' ) .GT. 0
C      
      DO ISPC = 1, NSPC                            ! Loop over spectral ranges
        DO IGAS = 1, NGAS                          ! Loop over gases
          IF ( IDXLFL(IGAS,ISPC) .GT. 0 ) GOTO 100 ! LUT already found
C At this point, spectral range/gas found requiring LUT data but no data loaded
C Construct spec/gas part of LUT filename, which depends on whether this is
C a SVD compressed LUT (SVDFIL=TRUE) or a direct tabulation (FALSE)
          JPT = INDEX ( LABSPC(ISPC)//' ', ' ' ) - 1
          IF ( SVDFIL ) THEN                        ! always has spectral label
            SUBSTR = LABSPC(ISPC)(1:JPT)//'_'
            WRITE ( SUBSTR(JPT+2:JPT+3), '(I2.2)' ) IDGOLD(IDXGAS(IGAS))
          ELSE
            GASSTR = NAMGAS ( IGAS, KPT ) 
            IF ( JPT .GE. 1 ) THEN
              SUBSTR = LABSPC(ISPC)(1:JPT)//GASSTR(1:KPT)
            ELSE                                     ! no spectral label
              SUBSTR = GASSTR(1:KPT)
            END IF
          END IF
          NAMLUT = EXPNAM ( NAMDEF, SUBSTR ) 
          CALL NAMLOG ( 'I-LUTDEF: looking for file:', NAMLUT, 
     &                  FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          IF ( CHKFIL ( NAMLUT ) ) THEN
C Read file contents and load if useful (incrementing LUNLUT)
            CALL LUTFIL ( LUNLUT, NAMLUT, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          ELSE
            CALL RFMLOG ( '... file not found', FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          END IF
 100      CONTINUE
        END DO
      END DO
C Normal exit
      FAIL = .FALSE.
C
      END
