      SUBROUTINE LUTPTH ( IGAS, FAIL, ERRMSG )
C
C VERSION
C     13JUL15 AD Add NAMGAS
C     22APR15 AD Bug#101: Correct rel.temperature interpolation with OFFTAB
C     16APR15 AD Log interpolation in VMR axis
C     08SEP14 AD Fix IQ,JQ calculation for NQ>1
C     15JAN14 AD Original.
C 
C DESCRIPTION    
C     Calculate LUT p,T,q-axis interpolation factors for each path.
C     Called by LUTCHK and SPCLUT for each LUT file/spec.rang
C     Also issues warnings if RFM paths exceed tabulation limits (apart from
C     below lowest p and q, which is assumed to be normal).
C                  
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      IGAS    !  I  Index of absorber
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL 
     &  BRAKET ! Return lower index I of the two points in array ARRAY(N)
     &, NAMGAS ! Return molecular name associated with /GASCOM/ index
     &, RFMLOG ! Write text message to RFM log file.
      CHARACTER*7 NAMGAS
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'lkpcom.inc' ! Look-Up Table interpolation coefficients
      INCLUDE 'pthcom.inc' ! RFM path data
      INCLUDE 'tabcom.inc' ! Table axes for tabulated absorb.coeffs.
C
C LOCAL VARIABLES
      INTEGER  IDUMMY    ! Dummy integer for swapping NT1LIM,NT2LIM
      INTEGER  ILEN      ! Length of GASSTR
      INTEGER  IP,IQ,IT  ! Indices of lower points in p,q,T-axes
      INTEGER  IPTH      ! Path counter
      INTEGER  JP,JQ,JT  ! Indices of upper points in p,q,T-axes
      INTEGER  KP,KQ,KT  ! Counter for lower/upper points in p,q,T-axes
      INTEGER  NP1LIM    ! Counter for no.times p outside PAXTAB lower index
      INTEGER  NP2LIM    ! Counter for no.times p outside PAXTAB upper index
      INTEGER  NQ1LIM    ! Counter for no.times q outside QAXTAB lower index
      INTEGER  NQ2LIM    ! Counter for no.times q outside QAXTAB upper index
      INTEGER  NT1LIM    ! Counter for no.times T outside TAXTAB lower index
      INTEGER  NT2LIM    ! Counter for no.times T outside TAXTAB upper index
      INTEGER  NTOT      ! Total number of calculated paths for IGAS
      INTEGER  NTQ       ! No.of T*q points for each p-axis value
      REAL     DP        ! Fraction of p-axis interval above IP
      REAL     DQ        ! Fraction of q-axis interval above IQ
      REAL     DT        ! Fraction of T-axis interval above IT
      REAL     PAX       ! Pressure [mb] of path segment 
      REAL     QAX       ! % of tab.VMR of path segment 
      REAL     PFACT     ! Interpolation weight for p-axis (DP or 1-DP)
      REAL     QFACT     ! Interpolation weight for q-axis (DQ or 1-DQ)
      REAL     TFACT     ! Interpolation weight for T-axis (DT or 1-DT)
      REAL     TAX       ! (Relative) Temperature [K] of path segment
      REAL     VMR       ! Volume mixing ratio [ppmv] of path segment
      REAL     XFACT     ! Product of interpolation weights P,Q,TFACT
      CHARACTER*7 GASSTR ! Molecule name ( + any isotopic ID)
      CHARACTER*80 WRNMSG ! Warning message
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      FAIL = .FALSE.
C
C Initialise out-of-axis-range counters
      NP1LIM = 0
      NP2LIM = 0
      NT1LIM = 0
      NT2LIM = 0
      NQ1LIM = 0
      NQ2LIM = 0
      NTOT = 0
C
      GASSTR = NAMGAS ( IGAS, ILEN )
C
C Ensure initial guess values are defined for BRAKET
      IP = 1
      IT = 1
      IQ = 1
      DO IPTH = 1, NCLC
        IF ( IGSPTH(IPTH) .EQ. IGAS ) THEN
          NTOT = NTOT + 1
          PAX = PREPTH(IPTH) * ATMB                ! convert [atm] to [mb]
          CALL BRAKET ( PAXTAB, NPTAB, PAX, IP ) 
          IF ( IP .LT. 1 ) THEN
            IP = 1
            DP = 0.0
            NP1LIM = NP1LIM + 1
          ELSE IF ( IP .EQ. NPTAB ) THEN
            DP = 0.0
            NP2LIM = NP2LIM + 1
          ELSE
            DP = LOG ( PAX/PAXTAB(IP) ) / LOG (PAXTAB(IP+1)/PAXTAB(IP)) 
          END IF
          JP = MIN ( NPTAB, IP + 1 )     ! MIN to allow for IP=NPTAB
C
          TAX = TEMPTH(IPTH)
          IF ( OFFTAB ) 
     &      TAX = TAX - ( TEMTAB(IP) * (1.0-DP) + TEMTAB(JP) * DP ) ! Bug#101
          CALL BRAKET ( TAXTAB, NTTAB, TAX, IT ) 
          IF ( IT .LT. 1 ) THEN
            IT = 1
            DT = 0.0
            NT1LIM = NT1LIM + 1
          ELSE IF ( IT .EQ. NTTAB ) THEN
            DT = 0.0
            NT2LIM = NT2LIM + 1
          ELSE
            DT = ( TAX - TAXTAB(IT) ) / ( TAXTAB(IT+1) - TAXTAB(IT) )
          END IF
          JT = MIN ( NTTAB, IT + 1 ) 
C           
          VMR = PPAPTH(IPTH) / PREPTH(IPTH) * 1.0E6
          IF ( LINFLG ) THEN
            QAX = 100.0 * VMR / ( VMRTAB(IP,1) * (1.0-DP) + 
     &                            VMRTAB(JP,1) * DP ) 
          ELSE
            QAX = 100.0 * VMR / EXP ( LOG ( VMRTAB(IP,1) ) * (1.0-DP) + 
     &                                LOG ( VMRTAB(JP,1) ) * DP ) 
          END IF  
          CALL BRAKET ( QAXTAB, NQTAB, QAX, IQ )
          IF ( IQ .LT. 1 ) THEN
            IQ = 1
            DQ = 0.0
            NQ1LIM = NQ1LIM + 1
          ELSE IF ( IQ .EQ. NQTAB ) THEN
            DQ = 0.0
            NQ2LIM = NQ2LIM + 1
          ELSE
            IF ( LINFLG ) THEN 
              DQ = ( QAX - QAXTAB(IQ) ) / ( QAXTAB(IQ+1) - QAXTAB(IQ) ) 
            ELSE
              DQ = LOG (QAX/QAXTAB(IQ)) / LOG (QAXTAB(IQ+1)/QAXTAB(IQ)) 
            END IF
          END IF
          JQ = MIN ( NQTAB, IQ + 1 ) 
C
C Calculate weights for lower and upper points in p,T,q axes
          NTQ = NTTAB * NQTAB
          IL1PTH(IPTH) = NLKP + 1
          PFACT = 1.0 - DP
          DO KP = IP, JP
            TFACT = 1.0 - DT
            DO KT = IT, JT
              QFACT = 1.0 - DQ
              DO KQ = IQ, JQ
                XFACT = PFACT * TFACT * QFACT 
                IF ( XFACT .GT. 0.0 ) THEN  ! only store non-zero weights
                  IF ( NLKP .GT. MAXLKP ) THEN
                    FAIL = .TRUE.
                    WRITE ( ERRMSG, '(A,I11)' ) 
     &                'F-LUTPTH: No.pTq coords for LUTs > MAXLKP '//
     &                'in rfmsiz.inc, =', MAXLKP
                    RETURN
                  END IF
                  NLKP = NLKP + 1
                  WGTLKP(NLKP) = XFACT
                  IDXLKP(NLKP) = (KP-1)*NTQ + (KT-1)*NQTAB + KQ
                END IF
                QFACT = DQ
              END DO
              TFACT = DT
            END DO
            PFACT = DP
          END DO                                
          IL2PTH(IPTH) = NLKP 
        END IF
      END DO
C
      IF ( NPTAB .GT. 1 ) THEN
        IF ( PAXTAB(NPTAB) .LT. PAXTAB(1) ) NP2LIM = NP1LIM
        IF ( NP2LIM .GT. 0 ) THEN
          WRITE ( WRNMSG, '(A,A,A,I6,A,F6.2,A)' ) 
     &      'W-LUTPTH: ', GASSTR(1:ILEN),
     &      ' Path Pre > LUT Max Pre for', NP2LIM,
     &      ' calc paths (', FLOAT(NP2LIM)/FLOAT(NTOT), '%)'
          CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
      END IF
      IF ( NTTAB .GT. 1 ) THEN
        IF ( TAXTAB(NTTAB) .LT. TAXTAB(1) ) THEN
          IDUMMY = NT2LIM
          NT2LIM = NT1LIM
          NT1LIM = IDUMMY
        END IF
        IF ( NT2LIM .GT. 0 ) THEN
          WRITE ( WRNMSG, '(A,A,A,I6,A,F6.2,A)' ) 
     &      'W-LUTPTH: ', GASSTR(1:ILEN),
     &      ' Path Tem > LUT Max Tem for', NT2LIM,
     &      ' calc paths (', FLOAT(NT2LIM)/FLOAT(NTOT), '%)'
          CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
        IF ( NT1LIM .GT. 0 ) THEN
          WRITE ( WRNMSG, '(A,A,A,I6,A,F6.2,A)' ) 
     &      'W-LUTPTH: ', GASSTR(1:ILEN), 
     &      ' Path Tem < LUT Min Tem for', NT1LIM,
     &      ' calc paths (', FLOAT(NT1LIM)/FLOAT(NTOT), '%)'
          CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
      END IF
      IF ( NQTAB .GT. 1 ) THEN
        IF ( QAXTAB(NPTAB) .LT. QAXTAB(1) ) NQ2LIM = NQ1LIM
        IF ( NQ2LIM .GT. 0 ) THEN
          WRITE ( WRNMSG, '(A,A,A,I6,A,F6.2,A)' ) 
     &      'W-LUTPTH: ', GASSTR(1:ILEN), 
     &      ' Path VMR > LUT Max VMR for', NQ2LIM,
     &      ' calc paths (', FLOAT(NQ2LIM)/FLOAT(NTOT), '%)'
          CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
      END IF
C
      END
