      SUBROUTINE LUTSPC ( V1, V2, IGAS, REJECT, FAIL, ERRMSG )
C
C VERSION
C     25FEB14 AD Original.
C
C DESCRIPTION
C     Determine spectral range(s) to which LUT can be applied
C     Called by LUTFIL for each file in *LUT section of RFM driver table.
C     If LUT applicable, assigns value NLFL+1 to SPCLFL matrix.
C
      IMPLICIT NONE
C
C ARGUMENTS
      DOUBLE PRECISION V1  !  I  Lower wno limit of LUT
      DOUBLE PRECISION V2  !  I  Upper wno limit of LUT
      INTEGER       IGAS   !  I  Index of LUT absorber in /GASCOM/
      LOGICAL       REJECT !  O  T=no spectral ranges, F=at least one found
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  NAMGAS ! Return molecular name associated with /GASCOM/ index
      CHARACTER*7 NAMGAS
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'lflcom.inc' ! Look-Up Table file data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
C
C LOCAL CONSTANTS
      DOUBLE PRECISION WNOTOL    ! Waveno. tolerance as fraction of Spc grid
        PARAMETER ( WNOTOL = 0.01D0 ) 
C
C LOCAL VARIABLES 
      INTEGER     ILEN     ! Length of GASSTR
      INTEGER     ISPC     ! Spectral range counter (1:NSPC)
      CHARACTER*7 GASSTR   ! Name of molecule (+isotopic ID)
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      REJECT = .TRUE.
      GASSTR = NAMGAS ( IGAS, ILEN ) 
      DO ISPC = 1, NSPC
        IF ( V1 .LE. WNLSPC(ISPC)+WNOTOL*WNRSPC(ISPC) .AND. 
     &       V2 .GE. WNUSPC(ISPC)-WNOTOL*WNRSPC(ISPC)   ) THEN
          IF ( IDXLFL(IGAS,ISPC) .GT. 0 ) THEN
            FAIL = .TRUE.
            ERRMSG = 'F-LUTSPC: ' // GASSTR(1:ILEN) //
     &        ' has two LUTs covering spectral range ' //LABSPC(ISPC)
            RETURN
          END IF
          IDXLFL(IGAS,ISPC) = NLFL + 1
          REJECT = .FALSE.        
        END IF
      END DO
C
      FAIL = .FALSE.
C
      END
