      SUBROUTINE LUTSVD ( LUNLUT, NAMLUT, ISVD, NL, JGAS, FAIL, ERRMSG )
C
C VERSION
C     14JAN14 AD Original. Derived from parts of SPCLUT
C
C DESCRIPTION
C     Load SVD-compressed LUT data from file
C     Called by SPCLUT for each SVD file in each spectral range 
C     If JGAS=0 on input, just read header and return IGAS value of LUT contents
C     If JGAS NE 0 on input, fatal error unless LUT contents match IGAS
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNLUT !  I  LUN for accessing SVD-LUT data
      CHARACTER*(*) NAMLUT !  I  Name of SVD-LUT file
      INTEGER       ISVD   !  I  Index in /SVDCOM/ for storing data
      INTEGER       NL     ! I/O I=Max.no of S.V.s to use, O=no.read in
      INTEGER       JGAS   ! I/O Index in /GASCOM/ of LUT data, or 0 
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  SVDGRD ! Read coded irregular grid data and turn into integer
     &, IGASID ! Determine GASCOM index for given Gas#ID and Iso#ID
     &, RFMLOG ! Write text message to RFM log file.
     &, SVDINF ! Extract info from SVD-LUT header record
      INTEGER IGASID
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'svdcom.inc' ! SVD-compressed Look-Up Table data
C
C LOCAL VARIABLES
      INTEGER      IDGAS   ! HITRAN ID of gas, read from SVD-LUT file 
      INTEGER      IDISO   ! Isotopic ID of gas, read from SVD-LUT file
      INTEGER      IDUMMY  ! Dummy variable for reading irreg grid indices
      INTEGER      IGAS    ! Index of gas in SVD-LUT file
      INTEGER      IL      ! Basis vector counter
      INTEGER      IOS     ! Saved value of IOSTAT for error messages
      INTEGER      IV      ! Relative pointer for Wno dimension 
      INTEGER      IVO     ! Pointer for Wno dimension offset
      INTEGER      IX      ! Counter for p,T dimension
      INTEGER      IXO     ! Pointer for Cmp. p,T dimension offset
      INTEGER      NSPACE  ! No.of free array elements remaining
      LOGICAL      IRREGV  ! Irregular spectral grid
      REAL         RDUMMY  ! Dummy variable for skipping NLSVD>NL values
      CHARACTER*8  MWCODE  ! MW code read from SVD-LUT file
      CHARACTER*80 RECORD  ! Record read from SVD-LUT file
      CHARACTER*3  TAB     ! Tabulated function
      CHARACTER*80 LOGMSG  ! Message sent to log file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      OPEN ( UNIT=LUNLUT, FILE=NAMLUT, STATUS='OLD', 
     &           IOSTAT=IOS, ERR=900 ) 
      READ ( LUNLUT, '(A)', IOSTAT=IOS, ERR=900 ) RECORD
      READ ( LUNLUT, '(A)', IOSTAT=IOS, ERR=900 ) RECORD
      IF ( RECORD(1:1) .EQ. '#' ) THEN
        CALL RFMLOG ( RECORD, FAIL, ERRMSG )
      ELSE
        FAIL = .TRUE. 
        ERRMSG = 'F-LUTSVD: 2nd record of file does not start'//
     &           ' with expected ''#'' character'
      END IF
      IF ( FAIL ) RETURN
      DO WHILE ( RECORD(1:1) .EQ. '#' ) 
        READ ( LUNLUT, '(A)', IOSTAT=IOS, ERR=900 ) RECORD
      END DO
C     
      CALL SVDINF ( RECORD, MWCODE, IDGAS, IDISO, TAB, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      IGAS = IGASID ( IDGAS, IDISO )
      IF ( JGAS .EQ. 0 ) THEN
        IF ( IGAS .EQ. 0 ) THEN   ! not a reqd absorber
          CLOSE ( LUNLUT, IOSTAT=IOS, ERR=900 ) 
          FAIL = .FALSE.
          RETURN
        END IF
      ELSE
C Shouldn't happen but possible that file has changed since initially checked
C while reading in driver table
        IF ( IGAS .NE. JGAS ) STOP 'F-LUTSVD: Logical error#1'
      END IF          
      IGSSVD(ISVD) = IGAS
C
      IF ( TAB .EQ. 'log' .OR. TAB .EQ. 'lin' .OR. TAB .EQ. '4rt' ) THEN
        TABSVD(ISVD) = TAB
      ELSE
        FAIL = .TRUE. 
        ERRMSG = 'F-LUTSVD: File contains unrecognised tabulation fn:'
     &           //TAB
        RETURN
      END IF
C
      READ ( LUNLUT, *, IOSTAT=IOS, ERR=900 ) 
     &  NLSVD(ISVD), NVSVD(ISVD), V1SVD(ISVD), DVSVD(ISVD),
     &  NPSVD(ISVD), P1SVD(ISVD), DPSVD(ISVD),
     &  NTSVD(ISVD), T1SVD(ISVD), DTSVD(ISVD)
C
      IRREGV = NVSVD(ISVD) .LT. 1 
      NVSVD(ISVD) = ABS ( NVSVD(ISVD) )
      V2SVD(ISVD) = V1SVD(ISVD) + ( NVSVD(ISVD) - 1 ) * DVSVD(ISVD)
C
      IF ( NL .GT. MAXLUL ) THEN           ! default value if no qualifiers
        NL = NLSVD(ISVD)
      ELSE IF ( NL .LE. MAXLUL .AND. NL .GT. NLSVD(ISVD) ) THEN
        WRITE ( LOGMSG, '(A,I11,A,I11,A)' )
     &    'W-LUTSVD: Including all ', NLSVD(ISVD),
     &    ' basis vectors in file (<No.Rqd=', NL, ')'
        NL = NLSVD(ISVD)
      ELSE IF ( NL .GE. 0 ) THEN
        WRITE ( LOGMSG, '(A,I11,A,I11,A)' )
     &    'I-LUTSVD: Including ', NL, ' out of ', NLSVD(ISVD),
     &    ' basis vectors from LUT file'
      ELSE IF ( NL .GE. -NLSVD(ISVD) ) THEN
        WRITE ( LOGMSG, '(A,I11,A,I11,A)' )
     &    'I-LUTSVD: Excluding ', -NL, ' out of ', NLSVD(ISVD),
     &    ' basis vectors from LUT file'
        NL = NLSVD(ISVD) + NL
      ELSE
        WRITE ( LOGMSG, '(A,I11,A,I11,A)' )
     &    'W-LUTSVD: Excluding all ', NLSVD(ISVD),
     &    ' basis vectors in file (<No.Rqd=', -NL, ')'
        NL = 0
      END IF
      IF ( NL .EQ. 0 ) TAB = 'lin'  ! to allow zero absorption
C
      IF ( NVSVD(ISVD) .EQ. 1. ) DVSVD(ISVD) = 1.0D0
      IF ( NPSVD(ISVD) .EQ. 1. ) DPSVD(ISVD) = 1.0
      IF ( NTSVD(ISVD) .EQ. 1. ) DTSVD(ISVD) = 1.0
C
      IF ( JGAS .EQ. 0 ) THEN     ! just read header 
        JGAS = IGAS
        IF ( IRREGV ) THEN  ! modify NV to actual no. irreg grid points
          CALL SVDGRD ( LUNLUT, 1, NVSVD(ISVD), IDUMMY, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
        CLOSE ( LUNLUT, IOSTAT=IOS, ERR=900 )
        RETURN                    ! normal exit with header info read in
      END IF
C
      IF ( ISVD .EQ. 1 ) THEN 
        IVOSVD(ISVD) = 0
        IXOSVD(ISVD) = 0
      ELSE
        IVOSVD(ISVD) = IVOSVD(ISVD-1) + NVSVD(ISVD-1)
        IXOSVD(ISVD) = IXOSVD(ISVD-1) + NPSVD(ISVD-1) * NTSVD(ISVD-1)
      END IF
      IVO = IVOSVD(ISVD)
      IXO = IXOSVD(ISVD)
C
      NSPACE = MAXLUV - IVO
      IF ( IRREGV ) THEN
        CALL SVDGRD ( LUNLUT, NSPACE, NVSVD(ISVD), IVSVD(IVO+1),! NVSVD modified
     &                FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      ELSE
        DO IV = 1, MIN ( NSPACE, NVSVD(ISVD) )
          IVSVD(IVO+IV) = IV
        END DO
      END IF
C
C Array sizes should have been checked previously in LUTCHK
      IF ( NL .GT. MAXLUL ) 
     &  STOP 'F-LUTSVD: Logical error#2'
      IF ( IVO + NVSVD(ISVD) .GT. MAXLUV ) 
     &  STOP 'F-LUTSVD: Logical error#3'
      IF ( IXO + NPSVD(ISVD)*NTSVD(ISVD) .GT. MAXLUX )
     &  STOP 'F-LUTSVD: Logical error#4'
C
      DO IV = IVO + 1, IVO + NVSVD(ISVD)
        READ ( LUNLUT, *, IOSTAT=IOS, ERR=900 ) 
     &    ( U(IV,IL), IL = 1, NL ),
     &    ( RDUMMY, IL = NL+1, NLSVD(ISVD) )
      END DO
C
      DO IX = IXO + 1, IXO + NPSVD(ISVD) * NTSVD(ISVD)
        READ ( LUNLUT, *, IOSTAT=IOS, ERR=900 ) 
     &   ( K(IL,IX), IL = 1, NL ), 
     &   ( RDUMMY, IL = NL+1, NLSVD(ISVD) )  
      END DO
C
      NLSVD(ISVD) = NL
C
C Normal exit
      CLOSE ( LUNLUT, IOSTAT=IOS, ERR=900 )
      FAIL = .FALSE.
      RETURN
C
C Exit with fatal I/O error
  900 WRITE ( ERRMSG, '(A,I11)')
     &  'F-LUTSVD: I/O failure on LUT file. IOSTAT=', IOS
      FAIL = .TRUE.
C
      END
