      SUBROUTINE MAKNAM ( ISPC, IGAS, ITAN, IGRA, IJAC, INPNAM, OUTNAM )
C
C VERSION
C     15JUL15 AD Convert NAMGAS from subroutine to function
C                Reduce GASSTR from C*9 to C*7
C     09JAN15 AD Add IJAC argument. Use EXPNAM, NAMGAS
C     09MAY04 AD Allow for isotopic species
C     06JAN04 AD Add IGRA argument
C     05DEC00 AD Avoid concatenation of variable character strings
C     08DEC99 AD Rewritten to avoid non-standard FORTRAN usage
C     18JUL98 AD Use STRTAN for tan.hgt identifier. Add CMINUS
C     31OCT97 AD Change sequence to write GAS after SPC label.      
C     22OCT97 AD Only write gas name if wildcard exists.
C     18SEP96 AD Remove redundant LOCASE
C                Always insert tangent height if there is a wildcard
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Construct filename for RFM output files.
C     General purpose.
C     CMINUS can be changed to some other character if operating system does 
C     not allow '-' sign in filenames.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       ISPC   !  I  Spectral range number
      INTEGER       ITAN   !  I  Tangent height number
      INTEGER       IGAS   !  I  Absorber number
      INTEGER       IGRA   !  I  Horizontal (psi) angle number
      INTEGER       IJAC   !  I  Index of Jacobian, or -1 = LOS Jacobian
      CHARACTER*(*) INPNAM !  I  Input (basic) filename
      CHARACTER*(*) OUTNAM !  O  Output filename
C
      EXTERNAL
     &  EXPNAM ! Replace '*' in filename with given string.
     &, NAMGAS ! Return molecular name associated with /GASCOM/ index
      CHARACTER*200 EXPNAM
      CHARACTER*7   NAMGAS
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES 
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
      INCLUDE 'outcom.inc' ! RFM output file data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
      INCLUDE 'tancom.inc' ! Tangent heights
C
C LOCAL CONSTANTS
      CHARACTER*1  CMINUS  ! Character used for negative tan.hgts, psi angles
        PARAMETER ( CMINUS = '-' )
      CHARACTER*1   CISO   ! Character used before Isotope# in filename
        PARAMETER ( CISO = 'i' )
C
C LOCAL VARIABLES
      INTEGER      IEND    ! Length of filename so far
      INTEGER      L       ! Total length of INSERT
      INTEGER      LENGTH  ! Length of sub-string to be inserted
      CHARACTER*80 INSERT  ! Inserted component of filename
      CHARACTER*6  TANSTR  ! Tangent height text 
      CHARACTER*7  GASSTR  ! Molecule/isotope name
      CHARACTER*6  GRASTR  ! Horizontal angle text 
      CHARACTER*16 JACSTR  ! Jacobian identification
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Find if there is a wildcard in the input name. 
      IF ( INDEX ( INPNAM, '*') .EQ. 0 ) THEN  ! No wildcard, so same filename
        OUTNAM = INPNAM
      ELSE                         ! Wildcard, so insert strings (if any)
C 
C Construct string to be inserted at wildcard position
        INSERT = ' '
        L = 0
C
C Insert any spectral range label
        IF ( ISPC .NE. 0 ) THEN
          LENGTH = INDEX ( LABSPC(ISPC)//' ', ' ' ) - 1
          IF ( LENGTH .GT. 0 ) 
     &      INSERT(L+1:L+LENGTH) = LABSPC(ISPC)(1:LENGTH)
          L = L + LENGTH
        END IF
C
C Insert any absorber/isotope name 
        IF ( IGAS .NE. 0 ) THEN
          GASSTR = NAMGAS ( IGAS, LENGTH ) 
          INSERT(L+1:L+LENGTH) = GASSTR(1:LENGTH)
          L = L + LENGTH
        END IF
C
C Insert any tangent height
        IF ( ITAN .NE. 0 ) THEN
          IF ( STRTAN(ITAN)(1:1) .EQ. '-' ) THEN
            TANSTR = CMINUS//STRTAN(ITAN)(2:6)
            LENGTH = 6
          ELSE
            TANSTR = STRTAN(ITAN)(1:5)
            LENGTH = 5
          END IF
          INSERT(L+1:L+LENGTH) = TANSTR(1:LENGTH)
          L = L + LENGTH
        END IF
C
C Insert any horizontal (psi) angle 
        IF ( IGRA .NE. 0 ) THEN
          IF ( PSIGRA(IGRA) .GE. 0.0 ) THEN     ! Psi angles should be <99deg
            WRITE ( GRASTR, '(I5.5)' ) NINT ( PSIGRA(IGRA) * 1000.0 )
            LENGTH = 5
          ELSE
            WRITE ( GRASTR, '(A,I5.5)' ) 
     &        CMINUS, -NINT ( PSIGRA(IGRA) * 1000.0 )
            LENGTH = 6
          END IF
          INSERT(L+1:L+LENGTH) = GRASTR(1:LENGTH)
          L = L + LENGTH
        END IF
C
C Insert any Jacobian identification
        IF ( IJAC .NE. 0 ) THEN
          IF ( IJAC .EQ. -1 ) THEN
            JACSTR = '_los'
          ELSE
            CALL NAMJAC ( IJAC, .TRUE., JACSTR ) 
          END IF
          LENGTH = INDEX ( JACSTR//' ', ' ' ) - 1
          INSERT(L+1:L+LENGTH) = JACSTR(1:LENGTH)
          L = L + LENGTH
        END IF          
C
C Construct new filename name including any insertion
        OUTNAM = EXPNAM ( INPNAM, INSERT ) 
C
      END IF
C
C Establish length of output name
      IEND = INDEX ( OUTNAM, ' ' ) - 1          ! point to last character
      IF ( IEND .EQ. -1 ) IEND = LEN ( OUTNAM ) ! No trailing spaces
C
C If a Run ID is specified, append that to filename.
      IF ( RUNID .NE. ' ' ) THEN
        LENGTH = INDEX ( RUNID//' ', ' ' ) - 1  
        IF ( LENGTH .GT. 0 ) THEN
          OUTNAM(IEND+1:IEND+LENGTH) = RUNID(1:LENGTH)
          IEND = IEND + LENGTH
        END IF
      END IF
C
      END
