      SUBROUTINE MOVGRA ( IGRA, JGRA )
C
C VERSION
C     01JAN15 AD Allow for TVib and QFN profiles
C                If moving within /GRACOM/ set old location to undefined
C                Change order of dimensions in /GRACOM/ arrays
C     31DEC99 AD Original.
C
C DESCRIPTION
C     Move profiles within /GRACOM/ arrays.
C     Called by PRFGRA and ATMLAY.
C     An index IGRA or JGRA =0 means use profiles in /ATMCOM/
C     Other indices refer to position in /GRACOM/
C     Note that NNTE is initialised to 0 in rfmdef.for so it is defined even
C     if NTE flag is not set.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER IGRA  !  I  Old index of profile data
      INTEGER JGRA  !  I  New index of profile data
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
      INCLUDE 'ntecom.inc' ! Non-LTE data
      INCLUDE 'qfncom.inc' ! non-LTE Partition Functions 
C
C LOCAL VARIABLES
      INTEGER IATM  ! Atmospheric profile level counter
      INTEGER IGAS  ! Absorber counter
      INTEGER INTE  ! Counter for Vib.Temp profiles
      INTEGER IQFN  ! Counter for Vib.Part.Fn profiles
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      IF ( JGRA .EQ. 0 ) THEN                      ! Move IGRA to ATM
        DO IATM = 1, NATM
          TEMATM(IATM) = TEMGRA(IATM,IGRA)
          PREATM(IATM) = PREGRA(IATM,IGRA)
          DO IGAS = 1, NGAS
            VMRATM(IATM,IGAS) = VMRGRA(IATM,IGRA,IGAS)
          END DO
          DO INTE = 1, NNTE              ! NNTE initialised to 0 in rfmdef.for
            TEMNTE(IATM,INTE) = TVBGRA(IATM,IGRA,INTE)
          END DO
          DO IQFN = 1, NQFN
            PRFQFN(IATM,IQFN) = QFNGRA(IATM,IGRA,IQFN)
          END DO
        END DO
      ELSE IF ( IGRA .EQ. 0 ) THEN                 ! Move ATM to JGRA
        DO IATM = 1, NATM
          TEMGRA(IATM,JGRA) = TEMATM(IATM)
          PREGRA(IATM,JGRA) = PREATM(IATM)
          DO IGAS = 1, NGAS
            VMRGRA(IATM,JGRA,IGAS) = VMRATM(IATM,IGAS)
          END DO
          DO INTE = 1, NNTE
            TVBGRA(IATM,JGRA,INTE) = TEMNTE(IATM,INTE) 
          END DO
          DO IQFN = 1, NQFN
            QFNGRA(IATM,JGRA,IQFN) = PRFQFN(IATM,IQFN)
          END DO
        END DO
      ELSE                                         ! Move IGRA to JGRA
        PSIGRA(JGRA) = PSIGRA(IGRA) 
        PSIGRA(IGRA) = -999.0
        FLTGRA(JGRA) = FLTGRA(IGRA)
        FLTGRA(IGRA) = .FALSE.
        FLPGRA(JGRA) = FLPGRA(IGRA)
        FLPGRA(IGRA) = .FALSE.
        DO IGAS = 1, NGAS
          FLVGRA(JGRA,IGAS) = FLVGRA(IGRA,IGAS)
          FLVGRA(IGRA,IGAS) = .FALSE.
        END DO
        DO INTE = 1, NNTE
          FLNGRA(JGRA,INTE) = FLNGRA(IGRA,INTE)
          FLNGRA(IGRA,INTE) = .FALSE.
        END DO
        DO IQFN = 1, NQFN
          FLQGRA(JGRA,IQFN) = FLQGRA(IGRA,IQFN)
          FLQGRA(IGRA,IQFN) = .FALSE.
        END DO
        DO IATM = 1, NATM
          TEMGRA(IATM,JGRA) = TEMGRA(IATM,IGRA)
          PREGRA(IATM,JGRA) = PREGRA(IATM,IGRA)
          DO IGAS = 1, NGAS
            VMRGRA(IATM,JGRA,IGAS) = VMRGRA(IATM,IGRA,IGAS)
          END DO
          DO INTE = 1, NNTE
            TVBGRA(IATM,JGRA,INTE) = TVBGRA(IATM,IGRA,INTE) 
          END DO
          DO IQFN = 1, NQFN
            QFNGRA(IATM,JGRA,IQFN) = QFNGRA(IATM,IGRA,IQFN)
          END DO
        END DO
        IF ( NOMGRA .EQ. IGRA ) NOMGRA = JGRA
      END IF
C
      END
