      SUBROUTINE NAMJAC ( IJAC, LFULL, NAM )
C
C VERSION
C     13JUL15 AD Add NAMGAS
C     08JAN15 AD Original. Based on part of old JACNAM
C
C DESCRIPTION
C     Construct Jacobian string for insertion into RFM filename
C     Called by MAKNAM and JACHDR for each Jacobian file.
C     Maximum length of NAM with LFULL=.FALSE. is C*9 (set by CODGAS)
C     Max length with LFULL=.TRUE. is C*16 (extra 7 characters)
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       IJAC    !  I  Index of Jacobian element
      LOGICAL       LFULL   !  I  T=incl.perturbation alt, F=no ptb alt.
      CHARACTER*(*) NAM     !  O  String for Jacobian identification
C
      EXTERNAL 
     &  NAMGAS ! Return molecular name associated with /GASCOM/ index
      CHARACTER*7 NAMGAS
C
C GLOBAL CONSTANTS
      INCLUDE 'jdxcon.inc' ! Indices for non-VMR Jacobians
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES 
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'jaccom.inc' ! Jacobian data
      INCLUDE 'ntecom.inc' ! Non-LTE data
C
C LOCAL CONSTANTS
      CHARACTER*1   CMINUS ! Character used for negative altitudes
        PARAMETER ( CMINUS = '-' )
      CHARACTER*1   CISO   ! Character used before Isotope# in filename
        PARAMETER ( CISO = 'i' )
      CHARACTER*1   CVIB   ! Character used before Vib.Glob.Quant# in filename
        PARAMETER ( CVIB = 'v' )
C
C LOCAL VARIABLES
      INTEGER      IATM   ! Atmos.profile level of Jacobian element
      INTEGER      IDG    ! HITRAN index of gas
      INTEGER      IGAS   ! Index of Jacobian species
      INTEGER      IHGT   ! Height [m or km] of Jacobian element
      INTEGER      INTE   ! Index of vibrational level for VT Jacobians
      INTEGER      L      ! Local pointer to end of string
      CHARACTER*9  JACSTR ! Jacobian type
C
C EXECUTABLE CODE ------------------------------------------------------------
C
C Initial '_' character
      NAM = '_'
      JACSTR = ' '
C
C Insert perturbed parameter string (not with MTX flag)
      IGAS = IGSJAC(IJAC)
      IF ( IGAS .GT. 0 ) THEN       ! JAC,LEV flags define IGSJAC, MTX leaves=0
        IF ( IGAS .EQ. MAXGAS+JDXTEM ) THEN
          JACSTR(1:3) = 'tem'
        ELSE IF ( IGAS .EQ. MAXGAS+JDXPRE ) THEN
          JACSTR(1:3) = 'pre'
        ELSE IF ( IGAS .EQ. MAXGAS+JDXSFT ) THEN
          JACSTR(1:6) = 'sfctem'
        ELSE IF ( IGAS .EQ. MAXGAS+JDXSFE ) THEN
          JACSTR(1:6) = 'sfcems'
C LEV flag: Values for 'up' and 'down' are assigned in subroutine LEVTAN
        ELSE IF ( IGAS .EQ. MAXGAS+JDXLVU ) THEN   ! Used with LEV flag
          JACSTR(1:2) = 'up'
        ELSE IF ( IGAS .EQ. MAXGAS+JDXLVD ) THEN   ! Used with LEV flag
          JACSTR(1:4) = 'down'
C VT Jacobians require gas, isotope and global quantum number
        ELSE IF ( IGAS .GT. MAXGAS+JDXNTE ) THEN   
          INTE = IGAS - ( MAXGAS + JDXNTE )
          IDG  = IDGNTE(INTE)
          L = INDEX ( CODGAS(IGSMOL(IDG))//' ', ' ' ) - 1
          JACSTR(1:L) = CODGAS(IGSMOL(IDG))(1:L)
          WRITE ( JACSTR(L+1:L+5), '(A,I1,A,I2.2)' ) 
     &      CISO, ISONTE(INTE), CVIB, IGQNTE(INTE)
C VMR Jacobians
        ELSE
          JACSTR = NAMGAS ( IGAS, L ) 
        END IF
      END IF
      L = INDEX ( JACSTR, ' ' ) - 1
      NAM = '_'//JACSTR(1:L)
      L = L + 1
C
C Insert perturbation altitude string
      IF ( LFULL ) THEN 
       IATM = IATJAC(IJAC) 
        IF ( IATM .GT. 0 ) THEN
          IHGT = NINT ( HGTATM(IATM)*1000.0 )
          IF ( ABS ( IHGT ) .GT. 99999 ) IHGT = NINT ( HGTATM(IATM) )
          IF ( IHGT .GE. 0 ) THEN
            WRITE ( NAM(L+1:L+5), '(I5.5)' ) IHGT
          ELSE
            WRITE ( NAM(L+1:L+6), '(A,I5.5)' ) CMINUS, ABS(IHGT)
          END IF
        ENDIF
      ENDIF
C 
      END
