      SUBROUTINE NEWPSI ( PSI, IGRA, FAIL, ERRMSG )
C
C VERSION
C     09JAN15 AD Original.
C
C DESCRIPTION
C     Create new horizontal location in horiz.gradient data
C     Called by ATMPSI if GRA flag enabled.
C     This module inserts location into /GRACOM/ arrays in order of increasing
C     psi value, using MOVGRA to initialise data for the new location.
C
      IMPLICIT NONE
C
C ARGUMENTS
      REAL          PSI    !  I  New location [deg] to be inserted
      INTEGER       IGRA   !  O  Index for new location in /GRACOM/
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  MOVGRA ! Move profiles within /GRACOM/ arrays.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      IF ( NGRA .EQ. MAXGRA ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-NEWPSI: No space to add extra horiz.location, '//
     &           'increase MAXGRA in rfmsiz.inc'
        RETURN
      END IF
      NGRA = NGRA + 1
C
C Insert PSI into ordered list (need MAX to ensure PSIGRA(0) not accessed)
      IGRA = NGRA
      DO WHILE ( IGRA .GT. 1 .AND. PSIGRA(MAX(IGRA-1,1)) .GT. PSI )
        CALL MOVGRA ( IGRA-1, IGRA )
        IGRA = IGRA - 1
      END DO
      PSIGRA(IGRA) = PSI
C
      END 
