      SUBROUTINE NTECLC ( PRE, TEM, PSI, GAMMA, ANLTE, CNLTE, SQ )
C
C VERSION
C     01JAN15 AD Add PSI argument.
C                Use Vib.Part.Fns from qfncom.inc and reorder loops.
C                Use VALINT and VALGLP instead of LOOKUP
C     25OCT02 AD Remove checks on GAS ID before calling QTNTE.
C     14DEC01 AD Set INTE=0 to avoid warning messages
C     26OCT00 AD Allow for VT=0
C     09AUG00 AD Change TEMNTE to VTKT rather than absolute VT
C     09AUG99 AD Make explicit DP components of RUPP, RLOW calc.
C     21OCT97 AD Change ANLTE,CNLTE to DOUBLE PRECISION
C     04APR97 AD Check QPRNTE flag before calc. Qtot.
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Calculate various non-LTE parameters for line
C     Called by ADJUST.
C
      IMPLICIT NONE
C
C ARGUMENTS
      REAL             PRE    !  I  Path pressure [atm]
      REAL             TEM    !  I  Path kinetic temperature [K]
      REAL             PSI    !  I  Horizontal angle (if GRA flag)
      DOUBLE PRECISION GAMMA  !  I  exp - ( hcv/kT )
      DOUBLE PRECISION ANLTE  !  O  Non-LTE Correction factor for k absorption
      DOUBLE PRECISION CNLTE  !  O  Non-LTE Correction factor for c absorption
      REAL             SQ     !  O  Ratio tot.partition sum @296K/tps@path.tem
C
      EXTERNAL
     &  QTNTE  ! Calculate total internal partition sums for non-LTE.
     &, QTFCT  ! Calculate total internal partition sums for line data.
     &, VALGLP ! Function interpolate value from (lnp,psi) atmospheric field.
     &, VALINT ! Function to linearly interpolate value from array.
      REAL VALGLP, VALINT
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'hitcom.inc' ! HITRAN line database variables
      INCLUDE 'ntecom.inc' ! Vibrational levels for Nonlte calcs
      INCLUDE 'qfncom.inc' ! non-LTE Partition Functions 
C
C LOCAL CONSTANTS 
      REAL          PRELIM          ! Press [atm] defining high alt limit
        PARAMETER ( PRELIM = 1.0E-5 )
      REAL          TEMLIM          ! Default Max Vib.Temp for high alt.emission
        PARAMETER ( TEMLIM = 275.0 )
      REAL          FACLIM          ! Min VT/KT ratio indisting. from VT=0
        PARAMETER ( FACLIM = 0.01 )
C
C LOCAL VARIABLES
      INTEGER INTE         ! Index of Non-LTE profile
      INTEGER IQFN         ! Index of Vib.Part.Fn, or 0 if none assigned
      REAL    ENBOT        ! Energy [/cm] of lower level
      REAL    ENTOP        ! Energy [/cm] of upper level
      REAL    LNP          ! Log(p/mb) for interpolating Vib.Temp. profiles
      REAL    QVTEM        ! Vib.Part.Fn for path
      REAL    TEMDEF       ! Default vibrational temperature
      REAL    VTBOT        ! Vib.Temp of lower level      
      REAL    VTTOP        ! Vib.Temp of upper level      
      DOUBLE PRECISION RLOW ! Ratio of lower state population to LTE value
      DOUBLE PRECISION RUPP ! Ratio of upper state population to LTE value
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      IF ( TEM .GT. TEMLIM .AND. PRE .LT. PRELIM ) THEN
        TEMDEF = TEMLIM
      ELSE
        TEMDEF = TEM
      END IF
      LNP = LOG ( PRE * ATMB )
C
      IF ( ILSNTE .NE. 0 ) THEN    ! lower state defined as non-LTE
        INTE = ILSNTE
        IF ( GRAFLG ) THEN
          VTBOT = VALGLP ( LNP, PSI, 'TVB', INTE ) 
        ELSE
          VTBOT = VALINT ( LNP, LNPATM, TEMNTE(1,INTE), NATM, .FALSE. )
        END IF
        VTBOT = VTBOT + TEM
        ENBOT  = ENGNTE(INTE)
      ELSE
        VTBOT = TEMDEF
        ENBOT = ELS
      END IF               
      IF ( VTBOT .GT. FACLIM * TEM ) THEN
        RLOW = DEXP ( -C2 * DBLE(ENBOT) * 
     &              DBLE(TEM-VTBOT) / DBLE(TEM*VTBOT) )
      ELSE
        RLOW = 0.0D0
      END IF
C
C Note that this routine is only called if IUSNTE and/or ILSNTE .NE. 0
C If there is no data for the top level, there must be data for the bottom
C level so assume the top level is in LTE with the bottom (RUPP=RLOW)
C
      IF ( IUSNTE .NE. 0 ) THEN      ! upper state defined as non-LTE
        INTE = IUSNTE
        IF ( GRAFLG ) THEN
          VTTOP = VALGLP ( LNP, PSI, 'TVB', INTE ) 
        ELSE
          VTTOP = VALINT ( LNP, LNPATM, TEMNTE(1,INTE), NATM, .FALSE. )
        END IF
        VTTOP = VTTOP + TEM
        ENTOP  = ENGNTE(INTE)
        IF ( VTTOP .GT. FACLIM * TEM ) THEN
          RUPP = DEXP ( -C2 * DBLE(ENTOP) * 
     &                  DBLE(TEM-VTTOP) / DBLE(TEM*VTTOP) )
        ELSE 
          RUPP = 0.0D0
        END IF
      ELSE
        RUPP = RLOW
      END IF
C
      ANLTE = ( RLOW - RUPP * GAMMA ) / ( 1.D0 - GAMMA )
      CNLTE = RUPP
C
C Partition functions - same partition function used for IUSNTE or ILSNTE
C so IQFNTE(INTE) for either INTE should point to same IQFN 
      IQFN = IQFNTE(INTE) 
      IF ( IQFN .NE. 0 ) THEN  
        IF ( GRAFLG ) THEN
          QVTEM = VALGLP ( LNP, PSI, 'QFN', IQFN ) 
        ELSE 
          QVTEM = VALINT ( LNP, LNPATM, PRFQFN(1,IQFN), NATM, .FALSE.)
        END IF
        CALL QTNTE ( IDGAS, ISO, TEM, QVTEM, SQ )
      ELSE
        CALL QTFCT ( IDGAS, ISO, TEM, SQ )
      END IF
C
      END
