      SUBROUTINE NTEDEF ( LUNNTE, NAMDEF, FAIL, ERRMSG )
C
C VERSION
C     11MAY15 AD Correction: Compare IDGNTE with IDGAS
C     17NOV14 AD Simplify by using EXPNAM and CHKFIL functions, and NAMLOG
C     23JUL03 AD Original.
C
C DESCRIPTION
C     Use default .nte filename to find any missing files.
C     Called once by INPNTE if filename template found in *NTE section of 
C     driver table.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNNTE ! I/O LUN for NTE File/next free LUN
      CHARACTER*(*) NAMDEF !  I  Default name of NTE file
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CHKFIL ! Check if argument represents an existing filename
     &, EXPNAM ! Replace '*' in filename with given string
     &, NAMLOG ! Send text plus variable length filename to log file
     &, NTEFIL ! Read NTE Vibrational Temperature Data from file
     &, RFMLOG ! Write text message to RFM log file.
      LOGICAL CHKFIL
      CHARACTER*200 EXPNAM
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'ntecom.inc' ! Non-LTE data
C
C LOCAL VARIABLES
      INTEGER       IGAS   ! Counter for absorbing species
      INTEGER       INTE   ! Counter for current NTE tabulations
      CHARACTER*80  NAMNTE ! Name of NTE file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Send message to LOG file saying which file is about to be opened
C
      CALL RFMLOG ( 'I-NTEDEF: Checking default .nte files', 
     &              FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      DO IGAS = 1, NGAS                            ! Loop over absorbers
        DO INTE = 1, NNTE                          ! Loop over NTE data
          IF ( IDGNTE(INTE) .EQ. IDXGAS(IGAS) ) GOTO 100 ! data already loaded
        END DO
C At this point, absorber found requiring .nte data but no data yet loaded
        NAMNTE = EXPNAM ( NAMDEF, CODGAS(IGAS) )
        CALL NAMLOG ( 'I-NTEDEF: looking for file: ', NAMNTE, 
     &                FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        IF ( CHKFIL ( NAMNTE ) ) THEN              ! If file exists, then read
          CALL NTEFIL ( LUNNTE, NAMNTE, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
        END IF
 100    CONTINUE
      END DO
C
      FAIL = .FALSE.
      RETURN
C
      END
