      SUBROUTINE NTEQFN ( IDG, ISO, IGRA, NLEV, LNPLEV, QFNLEV, 
     &                    FAIL, ERRMSG )
C
C VERSION
C     01JAN15 AD Change arguments. Allow for horizontal gradients.
C     20FEB01 AD Duplicte VTs to top of atmospheric profile if necessary
C     01JUL98 AD Remove IATMHI argument. Assume NTE profile always extends
C                    to top of ATM profile
C     04APR97 AD Remove FIRST argument - assume NQFN initialised elsewhere.
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     21SEP96 AD Original.
C
C DESCRIPTION
C     Store Vib.Partition Function data read from NTE file. 
C     Called by NTEFIL for each partitition function in each file.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      IDG       !  I  HITRAN ID for molecule 
      INTEGER      ISO       !  I  Isotope#
      INTEGER      IGRA      !  I  Index of horiz.location, or 0
      INTEGER      NLEV      !  I  No.of profile levels
      REAL         LNPLEV(*) !  I  ln(p/mb) profile
      REAL         QFNLEV(*) !  I  Partition Function profile
      LOGICAL      FAIL      !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG    !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  IDXQFN ! Index of non-LTE partition function data in /QFNCOM/ arrays
     &, INTERP ! General interpolation of arrays
     &, PRFGRA ! Copy single profile from /ATMCOM/ to /GRACOM/.
      INTEGER IDXQFN
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
      INCLUDE 'qfncom.inc' ! non-LTE Partition Functions 
C
C LOCAL VARIABLES
      INTEGER      IGAS    ! Index of GAS in RFM list /GASCOM/
      INTEGER      IQFN    ! Counter for Stored Partition Function profiles
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      FAIL   = .FALSE.
C
C Check partition function for molecule,isotope not already loaded
      IQFN = IDXQFN ( IDG, ISO )
      IF ( IQFN .EQ. 0 ) THEN
C Check sufficient space to add to list
        IF ( NQFN .EQ. MAXQFN ) THEN
          FAIL = .TRUE.
          WRITE ( ERRMSG, '(A,I11)' ) 
     &      'F-NTEQFN: No.Different Vib.Part.Fns > '//
     &      'MAXQFN in rfmsiz.inc,=', MAXQFN
          RETURN
        END IF 
C Increment NQFN and add molecule,isotope to list 
        NQFN = NQFN + 1
        IDGQFN(NQFN) = IDG
        ISOQFN(NQFN) = ISO
        IQFN = NQFN 
      ELSE IF ( .NOT. GRAFLG .OR. 
     &          ( GRAFLG .AND. FLQGRA(IGRA,IQFN) ) ) THEN
        WRITE ( ERRMSG, '(A,I11)' )
     &    'F-NTEQFN: Duplicate NTE Vib.Partition Fn for Gas='//
     &    CODGAS(IGAS)//' Iso#=', ISO
        FAIL = .TRUE.
        RETURN
      END IF
C
C LNPATM should have been interpolated for current PSI location
      CALL INTERP ( NLEV, NATM, LNPLEV, LNPATM, QFNLEV, 
     &              .FALSE., .FALSE., PRFQFN(1,IQFN) ) 
C
      IF ( GRAFLG ) CALL PRFGRA ( IGRA, 'Q', IQFN ) 
C
      END
