      SUBROUTINE NTETEM ( IDG, ISO, IGQ, IGRA, IATMLO, 
     &                    NLEV, LNPLEV, TEMLEV, ENG, FAIL, ERRMSG )
C
C VERSION
C     01JAN15 AD Rewritten, different arguments.
C     09JAN08 AD Set IDXVIB and allow for some VT preloaded in ATM section
C     20FEB01 AD Duplicte VTs to top of atmospheric profile if necessary
C     09AUG00 AD Store VTs as differences from KTs rather than absolute
C     01JUL98 AD Remove IATMHI argument. Assume NTE profile always extends
C                    to top of ATM profile
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     21SEP96 AD Original.
C
C DESCRIPTION
C     Store Vib.Temp profiles read from NTE file.
C     Called by NTEFIL for each Vib.Temp profile in .nte file.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      IDG       !  I  HITRAN ID for molecule
      INTEGER      ISO       !  I  Isotope#
      INTEGER      IGQ       !  I  Global Quantum#
      INTEGER      IGRA      !  I  Index of horiz.location, or 0
      INTEGER      IATMLO    !  I  Lower index of ATM profile for interpolatn.
      INTEGER      NLEV      !  I  No.of profile levels
      REAL         LNPLEV(*) !  I  ln(p/mb) profile
      REAL         TEMLEV(*) !  I  Vib.Temp difference profile [K]
      REAL         ENG       !  I  Energy [cm-1 of Vib.level
      LOGICAL      FAIL      !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG    !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  IDXNTE ! Index of Vib.Temp data in /NTECOM/ arrays
     &, INTERP ! General interpolation of arrays
     &, PRFGRA ! Copy single profile from /ATMCOM/ to /GRACOM/.
     &, RFMLOG ! Write text message to RFM log file.
      INTEGER IDXNTE
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
      INCLUDE 'ntecom.inc' ! Non-LTE data 
C
C LOCAL VARIABLES
      INTEGER      IATM    ! Counter for atmospheric profile levels
      INTEGER      IGAS    ! Index of GAS in RFM list /GASCOM/
      INTEGER      INTE    ! Counter for NTE Vib.Temp profiles
      CHARACTER*80 MESSGE  ! Warning message sent to log file
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      FAIL   = .FALSE.
C
C Check not already loaded. Files INTE=1:MNTE have been preloaded in the *ATM
C section - assume that these have precedence so just issue warning if 
C duplicated. However there should be no duplicates within the *NTE section
C
      INTE = IDXNTE ( IDG, ISO, IGQ )
      IF ( INTE .EQ. 0 ) THEN 
        IF ( NNTE .EQ. MAXNTE ) THEN
          FAIL = .TRUE.
          WRITE ( ERRMSG, '(A,I11)' )
     &      'F-NTETEM: No.Different Vib.Temp profiles > '//
     &      'MAXNTE in rfmsiz.inc,=', MAXNTE
          RETURN
        END IF
C Add to list
        NNTE = NNTE + 1
        IDGNTE(NNTE) = IDG
        ISONTE(NNTE) = ISO
        IGQNTE(NNTE) = IGQ
        ENGNTE(NNTE) = ENG
        IQFNTE(NNTE) = 0         ! may be assigned later by ALLQFN
        INTE = NNTE
      ELSE IF ( INTE .LE. MNTE ) THEN     ! don't overwrite VT from ATM section
          WRITE ( MESSGE, '(A,A7,A,I1,A,I2,A)' ) 
     &      'W-NTETEM: ignore VT for gas=', CODGAS(IGAS), 
     &      ', iso=', ISO, ' GQIdx=', IGQ, 
     &      ' - preloaded in *ATM section'
          CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
          RETURN
      ELSE IF ( IGRA .EQ. 0 .OR. 
     &            ( IGRA .GT. 0 .AND. FLNGRA(IGRA,INTE) ) ) THEN
          FAIL = .TRUE.
          WRITE ( ERRMSG, '(A,A,A,I2,A,I11)' )
     &     'F-NTETEM: Repeated Vib.Tem profile for gas=', 
     &     CODGAS(IGAS), ', ISO#=', ISO, ', GQIdx=', IGQ
          RETURN
      END IF
C
C Interpolate to atmospheric profile
C Assume VT=KT below specified VT profile
      CALL INTERP ( NLEV, NATM, LNPLEV, LNPATM, TEMLEV, 
     &              .FALSE., .FALSE., TEMNTE(1,INTE) )
      DO IATM = 1, IATMLO-1
        TEMNTE(IATM,INTE) = 0.0
      END DO
C
      IF ( IGRA .GT. 0 ) CALL PRFGRA ( IGRA, 'N', INTE ) 
C
      END
