      SUBROUTINE NXTLAB ( LUN, LABEL, RECORD, FAIL, ERRMSG )
C
C VERSION
C     24SEP15 AD Also skip empty records
C     14JUL15 AD Also test for end-of-file
C     01JAN15 AD Original.
C
C DESCRIPTION
C     Load next label from RFM .atm file
C     Called multiply by ATMFIL.
C     A label is defined as the first field in a record starting with '*'
C     Labels are converted to lower case
C     Also skips any records beginning with '!'.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUN     !  I  Logical Unit Number
      CHARACTER*(*) LABEL   !  O  Label
      CHARACTER*(*) RECORD  !  O  Full record containing label
      LOGICAL       FAIL    !  O  T=Fatal error detected
      CHARACTER*80  ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  LOCASE ! Convert text string to lower case
     &, RFMLOG ! Write text message to RFM log file.
     &, TXTFLD ! Identify start and end points of text field in record
C
C LOCAL VARIABLES
      INTEGER       ISTA    ! Pointer to start of label
      INTEGER       IEND    ! Pointer to end of label
      INTEGER       IOS     ! Saved value of IOSTAT for error message
      CHARACTER*80  WRNMSG  ! Warning message
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      FAIL = .TRUE.
      RECORD(1:1) = '!'
      DO WHILE ( RECORD(1:1) .EQ. '!' .OR. RECORD .EQ. ' ' )
        READ ( LUN, '(A80)', IOSTAT=IOS, ERR=900, END=800 ) RECORD
      END DO
      IF ( RECORD(1:1) .EQ. '*' ) THEN
        CALL TXTFLD ( LEN(RECORD), RECORD, 1, ISTA, IEND )
        LABEL = RECORD(1:IEND)
        CALL LOCASE ( LABEL, LABEL ) 
        FAIL = .FALSE.
      ELSE
        ERRMSG = 'F-NXTLAB: Unexpected record: '//RECORD(1:48)//'...'
      END IF
C
      RETURN
C
  800 LABEL = '*end'
      WRNMSG = 'W-NXTLAB: .atm file not properly terminated with '//
     &         '*END record - end assumed'
      CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
      RETURN
C
  900 WRITE ( ERRMSG, '(A,I11)' )
     &  'F-NXTLAB: Failed to read next record of file. IOSTAT=', IOS
C
      END
