      SUBROUTINE OPNOUT ( LUNNXT, ISPC, TITLE, NAMTMP, 
     &                    FAIL, ERRMSG )
C
C VERSION
C     21JUL15 AD Rewritten and simplified using OUTHDR.
C                NFLOUT no longer passed as an argument
C     09JAN15 AD Remove JACNAM, LOSNAM, use modified MAKNAM instead.
C                Add STASTR, FORSTR. Use C9FLT.
C     20SEP12 AD Change NAMTMP, NAMFIL, NAMLOW from C*80 to C*200
C     04APR06 AD Change 'X' to '1X' in output format
C     06JAN04 AD Add IGRA argument to MAKNAM
C     01JAN04 AD Add LEV flags
C     09AUG03 AD Allow for GHZ option
C     15AUG02 AD Correct previous modifications to preserve LUN ordering
C     20JUL02 AD Add NFLOUT argument, revise handling of LUNs
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Open spectral output files for current spectral range
C     Called by RFMOPN for each spectral range
C     Sequence of LUN assignments is:
C        TAN#1, TAN#2, ... TAN#NTAN, 
C        dTAN#1/dJAC#1, dTAN#2/dJAC#1, ... dTAN#NTAN/dJAC#1
C        ...
C        dTAN#1/dJAC#NJAC, dTAN#2/dJAC#NJAC, ... dTAN#NTAN/dJAC#NJAC
C        dTAN#1/dLOS, dTAN#2/dLOS, ... dTAN#NTAN/dLOS
C     This matches output sequence in RFMWRT. 
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNNXT  ! I/O Next available LUN
      INTEGER       ISPC    !  I  Spectral range index 
      CHARACTER*(*) TITLE   !  I  Code for output type
      CHARACTER*200 NAMTMP  ! I/O Filename template (converted to lower case)
      LOGICAL       FAIL    !  O  Set TRUE if a fatal error occurs
      CHARACTER*80  ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  C9FLT  ! Write real number as C*9 string up to 3 s.f.
     &, JACHDR ! Construct Jacobian header record
     &, LOCASE ! Convert text string to lower case.
     &, MAKNAM ! Construct filename for RFM output files.
     &, OUTHDR ! Open spectral output files and write header records
      CHARACTER*9 C9FLT
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'jaccom.inc' ! Jacobian data
      INCLUDE 'outcom.inc' ! RFM output file data
      INCLUDE 'tancom.inc' ! Tangent heights
C
C LOCAL VARIABLES
      INTEGER       IJAC   ! Counter for Jacobian elements
      INTEGER       IPT    ! Pointer to start of substring
      INTEGER       ITAN   ! Tangent height counter
      CHARACTER*80  HEADR1 ! 1st Header record for output files
      CHARACTER*80  HEADR2 ! Header from driver table *HDR section
      CHARACTER*80  HEADR3 ! titles, or Jacobian information (JACFLG)
      CHARACTER*15  LABEL  ! Label for output data 
      CHARACTER*200 NAMFIL ! Name of file actually opened (incl. RUNID)
      CHARACTER*200 NAMLOW ! Lower case version of filename 
      CHARACTER*32  PTHTXT ! Text describing viewing geometry
      CHARACTER*13  TYPTXT ! Text describing type of spectrum
      CHARACTER*10  WNOGHZ ! 'Wavenumber' or 'Frequency ' in HEADR3
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      CALL LOCASE ( NAMTMP, NAMLOW )
C
C Convert '.asc' to '.bin' in filename, or vice-versa, if appropriate 
      IF ( BINFLG ) THEN
        IPT = INDEX ( NAMLOW, '.asc' )
        IF ( IPT .NE. 0 ) NAMTMP(IPT:IPT+3) = '.bin'
      ELSE
        IPT = INDEX ( NAMLOW, '.bin' )
        IF ( IPT .NE. 0 ) NAMTMP(IPT:IPT+3) = '.asc'
      END IF
C
C Set according to whether output is in wavenumber or GHz
      IF ( GHZFLG ) THEN
        WNOGHZ = 'Frequency '
      ELSE
        WNOGHZ = 'Wavenumber'
      END IF
C
C Set header records for output files ('123456789' replaced by tangent height)
      TYPTXT = TITLE
      IF ( HOMFLG ) THEN
        PTHTXT = 'Homog. Path Length =123456789 km'
      ELSE IF ( FLXFLG ) THEN
        PTHTXT = 'for Altitude Level =123456789 km' 
      ELSE IF ( NADFLG ) THEN
        PTHTXT = 'Nadir Path Airmass =123456789   '
      ELSE IF ( ZENFLG ) THEN
        PTHTXT = 'Zenith Path Airmass=123456789   '
      ELSE IF ( USRELE ) THEN
        PTHTXT = 'View Elevation Ang.=123456789 dg'
      ELSE IF ( USRGEO ) THEN
        PTHTXT = 'Limb Geom.Tang.Hgt =123456789 km'
      ELSE                                    ! Normal limb-viewing geometry
        PTHTXT = 'Limb Path Tang.Hgt =123456789 km'
      END IF
      IF ( FLXFLG ) THEN
        HEADR1 = '! Flux '//TYPTXT//' calc.'//PTHTXT//
     &           ' by RFM v.'//VERSN
      ELSE
        HEADR1 = '! '//TYPTXT//' calc. for '//PTHTXT//
     &           ' by RFM v.'//VERSN
      END IF
      IPT = INDEX ( HEADR1, '123456789' )
C
      HEADR2 = '!'//TXTHDR
C Note that HEADR3 is modified by JACHDR if JAC,MTX,LEV flags enabled 
      HEADR3 = '!No.Pts  Lower_'//WNOGHZ//'   Delta_'//WNOGHZ//'  '//
     &         'Upper_'//WNOGHZ//'  Label'
C
C LABEL field in output file header includes single quotes
      IF ( LABOUT .EQ. ' ' ) THEN   ! No spectral range label,so use type label
        LABEL = ''''//TITLE//''''
      ELSE 
        LABEL = ''''//LABOUT//''''
      END IF
C
C Standard set of output spectra
      DO ITAN = 1, NTAN       
        CALL MAKNAM ( ISPC, 0, ITAN, 0, 0, NAMTMP, NAMFIL )
        HEADR1(IPT:IPT+8) = C9FLT ( USRTAN(ITAN) ) 
        CALL OUTHDR ( LUNNXT, NAMFIL, HEADR1, HEADR2, HEADR3, LABEL,
     &                FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END DO
C
C Tangent-pt Jacobian spectra - one tangent height for each Jacobian
      IF ( JTPFLG ) THEN
        DO IJAC = 1, NJAC
          ITAN = JTPJAC(IJAC)
          CALL MAKNAM ( ISPC, 0, ITAN, 0, IJAC, NAMTMP, NAMFIL )
          HEADR1(IPT:IPT+8) = C9FLT ( USRTAN(ITAN) ) 
          CALL JACHDR ( IJAC, ITAN, HEADR3 )
          CALL OUTHDR ( LUNNXT, NAMFIL, HEADR1, HEADR2, HEADR3, LABEL,
     &                  FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END DO
C
C Full Jacobians or Matrix outputs - every combination of tan.ht*Jac.
C in sequence tan#1,jac#1, tan#2,jac#1, ... tan#1,jac#2 etc
      ELSE IF ( JACFLG .OR. MTXFLG ) THEN
        DO IJAC = 1, NJAC
          DO ITAN = 1, NTAN
            CALL MAKNAM ( ISPC, 0, ITAN, 0, IJAC, NAMTMP, NAMFIL )
            HEADR1(IPT:IPT+8) = C9FLT ( USRTAN(ITAN) ) 
            CALL JACHDR ( IJAC, ITAN, HEADR3 ) 
            CALL OUTHDR ( LUNNXT, NAMFIL, HEADR1, HEADR2, HEADR3, LABEL,
     &                    FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          END DO
        END DO
C
C If calculating intermediate output levels, variable number of outputs for
C each nominal tangent path (unlike Jacobians)
      ELSE IF ( LEVFLG ) THEN
        DO IJAC = 1, NJAC
          DO ITAN = 1, NTAN
            IF ( ITNJAC(ITAN,IJAC) .NE. 0 ) THEN
              CALL MAKNAM ( ISPC, 0, ITAN, 0, IJAC, NAMTMP, NAMFIL )
              HEADR1(IPT:IPT+8) = C9FLT ( USRTAN(ITAN) ) 
              CALL JACHDR ( IJAC, ITAN, HEADR3 ) 
              CALL OUTHDR ( LUNNXT, NAMFIL, HEADR1, HEADR2, HEADR3,
     &                      LABEL, FAIL, ERRMSG )
              IF ( FAIL ) RETURN
            END IF
          END DO
        END DO
      END IF
C
C If calculating pointing Jacobians, open file for each tangent altitude
      IF ( LOSFLG ) THEN
        DO ITAN = 1, NTAN
          CALL MAKNAM ( ISPC, 0, ITAN, 0, -1, NAMTMP, NAMFIL )
          HEADR1(IPT:IPT+8) = C9FLT ( USRTAN(ITAN) ) 
          CALL JACHDR ( -1, ITAN, HEADR3 ) 
          CALL OUTHDR ( LUNNXT, NAMFIL, HEADR1, HEADR2, HEADR3, LABEL,
     &                  FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END DO
      END IF
C
C Normal exit
      FAIL = .FALSE.
C
      END
