      SUBROUTINE OPNTAB ( LUNNXT, ISPC, FAIL, ERRMSG )
C
C VERSION
C     13JUL15 AD Use NAMGAS. Assign IDX and avoid repeating ISO id in header.
C     09APR15 AD Assume VMRTAB already in [ppmv] (from TABPTH)
C     08JAN15 AD Extra argument for MAKNAM
C     12DEC14 AD Add Format number to output
C     04NOV14 AD Add DV to output header (from WNRSPC)
C                Remove redundant constant WNOTOL
C     16JAN14 AD New output format
C     07AUG13 AD Remove redundant local variable IISO
C     23MAY06 AD Put format statement on to single line
C     06APR06 AD Change 'X' to '1X' in format
C     31OCT97 AD Original.
C
C DESCRIPTION
C     Open TAB files for current spectral range
C     Called by RFMOPN for each spectral range.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNNXT  ! I/O Next available LUN
      INTEGER      ISPC    !  I  Spectral range index
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error occurs
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  LOCASE ! Convert text string to lower case.
     &, MAKNAM ! Construct filename for RFM output files.
     &, NAMGAS ! Return molecular name associated with /GASCOM/ index
     &, RFMLOG ! Write text message to RFM log file.
      CHARACTER*7 NAMGAS
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'rfmcon.inc' ! Constants for RFM calculations
C
C LOCAL CONSTANTS
      REAL   RFMT                 ! .tab file format identifier
        PARAMETER ( RFMT = 1.0 ) 
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'grdcom.inc' ! Irregular grid
      INCLUDE 'outcom.inc' ! RFM output file data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
      INCLUDE 'tabcom.inc' ! Table axes for tabulated absorb.coeffs.
C
C LOCAL VARIABLES
      INTEGER       I      ! Counter for axis values
      INTEGER       IDX    ! HITRAN index of molecule
      INTEGER       IFACT  ! Sign for NTTAB in output file
      INTEGER       IGAS   ! Absorber counter
      INTEGER       IOS    ! Value of IOSTAT saved for error messages.
      INTEGER       IPT    ! Pointer to start of substring
      INTEGER       ISGNNV ! +1 for WNo output, -1 for GHz output
      INTEGER       LUN    ! Local value of Logical Unit Number.
      INTEGER       NWNO   ! No.of wavenumber pts to be output (-ve if irreg)
      CHARACTER*9   CODTAB ! Gas code + optional isotopic ID (eg 'i1')
      CHARACTER*11  FORSTR ! FORMAT keyword in OPEN: 'FORMATTED', 'UNFORMATTED'
      CHARACTER*5   GASSTR ! Molecule ID, incl. isotope
      CHARACTER*80  HEADR1 ! Header record for output files
      CHARACTER*80  HEADR2 !
      CHARACTER*80  HEADR3 ! 
      CHARACTER*80  HEADR4 ! Format identifier
      CHARACTER*80  HEADR5 ! Molec/Iso ID, spec range and axis sizes 
      CHARACTER*132 MESSGE ! Text message sent to Log file.
      CHARACTER*80  NAMFIL ! Name of file actually opened (incl. RUNID)
      CHARACTER*80  NAMLOW ! Lower-case version of NAMTAB
      CHARACTER*7   STASTR ! STATUS keyword in OPEN: 'NEW' or 'UNKNOWN'
      DOUBLE PRECISION GHZFAC ! Factor to convert WNo to GHz if required
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      CALL LOCASE ( NAMTAB, NAMLOW )
C
C Convert '.asc' to '.bin' in filename, or vice-versa, if appropriate
      IF ( BINFLG ) THEN
        IPT = INDEX ( NAMLOW, '.asc' )
        IF ( IPT .NE. 0 ) NAMTAB(IPT:IPT+3) = '.bin'
      ELSE
        IPT = INDEX ( NAMLOW, '.bin' )
        IF ( IPT .NE. 0 ) NAMTAB(IPT:IPT+3) = '.asc'
      END IF
C
      IF ( GRDFLG ) THEN
        NWNO = NGRD
      ELSE 
        NWNO = NPTOUT
      END IF
C
      IF ( GHZFLG ) THEN
        ISGNNV = -1
        GHZFAC = VLIGHT * 1.0D-7         ! VLIGHT in phycon.inc
      ELSE
        ISGNNV = 1
        GHZFAC = 1.0D0
      END IF
C
      IFACT = 1
      IF ( OFFTAB ) IFACT = -1 
C
      LUNTAB = LUNNXT 
      LUNNXT = LUNNXT + NGAS         ! NGAS files will be created
      STASTR = 'UNKNOWN'
      IF ( NEWFLG ) STASTR = 'NEW'
      FORSTR = 'FORMATTED'
      IF ( BINFLG ) FORSTR = 'UNFORMATTED'
      DO IGAS = 1, NGAS
        LUN = LUNTAB + ( IGAS - 1 ) 
        CALL MAKNAM ( ISPC, IGAS, 0, 0, 0, NAMTAB, NAMFIL )
        MESSGE = 'I-OPNTAB: Opening output file: '//NAMFIL
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        OPEN ( UNIT=LUN, FILE=NAMFIL, STATUS=STASTR,
     &             FORM=FORSTR, IOSTAT=IOS, ERR=900 )
C
        CODTAB = NAMGAS ( IGAS, IPT ) 
        HEADR1 = '! '//CODTAB//
     &           ' Tabulated Absorp.Coeff. '
     &           //'created by RFM v.'// VERSN//'                '
        HEADR2 = '!'//TXTHDR(1:79)
        HEADR3 = '! GAS        NV      V1          V2        DV'//
     &    '        NA      NP      NT      NQ'
C
        WRITE ( HEADR4, '(F10.2)' ) RFMT
C
C Find out if this gas has been split into isotopes
        IDX = IDXGAS(IGAS)
        IF ( ISOMOL(IDX) ) THEN
          WRITE ( GASSTR, '(I2,A,I1)' ) IDXGAS(IGAS), '.', IDIGAS(IGAS)
        ELSE
          WRITE ( GASSTR, '(I5)' ) IDXGAS(IGAS)
        END IF
        WRITE ( HEADR5, '(A5,I10,2F12.4,F8.4,4I8)' ) 
     &      GASSTR, NWNO*ISGNNV, GHZFAC*WNLSPC(ISPC), 
     &      GHZFAC*WNUSPC(ISPC), GHZFAC*WNRSPC(ISPC), NATAB, NPTAB, 
     &      IFACT*NTTAB, NQTAB
C
        IF ( BINFLG ) THEN
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) HEADR1
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) HEADR2
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) HEADR3
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) HEADR4
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) HEADR5
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) ( PAXTAB(I), I = 1,NPTAB )
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) ( TEMTAB(I), I = 1,NPTAB )
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) 
     &      ( VMRTAB(I,IGAS), I = 1, NPTAB )    ! [ppmv]
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) ( TAXTAB(I), I = 1,NTTAB )
          WRITE ( LUN, IOSTAT=IOS, ERR=900 ) ( QAXTAB(I), I = 1,NQTAB )
        ELSE
          WRITE ( LUN, '(A)', IOSTAT=IOS, ERR=900 ) HEADR1
          WRITE ( LUN, '(A)', IOSTAT=IOS, ERR=900 ) HEADR2
          WRITE ( LUN, '(A)', IOSTAT=IOS, ERR=900 ) HEADR3
          WRITE ( LUN, '(A)', IOSTAT=IOS, ERR=900 ) HEADR4
          WRITE ( LUN, '(A)', IOSTAT=IOS, ERR=900 ) HEADR5
          WRITE ( LUN, *, IOSTAT=IOS, ERR=900 ) ( PAXTAB(I),I=1,NPTAB )
          WRITE ( LUN, *, IOSTAT=IOS, ERR=900 ) ( TEMTAB(I),I=1,NPTAB )
          WRITE ( LUN, *, IOSTAT=IOS, ERR=900 ) 
     &      ( VMRTAB(I,IGAS), I = 1, NPTAB )    ! [ppmv]
          WRITE ( LUN, *, IOSTAT=IOS, ERR=900 ) ( TAXTAB(I),I=1,NTTAB )
          WRITE ( LUN, *, IOSTAT=IOS, ERR=900 ) ( QAXTAB(I),I=1,NQTAB )
        END IF
      END DO
C
      FAIL = .FALSE.
      RETURN
C
  900 FAIL = .TRUE.
      WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-OPNTAB: I/O failure on output file. IOSTAT=', IOS
      END
