      SUBROUTINE OUTHDR ( LUN, NAMFIL, HEADR1, HEADR2, HEADR3, LABEL,
     &                    FAIL, ERRMSG )
C
C VERSION
C     21JUL15 AD Original. Extracted from OPNOUT.
C
C DESCRIPTION
C     Open spectral output files and write header records
C     Called by OPNOUT for each file
C     If LUN flag enabled, 
C       the file is closed, 
C       NFLOUT in /OUTCOM/ incremented and checked against MAXOUT
C       NAMFIL stored in /OUTCOM/FILOUT(NFLOUT)
C     Else 
C       the file is kept open
C       LUN incremented by 1.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUN    ! I/O LUN for output
      CHARACTER*(*) NAMFIL !  I  Name of file 
      CHARACTER*80  HEADR1 !  I  Header record#1 for output files
      CHARACTER*80  HEADR2 !  I  Header record#1 for output files
      CHARACTER*80  HEADR3 !  I  Header record#1 for output files
      CHARACTER*(*) LABEL  !  I  Label for type of output spectrum
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error occurs
      CHARACTER*80  ERRMSG !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  NAMLOG ! Send text plus variable length filename to log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'outcom.inc' ! RFM output file data
C
C LOCAL VARIABLES
      INTEGER       IOS    ! Value of IOSTAT saved for error messages.
      CHARACTER*11  FORSTR ! Value for FORM keyword in OPEN statement
      CHARACTER*7   STASTR ! Value for STATUS keyword in OPEN statement
      DOUBLE PRECISION GHZFAC ! Wno to GHz conversion factor
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      CALL NAMLOG ( 'I-OUTHDR: Opening output file: ', NAMFIL, 
     &              FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
C Open file with appropriate STATUS, FORM according to NEWFLG, BINFLG
      IF ( NEWFLG ) THEN
        STASTR = 'NEW' 
      ELSE 
        STASTR = 'UNKNOWN'
      END IF
      IF ( BINFLG ) THEN
        FORSTR = 'UNFORMATTED' 
      ELSE 
        FORSTR = 'FORMATTED'
      END IF
      OPEN ( UNIT=LUN, FILE=NAMFIL, STATUS=STASTR,
     &       FORM=FORSTR, IOSTAT=IOS, ERR=900 )
C
C Conversion factor from [cm-1] to [GHz] if required
      IF ( GHZFLG ) THEN
        GHZFAC = VLIGHT * 1.0D-7
      ELSE
        GHZFAC = 1.0D0
      END IF
C
      IF ( BINFLG ) THEN
        WRITE ( LUN, IOSTAT=IOS, ERR=900 ) HEADR1
        WRITE ( LUN, IOSTAT=IOS, ERR=900 ) HEADR2
        WRITE ( LUN, IOSTAT=IOS, ERR=900 ) HEADR3
        WRITE ( LUN, IOSTAT=IOS, ERR=900 )
     &    NPTOUT, WNLOUT*GHZFAC, WNROUT*GHZFAC, WNUOUT*GHZFAC, LABEL
      ELSE
        WRITE ( LUN, '(A)', IOSTAT=IOS, ERR=900 ) HEADR1
        WRITE ( LUN, '(A)', IOSTAT=IOS, ERR=900 ) HEADR2
        WRITE ( LUN, '(A)', IOSTAT=IOS, ERR=900 ) HEADR3
        WRITE ( LUN, '(I7, 3F18.10, 1X, A)', IOSTAT=IOS, ERR=900)
     &    NPTOUT, WNLOUT*GHZFAC, WNROUT*GHZFAC, WNUOUT*GHZFAC, LABEL
      END IF
C
      IF ( LUNFLG ) THEN
        CLOSE ( LUN, IOSTAT=IOS, ERR=900 )
        NFLOUT = NFLOUT + 1
        IF ( NFLOUT .GT. MAXOUT ) THEN
          WRITE ( ERRMSG, '(A,I11)' ) 'F-OUTHDR: No.output files '//
     &      '> MAXOUT in rfmsiz.inc, =', MAXOUT
          FAIL = .TRUE.
          RETURN
        END IF
        FILOUT(NFLOUT) = NAMFIL
      ELSE
        LUN = LUN + 1
      END IF
C
C Normal exit
      FAIL = .FALSE.
      RETURN
C
C Exit with fatal I/O error
  900 FAIL = .TRUE.
      WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-OUTHDR: I/O failure on output file. IOSTAT=', IOS
C
      END
