      SUBROUTINE PARVAL ( RECORD, PARAM, VALUE, FAIL, ERRMSG )
C
C VERSION
C     12FEB14 AD Original.
C
C DESCRIPTION
C     Extract Parameter and Value strings from record
C     Called by INPPHY for each record in *PHY section.
C     This parses a RECORD containing two contiguous (ie no internal spaces)
C     strings separated by a '=' sign. Spaces may be inserted before or after
C     each of the two strings.
C
      IMPLICIT NONE
C
C ARGUMENTS
      CHARACTER*(*) RECORD !  I  Record from Driver File
      CHARACTER*(*) PARAM  !  O  PARAM extracted from record
      CHARACTER*(*) VALUE  !  O  VALUE extracted from record
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
C LOCAL VARIABLES
      INTEGER       IPT    ! Location of '=' sign in record
      INTEGER       I,J    ! Pointers to start/end of substrings
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      PARAM = ' '
      VALUE = ' ' 
C
      IPT = INDEX ( RECORD, '=' )
      IF ( IPT .LT. 1 .OR. IPT .GT. LEN ( RECORD ) -1 ) THEN
        ERRMSG = 'F-PARVAL: Record not of form PARAM=VALUE'
        FAIL = .TRUE.
        RETURN
      END IF
C
C Extract PARAM string, removing leading and trailing spaces
      I = 1
      DO WHILE ( RECORD(I:I) .EQ. ' ' )
        I = I + 1
      END DO
      J = IPT-1
      DO WHILE ( RECORD(J:J) .EQ. ' ' .AND. J .GT. I )
        J = J - 1
      END DO
      FAIL = .TRUE.
      IF ( J .LT. I ) THEN
        ERRMSG = 'F-PARVAL: No ''PARAM'' string in PARAM=VALUE record'
      ELSE IF ( J - I + 1 .GT. LEN ( PARAM ) ) THEN
        ERRMSG = 'F-PARVAL: PARAM longer than available string, ='//
     &           RECORD(I:MIN(J,I+19))
      ELSE
        PARAM = RECORD(I:J)
        FAIL = .FALSE.
      END IF
      IF ( FAIL ) RETURN
C
C Extract VALUE string, removing leading and trailing spaces
      J = LEN ( RECORD ) 
      DO WHILE ( RECORD(J:J) .EQ. ' ' .OR. 
     &           ICHAR(RECORD(J:J)) .EQ. 13 )    ! also skip any '<CR>'
        J = J - 1
      END DO
      I = IPT+1
      DO WHILE ( RECORD(I:I) .EQ. ' ' .AND. I .LT. J )
        I = I + 1
      END DO
      FAIL = .TRUE.
      IF ( J .LT. I ) THEN
        ERRMSG = 'F-PARVAL: No ''VALUE'' string in PARAM=VALUE record'
      ELSE IF ( J - I + 1 .GT. LEN ( VALUE ) ) THEN
        ERRMSG = 'F-PARVAL: VALUE longer than available string, ='//
     &           RECORD(I:MIN(J,I+19))
      ELSE
        VALUE = RECORD(I:J)
        FAIL = .FALSE.
      END IF
C
      END
