      SUBROUTINE PLANCK ( TEM, NWNO, WNOLST, EMS )
C
C VERSION
C     06JAN15 AD Tidied up
C     26MAY00 AD Convert EMS from SP to DP
C     09AUG99 AD Use local D.P. DARGMN instead of S.P. ARGMIN 
C                  Make explicit EMS = SNGL( ) 
C     15DEC98 AD Avoid for zero divide if Wno=0.0
C     29JUL98 AD Check for overflows for low temperatures
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Calculate Planck emission spectrum at specified temperature
C     Called by FLXTRA, RADSFC, RADSPA, RFMFLX, RFMRAD.
C
      IMPLICIT NONE
C
C ARGUMENTS 
      REAL             TEM          ! Temperature [K]
      INTEGER          NWNO         ! No.of wavenumber points
      DOUBLE PRECISION WNOLST(NWNO) !  List of wavenumbers [/cm]
      DOUBLE PRECISION EMS(NWNO)    !  Planck emission 
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C LOCAL CONSTANTS
      DOUBLE PRECISION DARGMN   ! Minimum value for argument of exponent.
        PARAMETER ( DARGMN = 1.0D-38 )
C
C LOCAL VARIABLES
      INTEGER          IWNO  ! Wavenumber counter
      DOUBLE PRECISION ARG   ! Intermediate calculation
      DOUBLE PRECISION EFACT ! Term for exponential 
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C Limit temperature to a minimum value of 1e-38/Wmax/C2 so that argument of 
C exponent is limited to magnitude of 1e-38
      EFACT = -C2 / MAX ( DBLE(TEM), DARGMN*WNOLST(NWNO)*C2 )
      DO IWNO = 1, NWNO
        ARG = EXP ( EFACT * WNOLST(IWNO) )
        EMS(IWNO) = C1 * WNOLST(IWNO)**3 * ARG 
     &              / MAX ( 1.0D0 - ARG, DARGMN )
      END DO
C
      END 
