      SUBROUTINE PTBVIB ( IJAC )
C
C VERSION
C     01JAN15 AD Rewritten, assume argument +/- IJAC. Also perturb TVBGRA 
C     03MAY05 AD Original.
C
C DESCRIPTION
C     Perturb/unperturb VT profiles for Jacobian calc.
C     Called by ADJUST for each perturbed VT path element
C     If IJAC > 0 adds perturbation, if IJAC < 0 subtracts perturbation
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      IJAC    !  I  Index of VT Jacobian 
C
C GLOBAL CONSTANTS
      INCLUDE 'jdxcon.inc' ! Indices for non-VMR Jacobians
      INCLUDE 'rfmcon.inc' ! Constants for RFM calculations
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
      INCLUDE 'jaccom.inc' ! Jacobian data
      INCLUDE 'ntecom.inc' ! Non-LTE data
C
C LOCAL VARIABLES
      INTEGER  IATM   ! Atmospheric level counter
      INTEGER  IGRA   ! Index for horizontal locations in /GRACOM/
      INTEGER  ILOW   ! Atmospheric level# just below perturbed levels
      INTEGER  INTE   ! Index of vibrational temperature profile
      INTEGER  IPTB   ! Atmospheric level# of Jacobian retrieval element
      INTEGER  ISGN   ! Sign of perturbation (+1 or -1)
      INTEGER  IUPP   ! Atmospheric level# just above perturbed levels
      LOGICAL  LOWCOL ! True=all lower levels treated as column perturbation
      LOGICAL  UPPCOL ! True=all upper levels treated as column perturbation
      REAL     FACTOR ! Scaling factor for perturbation at atmos.level
      REAL     PTB    ! Temperature perturbation at one level
C
C EXECUTABLE CODE ------------------------------------------------------------
C
      ISGN = SIGN ( 1, IJAC ) 
      IJAC = ABS ( IJAC ) 
C
      INTE = IGSJAC(IJAC) - ( MAXGAS + JDXNTE )
      IPTB = IATJAC(IJAC)
      ILOW = ILOJAC(IJAC)
      IUPP = IUPJAC(IJAC)
      LOWCOL = ILOW .EQ. 0
      UPPCOL = IUPP .EQ. NATM+1 
      DO IATM = ILOW+1, IUPP-1
        FACTOR = 1.0
        IF ( IATM .LT. IPTB .AND. .NOT. LOWCOL ) THEN
          FACTOR = ( HGTATM(IATM) - HGTATM(ILOW) ) /
     &             ( HGTATM(IPTB) - HGTATM(ILOW) )
        ELSE IF ( IATM .GT. IPTB .AND. .NOT. UPPCOL ) THEN
          FACTOR = ( HGTATM(IUPP) - HGTATM(IATM) ) /
     &             ( HGTATM(IUPP) - HGTATM(IPTB) )
        END IF
        PTB = ISGN * FACTOR * PTBNTE
        TEMNTE(IATM,INTE) = TEMNTE(IATM,INTE) + PTB
        IF ( GRAFLG ) THEN
          DO IGRA = 1, NGRA
            TVBGRA(IATM,IGRA,INTE) = TVBGRA(IATM,IGRA,INTE) + PTB
          END DO
        END IF
      END DO
C
      END        
