      SUBROUTINE REAGRD ( LUNGRD, FILGRD, WNOMIN, WNOMAX, FAIL, ERRMSG )
C
C VERSION
C     17NOV14 AD Original. Based on parts of SPCGRD, SVDGRD
C
C DESCRIPTION
C     Read irregular grid data from .grd file into /GRDCOM/
C     Called multiply by GRDFIL and SPCGRD
C     If called with WNOMAX = 0.0 this just reads the .grd file header, putting
C     the min/max waveno.range into WNOGRD(1:2).
C     If callled with WNOMAX .NE. 0.0 this performs this sets up WNOGRD as
C       WNOGRD(1) = WNOMIN
C       WNOGRD(2) = WNOMIN+WNRGRD if 4-pt interpolation function to be used
C       WNOGRD(...) = values from .grd file
C       WNOGRD(N-1) = WNOMAX-WNRGRD if 4-pt interpolation function to be used
C       WNOGRD(N) = WNOMAX
C     This ensures that the WNOGRD array will contain grid points at the 
C     specified wno limits and, if 4-pt interpolation function to be used, at
C     the next points as well. 
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNGRD !  I  LUN for open/read/close
      CHARACTER*(*) FILGRD !  I  Name of .grd file
      DOUBLE PRECISION WNOMIN !  I  Lowest wavenumber [cm-1] to be set
      DOUBLE PRECISION WNOMAX !  I  Highest wavenumber [cm-1] to be set
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  RFMLOG ! Write text message to RFM log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'grdcom.inc' ! Irregular grid 
C
C LOCAL CONSTANTS
      CHARACTER*39 FNCSTR 
        PARAMETER ( FNCSTR='lin qad cub 1li 1qa 1cu 1sq lor lnl lnc' )
C
C LOCAL VARIABLES
      INTEGER      ICHAR   ! Counter for hex characters within record (1:50)
      INTEGER      IDXMAX  ! Inde of Highest grid point to be used from grd file
      INTEGER      IDXMIN  ! Inde of Lowest  grid point to be used from grd file
      INTEGER      IHEX    ! Integer value of hexadecimal character
      INTEGER      ITOT    ! Counter for regular grid points
      INTEGER      ITWO    ! Factors of two for selecting hex bits
      INTEGER      IOS     ! Saved value of IOSTAT for error messages
      CHARACTER*80 CDUMMY  ! Header record read from GRD file (dummy)
      CHARACTER*25 CONFIG  ! GRD file configuration info
      CHARACTER*80 MESSGE  ! Message for RFM log file
      CHARACTER*50 REC50   ! Grid record read from file
      INTEGER      NTOT    ! Total no. of regular grid points,-ve=GHz
      INTEGER      NUSE    ! Number of irreg.grid points represented
      DOUBLE PRECISION WNO1 ! Wavenumber [cm-1/GHz] at start of reg.grid
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      OPEN ( LUNGRD, FILE=FILGRD, STATUS='OLD', IOSTAT=IOS, ERR=900 ) 
      READ ( LUNGRD, '(A)', IOSTAT=IOS, ERR=900 ) CONFIG
      READ ( LUNGRD, '(A)', IOSTAT=IOS, ERR=900 ) CDUMMY
      READ ( LUNGRD, '(A)', IOSTAT=IOS, ERR=900 ) FNCGRD
      IF ( MOD ( INDEX ( FNCSTR, FNCGRD ), 4 ) .NE. 1 ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-REAGRD: Unrecognised interpolation method='//FNCGRD
        RETURN
      END IF
C
      READ ( LUNGRD, *, IOSTAT=IOS, ERR=900 ) NTOT, NUSE, WNO1, WNRGRD
      READ ( LUNGRD, '(A)', IOSTAT=IOS, ERR=900 ) CDUMMY
C
C On initial file access only, send warning message if grid spectral axis units
C are inconsistent with RFM output spectral axis units.
      IF ( WNOMAX .EQ. 0.0D0 ) THEN
        IF ( NTOT .LT. 0 .AND. .NOT. GHZFLG ) THEN
          MESSGE = 'W-GRDFIL: GRD specified in GHz - converting to cm-1'
          CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
        ELSE IF ( NTOT .GT. 0 .AND. GHZFLG ) THEN
          MESSGE = 'W-GRDFIL: GRD specified in cm-1, not GHz'
          CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
        END IF
      END IF
C
C Convert spectral axis from GHz to cm-1
      IF ( NTOT .LT. 0 ) THEN        
        NTOT = -NTOT
        WNO1 = WNO1 * 1.0D7 / VLIGHT
        WNRGRD = WNRGRD * 1.0D7 / VLIGHT
      END IF
C
C If reading header, just set min/max wavenumber range and return
      IF ( WNOMAX .EQ. 0.0D0 ) THEN
        NGRD = 2
        WNOGRD(1) = WNO1
        WNOGRD(2) = WNO1 + ( NTOT - 1 ) * WNRGRD        
        FAIL = .FALSE.
        CLOSE ( LUNGRD, IOSTAT=IOS, ERR=900 )
        RETURN
      END IF
C
      TWOGRD = INDEX ( 'lin 1li 1sq lor lnl', FNCGRD ) .NE. 0
C
      WNOGRD(1) = WNOMIN
      NGRD = 1
      IDXMIN = NINT ( ( WNOMIN - WNO1 ) / WNRGRD ) + 2
      IDXMAX = NINT ( ( WNOMAX - WNO1 ) / WNRGRD ) 
      IF ( .NOT. TWOGRD ) THEN
        WNOGRD(2) = WNOMIN + WNRGRD
        IDXMIN = IDXMIN + 1
        IDXMAX = IDXMAX - 1
        NGRD = 2
      END IF
C
      DO ITOT = 1, IDXMAX
        IF ( MOD ( ITOT, 200 ) .EQ. 1 ) THEN
          READ ( LUNGRD, '(A)', IOSTAT=IOS, ERR=900 ) REC50
          ICHAR = 0
        END IF
        IF ( MOD ( ITOT, 4 ) .EQ. 1 ) THEN
          ICHAR = ICHAR + 1
          READ ( REC50(ICHAR:ICHAR), '(Z1)', IOSTAT=IOS, ERR=900 ) IHEX
          ITWO = 16
        ENDIF
        ITWO = ITWO/2
        IF ( IHEX .GE. ITWO ) THEN
          IF ( ITOT .GE. IDXMIN ) THEN
            NGRD = NGRD + 1
            IF ( NGRD .GT. MAXGRD ) GOTO 800
            WNOGRD(NGRD) = WNO1 + ( ITOT - 1 ) * WNRGRD
          END IF
          IHEX = IHEX - ITWO
        END IF
      END DO
C
      IF ( .NOT. TWOGRD ) THEN
        NGRD = NGRD + 1
        IF ( NGRD .GT. MAXGRD ) GOTO 800
        WNOGRD(NGRD) = WNOMAX - WNRGRD
      END IF        
      NGRD = NGRD + 1
      IF ( NGRD .GT. MAXGRD ) GOTO 800
      WNOGRD(NGRD) = WNOMAX
C
      CLOSE ( LUNGRD, IOSTAT=IOS, ERR=900 )
      FAIL = .FALSE.
      RETURN
C
 800  WRITE ( ERRMSG, '(A,I8)' ) 'F-REAGRD: No.irreg grid pts '//
     &  'required > MAXGRD in rfmsiz.inc,=', MAXGRD
      FAIL = .TRUE.
      RETURN
C
 900  CONTINUE
      WRITE ( ERRMSG, '(A,I11)' ) 'F-REAGRD: I/O error reading file,'//
     &  ' IOSTAT=', IOS
      FAIL = .TRUE.
C
      END
