      SUBROUTINE REALUT ( ILFL, WNO, ZERABS, TABWNO, FAIL, ERRMSG )
C
C VERSIONG
C     12DEC14 AD Assume file contains log(k) rather than k
C     16JAN14 AD Original.
C 
C DESCRIPTION    
C     Interpolate data records from LUT file for given wavenumber
C     Called multiple times by RFMLUT.
C     ZERABS is set TRUE (and TABWNO undefined) if all abs coeffs are zero, 
C     either due to interpolating between two records containing only zeros, 
C     or due to wavenumber being outside spectral range of tabulation.
C                  
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      ILFL    !  I  Index of LUT in /LFLCOM/
      DOUBLE PRECISION WNO !  I  Wavenumber [cm-1] to be interpolated
      LOGICAL      ZERABS  !  O  T=zero absorption
      REAL       TABWNO(*) !  O  Tabulated ln(Abs.Coeff) interpolated to WNO
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  SUBTAB ! Subsample tabulated abs.coeff data for reduced p,T axes.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'shpcon.inc' ! Line-shape codes
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C LOCAL CONSTANTS
      REAL LNKZER          ! Value of ln(k) treated as k=0
        PARAMETER ( LNKZER = -80.0 ) ! ln(k)=-80 equiv to k=1.8e-35
C
C COMMON VARIABLES
      INCLUDE 'lflcom.inc' ! Look-Up Table file data
C
C LOCAL VARIABLES
      INTEGER IBUF         ! Counter over buffers (1:2)
      INTEGER ILUT         ! Local index of LUT file data
      INTEGER IOS          ! Saved value of IOSTAT for error message
      INTEGER IV(MAXLUT)   ! Record pointer for each file (=no.data recs read)
      INTEGER IX           ! Counter for p,T points
      INTEGER LUNLUT       ! LUN of open LUT file
      INTEGER NX           ! Number of p,T,q points in record of LUT file
      LOGICAL BINFIL       ! T=binary file, F=ASCII file
      LOGICAL NEWBUF(2,MAXLUT) ! T=new buffer contents loaded, F=no change
      LOGICAL ZERBUF(2,MAXLUT) ! T=buffer contents all zeros
      REAL    DV           ! interpolation weight for WNO interval
      REAL    LNKMAX       ! Max value of TAB data in buffer
      REAL    TABBUF(MAXLUX,2,MAXLUT)   ! Storage for 2 wno records of TAB file
      DOUBLE PRECISION WNOBUF(2,MAXLUT) ! Waveno of buffer contents
      DOUBLE PRECISION WNOUPP           ! Upper wavenumber [cm-1] of two buffers
C
C DATA STATEMENTS
      DATA IV / MAXLUT * 0 /
      DATA NEWBUF / MAXLUT * .FALSE., MAXLUT * .FALSE. /
      DATA ZERBUF / MAXLUT * .FALSE., MAXLUT * .FALSE. /
      DATA WNOBUF / MAXLUT * 0.0, MAXLUT * 0.0 /
      SAVE IV, NEWBUF, TABBUF, WNOBUF, ZERBUF
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      FAIL = .FALSE.
C
      LUNLUT = LUNLFL(ILFL)
      BINFIL = BINLFL(ILFL)
      NX = NXLFL(ILFL)
      ILUT = ILTLFL(ILFL)
C
C ILUT is set -ve at the start of each new spectral range to initialise buffers
      IF ( ILUT .LT. 0 ) THEN
        ILUT = ABS ( ILUT )
        ILTLFL(ILFL) = ILUT
        DO IBUF = 1, 2
          IF ( BINFIL ) THEN
            READ ( LUNLUT, IOSTAT=IOS, ERR=900 ) WNOBUF(IBUF,ILUT), 
     &        ( TABBUF(IX,IBUF,ILUT), IX = 1, NX )
          ELSE 
            READ ( LUNLUT, *, IOSTAT=IOS, ERR=900 ) WNOBUF(IBUF,ILUT),
     &        ( TABBUF(IX,IBUF,ILUT), IX = 1, NX )
          END IF
          IF ( GHZLFL(ILFL) ) 
     &      WNOBUF(IBUF,ILUT) = WNOBUF(IBUF,ILUT) * 1.0D7 / VLIGHT
          NEWBUF(IBUF,ILUT) = .TRUE.
        END DO
        IV(ILUT) = 2         ! 2 wavenumber records now read from file
      END IF
C
      IF ( WNOBUF(2,ILUT) .GT. WNOBUF(1,ILUT) ) THEN
        IBUF = 2
      ELSE
        IBUF = 1
      END IF
      WNOUPP = WNOBUF(IBUF,ILUT)
C
C If WNO above WNOUPP then advance through file swapping between buffers
      DO WHILE ( WNO .GT. WNOUPP .AND. 
     &           IV(ILUT) .LT. NVLFL(ILFL) ) 
        IBUF = 3 - IBUF
        IF ( BINFIL ) THEN
          READ ( LUNLUT, IOSTAT=IOS, ERR=900 ) WNOUPP, 
     &      ( TABBUF(IX,IBUF,ILUT), IX = 1, NX )
        ELSE 
          READ ( LUNLUT, *, IOSTAT=IOS, ERR=900 ) WNOUPP,
     &      ( TABBUF(IX,IBUF,ILUT), IX = 1, NX )
        END IF
        IF ( GHZLFL(ILFL) ) WNOUPP = WNOUPP * 1.0D7 / VLIGHT
        NEWBUF(IBUF,ILUT) = .TRUE.
        WNOBUF(IBUF,ILUT) = WNOUPP
        IV(ILUT) = IV(ILUT) + 1
      END DO
C
C Subsample p,T dimensions if required
      IF ( NDPLFL(ILFL) .NE. 1 .OR. NDTLFL(ILFL) .NE. 1 ) THEN
        IF ( NEWBUF(1,ILUT) ) CALL SUBTAB ( ILFL, TABBUF(1,1,ILUT), NX )
        IF ( NEWBUF(2,ILUT) ) CALL SUBTAB ( ILFL, TABBUF(1,2,ILUT), NX )
      END IF
C
C Check if buffers are full of zero absorption values
      DO IBUF = 1, 2
        IF ( NEWBUF(IBUF,ILUT) ) THEN
          ZERBUF(IBUF,ILUT) = .FALSE.
          LNKMAX = LNKZER
          DO IX = 1, NX
            LNKMAX = MAX ( LNKMAX, TABBUF(IX,IBUF,ILUT) ) 
          END DO
          ZERBUF(IBUF,ILUT) = LNKMAX .EQ. LNKZER
 100      CONTINUE
          NEWBUF(IBUF,ILUT) = .FALSE.
        END IF
      END DO
C
      ZERABS = ( ZERBUF(1,ILUT) .AND. ZERBUF(2,ILUT) )
      IF ( ZERABS ) RETURN
C
C Check if WNO bracketed by loaded buffers
      DV = SNGL ( ( WNO - WNOBUF(1,ILUT) ) / 
     &            ( WNOBUF(2,ILUT) - WNOBUF(1,ILUT) ) )
      ZERABS = ( DV .LT. 0.0 .OR. DV .GT. 1.0 )
      IF ( ZERABS ) RETURN
C
      DO IX = 1, NX
        TABWNO(IX) = (1.0-DV) * TABBUF(IX,1,ILUT)  +
     &                     DV * TABBUF(IX,2,ILUT)
      END DO
C
      RETURN
C
 900  FAIL = .TRUE.
      WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-REALUT: Input failure on TAB file. IOSTAT=', IOS
C
      END
