      SUBROUTINE REAQAL ( QALSTR, ONEQAL, I1, I2, FAIL, ERRMSG )
C
C VERSION
C     01APR15 AD Allow for '*' character, returned as I1,I2=0.
C     16JAN14 AD Original.
C
C DESCRIPTION
C     Decode Qualifier strings '(I1)' or '(I1:I2)'
C     Called by LUTQAL if Qualifier strings attached to LUT filenames 
C
      IMPLICIT NONE
C
C ARGUMENTS
      CHARACTER*(*) QALSTR  !  I  String to be decoded
      LOGICAL       ONEQAL  !  O  Set TRUE if single qualifier found
      INTEGER       I1      !  O  First qualifier value
      INTEGER       I2      !  O  Second qualifier value
      LOGICAL       FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG  !  O  Error message written if FAIL is TRUE
C
C LOCAL VARIABLES
      INTEGER       IOS     !  Saved value of IOSTAT
      INTEGER       IPT     !  Location of '('
      INTEGER       JPT     !  Location of ')'
      INTEGER       KPT     !  Location of ':'
      INTEGER       LPT     !  Location of last non-blank character
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      I1 = 0
      I2 = 0
C
      IPT = INDEX ( QALSTR, '(' ) 
      JPT = INDEX ( QALSTR, ')' ) 
      LPT = LEN ( QALSTR )
      DO WHILE ( QALSTR(LPT:LPT) .EQ. ' ' ) 
        LPT = LPT - 1 
      END DO
      FAIL = .TRUE.
      IF ( IPT .NE. 1 ) THEN
        ERRMSG = 'F-REAQAL: Qualifier string does not start with ''('''
      ELSE IF ( JPT .NE. LPT ) THEN
        ERRMSG = 'F-REAQAL: Qualifier string does not end with '')'''
      ELSE IF ( JPT .EQ. IPT+1 ) THEN
        ERRMSG = 'F-REAQAL: Qualifier string has no contents'
      ELSE
        FAIL = .FALSE.
      END IF
      IF ( FAIL ) RETURN
C
      FAIL = .TRUE.
      ONEQAL = INDEX ( QALSTR, ':' ) .EQ. 0
C
      IF ( ONEQAL ) THEN
        IF ( QALSTR(IPT+1:JPT-1) .EQ. '' ) THEN
          ERRMSG = 'F-REAQAL: Qualifier string is empty'
          RETURN
        ELSE IF ( QALSTR(IPT+1:JPT-1) .NE. '*' ) THEN  ! I1=0 already defined
          READ ( QALSTR(IPT+1:JPT-1), *, IOSTAT=IOS ) I1
          IF ( IOS .NE. 0 ) THEN  
            WRITE ( ERRMSG, '(A,I11)' ) 'F-REAQAL: Error reading '//
     &         'contents of Qualifier string. IOSTAT=', IOS
            RETURN
          END IF
        END IF
      ELSE
C
        KPT = INDEX ( QALSTR, ':' )
        IF ( QALSTR(IPT+1:KPT-1) .EQ. '' ) THEN
          ERRMSG = 'F-REAQAL: Qualifier string 1st field is empty'
          RETURN
        ELSE IF ( QALSTR(IPT+1:KPT-1) .NE. '*' ) THEN   ! I1=0 already defined
          READ ( QALSTR(IPT+1:KPT-1), *, IOSTAT=IOS ) I1
          IF ( IOS .NE. 0 ) THEN  
            WRITE ( ERRMSG, '(A,I11)' ) 
     &        'F-REAQAL: Qualifier string error reading 1st field.'//
     &        ' IOSTAT=', IOS
            RETURN
          END IF
        END IF
C
        IF ( QALSTR(KPT+1:JPT-1) .EQ. '' ) THEN
          ERRMSG = 'F-REAQAL: Qualifier string 2nd field is empty'
          RETURN
        ELSE IF ( QALSTR(KPT+1:JPT-1) .NE. '*' ) THEN  ! I2=0 already defined
          READ ( QALSTR(KPT+1:JPT-1), *, IOSTAT=IOS ) I2
          IF ( IOS .NE. 0 ) THEN
            WRITE ( ERRMSG, '(A,I11)' ) 
     &        'F-REAQAL: Qualifier string error reading 2nd field.'//
     &        ' IOSTAT=', IOS
            RETURN
          END IF
        END IF
      END IF
C
      FAIL = .FALSE.
C
      END 
