      REAL FUNCTION REFRAC ( PRE, TEM, WNO )
C
C VERSION
C     01JAN15 AD Change arguments, but functionally the same
C                p,T,wno now via arguments rather than include files
C                Much simplified to remove redundant code for water vapour
C     23MAR00 AD Revised to use Kaye & Laby form
C     09AUG99 AD Use local variable HGT in LOOKUP 
C     24JAN99 AD Original. Based on RFRGL2.
C
C DESCRIPTION
C     Calculate refractivity.
C     Ref: Tables of Physical and Chemical Constants (16th Ed), 
C          G. W. C. Kaye and T. H. Laby
C          Published by Longman, 1995.
C
      IMPLICIT NONE
C
C ARGUMENTS
      REAL             PRE !  I  Pressure [mb]
      REAL             TEM !  I  Temperature [K]
      DOUBLE PRECISION WNO !  I  Wavenumber [cm-1]
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C LOCAL CONSTANTS
      REAL          TREF          ! Ref.Temperature for Edlen refrac. calc.
        PARAMETER ( TREF = 288.16 )
C
C LOCAL VARIABLES
      REAL     SIGMA2 ! (Wavenumber[/micron])^2
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C K&L formula expressed in sigma^2, where sigma=1/wavelength[microns] 
      SIGMA2 = (SNGL(WNO)*0.0001)**2
      REFRAC = 1.0E-8 * PRE / ATMB * TREF / TEM *
     &         (    8342.54 +
     &           2406147.0 / ( 130.0 - SIGMA2 ) +
     &             15998.0 / (  38.9 - SIGMA2 )    ) 
c K&L Water Vapour correction only appropriate for 405-644nm, so comment out
c     &       - 1.0E-8 * WPP * ( 3.7345 - 0.0401 * SIGMA2 ) 
C
      END
