      PROGRAM RFM
C
C VERSION
C     01OCT15 AD v4.34 official release
C     25SEP15 AD Recompiled - modified CIA modules
C     11AUG15 AD Bug#112 - modified ADJUST
C     05AUG15 AD Allow -ve isotope# in *GAS section - modified GASQAL
C     04AUG15 AD Add modified QTFCT, TPSDAT.INC for C3H8, COCl2
C     30JUL15 AD Bug#111 - modified CHKGAS
C     28JUL15 AD Bug#110 - modified XSCFIL
C     24JUL15 AD Add Molec#48 C3H8, #49 COCl2
C     21JUL15 AD JTP Flag and TAN option in *JAC section
C     15JUL15 AD Add SUB/NOSUB options for H2O
C     14JUL15 AD Bug#107 - modified isotopic filenames, CODGAS etc
C                Bug#108 - modified RFMNAD
C                Bug#109 - modified NXTLAB
C     13JUL15 AD Add RFMCIA 
C     10JUL15 AD Bug#106 - modified RFMPTH,CHKPRF,JACCHK
C     30JUN15 AD Bug#105 - modified RFMNAD
C     24JUN15 AD Bug#104 - modified TABPTH
C     18JUN15 AD Bug#103 - modified FINCHK
C     01MAY15 AD Bug#102 - modified RFMNAD
C     22APR15 AD Bug#101 - modified LUTPTH
C                Subtract 25cm-1 offset if H2O lines with TABFLG 
C                - modified RFMWID,RFMFIN
C     09APR15 AD Bug#100 - modified LUTFIL
C     07APR15 AD Bug#99 - modified TANITR
C     19MAR15 AD v4.33 public release
C     12MAR15 AD Bug#98 - modified INPJAC
C     04MAR15 AD Bug#97 - modified FINCHK
C     01JAN15 AD v4.33 prototype
C     12DEC14 AD Bug#96 - modified RFMSPC. 
C                Add SHHFLG. 
C                New .tab file format.
C     10DEC14 AD Bug#95 - modified CHICO2
C     04NOV14 AD Add DV to .tab file header
C     25SEP14 AD Add 'PCG' and 'PLV' options for *DIM section
C     24SEP14 AD Bug#93,#94
C     22JUL14 AD Bug#91,92
C     16JUN14 AD v4.32 official
C     16JAN14 AD v4.31 official
C     01SEP13 AD v4.30 official
C     (Remove old version comments)
C     01-SEP-96  AD  Version 1.
C
C DESCRIPTION
C     MIPAS Reference Forward Model (RFM).
C     See http://www.atm.ox.ac.uk/RFM/ for details
C
      IMPLICIT NONE
C
      EXTERNAL
     &  RFMCTM ! Calculate continuum absorption on fine mesh
     &, RFMDEF ! Set RFM default filenames
     &, RFMFIN ! Calculate absorption on fine mesh
     &, RFMFLX ! Perform RFM Flux calculation
     &, RFMFOV ! Apply field-of-view convolution.
     &, RFMGRA ! Construct ray paths through 2D atmosphere.
     &, RFMGRD ! Sets up fine-resolution grid for each widemesh interval
     &, RFMILS ! Apply instrument line shape convolution
     &, RFMINP ! Open RFM Driver file and read input data
     &, RFMINT ! Interpolates irregular to regular fine resolution grid.
     &, RFMJAC ! Calculate Jacobian spectra
     &, RFMLOG ! Write text message to RFM log file
     &, RFMLOS ! Calculate LOS Jacobian spectra.
     &, RFMLUT ! Calculate the absorption using external Abs.Coeff. Tables.
     &, RFMNAD ! Calculate nadir/zenith path parameters through atmosphere
     &, RFMOPN ! Open RFM output files and write headers
     &, RFMPRF ! Open PRF files and write out internal profile(s)
     &, RFMPTB ! Set up list of pertubations required for RFM Jacobian calc
     &, RFMPTH ! Open PTH files and write RFM ray path diagnostics 
      EXTERNAL
     &  RFMRAD ! Perform RFM radiance calculation
     &, RFMRAY ! Construct ray paths through atmosphere
     &, RFMREX ! Calculate the contribution of Rayleigh extinction
     &, RFMSCA ! Determine which path absorption calculations can be scaled.
     &, RFMSPC ! Initialise RFM for each new spectral range
     &, RFMSVD ! Calculate absorption using SVD-compressed Look-Up Tables
     &, RFMWID ! Perform wide mesh absorption calculations
     &, RFMWNG ! Interpolate tabulated wide mesh absorption across fine mesh
     &, RFMWRT ! Write RFM output data for current widemesh interval.
     &, RFMXSC ! Calculate the absorption due to cross-section species
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'rfmfil.inc' ! Standard filenames of RFM I/O files
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'logcom.inc' ! Runlog file data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
      INCLUDE 'widcom.inc' ! Wide mesh data
      INCLUDE 'outcom.inc' ! RFM output file data
C
C LOCAL CONSTANTS
      INTEGER       LUNRUN                  ! LUN for RUNLOG File
        PARAMETER ( LUNRUN = 1 )            
      INTEGER       LUNDRV                  ! LUN for Driver File
        PARAMETER ( LUNDRV = 2 )            
C
C LOCAL VARIABLES
      INTEGER       IOS        ! Saved value of IOSTAT for checks
      INTEGER       ISPC       ! Spectral range counter
      INTEGER       IWID       ! Wide-mesh counter
      INTEGER       LUN        ! LUN counter
      INTEGER       LUNNXT     ! Next available LUN
      INTEGER       LUNSAV     ! Save LUN up to start of spectral range loop
      LOGICAL       FAIL       ! Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG     ! Error message written if FAIL is TRUE
      CHARACTER*80  RFMTXT     ! Message identifying program and version
      CHARACTER*132 MESSGE     ! Other messages for Log file
        DATA  LUNNXT / 7 /
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C VERSN is a CHARACTER*11 field which appears in the header record of all 
C output files. Any local modifications to the RFM should be assigned a 
C different VERSN value, eg '4.00_OXF_13' for Oxford modification#13 to 
C "official" RFM v 4.00 
C
      VERSN = '4.34_01OCT'           ! Loaded into /OUTCOM/ 
C
C Print program and version identifier to screen
C
      RFMTXT = 'R-RFM:    Program RFM v'//VERSN
      WRITE ( *, * ) RFMTXT 
C
C Prompt for any run identifier label to be appended to all output file
C
      WRITE ( *, * ) 
     &  'Optional ID to be appended to filenames (<CR>=none):'
      READ ( *, '(A)' ) RUNID
      IF ( RUNID .NE. ' ' ) THEN
        MESSGE = 'R-RFM:    Filename append string='//RUNID
        WRITE ( *, * ) MESSGE
      END IF
C
C Open Runlog file (Transfer LUN to RFMLOG via /LOGCOM/LUNLOG)
C
      LUNLOG = LUNRUN
      NWMLOG = 0                  ! Initialise no.warning messages
      OPEN ( UNIT=LUNLOG, FILE=NAMLOG//RUNID, STATUS='UNKNOWN', 
     &       IOSTAT=IOS )
      IF ( IOS .NE. 0 ) THEN
        WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-RFM: Failed to open LOG file. IOSTAT=', IOS
        FAIL = .TRUE.
        GOTO 900
      END IF
      CALL RFMLOG ( RFMTXT, FAIL, ERRMSG )  ! Write RFM identifier to log file
      IF ( FAIL ) GOTO 900
C
C Set default filenames
C
      CALL RFMDEF
C
C Load input data
C
      CALL RFMINP ( LUNDRV, LUNNXT, FAIL, ERRMSG )
      IF ( FAIL ) GOTO 900
C
C Write out profile diagnostics if required
C 
      IF ( PRFFLG ) THEN 
        CALL RFMPRF ( LUNNXT, FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
      END IF
C
C Construct ray paths
C
      IF ( NADFLG .OR. ZENFLG .OR. FLXFLG ) THEN
        CALL RFMNAD 
      ELSE IF ( .NOT. HOMFLG .AND. .NOT. TABFLG ) THEN 
        IF ( GRAFLG ) THEN
          CALL RFMGRA
        ELSE
          CALL RFMRAY 
        END IF
        IF ( .NOT. CLCFLG ) THEN
          CALL RFMSCA ( FAIL, ERRMSG )
          IF ( FAIL ) GOTO 900
        END IF
      END IF
C
C Write out path diagnostics if required
C 
      IF ( PTHFLG ) THEN 
        CALL RFMPTH ( LUNNXT, FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
      END IF
C
C Calculate perturbed paths if performing Jacobian calculations
C
      IF ( JACFLG ) THEN
        CALL RFMPTB ( FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
      END IF
C
C Loop over all required spectral ranges
C
      LUNSAV = LUNNXT
      DO ISPC = 1, NSPC
C
C Initialise frequency grids for current range
C
        CALL RFMSPC ( ISPC, FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
C
C Open output files
C
        CALL RFMOPN ( LUNNXT, ISPC, FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
        MESSGE = 'R-RFM:    Commencing Wide Mesh Calculation'
        IF ( LABSPC(ISPC) .NE. ' ' ) 
     &    MESSGE = MESSGE(1:42)//' for Spectral Range='//LABSPC(ISPC)
        WRITE ( *, * ) MESSGE(1:80)
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
C
C Calculate absorption at wide-mesh points
C
        CALL RFMWID ( FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
C
C Include continuum contribution to absorption
C
        IF ( CTMFLG ) CALL RFMCTM 
C
C Main loop over wide mesh. Fine mesh data is stored for current interval only
C  
        MESSGE = 'R-RFM:    Commencing Fine Mesh Calculation'
        WRITE ( *, * ) MESSGE(1:80)
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
        DO IWID = 1, NWID 
          IF ( .NOT. SHHFLG ) WRITE (*,*) IWID, NWID
C
C Set up fine mesh grid for this interval (regular or irregular)
C
          CALL RFMGRD ( IWID )
C         
C Interpolate line wing and continuum absorption to on fine mesh
C       
          CALL RFMWNG ( IWID )
C
C Calculate cross-section absorption on fine mesh
C
          CALL RFMXSC ( FAIL, ERRMSG )
          IF ( FAIL ) GOTO 900
C
C Calculate collision-induced absorption
          IF ( CIAFLG ) CALL RFMCIA
C
C Calculate absorption using Look-up tables on fine mesh
C
          IF ( LUTFLG ) THEN
            CALL RFMLUT ( FAIL, ERRMSG )
            IF ( FAIL ) GOTO 900
            CALL RFMSVD 
          END IF
C
C Calculate contribution of Rayleigh extinction
C
          IF ( REXFLG ) CALL RFMREX 
C
C Calculate line absorption on fine mesh
C
          CALL RFMFIN ( IWID, FAIL, ERRMSG )
          IF ( FAIL ) GOTO 900
C
C Calculate radiance on fine mesh (not required for TAB output)
C
          IF ( FLXFLG ) THEN
            CALL RFMFLX
          ELSE IF ( .NOT. TABFLG ) THEN
            CALL RFMRAD 
          END IF
C
C Calculate Jacobian spectra if required
C
          IF ( JACFLG .OR. MTXFLG ) CALL RFMJAC
C
C Convolve with FOV function if required
C
          IF ( FOVFLG ) CALL RFMFOV
C
C Interpolate to regular grid if required
C
          IF ( GRDFLG .AND. .NOT. TABFLG ) CALL RFMINT 
C
C Convolve with ILS function if required
C
          IF ( ILSFLG .OR. AVGFLG ) 
     &      CALL RFMILS ( IWID, ISPC, FAIL, ERRMSG )
          IF ( FAIL ) GOTO 900
C
C Calculate any LOS Jacobians
          IF ( LOSFLG ) CALL RFMLOS
C
C Output radiances/transmissions for each tangent point
C
          CALL RFMWRT ( IWID, FAIL, ERRMSG )
          IF ( FAIL ) GOTO 900
C
        END DO
C
C If performing ILS convolution, output lags calc. by one widemesh interval
C so output last interval
C
        IF ( ILSFLG .OR. AVGFLG ) THEN        
          CALL RFMILS ( NWID+1, ISPC, FAIL, ERRMSG )
          IF ( FAIL ) GOTO 900
          IF ( LOSFLG ) CALL RFMLOS
          CALL RFMWRT ( NWID+1, FAIL, ERRMSG )
          IF ( FAIL ) GOTO 900
        END IF
C
C Close any files specific to this spectral range
C
        DO LUN = LUNNXT-1, LUNSAV, -1
          CLOSE ( LUN, IOSTAT=IOS )
          IF ( IOS .NE. 0 ) THEN
            FAIL = .TRUE.
            WRITE ( ERRMSG, '(A,I3,A,I11)' ) 
     &        'F-RFM:   Error closing LUN', LUN, '. IOSTAT=', IOS 
            GOTO 900
          END IF
        END DO
        LUNNXT = LUNSAV
C
      END DO
C
C Program termination
C
  900 IF ( FAIL ) THEN 
        WRITE (*,*) ERRMSG
        CALL RFMLOG ( ERRMSG, FAIL, ERRMSG )
      ELSE
        IF ( NWMLOG .GT. 0 ) THEN
          WRITE ( MESSGE, '(A,I11,A)' ) 
     &      'R-RFM:', NWMLOG, ' Warning messages in RUNLOG file'
          WRITE ( *, * ) MESSGE(1:80)
        END IF
        MESSGE = 'R-RFM:    Successful completion.'
        WRITE ( *, * ) MESSGE(1:80)
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        IF ( FAIL ) GOTO 900
      END IF
C
      END 
