      SUBROUTINE RFMCIA
C
C VERSION
C     25SEP15 AD Original.
C 
C DESCRIPTION    
C     Calculate the Collision-induced absorption 
C     Called by RFM for each wide mesh interval.
C                  
      IMPLICIT NONE
C
      EXTERNAL
     &  CIAPTH ! Calculate absorber amounts for CIA paths.
     &, INTCIA ! Interpolate CIA spectrum.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'fincom.inc' ! Fine mesh data
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'pthcom.inc' ! RFM path data
C
C LOCAL CONSTANTS
      INTEGER MAXAM2       ! Max no. of Amt^2 paths
        PARAMETER ( MAXAM2 = MAXCLC ) 
C
C LOCAL VARIABLES
      INTEGER IAM2         ! Counter for AM2 paths
      INTEGER ID1,ID2      ! HITRAN/RFM indices of collision pairs
      INTEGER ID2AM2(MAXAM2) ! HITRAN/RFM ID of molec#2 assoc. with AM2 path
      INTEGER IFIN         ! Fine mesh grid point counter (0:NFIN)
      INTEGER IGAS         ! Gas counter
      INTEGER IPTAM2(MAXAM2) ! Index of IPTH associated with each AM2 path
      INTEGER IPTH         ! Path counter
      INTEGER NAM2         ! No. Amt^2 values calculated
      LOGICAL FIRST        ! T=first call of this routine
      REAL    AM2(MAXAM2)  ! Amt^2 [kmole^2/cm^5] 
      REAL    CIAFIN(MAXFIN) ! Interpolated CIA values [cm^5/kmol^2] 
      REAL    TEM          ! Temperature of current path
C
C DATA STATEMENTS
      DATA FIRST / .TRUE. /
      SAVE FIRST, NAM2, IPTAM2, ID2AM2, AM2
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C On first call, construct list of collision partners for each molecule
C and save index of corresponding path
      IF ( FIRST ) THEN 
        CALL CIAPTH ( MAXAM2, NAM2, IPTAM2, ID2AM2, AM2 )
        FIRST = .FALSE.
      END IF
C
      IAM2 = 1
      DO IPTH = 1, NCLC
        DO WHILE ( IPTH .EQ. IPTAM2(IAM2) )
          TEM = TEMPTH(IPTH)
          IGAS = IGSPTH(IPTH)
          ID1 = IDXGAS(IGAS) 
          ID2 = ID2AM2(IAM2)
          CALL INTCIA ( ID1, ID2, TEM, NFIN, WNOFIN, CIAFIN ) 
          DO IFIN = 1, NFIN
            ABSFIN(IFIN,IPTH) = ABSFIN(IFIN,IPTH) + 
     &                          CIAFIN(IFIN) * AM2(IAM2)
            CNTFIN(IFIN,IPTH) = ABSFIN(IFIN,IPTH)
          END DO
          IAM2 = IAM2 + 1
        END DO
      END DO
C
      END
