      SUBROUTINE RFMFOV 
C
C VERSION
C     21JUL15 AD Allow for JTPFLG
C     06JAN15 AD Tidied up
C     26MAY00 AD Convert from S.P. to D.P.
C     09AUG99 AD Use explicit DBLE( ) in transmittance calc.
C     03JAN99 AD Allow for Jacobians
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Apply field-of-view convolution.
C     Called by RFM for each widemesh interval.
C     With Jacobian calculations the FOV convolved Jacobians end up in
C     NTAN+1:2*NTAN (IJAC=1);  2*NTAN+1:3*NTAN (IJAC=2) ... etc.
C     Routine RFMPTB checks that there will be enough space for this.
C
      IMPLICIT NONE
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'fincom.inc' ! Fine mesh data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'fovcom.inc' ! FOV Data
      INCLUDE 'jaccom.inc' ! Jacobian data
      INCLUDE 'tancom.inc' ! Tangent heights
C
C LOCAL VARIABLES
      INTEGER IFIN         ! Fine mesh counter
      INTEGER IFOV         ! Field of view point counter
      INTEGER IJAC         ! Jacobian element counter
      INTEGER ITAN         ! Tangent height counter
      INTEGER ITAN1,ITAN2  ! Loop range for nom.tans for each Jacobian
      INTEGER JTAN         ! Index of Tan.Hgt contributing to FOV
      INTEGER NXTTAN       ! Index of next o/p tan.path 
      DOUBLE PRECISION RADTMP(MAXTAN) ! Temporary Radiance array
      DOUBLE PRECISION TRATMP(MAXTAN) ! Temporary transmission array
C
C EXECUTABLE CODE ------------------------------------------------------------
C
      DO IFIN = 1, NFIN
        DO ITAN = 1, NTAN
          RADTMP(ITAN) = 0.0D0
          TRATMP(ITAN) = 0.0D0
          DO IFOV = 1, NFOV
            JTAN = IFVTAN(IFOV,ITAN)
            RADTMP(ITAN) = RADTMP(ITAN) + FNCFOV(IFOV)*RADTAN(IFIN,JTAN)
            TRATMP(ITAN) = TRATMP(ITAN) + FNCFOV(IFOV)*TRATAN(IFIN,JTAN)
          END DO
        END DO
        NXTTAN = NTAN
        IF ( JACFLG ) THEN
          DO IJAC = 1, NJAC
            IF ( JTPFLG ) THEN  ! only one o/p tan for each Jacobian
              ITAN1 = JTPJAC(IJAC)
              ITAN2 = ITAN1
            ELSE                ! NTAN o/p tans for each Jacobian
              ITAN1 = 1
              ITAN2 = NTAN
            END IF
            DO ITAN = ITAN1, ITAN2
              NXTTAN = NXTTAN + 1
              RADTMP(NXTTAN) = 0.0D0
              TRATMP(NXTTAN) = 0.0D0
              DO IFOV = 1, NFOV
                JTAN = IFVTAN(IFOV,ITAN)
                JTAN = ITNJAC(JTAN,IJAC)
                IF ( JTAN .NE. 0 ) THEN     ! 0=tan.path insensitive to ptb
                  RADTMP(NXTTAN) = RADTMP(NXTTAN) + 
     &                             FNCFOV(IFOV) * RADTAN(IFIN,JTAN)
                  TRATMP(NXTTAN) = TRATMP(NXTTAN) + 
     &                             FNCFOV(IFOV) * TRATAN(IFIN,JTAN)
                END IF
              END DO
            END DO
          END DO
        END IF
        DO ITAN = 1, LTAN
          RADTAN(IFIN,ITAN) = RADTMP(ITAN)
          TRATAN(IFIN,ITAN) = TRATMP(ITAN)
        END DO
      END DO
C
      END 
