      SUBROUTINE RFMLUT ( FAIL, ERRMSG )
C
C VERSION
C     11JUN15 AD Test for FAIL after REALUT.
C                Remove phycon.inc - no longer required
C     24SEP14 AD Change factor 1E7 to 1E4 for mole/m2 to kmole/m2 in TAB k file.
C     16JAN14 AD Change LUT file handling
C                Renamed from rfmtab.for to rfmlut.for
C     07JUN00 AD Allow for irregular grids
C     09AUG99 AD Make XV = SNGL( ) 
C     04JUN99 AD Allow for Binary files as well
C     04MAY99 AD Allow for NP or NT = 1 in look-up tables
C     28APR99 AD Allow for -lnp,Tem axis increment scaling factors
C                    Also allow for temperature offset profiles
C     19JUN98 AD Correction: ensure buffer entries separated correctly 
C                    when two or more TAB.LUT files are used.
C     01NOV97 AD Original.
C 
C DESCRIPTION    
C     Calculate the absorption using external Abs.Coeff. Tables.
C     Called by RFM for each wide mesh interval if LUT flag enabled.
C     Note that different tables are stored in the same two buffers using
C     different IX values, so that only part of these buffers are written with
C     new data from each record.
C                  
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  REALUT ! Interpolate data records from LUT file for given wavenumber 
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'fincom.inc' ! Fine mesh data
      INCLUDE 'lflcom.inc' ! Look-Up Table file data
      INCLUDE 'lkpcom.inc' ! Look-Up Table interpolation coefficients
      INCLUDE 'pthcom.inc' ! RFM path data
C
C LOCAL VARIABLES
      INTEGER IFIN         ! Fine mesh grid point counter (0:NFIN)
      INTEGER IGAS         ! Gas counter
      INTEGER ILFL         ! Index of LUT file
      INTEGER ILKP         ! Index in look-up coeff array /LKPCOM/
      INTEGER IPTH         ! Path counter
      INTEGER IX           ! Index of point in TABWNO for p,T,q interpolation
      LOGICAL ZERABS       ! T=zero absorption for all p,T,q points
      REAL    K            ! Interp.Abs.Coeffs at high, low wavenumbers
      REAL  TABWNO(MAXLUX) ! Spectrally interpolated record from TAB file
      DOUBLE PRECISION WNO ! Waveno of current Fine Mesh grid point
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Loop over all LUT for this spectral range
      DO ILFL = 1, NLFL
        IF ( SPCLFL(ILFL) ) THEN      ! Flag for use in current spectral range
          IGAS = IGSLFL(ILFL)
C
C Loop over fine mesh grid points
          DO IFIN = 1, NFIN
            WNO = WNOFIN(IFIN)
C Advance buffers until WNOUPP larger than fine mesh point or two recs.loaded
            CALL REALUT ( ILFL, WNOFIN(IFIN), ZERABS, TABWNO, 
     &                    FAIL, ERRMSG )
              IF ( FAIL ) RETURN
C
            IF ( .NOT. ZERABS ) THEN
              DO IPTH = 1, NCLC
                IF ( IGAS .EQ. IGSPTH(IPTH) ) THEN
                  K = 0.0 
                  DO ILKP = IL1PTH(IPTH), IL2PTH(IPTH)
                    IX = IDXLKP(ILKP)
                    K = K + WGTLKP(ILKP) * TABWNO(IX)  ! TABWNO is ln(k)
                  END DO
C Factor 1.0e4 to convert AMT [kmoles/cm^2]) to [kmoles/m^2] for compatibility
C with pretabulated K coefficients.
                  ABSFIN(IFIN,IPTH) = ABSFIN(IFIN,IPTH) + 
     &                                EXP(K) * AMTPTH(IPTH) * 1.0E4
                  CNTFIN(IFIN,IPTH) = ABSFIN(IFIN,IPTH)
                END IF
              END DO
            END IF
          END DO
        END IF
      END DO
      FAIL = .FALSE.
C
      END
