      SUBROUTINE RFMOPN ( LUNNXT, ISPC, FAIL, ERRMSG )
C
C VERSION
C     21JUL15 AD NFLOUT passed via /OUTCOM/ rather than array argument
C     13FEB15 AD Tidied up
C     20SEP12 AD Change NAMTMP from C*80 to C*200
C     14SEP11 AD Add RJT flag
C     09AUG03 AD Add BBT flag
C     20JUL02 AD Set file counters for LUN flag.
C     20APR00 AD Add COOling rate files
C     01OCT99 AD Use local variable NAMTMP as argument to subroutines 
C     02FEB99 AD Add RFMSIZ.INC
C     22OCT97 AD Add OPNTAB
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Open RFM output files and write headers
C     Called by RFM for each spectral range.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNNXT  ! I/O Next available LUN
      INTEGER      ISPC    !  I  Spectral range number
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error occurs
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  OPNOUT ! Open spectral output files for current spectral range
     &, OPNTAB ! Open TAB files for current spectral range
     &, OPNWID ! Open WID files for current spectral range
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'outcom.inc' ! RFM output file data
C
C LOCAL VARIABLES
      CHARACTER*200 NAMTMP ! Temporary file name
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      NFLOUT = 0
C
C If Absorption data required, open output ABS files and write headers
      IF ( ABSFLG ) THEN
        LUNABS = LUNNXT
        NAMTMP = NAMABS
        IFLABS = NFLOUT
        CALL OPNOUT ( LUNNXT, ISPC, 'Absorption', NAMTMP, 
     &                FAIL, ERRMSG ) 
        IF ( FAIL ) RETURN
        NAMABS = NAMTMP
      END IF
C
C If Bright.Temp data required, open output BBT files and write headers
      IF ( BBTFLG ) THEN
        LUNBBT = LUNNXT 
        NAMTMP = NAMBBT
        IFLBBT = NFLOUT
        CALL OPNOUT ( LUNNXT, ISPC, 'Bright. Temp.', NAMTMP, 
     &                FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        NAMBBT = NAMTMP
      END IF
C
C If Cooling Rate data required, open output COO files and write headers
      IF ( COOFLG ) THEN
        LUNCOO = LUNNXT
        NAMTMP = NAMCOO
        IFLCOO = NFLOUT
        CALL OPNOUT ( LUNNXT, ISPC, 'Cooling Rate', NAMTMP, 
     &                FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        NAMCOO = NAMTMP
      END IF
C
C If Optical Depth data required, open output OPT files and write headers
      IF ( OPTFLG ) THEN
        LUNOPT = LUNNXT
        NAMTMP = NAMOPT
        IFLOPT = NFLOUT
        CALL OPNOUT ( LUNNXT, ISPC, 'Optical Depth', NAMTMP, 
     &                FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        NAMOPT = NAMTMP
      END IF
C
C If Radiance data required, open output RAD files and write headers
      IF ( RADFLG ) THEN
        LUNRAD = LUNNXT 
        NAMTMP = NAMRAD
        IFLRAD = NFLOUT
        CALL OPNOUT ( LUNNXT, ISPC, 'Radiance', NAMTMP, 
     &                FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        NAMRAD = NAMTMP
      END IF
C
C If Rayl-J.Temp data required, open output RJT files and write headers
      IF ( RJTFLG ) THEN
        LUNRJT = LUNNXT 
        NAMTMP = NAMRJT
        IFLRJT = NFLOUT
        CALL OPNOUT ( LUNNXT, ISPC, 'Rayl-J.Temp.', NAMTMP, 
     &                FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        NAMRJT = NAMTMP
      END IF
C
C If Transmission data required, open output TRA files and write headers
      IF ( TRAFLG ) THEN
        LUNTRA = LUNNXT
        NAMTMP = NAMTRA
        IFLTRA = NFLOUT
        CALL OPNOUT ( LUNNXT, ISPC, 'Transmission', NAMTMP, 
     &                FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        NAMTRA = NAMTMP
      END IF
C
C If Tabulated absorption coeffs reqd, open output TAB files and write headers
      IF ( TABFLG ) THEN
        CALL OPNTAB ( LUNNXT, ISPC, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
C If Widemesh diagnostics required, open output WID files and write headers
      IF ( WIDFLG ) THEN
        CALL OPNWID ( LUNNXT, ISPC, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
      END
