      SUBROUTINE RFMPTH ( LUNPTH, FAIL, ERRMSG )
C
C VERSION
C     10JUL15 AD Put C9FLT into concatenated strings
C                Change variable name RECORD to REC
C     09JAN15 AD Use C9FLT. Add extra argument to MAKNAM
C     12FEB14 AD Remove crvcom.inc, add phycom.inc (containing RADCRV)
C     23APR12 AD Use RFLSFC rather than EMSSFC to set OBS path
C     19OCT11 AD Bug#80: Initialise NSEG2
C     16JAN04 AD Set IDIR argument to IDXPTH=0 unless GRAFLG=T
C     06JAN04 AD Add IGRA argument to MAKNAM
C     (remove old version comments)
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Open PTH files and write RFM ray path diagnostics.
C     Called once by RFM if PTH flag selected.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      LUNPTH  !  I  Next available LUN
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error occurs
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  C9FLT  ! Write real number as C*9 string up to 3 s.f.
     &, IDXPTH ! Indexing function for Pth# from Tan.pt#, Atm.Layer# and Gas#
     &, MAKNAM ! Construct filename for RFM output files.
     &, RFMLOG ! Write text message to RFM log file.
      CHARACTER*9 C9FLT
      INTEGER IDXPTH
 
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'obscom.inc' ! Observer Position
      INCLUDE 'outcom.inc' ! RFM output file data
      INCLUDE 'phycom.inc' ! Adjustable physical constants (RADCRV)
      INCLUDE 'pthcom.inc' ! RFM path data
      INCLUDE 'sfccom.inc' ! Surface parameters
      INCLUDE 'tancom.inc' ! Tangent heights
C
C LOCAL VARIABLES
      INTEGER       IATM   ! Atmospheric layer counter
      INTEGER IATM1, IATM2 ! Limits for atmospheric level counter
      INTEGER       ICLC   ! Flag for whether LBL calc.performed on path
      INTEGER       IDIR   ! Direction pointer
      INTEGER       IGAS   ! Absorber counter
      INTEGER       IOS    ! Value of IOSTAT saved for error messages.
      INTEGER       IPTH   ! Counter for RFM paths
      INTEGER       ITAN   ! Tangent height counter
      INTEGER NSEG1, NSEG2 ! No. segments for each tangent path.
      REAL          AMTSUM ! Total absorber mass [kmol/cm^2]
      REAL          HGT    ! Lowest altitude for path segment
      REAL          RAYSUM ! Total pathlength [km]
      CHARACTER*132 MESSGE ! Text message sent to Log file.
      CHARACTER*80  NAMFIL ! Name of file actually opened (incl. RUNID)
      CHARACTER*80  REC    ! Text record written out
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      DO ITAN = 1, NTAN
C
C Construct filename and open file
        CALL MAKNAM ( 0, 0, ITAN, 0, 0, NAMPTH, NAMFIL )
        MESSGE = 'I-RFMPTH: Opening output file: '//NAMFIL
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        IF ( NEWFLG ) THEN
          OPEN ( UNIT=LUNPTH, FILE=NAMFIL, STATUS='NEW', 
     &           IOSTAT=IOS, ERR=900 )
        ELSE
          OPEN ( UNIT=LUNPTH, FILE=NAMFIL, STATUS='UNKNOWN', 
     &           IOSTAT=IOS, ERR=900 )
        END IF
C
C Write File Header 
        IF ( HOMFLG ) THEN 
          REC = '! Path diagnostics calculated for Length ='//
     &      C9FLT(USRTAN(ITAN))//' [km] by RFM v.'//VERSN
          WRITE ( LUNPTH, '(A)', IOSTAT=IOS, ERR=900 ) REC
          WRITE ( LUNPTH, '(A,A)', IOSTAT=IOS, ERR=900 ) '!',TXTHDR
          IATM1 = 1
          IATM2 = 1
          IDIR  = 1
          NSEG1 = 1
          NSEG2 = 0
        ELSE IF ( ZENFLG .OR. NADFLG ) THEN
          IF ( USRELE ) THEN
            REC = '! Path diagnostics calculated for Ele.Ang='//
     &        C9FLT(USRTAN(ITAN))//' [dg] by RFM v.'//VERSN
          ELSE
            REC = '! Path diagnostics calculated for AirMass='//
     &        C9FLT(USRTAN(ITAN))//'      by RFM v.'//VERSN
          END IF
          WRITE ( LUNPTH, '(A)', IOSTAT=IOS, ERR=900 ) REC
          WRITE ( LUNPTH, '(A,A)', IOSTAT=IOS, ERR=900 ) '!',TXTHDR
          IF ( ZENFLG ) THEN
            IATM1 = 1
            IATM2 = NATM - 1
            IF ( OBSFLG ) IATM1 = MIN ( IATOBS, NATM-1 )
            IDIR = 1
            NSEG1 = IATM2 - IATM1 + 1
            NSEG2 = 0
          ELSE                              ! NADFLG
            IATM1 = NATM - 1
            IATM2 = 1
            IF ( OBSFLG .AND. .NOT. RFLSFC ) 
     &        IATM1 = MIN ( IATOBS-1, NATM-1 ) 
            IDIR = -1
            NSEG1 = IATM1 - IATM2 + 1
            NSEG2 = 0
          END IF
        ELSE
          IF ( USRELE ) THEN
            REC = '! Path diagnostics calculated for Ele.Ang='//
     &        C9FLT(ELETAN(ITAN))//' [dg] by RFM v.'//VERSN
          ELSE IF ( USRGEO ) THEN
            REC = '! Path diagnostics calculated for Geo.Tan='//
     &        C9FLT(GEOTAN(ITAN))//' [km] by RFM v.'//VERSN
          ELSE
            REC = '! Path diagnostics calculated for Tan Hgt='//
     &        C9FLT(HGTTAN(ITAN))//' [km] by RFM v.'//VERSN
          END IF
          WRITE ( LUNPTH, '(A)', IOSTAT=IOS, ERR=900 ) REC
          WRITE ( LUNPTH, '(A,A)', IOSTAT=IOS, ERR=900 ) '!',TXTHDR
C For limb-viewing, write out extra couple of header records giving additional
C information on viewing/tangent point geometry
          WRITE ( LUNPTH, '(A)', IOSTAT=IOS, ERR=900 )
     &      '!  Rfr.Tan   Geo.Tan   Tan.Zen   Tan.Psi   Rad.Crv   '//
     &      'Obs.Ele   Obs.Alt   Obs.Psi'
          REC = '!'
          WRITE ( REC(2:10), '(F9.3)' ) HGTTAN(ITAN)
          WRITE ( REC(11:20), '(F10.3)' ) GEOTAN(ITAN)
          WRITE ( REC(21:30), '(F10.3)' ) 
     &      SNGL(ASIN(SZNTAN(ITAN)))/DTORAD
          IF ( GRAFLG ) WRITE ( REC(31:40), '(F10.3)' ) PSITAN(ITAN)
          WRITE ( REC(41:50), '(F10.3)' ) RADCRV
          IF ( OBSFLG ) THEN
            WRITE ( REC(51:60), '(F10.3)' ) ELETAN(ITAN)
            WRITE ( REC(61:70), '(F10.3)' ) ALTOBS
            IF ( GRAFLG ) WRITE ( REC(71:80), '(F10.3)' ) PSIOBS
          END IF
          WRITE ( LUNPTH, '(A)' ) REC
          IATM1 = NATM-1
          IATM2 = IATTAN(ITAN)
          IDIR = -1
          NSEG1 = IATM1 - IATM2 + 1  ! top of atmosphere to tangent level
          NSEG2 = 0                              ! Bug#80 fix: add this line
          IF ( GRAFLG ) THEN  ! Allow diagnostics for both down and up parts 
            IF ( OBSFLG ) THEN
              IATM1 = MIN ( IATOBS-1, NATM-1 ) 
              IF ( IATTAN(ITAN) .EQ. IATOBS ) THEN ! Upview, skip downward loop
                IATM1 = IATOBS
                IATM2 = IATM1 + 1               
              ELSE
                NSEG2 = NSEG1
                NSEG1 = IATM1 - IATM2 + 1  ! Add obs to tan.level
              END IF
            ELSE
              NSEG2 = NSEG1
            END IF
          END IF
        END IF
C
        WRITE ( LUNPTH, * ) NGAS, NSEG1, NSEG2, ' = NGas, NSeg1, NSeg2'
C
C For each absorber....
        DO IGAS = 1, NGAS
          WRITE ( LUNPTH, '(A)', IOSTAT=IOS, ERR=900 ) CODGAS(IGAS)
          IF ( GRAFLG ) THEN
            WRITE ( LUNPTH, '(A)', IOSTAT=IOS, ERR=900 ) 
     &        'Lev  Zlow[km]  Psi[dg] Temp[K]  Press[mb]  VMR[ppv]'//
     &        '   Amt[kmol/cm2] Len.[km] Clc'
          ELSE
            WRITE ( LUNPTH, '(A)', IOSTAT=IOS, ERR=900 ) 
     &        'Lev  Zlow[km]  Zen[dg] Temp[K]  Press[mb]  VMR[ppv]'//
     &        '   Amt[kmol/cm2] Len.[km] Clc'
          END IF
C
  100     CONTINUE
          RAYSUM = 0.0
          AMTSUM = 0.0
          DO IATM = IATM1, IATM2, IDIR
            IF ( GRAFLG ) THEN
              IPTH = IDXPTH ( ITAN, IATM, IGAS, IDIR )
            ELSE
              IPTH = IDXPTH ( ITAN, IATM, IGAS, 0 )
            END IF
            IF ( CLCPTH(IPTH) ) THEN
              ICLC = 1
            ELSE
              ICLC = 0
            END IF
            IF ( IATM .EQ. IATTAN(ITAN) ) THEN
              HGT = HGTTAN(ITAN)
            ELSE
              HGT = HGTATM(IATM)
            END IF
            WRITE ( LUNPTH, '(I3, 3F9.3, 1P3E12.5, 0PF10.3, I3)',
     &                IOSTAT=IOS, ERR=900 )
     &        IATM, HGT, PSIPTH(IPTH), TEMPTH(IPTH), PREPTH(IPTH)*ATMB,
     &        PPAPTH(IPTH)/PREPTH(IPTH), AMTPTH(IPTH),
     &        RAYPTH(IPTH), ICLC
            RAYSUM = RAYSUM + RAYPTH(IPTH)
            AMTSUM = AMTSUM + AMTPTH(IPTH)
          END DO
          WRITE ( LUNPTH, '(48X,A,1PE12.5,0PF10.3)', IOSTAT=IOS, 
     &      ERR=900 ) 'Total:', AMTSUM, RAYSUM
          IF ( GRAFLG ) THEN
            IF ( IDIR .EQ. -1 ) THEN ! Repeat from tan.pt to t.o.a.
              IDIR = +1
              IATM1 = IATTAN(ITAN)
              IATM2 = NATM - 1
              GOTO 100
            ELSE                     ! IDIR=+1, ie tan.pt to t.o.a.
              IDIR = -1              ! Reset downward path for next IGAS
              IATM1 = NATM - 1
              IATM2 = IATTAN(ITAN)
            END IF            
          END IF            
        END DO
        CLOSE ( LUNPTH, IOSTAT=IOS, ERR=900 )
      END DO
      FAIL = .FALSE.
      RETURN
C
  900 FAIL = .TRUE.
      WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-RFMPTH: I/O failure on output file. IOSTAT=', IOS
      END
