      SUBROUTINE RFMRAD 
C
C VERSION
C     11FEB15 AD Tidied up
C     07AUG13 AD Remove redundant local variable REFLCT
C     23APR12 AD Remove REFLCT argument from RADSFC, instead use 
C                    RFLSFC in sfccom.inc
C     14SEP11 AD Add RADSPA for cosmic background radiance
C     03SEP03 AD Change SFCTAN from local to common variable
C     12OCT99 AD Check each limb tan.path for surface intersection
C     31JUL99 AD Remove unused variable ISGN 
C     30DEC98 AD Split into new subroutines RADTRA and RADSFC
C                     Implement BFX flag.
C                     Correct to allow surface effects in limb-viewing mode
C     14JUL98 AD Allow Observer (OBS) option
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Perform RFM radiance calculation
C     Called by RFM for each widemesh interval.
C
      IMPLICIT NONE
C
      EXTERNAL
     &  RADSFC ! Surface contribution to radiative transfer calculation
     &, RADSPA ! Cosmic background contribution to radiative transfer calc.
     &, RADTRA ! Radiative transfer calculation for single ray
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data 
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'obscom.inc' ! Observer Position
      INCLUDE 'sfccom.inc' ! Surface parameters
      INCLUDE 'tancom.inc' ! Tangent heights
C
C LOCAL VARIABLES
      INTEGER     IATMIN   !  Lowest layer# (either tang.layer or bottom layer)
      INTEGER     IATTOP   !  Top layer# of atmosphere
      INTEGER     ITAN     !  Tangent point counter
      LOGICAL     INIT     !  T=initialise for start of new ray path
      LOGICAL     UPVIEW   !  T=upward limb-view
       
C EXECUTABLE CODE -------------------------------------------------------------
C
      IATTOP = NATM-1
      DO ITAN = 1, MTAN
        IF ( CLCTAN(ITAN) ) THEN
C
C All calculations start at the observer and proceed away into the atmosphere
          INIT = .TRUE.      ! Set .FALSE. after calling RADTRA
C Homogeneous path geometry
          IF ( HOMFLG ) THEN
            CALL RADTRA ( ITAN, 1, 1, 1, INIT )
            IF ( SFCFLG ) THEN
              CALL RADSFC ( ITAN )
              IF ( RFLSFC ) CALL RADTRA ( ITAN, 1, 1, 1, INIT )
            END IF
C Zenith-viewing geometry
          ELSE IF ( ZENFLG ) THEN 
            IF ( OBSFLG ) THEN   
              CALL RADTRA ( ITAN, IATOBS, IATTOP, 1, INIT )
            ELSE
              CALL RADTRA ( ITAN, 1, IATTOP, 1, INIT )
            END IF
            CALL RADSPA ( ITAN )
C Nadir-viewing geometry
          ELSE IF ( NADFLG ) THEN
            IF ( OBSFLG ) THEN
              CALL RADTRA ( ITAN, (IATOBS-1), 1, -1, INIT )
            ELSE
              CALL RADTRA ( ITAN, IATTOP, 1, -1, INIT )
            END IF
            CALL RADSFC ( ITAN ) ! SFC flag=T for all NAD calculations
            IF ( RFLSFC ) THEN
              CALL RADTRA ( ITAN, 1, IATTOP, 1, INIT )
              CALL RADSPA ( ITAN )
            END IF
C Limb-viewing geometry
          ELSE                           ! limb viewing
            IATMIN = IATTAN(ITAN)
            IF ( OBSFLG ) THEN
              UPVIEW = IATMIN .EQ. IATOBS
              IF ( UPVIEW ) THEN
                CALL RADTRA ( ITAN, IATOBS, IATTOP, 1, INIT )
                CALL RADSPA ( ITAN ) 
              ELSE
                CALL RADTRA ( ITAN, (IATOBS-1), IATMIN, -1, INIT )
                IF ( SFCTAN(ITAN) ) THEN
                  CALL RADSFC ( ITAN )
                  IF ( RFLSFC ) THEN
                    CALL RADTRA ( ITAN, 1, IATTOP, 1, INIT )
                    CALL RADSPA ( ITAN ) 
                  END IF
                ELSE
                  CALL RADTRA ( ITAN, IATMIN, IATTOP, 1, INIT )
                  CALL RADSPA ( ITAN ) 
                END IF
              END IF
            ELSE
              CALL RADTRA ( ITAN, IATTOP, IATMIN, -1, INIT )
              IF ( SFCTAN(ITAN) ) THEN
                CALL RADSFC ( ITAN )
                IF ( RFLSFC ) THEN
                  CALL RADTRA ( ITAN, 1, IATTOP, 1, INIT )
                  CALL RADSPA ( ITAN ) 
                END IF
              ELSE
                CALL RADTRA ( ITAN, IATMIN, IATTOP, 1, INIT )
                CALL RADSPA ( ITAN ) 
              END IF
            END IF
C
          END IF
        END IF
      END DO
C
      END 
