C RFMSIZ.INC ------------------------------------------------------------------
C 
C VERSION
C     10JUL15 AD Add MAXCIA, MAXCAP
C     21NOV14 AD Remove MAXXFL
C     16JUN14 AD Add GEISA molecules & Bro: change MAXHLN from 47 to 56
C                Remove redundant MAXHFS
C     15JAN14 AD Add MAXLKP, MAXSVD, remove MAXLUG 
C     06DEC13 AD Add MAXTBP, MAXTBQ, MAXTBT
C     01AUG13 AD Changes for HITRAN 2012 compatibility:
C                Increase MAXMOL from 85 to 160
C                Increase MAXHLN from 46 to 47
C                Increase MAXISO from 9 to 11
C     23APR12 AD Add MAXSFC
C     14APR08 AD Increase MAXMOL from 81 to 85
C     18NOV04 AD Remove MAXPNT
C     23FEB03 AD Increase MAXHLN from 45 to 46
C     13FEB03 AD Add MAXTPS, MAXTPT
C     03JAN03 AD Add MAXOPG
C     11JUN02 AD Remove MAXHFL
C     27MAR02 AD Version 4.20
C     27DEC01 AD Version 4.10
C     15SEP99 AD Version 4.00
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Parameters defining RFM array sizes
C     Apart from the parameters which depend on other parameters (also indicated
C     by the comments "don't change this!") all of these values can be safely
C     altered to any positive integer (1,2,...) - the RFM code will check that
C     enough array space is allocated before using the arrays.
C     MAXCLC, MAXWID and MAXFIN are usually the critical parameters in defining 
C     total RFM memory requirements.
C
      INTEGER MAXATM               ! Max no. of profile data points 
        PARAMETER ( MAXATM = 121 ) ! 
      INTEGER MAXBND               ! Max no. of selected vibration bands 
        PARAMETER ( MAXBND = 5 )   ! 
C
C Array sizes associated with Collision-Induced Absorption data, can be set
C to 1 if CIA not required
      INTEGER MAXCAP               ! Max no. CIA data points
        PARAMETER ( MAXCAP = 100000 )  
      INTEGER MAXCIA               ! Max no. CIA data tabulations
        PARAMETER ( MAXCIA = 15 )
C
C Note: MAXCLC is a major factor in determining total memory (MAXCLC*MAXWID and
C MAXCLC*MAXFIN). Its size determines the total number of path segments that 
C can be calculated within a single run of the RFM (product of the number of
C tangent heights, incl.FOV convolution, gases, and atmospheric layers). You 
C probably want to set this as large as your machine can handle.
      INTEGER MAXCLC               ! Max no. of paths with line-by-line calc.
        PARAMETER ( MAXCLC = 10000 ) ! 1260 500 
C
      INTEGER MAXCYC               ! Max no. of lines stored in cyclic buffer
        PARAMETER ( MAXCYC = 45000 )! 10000 adequate for standard HITRAN 96

C Note: MAXFIN is a major factor in determining total memory (MAXFIN*MAXCLC)
C Its size determines the maximum resolution (pts/wavenumber) that can be 
C calculated with the RFM. Probably best to change MAXCLC or MAXWID first.
      INTEGER MAXFIN               ! Max no. of fine mesh grid pts per widemesh
        PARAMETER ( MAXFIN = 2016 ) ! 2000 required to resolve Doppler widths 
C                                   ! in the middle atmosphere
      INTEGER MAXFOV               ! Max no. of FOV tabulation points
        PARAMETER ( MAXFOV = 21 )  ! 
      INTEGER MAXGAS               ! Max no. gases read from line/xsec dataset
        PARAMETER ( MAXGAS = 25 )
      INTEGER MAXGFL               ! Max no. of GRD input files
        PARAMETER ( MAXGFL = 5 )  ! 
      INTEGER MAXGRA               ! Max no. of horizontal gradient profiles
        PARAMETER ( MAXGRA = 3 )   
      INTEGER MAXGRD               ! Max no. of Irreg. GRD points (.GE. 2)
        PARAMETER ( MAXGRD = 250000 )   ! 2 is the minimum value allowed
      INTEGER MAXHLN               ! No. species with HITRAN line data
        PARAMETER ( MAXHLN = 56 )  ! 56 = C6H6
      INTEGER MAXHXS               ! No. species with HITRAN X/S data
        PARAMETER ( MAXHXS = 13 )  ! 13 defined species
      INTEGER MAXILF               ! Max.no fine-grid pts in either wing of ILS
        PARAMETER ( MAXILF = 2501 )! 2501 allows +/- 1.0cm-1 @ 0.0004cm-1 spacing
      INTEGER MAXILS               ! Max.no ILS functions that can be stored
        PARAMETER ( MAXILS = 6 )   ! 6 = 1 for each passband, plus 1 general
      INTEGER MAXILP               ! Max.no tabulation points for ILS functions
        PARAMETER ( MAXILP = 5001 )! 5001 allows +/- 1.0cm-1 @ 0.0004cm-1 spacing
      INTEGER MAXISO               ! Highest molecular isotope id in use [9]
        PARAMETER ( MAXISO = 11 )   ! Dimension of DATA statement in GASISO.
C
      INTEGER MAXJAC               ! Max. no. Jacobian retrieval elements
        PARAMETER ( MAXJAC = 300 )  ! 37 allows for 2 species 5,8...56 km +1
C
C Note: the MAXL** dimensions refer to arrays which are only used when running
C the RFM with Look-Up Tables (LUT flag) and may be reduced to 1 otherwise
      INTEGER MAXLFL               ! Max no. LUT files used in single RFM run
        PARAMETER ( MAXLFL = 10 )   ! Separate LUN reserved for each.
      INTEGER MAXLKP                ! Max no p,T,q coords reqd for TAB interp.
        PARAMETER ( MAXLKP = 1000 ) ! Up to 8 coords for each calc path segment.
      INTEGER MAXLUL               ! Max no. basis vectors in any LUT
        PARAMETER ( MAXLUL = 30 )   !
      INTEGER MAXLUT               ! Max no. LUT files for any spectral range
        PARAMETER ( MAXLUT = 10 )   ! reqd no will be in range 1:MAXLFL 
      INTEGER MAXLUV               ! Max no. LUT Wno pts in single spec.range
        PARAMETER ( MAXLUV = 30000 )   !
      INTEGER MAXLUX               ! Max no. Cmp.LUT p,T pts in single spc.range
        PARAMETER ( MAXLUX = 6005 )   !
C
      INTEGER MAXMOL               ! Highest molecular id in use [81]
        PARAMETER ( MAXMOL = 160 )  ! NB: Used as dimension for DATA statements
      INTEGER MAXNTE               ! Max no. of non-LTE vibrational Tem.profiles
        PARAMETER ( MAXNTE = 500 )
C
      INTEGER MAXOPG               ! Max no.output points for each irr.grd pt
        PARAMETER ( MAXOPG = 15 )  ! Set to 1 unless using GRD + ILS/AVG options
      INTEGER MAXOUT
        PARAMETER ( MAXOUT = 3000 ) ! (approx) Max no.output files written
C
C Note: MAXPTH refers to total paths as opposed to calculated paths (MAXCLC)
C Using the SCA flag typically means only 10% of the total are calculated 
      INTEGER MAXPTH               ! Max no. of paths to be used
        PARAMETER ( MAXPTH = 120000 )  
C
      INTEGER MAXPTR               ! Max no.Forward Pointers in HITLIN file
        PARAMETER ( MAXPTR = 56 )  ! 56 allows for up to 4 records of 14
      INTEGER MAXQFN               ! Max no. of non-LTE Partition profs.stored
        PARAMETER ( MAXQFN = 10 )  ! ie maximum no.usable from any one NTE file.
      INTEGER MAXSFC               ! Max no. tab.points for surface emissivity
        PARAMETER ( MAXSFC = 2 ) 
      INTEGER MAXSPC               ! Max no. of spectral ranges stored 
        PARAMETER ( MAXSPC = 30 )  
C
      INTEGER MAXSVD               ! Max no. SVD-LUTs in single spectral range
        PARAMETER ( MAXSVD = 10 )   ! Should be .LE. MAXLFL
C
      INTEGER MAXTAN               ! Max no. of tangent points to be calculated
        PARAMETER ( MAXTAN = 4000 )  
C
C The following can be set to 1 unless creating TAB files. 
C However, these are only small arrays.
      INTEGER MAXTAB               ! Max no. of TAB axis values for p,T or q
        PARAMETER ( MAXTAB = 200 ) 
C
C The following can be set to 1 unless the TPS flag is used
      INTEGER MAXTPS               ! Max no. of external TIPS tabulations
        PARAMETER ( MAXTPS = 10 ) 
      INTEGER MAXTPT               ! Max no. temperatures in TIPS tabulations
        PARAMETER ( MAXTPT = 2931 )
C
C Note: MAXWID is a major factor in determining total memory (MAXWID*MAXCLC)
C Its size determines the widest spectrum (in wavenumbers) that can be 
C calculated with a single run of the RFM. 
      INTEGER MAXWID               ! Max. no. of widemesh intervals
        PARAMETER ( MAXWID = 3005 ) ! 1900 = 600-2500 in steps of 1.0
      INTEGER MAXWD2               ! 2 * MAXWID + 1 (+1 allows quick loading) 
        PARAMETER ( MAXWD2 = 2 * MAXWID + 1 ) ! Don't change this!
C
C Array sizes associated with .xsc files
      INTEGER MAXXSC               ! Max.no. X/S data sets to be used
        PARAMETER ( MAXXSC = 20 )
      INTEGER MAXXST               ! Max no. of X/S p,T tables per molecule
        PARAMETER ( MAXXST = 107 )  ! 55 is max.no sets in HITRAN2K X/S data 
      INTEGER MAXXSP               ! Max no. of X/S waveno.pts for any molecule
c        PARAMETER ( MAXXSP = 3500000 ) ! 400k req for F11 in HITRAN 96 X/S
        PARAMETER ( MAXXSP = 1657797 ) ! 400k req for F11 in HITRAN 96 X/S
C
C -----------------------------------------------------------------------------
