      SUBROUTINE RFMSVD 
C
C VERSION
C     13JAN14 AD Original. Extracted from old RFMLUT. New LUT handling
C 
C DESCRIPTION    
C     Calculate absorption using SVD-compressed Look-Up Tables.
C     Called by RFM for each wide mesh interval if LUT flag enabled
C                  
      IMPLICIT NONE
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'fincom.inc' ! Fine mesh data
      INCLUDE 'lkpcom.inc' ! Look-Up Table interpolation coefficients
      INCLUDE 'pthcom.inc' ! RFM path data
      INCLUDE 'svdcom.inc' ! SVD-compressed Look-Up Table data
C
C LOCAL VARIABLES
      INTEGER  IFIN        ! Fine mesh grid point counter (0:NFIN)
      INTEGER  IGAS        ! Gas counter
      INTEGER  IL          ! Counter for basis vectors
      INTEGER  ILKP        ! Counter for p,T interp pts for each path segment
      INTEGER  ISVD        ! Counter for SVD-LUT data sets
      INTEGER  IPTH        ! Path counter
      INTEGER  IV          ! Index for Tab.grid for particular SVD-LUT
      INTEGER  IVL         ! Absolute index for IV in IVSVD array 
      INTEGER  IVLMAX      ! Index for IVSVD array element corresp. to WNOMAX
      INTEGER  IVLMIN      ! Index for IVSVD array element corresp. to WNOMIN
      INTEGER  IVMAX(MAXSVD) ! Tab.grid pointers correspoding to WNOMAX
      INTEGER  IVMIN(MAXSVD) ! Tab.grid pointers correspoding to WNOMIN
      INTEGER  IVUMTX      ! Index for U-matrix wavenumber axis
      INTEGER  IX          ! Index for K-matrix p,T axis
      LOGICAL  USELOG      ! T=Tabulated function is ln(k)
      LOGICAL  USE4RT      ! T=Tabulated function is SQRT(SQRT(k))
      REAL     ABS         ! Single gas optical depth for path segment 
      REAL     DV          ! Fraction of Wno  Tab.interval above Fine Mesh value
      REAL     KV          ! Abs.Coeff constructed at particular wavenumber
      REAL     KX          ! Abs.Coeff constructed for tabulated p,T pt
      REAL     KABS(MAXLUV) ! Reconstructed SVD-LUT Absorption Coefficient.
      DOUBLE PRECISION WNO    ! Waveno of current Fine Mesh grid point
      DOUBLE PRECISION WNO2ND ! Next tabulated wno above WNOMIN
      DOUBLE PRECISION WNOLOW ! Tabulated wno immediately below fine grid point
      DOUBLE PRECISION WNOMAX ! Upper tabulated wno spanning WM interval
      DOUBLE PRECISION WNOMIN ! Lower tabulated wno spanning WM interval
      DOUBLE PRECISION WNOUPP ! Tabulated wno immediately above fine grid point
C
C DATA STATEMENTS
      DATA IVMIN / MAXSVD * 1 /
      DATA IVMAX / MAXSVD * 1 /
      SAVE IVMIN, IVMAX
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      DO ISVD = 1, NSVD
        IGAS = IGSSVD(ISVD)
        USELOG = TABSVD(ISVD) .EQ. 'log'
        USE4RT = TABSVD(ISVD) .EQ. '4rt'
        DO IPTH = 1, NCLC
          IF ( IGSPTH(IPTH) .EQ. IGAS ) THEN 
C
C Multiply out basis vectors to construct Absorption Coefficient array
C
C Find index range of LUT wavenumber axes that span this interval
C In the following, the tabulated points are WNOMIN,WNO2ND,...,WNOMAX
C and the aim is to set the tabulation pointers so that the end points of the 
C current WM interval (WN1FIN:WN2FIN) are each bracketed by the end two tabulated
C points: WNOMIN < WN1FIN < WNO2ND and (penultimate pt) < WN2FIN < WNOMAX 
C
C Use previously saved value for WNOMIN for this LUT
            IVLMIN = IVMIN(ISVD) + IVOSVD(ISVD)
            WNOMIN = V1SVD(ISVD) + ( IVSVD(IVLMIN) - 1 ) * DVSVD(ISVD)
C
C If WM intvl starts below current lower tabulated point, this could just be 
C because the spectral range is still below the lowest tabulated point, or it
C could be the start of a new spectral range. Either way: reset pointer to
C lowest tabulated points.
            IF ( WNOMIN .GT. WN1FIN ) THEN  
              IVMIN(ISVD) = 1
              IVLMIN = 1 + IVOSVD(ISVD)
              WNOMIN = V1SVD(ISVD) 
              IVMAX(ISVD) = 1
              IVLMAX = 1 + IVOSVD(ISVD)
              WNOMAX = V1SVD(ISVD) 
            END IF
C
C Advance WNOMIN,WNO2ND pointers until WN1FIN < WNO2ND
            WNO2ND = V1SVD(ISVD) + ( IVSVD(IVLMIN+1)-1 ) * DVSVD(ISVD)
            DO WHILE ( WNO2ND .LT. WN1FIN .AND. 
     &                 IVMIN(ISVD) .LT. NVSVD(ISVD)-1 )
              IVMIN(ISVD) = IVMIN(ISVD) + 1
              IVLMIN = IVLMIN + 1
              WNOMIN = WNO2ND
              WNO2ND = V1SVD(ISVD) + ( IVSVD(IVLMIN+1)-1 ) * DVSVD(ISVD)
            END DO
C
C Adance WNOMAX pointer until WN2FIN < WNOMAX
            IVLMAX = IVMAX(ISVD) + IVOSVD(ISVD)
            WNOMAX = V1SVD(ISVD) + ( IVSVD(IVLMAX) - 1 ) * DVSVD(ISVD)
            DO WHILE ( WNOMAX .LT. WN2FIN .AND. 
     &                 IVMAX(ISVD) .LT. NVSVD(ISVD) )
              IVMAX(ISVD) = IVMAX(ISVD) + 1
              IVLMAX = IVLMAX + 1
              WNOMAX= V1SVD(ISVD) + ( IVSVD(IVLMAX) - 1 ) * DVSVD(ISVD)
            END DO
C
C Expand basis vectors to fill KABS array for required wavenumber range to span
C this widemesh interval
            DO IV = IVMIN(ISVD), IVMAX(ISVD)
              IVUMTX = IV + IVOSVD(ISVD)
              KV = 0.0
              DO ILKP = IL1PTH(IPTH), IL2PTH(IPTH)
                IX = IDXLKP(ILKP)
                KX = 0.0
                DO IL = 1, NLSVD(ISVD)              ! loop over all basis vector
                  KX = KX + U(IVUMTX,IL) * K(IL,IX) ! multiply U * K(p,T)
                END DO
                IF ( USELOG ) THEN
                  KV = KV + WGTLKP(ILKP) * KX
                ELSE
                  KV = KV + WGTLKP(ILKP) * LOG ( MAX ( KX, ARGMIN ) ) 
                END IF
              END DO
              IF ( USE4RT ) KV = 4.0*KV
              if ( kv .gt. 100.0 ) then
                write (*,*) uselog
                write (*,*) il1pth(ipth),il2pth(ipth)
                write (*,*) kv, wgtlkp(ilkp), nlsvd(isvd), isvd
                stop
              end if
              KABS(IV) = KV
            END DO
C
C Interpolate absorption coeff array to fine mesh and scale by absorber amounts
C for single-gas optical depths. Note that ABSFIN may contain continuum data
C already, so add on this term.
C Factor 1.0e7 to convert AMT [kmoles/cm^2]) to [moles/m^2] for compatibility
C with pretabulated K coefficients.
C
            IVL   = IVLMIN
            IV    = IVLMIN - IVOSVD(ISVD)
            WNOLOW = WNOMIN
            WNOUPP = WNO2ND
            DO IFIN = 1, NFIN
              WNO = WNOFIN(IFIN)
              DO WHILE ( WNO .GT. WNOUPP .AND. IV .LT. NVSVD(ISVD)-1 ) 
                IVL   = IVL + 1
                IV    = IV + 1
                WNOLOW = WNOUPP
                WNOUPP = V1SVD(ISVD) + ( IVSVD(IVL+1)-1 ) * DVSVD(ISVD)
              END DO
              DV = SNGL ( ( WNO - WNOLOW ) / ( WNOUPP - WNOLOW ) )
              IF ( DV .GE. 0.0 .AND. DV .LE. 1.0 ) THEN
                ABS = EXP ( ( 1.0 - DV ) * KABS(IV) + DV * KABS(IV+1) )  
     &                * AMTPTH(IPTH) * 1.0E7
                ABSFIN(IFIN,IPTH) = ABSFIN(IFIN,IPTH) + ABS  
                CNTFIN(IFIN,IPTH) = ABSFIN(IFIN,IPTH)
              END IF
            END DO
          END IF
        END DO
      END DO
C
      END
