      SUBROUTINE SPCFIL ( LUNSPC, NAMSPC, FAIL, ERRMSG )
C
C VERSION
C     05JAN15 AD Tidied up. Use DO ... WHILE rather than GOTO
C     22JAN98 AD Remove redundant EXTERNAL declaration: RFMLOG
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Open file and load pretabulated spectral range data.
C     Called by INPSPC for each record in *SPC section with 1 field.
C
      IMPLICIT NONE 
C
C ARGUMENTS 
      INTEGER       LUNSPC  !  I  Logical unit number for opening file
      CHARACTER*(*) NAMSPC  !  I  Name of spectral range data file
      LOGICAL       FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  NXTREC ! Load next record from RFM input file
     &, OPNFIL ! Open ASCII input file, and skip/Log any initial comments.
     &, SPCLAB ! Check Spc.range label find index in table.
     &, SPCRNG ! Check Spectral Range & Resln parameters and update table.
     &, TXTFLD ! Identify start and end points of text field in record
C
C LOCAL VARIABLES
      INTEGER      IDXSPC    ! Index of spectral range in tabulated data
      INTEGER      ISTA,IEND ! Pointers to start,end of field in RECORD
      LOGICAL      ENDSEC    !  TRUE = end of section or file
      LOGICAL      LDUMMY    ! TRUE = new spectral range added (ignored here)
      CHARACTER*80 RECORD    ! Record read from Spc.range file
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      CALL OPNFIL ( LUNSPC, NAMSPC, FAIL, ERRMSG )
      IF ( FAIL ) RETURN                    
C
C Load first record from Spc.range file
      CALL NXTREC ( LUNSPC, RECORD, ENDSEC, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
      DO WHILE ( .NOT. ENDSEC) 
C
C Extract Label and index in internal table of spectral ranges 
        CALL TXTFLD ( 80, RECORD, 1, ISTA, IEND )
        CALL SPCLAB ( RECORD(ISTA:IEND), IDXSPC, LDUMMY, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
C
C Pass remainder of record for extraction of range and resolution parameters
        CALL SPCRNG ( IDXSPC, RECORD(IEND+1:), FAIL, ERRMSG )
        IF ( FAIL ) RETURN
C
C Get next record from Spectral Range file
        CALL NXTREC ( LUNSPC, RECORD, ENDSEC, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END DO
C
      CLOSE ( LUNSPC )
C
      END
