      SUBROUTINE SPCFIN ( ISPC )
C
C VERSION
C     05JAN15 AD Tidied up
C     04JAN99 AD Allow for AVGFLG as well a ILSFLG
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     17SEP96 AD Remove redundant RFMCON.INC
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Set Fine Mesh grid parameters from spectral range/resln.
C     Called by FINCHK and RFMSPC for each required spectral range.
C     WNRSPC is resolution parameter, either as no.pts/wavenumber (WNRSPC>1)
C       or as actual resolution (<1).
C     If not using ILS convolution, WNRSPC refers to finemesh spacing directly.
C     If using ILS convolution, WNRSPC refers to final output spectra resolution
C       so set finemesh to closest sub-multiple of WNRSPC to NOMFIN pts/wno.
C 
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      ISPC    !  I  Index of spectral range 
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'fincom.inc' ! Fine mesh data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
      INCLUDE 'widcom.inc' ! Wide mesh data
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Calculation of WNRFIN should match that in ILSCHK.FOR
      IF ( ILSFLG .OR. AVGFLG ) THEN                     ! Using ILS 
        IF ( WNRSPC(ISPC) .GT. 1.0 ) THEN                ! N.Pts/wavenumber
          WNRFIN = 1.D0 / ( WNRSPC(ISPC) * NINT ( NOMFIN /WNRSPC(ISPC)))
        ELSE                                             ! Resolution
          WNRFIN = WNRSPC(ISPC) / NINT ( NOMFIN * WNRSPC(ISPC) )
        END IF
      ELSE                                               ! Not using ILS
        IF ( WNRSPC(ISPC) .GT. 1.0 ) THEN                ! N.Pts/wavenumber
          WNRFIN = 1.D0 / WNRSPC(ISPC)
        ELSE                                             ! Resolution
          WNRFIN = WNRSPC(ISPC)
        END IF
      END IF
C
      NFIN = NINT ( DELWID / WNRFIN )
C
      END
