      SUBROUTINE SPCGRD ( ISPC, FAIL, ERRMSG )
C
C VERSION
C     10DEC14 AD Determine if /GRDCOM/ already contains required grid
C     01DEC14 AD Rewritten
C     17AUG06 AD Allow for -NPT (ie grd in GHz). REWIND LUNGRD 
C     13JAN03 AD Add GRDILS
C     02JAN03 AD Add outcom.inc since *OUT variables now set beforehand
C     27APR00 AD Convert ILS fn to DP
C     11AUG99 AD Change variable names HEADER,NUSE to CDUMMY, IDUMMY.
C                    Make D.P. operations explicit
C     24JUL99 AD Modify CONFIG from C*40 to C*35
C     23APR99 AD Adapt error messages for C*8 LABSPC 
C     18DEC97 AD Original.
C
C DESCRIPTION
C     Initialise GRD data for each new spectral range.
C     Called RFMSPC once for each spectral range.
C     Note that all array dimensions have been checked previously by GRDCHK.
C     This routine finds which GRD file (if any) contains the grid points for
C     the current spectral range and loads the grid in GRDCOM.INC.
C     If no grid exists, then NGRD is set to zero.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       ISPC    !  I  Current spectral range
      LOGICAL       FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  GRDILS ! Calc. Irreg. grid direct contribs to convolved output grid. 
     &, LUTGRD ! Use LUT files to set irregular grid.
     &, NAMLOG ! Send text plus variable length filename to log file.
     &, REAGRD ! Read irregular grid data from .grd file into /GRDCOM/
     &, RFMLOG ! Write text message to RFM log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gflcom.inc' ! Grid file data
      INCLUDE 'grdcom.inc' ! Irregular grid 
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
C
C LOCAL VARIABLES
      INTEGER          IGFL   ! GRD file counter
      INTEGER          JSPC   ! Counter for different spectral ranges
      INTEGER          NSPGRD ! No.spectral ranges with associated irreg.grids
      CHARACTER*80     MESSGE ! Message for RFM log file
      DOUBLE PRECISION WNOMAX ! Highest Wno [/cm] required from GRD 
      DOUBLE PRECISION WNOMIN ! Lowest Wno [/cm] required from GRD 
C
C DATA STATEMENTS
      DATA NSPGRD / -1 / 
      SAVE NSPGRD
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C On first call, establish how many spectral ranges have associated irreg.grids
      FAIL = .FALSE.
      IF ( NSPGRD .EQ. -1 ) THEN
        NSPGRD = 0
        DO JSPC = 1, NSPC
          IF ( IDXGFL(JSPC) .NE. 0 ) THEN 
            NSPGRD = NSPGRD + 1
          END IF
        END DO
        IF ( NSPGRD .EQ. 0 ) THEN
          NGRD = 0                ! This has to be set since checked in RFMWRT
          MESSGE = 'W-SPCGRD: No irreg.grid data used for any spc.range'
          CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
          RETURN
        END IF
      ELSE
        IF ( NSPGRD .EQ. 0 ) RETURN
      END IF          
C
C Set min/max wavenumber points required for spectral range (including any
C convolution)
      WNOMAX = WXUSPC(ISPC)
      WNOMIN = WXLSPC(ISPC)
C
C Find if an irregular grid is defined for this spectral range
      OUTGRD = .FALSE.
      IF ( IDXGFL(ISPC) .EQ. 0 ) THEN
        NGRD = 0
        MESSGE = 'I-SPCGRD: Spc.Rng='//LABSPC(ISPC)//
     &        ': no GRD data applicable so using full grid'
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        RETURN
      END IF
C
C Irreg grids are read into /GRDCOM/ as part of driver table checks, so if
C only one spectral range has an associated grid then it will already be 
C loaded into /GRDCOM/ so no need to re-read it.
      IF ( NSPGRD .NE. 1 ) THEN      ! Grid not currently loaded
        IF ( IDXGFL(ISPC) .EQ. -1 ) THEN  ! Construct from LUT files
          CALL LUTGRD ( ISPC, FAIL, ERRMSG ) 
        ELSE                                   ! Read in specific grd file
          IGFL = IDXGFL(ISPC)
          CALL NAMLOG ( 'I-SPCGRD: Opening file:', NAMGFL(IGFL),
     &                  FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          CALL REAGRD ( LUNGFL, NAMGFL(IGFL), WNOMIN, WNOMAX, 
     &                  FAIL, ERRMSG )
            IF ( FAIL ) RETURN
        ENDIF
      END IF
C
C Attempt direct interpolation from irregular grid to output grid if possible
      IF ( ILSFLG .OR. AVGFLG ) THEN
        CALL GRDILS ( ISPC, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF            
C
      END
