      SUBROUTINE SPCLUT ( ISPC, FAIL, ERRMSG )
C
C VERSION
C     15JAN14 AD Rewritten for new LUTs
C     06APR06 AD Change 'X' to '1X' in format
C     09JUN05 AD Remove test for old format LUT files.
C     09MAY04 AD Allow for isotopic LUTs
C     02JAN03 AD Add outcom.inc since *OUT variables now set beforehand
C     08JUN00 AD Allow for Irregular Grid LUT files
C     27APR00 AD Convert ILS to DP
C     05JAN00 AD Allow for AVG option.
C     11AUG99 AD Change variable names and make D.P. explicit
C                    Initialise and SAVE SHPSAV
C     03JUL97 AD Original.
C
C DESCRIPTION
C     Initialise LUT data for each new spectral range.
C     Called RFMSPC once for each spectral range.
C     Note that all array dimensions have been checked previously by LUTCHK.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      ISPC    !  I  Current spectral range
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  LUTPTH ! Calculate LUT p,T,q-axis interpolation factors for each path.
     &, LUTSVD ! Load SVD-compressed LUT data from file.
     &, LUTTAB ! Open TAB-LUT file and read in header info.
     &, SVDPTH ! Calculate LUT p,T-axis interpolation factors for each path.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'shpcon.inc' ! Line-shape codes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'lflcom.inc' ! Look-Up Table file data
      INCLUDE 'lkpcom.inc' ! Look-Up Table interpolation coefficients
      INCLUDE 'svdcom.inc' ! SVD-compressed Look-Up Table data
C
C LOCAL VARIABLES
      INTEGER IGAS         ! Index of gas in LUT file
      INTEGER ILFL         ! LUT file counter
      INTEGER NLUT         ! Counter for LUT files in current spectral range 
      INTEGER SHPSAV(MAXGAS) ! Saved values of SHPGAS
C
      DATA SHPSAV / MAXGAS * 0 / 
      SAVE SHPSAV
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Reset - assume closing LUNs which are not open will not cause any error
      DO ILFL = 1, NLFL
        SPCLFL(ILFL) = .FALSE.
        CLOSE ( LUNLFL(ILFL) )
        ILTLFL(ILFL) = 0
      END DO
C
C For each spectral range, any gas using LUT data has SHPGAS overwritten with 
C info identifying LUT, so this needs to be replaced from previous Spc.range
      DO IGAS = 1, NGAS
        IF ( SHPGAS(IGAS) .EQ. SHPLUT ) SHPGAS(IGAS) = SHPSAV(IGAS)
      END DO
C
      NSVD = 0
      NLKP = 0
      NLUT = 0
C
      DO IGAS = 1, NGAS
        ILFL = IDXLFL(IGAS,ISPC) 
        IF ( ILFL .GT. 0 ) THEN
          SHPSAV(IGAS) = SHPGAS(IGAS)
          SHPGAS(IGAS) = SHPLUT
          IF ( SVDLFL(ILFL) ) THEN
            NSVD = NSVD + 1
            CALL LUTSVD ( LUNLFL(ILFL), NAMLFL(ILFL), NSVD, NLLFL(ILFL),
     &                    IGAS, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
            CALL SVDPTH( NSVD, FAIL, ERRMSG )
          ELSE 
            NLUT = NLUT + 1
            ILTLFL(ILFL) = -NLUT          ! -ve is flag to initialise REALUT
            SPCLFL(ILFL) = .TRUE.
            CALL LUTTAB ( LUNLFL(ILFL), NAMLFL(ILFL), BINLFL(ILFL), 
     &               IGAS, NDPLFL(ILFL), NDTLFL(ILFL), FAIL, ERRMSG )
            IF ( FAIL ) RETURN
            CALL LUTPTH ( IGAS, FAIL, ERRMSG )
          END IF
          IF ( FAIL ) RETURN
        END IF
      END DO
C Normal exit
      FAIL = .FALSE.
C
      END
