      SUBROUTINE SPCRES ( RECORD, FAIL, ERRMSG )
C
C VERSION
C     03JAN15 AD Tidied up
C     23APR99 AD Adapt for C*8 LABEL instead of C*6
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Set calculation resolution for labelled spectral range.
C     Called by INPSPC for each record in *SPC section with 2 fields.
C     
      IMPLICIT NONE
C
C ARGUMENTS
      CHARACTER*80 RECORD  !  I  Record read from Driver Table
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  SPCLAB ! Check Spc.range label find index in table.
     &, TXTFLD ! Identify start and end points of text field in record
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
C
C LOCAL VARIABLES
      INTEGER       ISPC   ! Table index of required spectral range 
      INTEGER       IEND   ! Pointer to end of field in text record
      INTEGER       IOS    ! Saved value of IOSTAT   
      INTEGER       ISTA   ! Pointer to start of field in text record
      LOGICAL       NEW    ! Set TRUE if label not previously listed
      DOUBLE PRECISION WNORES ! Spectral resolution for calculations
      CHARACTER*8   LABEL  ! Checked Label for required spectral range 
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C Locate first field in record - should be Label - and check that a range has
C already been tabulated for it (ie not a NEW label)
C 
      CALL TXTFLD ( 80, RECORD, 1, ISTA, IEND )
      CALL SPCLAB ( RECORD(ISTA:IEND), ISPC, NEW, FAIL, ERRMSG )
      IF ( FAIL ) RETURN
      LABEL = LABSPC(ISPC)
      IF ( NEW ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-SPCRES: No pretabulated Spectral Range for Label: '
     &           //LABEL
        RETURN
      END IF
C
C Check that no calculation yet defined for this spectral range (if a non-zero
C resolution is specified then the range is already marked for use in this run)
C
      IF ( WNRSPC(ISPC) .NE. 0.0 ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-SPCRES: Resolution already defined for '//
     &           'Spectral Range, Label: '//LABEL
        RETURN
      END IF
C
C Read resolution from remainder of RECORD - value will be checked later
C
      READ ( RECORD(IEND+1:), *, IOSTAT=IOS ) WNORES
      IF ( IOS .NE. 0 ) THEN
        FAIL = .TRUE.
        WRITE ( ERRMSG, '(A,I11)' ) 
     &    'F-SPCRES: Failed to read Resln for Spc.range '//
     &    'label='//LABEL//'. IOSTAT=', IOS
        RETURN
      END IF
C
      WNRSPC(ISPC) = WNORES
      FAIL = .FALSE.
C
      END
