      SUBROUTINE SPCRNG ( ISPC, RECORD, FAIL, ERRMSG )
C
C VERSION
C     01JAN14 AD Tidied up.
C     23APR99 AD Adapt for C*8 label instead of C*6
C     03MAR97 AD Version 3.
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Check Spectral Range & Resln parameters and update table.
C     Called by INPSPC and SPCFIL
C
      IMPLICIT NONE 
C
C ARGUMENTS 
      INTEGER       ISPC    !  I  Index in table (range 1:NSPC)
      CHARACTER*(*) RECORD  !  I  Text record containing range & resln params
      LOGICAL       FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  RFMLOG ! Write text message to RFM log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmcon.inc' ! Constants for RFM calculations
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
C 
C LOCAL VARIABLES
      INTEGER          IOS    ! Saved value of IOSTAT for error message
      DOUBLE PRECISION WNOLOW ! Lower limit of Spc.range read from file [cm]
      DOUBLE PRECISION WNOUPP ! Upper limit of Spc.range read from file [cm]
      DOUBLE PRECISION WNORES ! Resolution of Spc.range read from file [cm]
      CHARACTER*8      LABEL  ! Spc.range label read from file
      CHARACTER*80     MESSGE ! Text for messages printed to Log file
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      LABEL = LABSPC(ISPC)
C
C Check that no calculation yet defined for this spectral range (if a non-zero
C resolution is specified then the range is already marked for use in this run)
C
      IF ( WNRSPC(ISPC) .NE. 0.0 ) THEN
        FAIL = .TRUE.
        ERRMSG = 'F-SPCRNG: Calculation already defined for '//
     &           'spectral range, Label: '//LABEL
        RETURN
      END IF
C
C Check that 3 numbers can be read successfully from record (actual values are
C checked later by SPCCHK)
C       
      READ ( RECORD, *, IOSTAT=IOS ) WNOLOW, WNOUPP, WNORES
      IF ( IOS .NE. 0 ) THEN
        FAIL = .TRUE.
        WRITE ( ERRMSG, '(A,I11)' ) 
     &   'F-SPCRNG: Error reading Rng/Res params for Label='//
     &    LABEL//'. IOSTAT=', IOS
        RETURN
      END IF
C
C If range already defined - check if now redefining range and issue warning
C NB: OK to redefine ranges for which no calculation yet specified (WNRSPC=0.0)
C
      IF ( WNLSPC(ISPC) .NE. 0.0 .AND. WNUSPC(ISPC) .NE. 0.0 ) THEN  ! defined
        IF ( WNOLOW .NE. WNLSPC(ISPC) .OR. 
     &       WNOUPP .NE. WNUSPC(ISPC)       ) THEN
          MESSGE = 'W-SPCRNG: Redefining Spectral Range for Label: '//
     &      LABEL
          CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF 
      END IF 
C
      WNLSPC(ISPC) = WNOLOW
      WNUSPC(ISPC) = WNOUPP
      WNRSPC(ISPC) = WNORES
C
      END
