      SUBROUTINE SUBAXS ( NDP, NDT )
C
C VERSION
C     25FEB14 AD Original. Based on TABAXS.
C 
C DESCRIPTION    
C     Subsample (p,T) axes from LUT input file.
C     Called by LUTTAB for each record read from TAB file if qualifiers used
C     to resample (p,T) axes.
C     Notes: interpretation of resampling increments NDP, NDT
C        +ve sample from first point on axis
C        -ve sample from last point on axis (ie keep last point on axis 
C            rather than first point)
C        0   Take single point nearest middle of axes (changes P1,T1).
C                  
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER NDP          !  I  p-axis subsample factor
      INTEGER NDT          !  I  T-axis subsample factor
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'tabcom.inc' ! Table axes for tabulated absorb.coeffs.
C
C LOCAL VARIABLES
      INTEGER IP           ! DO loop counter for original -lnp axis
      INTEGER IP1, IP2     ! DO loop limits for subsampling p-axis
      INTEGER IPSPAN       ! Range of Npts of orig p-axis that will be sampled
      INTEGER IPSTEP       ! Step size for subsampling p-axis
      INTEGER IT           ! DO loop counter for original Temp axis
      INTEGER IT1, IT2     ! DO loop limits for subsampling T-axis
      INTEGER ITSPAN       ! Range of Npts of Orig T-axis that will be sampled
      INTEGER ITSTEP       ! Step size for subsampling T-axis
      INTEGER IX           ! Counter for original axis
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      IF ( NDP .EQ. 0 ) THEN       
        IP1 = 1 + INT ( ( NPTAB - 1 ) / 2 ) ! NP=1,2,3,4,5 :IP1=1,1,2,2,3
        IP2 = IP1
        IPSTEP = 1
      ELSE
        IPSTEP = ABS ( NDP ) 
        IPSPAN = ( ( NPTAB - 1 ) / IPSTEP ) * IPSTEP
        IF ( NDP .GT. 0 ) THEN
          IP1 = 1
        ELSE
          IP1 = NPTAB - IPSPAN
        END IF
        IP2 = IP1 + IPSPAN
      END IF
      IX = 0
      DO IP = IP1, IP2, IPSTEP
        IX = IX + 1
        PAXTAB(IX) = PAXTAB(IP)
        TEMTAB(IX) = TEMTAB(IP)
        VMRTAB(IX,1) = VMRTAB(IP,1)   ! assume only IGAS=1 is used
      END DO
      NPTAB = IX
C
      IF ( NDT .EQ. 0 ) THEN       
        IT1 = 1 + INT ( ( NTTAB - 1 ) / 2 ) 
        IT2 = IT1
        ITSTEP = 1
      ELSE
        ITSTEP = ABS ( NDT ) 
        ITSPAN = ( ( NTTAB - 1 ) / ITSTEP ) * ITSTEP
        IF ( NDT .GT. 0 ) THEN
          IT1 = 1
        ELSE
          IT1 = NTTAB - ITSPAN
        END IF
        IT2 = IT1 + ITSPAN
      END IF
      IX = 0
      DO IT = IT1, IT2, ITSTEP
        IX = IX + 1
        TAXTAB(IX) = TAXTAB(IT)
      END DO
      NTTAB = IX
C
      END
