      SUBROUTINE SUBTAB ( ILFL, X, NX )
C
C VERSION
C     25FEB14 AD Original. Based on old TABAXS
C 
C DESCRIPTION    
C     Subsample tabulated abs.coeff data for reduced p,T axes.
C     Called by RFMTAB for each record read from TAB file if qualifiers used
C     to resample (p,T) axes.
C     See also SUBAXS which subsamples the individual p,T axis values
C     Notes: interpretation of resampling increments NDP, NDT
C        +ve sample from first point on axis
C        -ve sample from last point on axis (ie keep last point on axis 
C            rather than first point)
C        0   Take single point nearest middle of axes (changes P1,T1).
C                  
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER     ILFL     !  I  Index of LUT in /LFLCOM/
      REAL        X(*)     ! I/O Array to be subsampled
      INTEGER     NX       !  I  No.points in X after subsampling
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'lflcom.inc' ! Look-Up Table file data
C
C LOCAL VARIABLES
      INTEGER IP           ! DO loop counter for original -lnp axis
      INTEGER IP1, IP2     ! DO loop limits for subsampling p-axis
      INTEGER IPSPAN       ! Range of Npts of orig p-axis that will be sampled
      INTEGER IPSTEP       ! Step size for subsampling p-axis
      INTEGER IQ           ! DO loop counter for q-axis
      INTEGER IT           ! DO loop counter for original Temp axis
      INTEGER IT1, IT2     ! DO loop limits for subsampling T-axis
      INTEGER ITSPAN       ! Range of Npts of orig T-axis that will be sampled
      INTEGER ITSTEP       ! Step size for subsampling T-axis
      INTEGER IX           ! Counter for original axis
      INTEGER IY           ! Counter for new axis
      INTEGER NQ           ! No. points in q-axis
      INTEGER NTQ          ! Npts in q-axis * Npts in original T-axis
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      IF ( NDPLFL(ILFL) .EQ. 0 ) THEN       
        IP1 = 1 + INT ( ( NPLFL(ILFL) - 1 ) / 2 ) ! NP=1,2,3,4,5 :IP1=1,1,2,2,3
        IP2 = IP1
        IPSTEP = 1
      ELSE
        IPSTEP = ABS ( NDPLFL(ILFL) ) 
        IPSPAN = ( ( NPLFL(ILFL) - 1 ) / IPSTEP ) * IPSTEP
        IF ( NDPLFL(ILFL) .GT. 0 ) THEN
          IP1 = 1
        ELSE 
          IP1 = NPLFL(ILFL) - IPSPAN 
        END IF 
        IP2 = IP1 + IPSPAN 
      END IF 
C
      IF ( NDTLFL(ILFL) .EQ. 0 ) THEN       
        IT1 = 1 + INT ( ( NTLFL(ILFL) - 1 ) / 2 ) 
        IT2 = IT1
        ITSTEP = 1
      ELSE
        ITSTEP = ABS ( NDTLFL(ILFL) ) 
        ITSPAN = ( ( NTLFL(ILFL) - 1 ) / ITSTEP ) * ITSTEP
        IF ( NDTLFL(ILFL) .GT. 0 ) THEN
          IT1 = 1
        ELSE
          IT1 = NTLFL(ILFL) - ITSPAN
        END IF
        IT2 = IT1 + ITSPAN
      END IF
C
      IX = 0
      NQ = NQLFL(ILFL)
      NTQ = NTLFL(ILFL) * NQ
      DO IP = IP1, IP2, IPSTEP
        DO IT = IT1, IT2, ITSTEP
          IY = (IP-1) * NTQ + (IT-1) * NQ
          DO IQ = 1, NQ
            IX = IX + 1
            IY = IY + 1
            X(IX) = X(IY)
          END DO
        END DO
      END DO
      NX = IX
C
      END
