      SUBROUTINE SVDPTH ( ISVD, FAIL, ERRMSG )
C
C VERSION
C     13JUL15 AD Add NAMGAS
C     15JAN14 AD Original.
C 
C DESCRIPTION    
C     Calculate SVD-LUT p,T-axis interpolation factors for each path.
C     Called by SPCLUT for each SVD-LUT file.
C                  
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER      ISVD    !  I  Index of SVD-LUT
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL 
     &  NAMGAS ! Return molecular name associated with /GASCOM/ index
     &, RFMLOG ! Write text message to RFM log file.
      CHARACTER*7 NAMGAS
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'lkpcom.inc' ! Look-Up Table interpolation coefficients
      INCLUDE 'pthcom.inc' ! RFM path data
      INCLUDE 'svdcom.inc' ! SVD-compressed Look-Up Table data
C
C LOCAL VARIABLES
      INTEGER  IDUMMY      ! Dummy integer for swapping NT1LIM,NT2LIM
      INTEGER  ILEN        ! Length of GASSTR
      INTEGER  IP,IT       ! Indices of lower points in p,T-axes
      INTEGER  IGAS        ! Index of absorber in /GASCOM/
      INTEGER  IPTH        ! Path counter
      INTEGER  IXOFF       ! 0ffet for p,T axis for current SVD-LUT
      INTEGER  JP,JT       ! Indices of upper points in p,T-axes
      INTEGER  KP,KT       ! Counter for lower/upper points in p,T-axes
      INTEGER  NP1LIM      ! Counter for no.times p outside PAXTAB lower index
      INTEGER  NP2LIM      ! Counter for no.times p outside PAXTAB upper index
      INTEGER  NT1LIM      ! Counter for no.times T outside TAXTAB lower index
      INTEGER  NT2LIM      ! Counter for no.times T outside TAXTAB upper index
      INTEGER  NTOT        ! Total number of calculated paths for IGAS
      REAL     DP          ! Fraction of p-axis interval above IP
      REAL     DT          ! Fraction of T-axis interval above IT
      REAL     XP          ! Position of path p in p-axis units
      REAL     XT          ! Position of path T in T-axis units
      REAL     LNP         ! -ln(Pressure [mb]) of path segment 
      REAL     PFACT       ! Interpolation weight for p-axis (DP or 1-DP)
      REAL     TFACT       ! Interpolation weight for T-axis (DT or 1-DT)
      REAL     XFACT       ! Product of interpolation weights PFACT,TFACT
      CHARACTER*7 GASSTR   ! Molecule name ( + any isotopic ID)
      CHARACTER*80 WRNMSG  ! Warning message
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      FAIL = .FALSE.
C
C Initialise out-of-axis-range counters
      NP1LIM = 0
      NP2LIM = 0
      NT1LIM = 0
      NT2LIM = 0
      NTOT = 0
C
      GASSTR = NAMGAS ( IGAS, ILEN )
C
      IXOFF = IXOSVD(ISVD)
      IGAS = IGSSVD(ISVD)
      DO IPTH = 1, NCLC
        IF ( IGSPTH(IPTH) .EQ. IGAS ) THEN
          NTOT = NTOT + 1
C
          LNP = - LOG ( PREPTH(IPTH) * ATMB )          ! convert [atm] to [mb]
          XP = ( LNP - P1SVD(ISVD) ) / DPSVD(ISVD) + 1.0
          IP = INT ( XP )
          IF ( XP .LT. 1 ) THEN
            IP = 1
            DP = 0.0
            NP1LIM = NP1LIM + 1
          ELSE IF ( XP .GT. NPSVD(ISVD) ) THEN
            IP = NPSVD(ISVD)
            DP = 0.0
            NP2LIM = NP2LIM + 1
          ELSE
            DP = XP - IP
          END IF
          JP = MIN ( NPSVD(ISVD), IP + 1 )     ! MIN to allow for IP=NPSVD
C
          XT = ( TEMPTH(IPTH) - T1SVD(ISVD) ) / DTSVD(ISVD) + 1.0
          IT = INT ( XT )
          IF ( XT .LT. 1 ) THEN
            IT = 1
            DT = 0.0
            NT1LIM = NT1LIM + 1
          ELSE IF ( XT .GT. NTSVD(ISVD) ) THEN
            IT = NTSVD(ISVD)
            DT = 0.0
            NT2LIM = NT2LIM + 1
          ELSE
            DT = XT - IT
          END IF
          JT = MIN ( NTSVD(ISVD), IT + 1 )     ! MIN to allow for IT=NTSVD
C
C Calculate weights for lower and upper points in p,T,q axes
          IL1PTH(IPTH) = NLKP + 1
          TFACT = 1.0 - DT
          DO KT = IT, JT
            PFACT = 1.0 - DP
            DO KP = IP, JP
              XFACT = TFACT * PFACT 
              IF ( XFACT .GT. 0.0 ) THEN  ! only store non-zero weights
                IF ( NLKP .GT. MAXLKP ) THEN
                  FAIL = .TRUE.
                  WRITE ( ERRMSG, '(A,I11)' ) 
     &              'F-SVDPTH: No.pT coords for SVD-LUTs > MAXLKP '//
     &              'in rfmsiz.inc, =', MAXLKP
                  RETURN
                END IF
                NLKP = NLKP + 1
                WGTLKP(NLKP) = XFACT
                IDXLKP(NLKP) = IXOFF + (KT-1)*NPSVD(ISVD) + KP
              END IF
              PFACT = DP
            END DO
            TFACT = DT
          END DO                                
          IL2PTH(IPTH) = NLKP 
        END IF
      END DO
C
      IF ( NPSVD(ISVD) .GT. 1 ) THEN
        IF ( DPSVD(ISVD) .GT. 0.0 ) NP2LIM = NP1LIM  ! DP +ve is max(p) as P1
        IF ( NP2LIM .GT. 0 ) THEN
          WRITE ( WRNMSG, '(A,A,A,I6,A,F6.2,A)' ) 
     &      'W-SVDPTH: ', GASSTR(1:ILEN), 
     &      ' Path Pre > LUT Max Pre for', NP2LIM,
     &      ' calc paths (', FLOAT(NP2LIM)/FLOAT(NTOT), '%)'
          CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
      END IF
      IF ( NTSVD(ISVD) .GT. 1 ) THEN
        IF ( DTSVD(ISVD) .LT. 0.0 ) THEN  ! DT -ve is max(T) as T1
          IDUMMY = NT2LIM
          NT2LIM = NT1LIM
          NT1LIM = IDUMMY
        END IF
        IF ( NT2LIM .GT. 0 ) THEN
          WRITE ( WRNMSG, '(A,A,A,I6,A,F6.2,A)' ) 
     &      'W-SVDPTH: ', GASSTR(1:ILEN),
     &      ' Path Tem > LUT Max Tem for', NT2LIM,
     &      ' calc paths (', FLOAT(NT2LIM)/FLOAT(NTOT), '%)'
          CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
        IF ( NT1LIM .GT. 0 ) THEN
          WRITE ( WRNMSG, '(A,A,A,I6,A,F6.2,A)' ) 
     &      'W-SVDPTH: ', GASSTR(1:ILEN), 
     &      ' Path Tem < LUT Min Tem for', NT1LIM,
     &      ' calc paths (', FLOAT(NT1LIM)/FLOAT(NTOT), '%)'
          CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
      END IF
C
      END
