      SUBROUTINE TABPTH ( FAIL, ERRMSG )
C
C VERSION
C     24JUN15 AD Bug#104: reword error message if MAXCLC exceeded
C     09APR15 AD Convert VMRTAB from [ppv] to [ppmv]
C     24SEP14 AD Change AMTPTH factor 1E-7 to 1E-4 for kmol/m2 output (not mole)
C     13DEC13 AD Rewritten for new table dimensions.
C     29APR99 AD Allow for temperature offset
C     14JUL98 AD Comment change only.
C     22OCT97 AD Original. 
C
C DESCRIPTION
C     Set up paths RFM TABulated abs.coeff. calculations.
C     Called by INPDIM if TAB flag enabled.
C     A path is defined for each absorber, pressure and temperature.
C
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG  !  O  Contains error message if FAIL is TRUE.
C
      EXTERNAL
     &  INTERP ! General interpolation of arrays
     &, RFMLOG ! Write text message to RFM log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data 
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'pthcom.inc' ! RFM path data
      INCLUDE 'tabcom.inc' ! Table axes for tabulated absorb.coeffs.
C
C LOCAL VARIABLES
      INTEGER      IGAS    ! Gas counter
      INTEGER      IPTAB   ! Counter for P-axis points 
      INTEGER      IQTAB   ! Counter for Q-axis points 
      INTEGER      ITTAB   ! Counter for T-axis points 
      INTEGER      IPTH    ! Path segment counter
      REAL         LNPTAB(MAXTAB) ! Log ( P-axis [mb] values )
      REAL         PMAX    ! Max value [mb] of P-axis 
      REAL         PMIN    ! Min value [mb] of P-axis
      REAL         PRE     ! Pressure axis value converted to [atm]
      REAL         TEM     ! Temperature axis value [K]
      REAL         VMR     ! Volume mixing ratio [ppv]
      CHARACTER*80 WRNMSG  ! Warning message sent to log file
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C Calculate the total number of different paths required (=tabulated points
      NATAB = NPTAB * NTTAB * NQTAB
      NCLC = NATAB * NGAS
      NPTH = NCLC
C
C Check sufficient array space for NPTH and NCLC
      FAIL = .TRUE.
      IF ( NPTH .GT. MAXPTH ) THEN
        WRITE ( ERRMSG, '(A,I11,A,I7)' ) 'F-TABPTH: No.paths reqd=', 
     &    NPTH, ' >MAXPTH in rfmsiz.inc=', MAXPTH
      ELSE IF ( NCLC .GT. MAXCLC ) THEN
        WRITE ( ERRMSG, '(A,I11,A,I7)' ) 
     &    'F-TABPTH: No.paths for LBL calc=', NCLC,
     &    ' >MAXCLC in rfmsiz.inc=', MAXCLC
      ELSE 
        FAIL = .FALSE.
      END IF
      IF ( FAIL ) RETURN
C
C Compare tabulated pressures with atmospheric profile range and send warning
C message if P-axis extends outside profile (unless HOMFLG enabled, which would
C always generate a warning - assume the user knows what they're doing!)
      PMIN = MIN ( PAXTAB(1), PAXTAB(NPTAB) )
      IF ( PMIN .LT. PREATM(NATM) .AND. .NOT. HOMFLG ) THEN
        WRITE ( WRNMSG, '(A,1PG10.3,A,1PG10.3,A)' )
     &    'W-TABPTH: Min P-axis value=', PMIN, 
     &    '[mb] < Min P profile value=', PREATM(NATM), '[mb]'
        CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
      PMAX = MAX ( PAXTAB(1), PAXTAB(NPTAB) )
      IF ( PMAX .GT. PREATM(1) .AND. .NOT. HOMFLG ) THEN
        WRITE ( WRNMSG, '(A,1PG10.3,A,1PG10.3,A)' )
     &    'W-TABPTH: Max P-axis value=', PMAX, 
     &    '[mb] > Max P profile value=', PREATM(1), '[mb]'
        CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
      END IF
C
C Set up log(p) array for p-axis values
      DO IPTAB = 1, NPTAB
        LNPTAB(IPTAB) = LOG ( PAXTAB(IPTAB) ) 
      END DO
C
C Interpolate atmospheric T profile values to lnp-axis
      CALL INTERP ( NATM, NPTAB, LNPATM, LNPTAB, TEMATM, .FALSE., 
     &              .FALSE., TEMTAB )       ! F=no extrapolation outside LNPATM
C
C Determine if temperature axis is absolute or relative to TEMTAB
      OFFTAB = MIN ( TAXTAB(1), TAXTAB(NTTAB) ) .LE. 0.0
C
C Set up arrays in pthcom.inc
      IPTH = 0
      DO IGAS = 1, NGAS
C Interpolate VMR [ppv] profile to lnp axis, linearly or log in VMR
        CALL INTERP ( NATM, NPTAB, LNPATM, LNPTAB, VMRATM(1,IGAS), 
     &                LINFLG, .FALSE., VMRTAB(1,IGAS) )
        DO IPTAB = 1, NPTAB
          PRE = PAXTAB(IPTAB) / ATMB        ! Convert [mb] to [atm]
          TEM = TEMTAB(IPTAB)               
          VMR = VMRTAB(IPTAB,IGAS)          ! [ppv]
          VMRTAB(IPTAB,IGAS) = VMRTAB(IPTAB,IGAS) * 1.0E6  ! [ppv] to [ppmv]
          DO ITTAB = 1, NTTAB
            TEM = TAXTAB(ITTAB)             
            IF ( OFFTAB ) TEM = TEM + TEMTAB(IPTAB)
            DO IQTAB = 1, NQTAB
              IPTH = IPTH + 1
              IGSPTH(IPTH) = IGAS
              PREPTH(IPTH) = PRE
              TEMPTH(IPTH) = TEM
              PPAPTH(IPTH) = VMR * PRE * QAXTAB(IQTAB)*0.01     ! 0.01 for %
              AMTPTH(IPTH) = 1.0E-4 ! 10^-4 kmol/cm^2 = 1 kmol/m^2 in output
              CLCPTH(IPTH) = .TRUE.
            END DO
          END DO
        END DO
      END DO
C
      END
