      SUBROUTINE TANHGT ( FAIL, ERRMSG )
C
C VERSION 
C     01JAN15 AD Simplify into single loop over ITAN
C     03SEP03 AD Set SFCTAN
C     18MAR01 AD Add CHKLIM
C     29DEC99 AD Use GRACNV instead of TANCNV if GRAFLG enabled.
C     18JUL98 AD Original.
C
C DESCRIPTION
C     Calculate full tangent height information
C     Called once by INPCHK.
C     Only calculates for nominal output tangent heights since the information
C     for additional FOV-convolution tangent paths is calculated during FOVTAN.
C
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL      FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80 ERRMSG !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  CHKLIM ! Check path for Limb-viewing mode
     &, GRACNV ! Convert tangent point specifications for 2D atmosphere.
     &, TANCNV ! Convert tangent point specifications
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'tancom.inc' ! Tangent heights
C
C LOCAL VARIABLES
      INTEGER  ITAN   ! Tangent path counter
      INTEGER  MODE   ! #1=ELETAN,#2=GEOTAN,#3=HGTTAN initially defined
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      MODE = 3
      IF ( USRELE ) MODE = 1
      IF ( USRGEO ) MODE = 2
      DO ITAN = 1, NTAN
        CALL CHKLIM ( USRTAN(ITAN), USRELE, USRGEO, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        HGTTAN(ITAN) = USRTAN(ITAN)
        IF ( USRELE ) ELETAN(ITAN) = USRTAN(ITAN)
        IF ( USRGEO ) GEOTAN(ITAN) = USRTAN(ITAN)
        IF ( GRAFLG ) THEN 
          CALL GRACNV ( MODE, ELETAN(ITAN), GEOTAN(ITAN), HGTTAN(ITAN),
     &                    SZNTAN(ITAN), PSITAN(ITAN), SFCTAN(ITAN) )
        ELSE
          CALL TANCNV ( MODE, ELETAN(ITAN), GEOTAN(ITAN), HGTTAN(ITAN),
     &                    SZNTAN(ITAN), SFCTAN(ITAN) )
        END IF
      END DO
C
      END
