      SUBROUTINE TPSDEF ( LUNTPS, NAMDEF, FAIL, ERRMSG )
C
C VERSION
C     17NOV14 AD Simplify by using EXPNAM and CHKFIL functions, and NAMLOG
C     23JUL03 AD Original.
C
C DESCRIPTION
C     Use default .tps filename to find any missing files.
C     Called once by INPTPS if filename template found in *TPS section of 
C     driver table.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNTPS ! I/O LUN for TPS File/next free LUN
      CHARACTER*(*) NAMDEF !  I  Default name of TPS file
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CHKFIL ! Check if argument represents an existing filename
     &, EXPNAM ! Replace '*' in filename with given string
     &, NAMLOG ! Send text plus variable length filename to log file
     &, RFMLOG ! Write text message to RFM log file.
     &, TPSFIL ! Open TIPS data file, check and load contents.
      LOGICAL CHKFIL
      CHARACTER*200 EXPNAM
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'tpscom.inc' ! Tabulated TIPS data
C
C LOCAL VARIABLES
      INTEGER       IGAS   ! Counter for absorbing species
      INTEGER       ITPS   ! Counter for current TPS tabulations
      CHARACTER*80  NAMTPS ! Name of TPS file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Send message to LOG file saying which file is about to be opened
      CALL RFMLOG ( 'I-TPSDEF: Checking default .tps files', 
     &              FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      DO IGAS = 1, NGAS                            ! Loop over absorbers
        DO ITPS = 1, NTPS                          ! Loop over TPS data
          IF ( IDGTPS(ITPS) .EQ. IGSMOL(IGAS) ) GOTO 100 ! data already loaded
        END DO
C At this point, absorber found requiring .tps data but no data yet loaded
        NAMTPS = EXPNAM ( NAMDEF, CODGAS(IGAS) )
        CALL NAMLOG ( 'I-TPSDEF: looking for file: ', NAMTPS, 
     &                FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        IF ( CHKFIL ( NAMTPS ) ) THEN              ! If file exists, then read
          CALL TPSFIL ( LUNTPS, NAMTPS, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
        END IF
 100    CONTINUE         ! jump here if TIPS data already found
      END DO
C
      FAIL = .FALSE.
C
      END
