      CHARACTER*3 FUNCTION TYPLUT ( LUNLUT, NAMLUT )
C
C VERSION
C     19JUN15 AD Change default sequence, check for error reading RFMT
C     24FEB15 AD Check if RFMT can be read for .tab files
C     09JAN14 AD Original.
C
C DESCRIPTION
C     Identify type of LUT file.
C     Called by LUTFIL for each file in *LUT section of driver table
C     Returns 'ASC', 'BIN', 'SVD' or ' ' if cannot identify LUT.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNLUT !  I  LUN for LUT File
      CHARACTER*(*) NAMLUT !  I  Name of LUT file 
C
C LOCAL CONSTANTS
      INTEGER NTYP         ! No different LUT file types
        PARAMETER ( NTYP = 3 )
C
C LOCAL VARIABLES
      INTEGER       IOS    ! Saved value of IOSTAT for error messages
      INTEGER       ITYP   ! Index of LUT type in TYPLST
      LOGICAL       GOTTYP ! T=identified LUT type
      REAL          RFMT   ! Format identifier for .tab files
      CHARACTER*80  REC80  ! Record from LUT file
      CHARACTER*3   TYPLST(NTYP) ! List of different LUT types
      CHARACTER*3   TYP    ! Current LUT type being tested
C
C DATA STATEMENTS
      DATA TYPLST / 'ASC', 'SVD', 'BIN' /
      SAVE TYPLST
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Use filename to guess probable type and put first in trial list
      IF ( INDEX ( NAMLUT, '.bin' ) .GT. 0 ) THEN
        TYPLST(1) = 'BIN'
        TYPLST(2) = 'ASC'
      ELSE IF ( INDEX ( NAMLUT, 'CS_' ) .GT. 0 ) THEN
        TYPLST(1) = 'SVD'
        TYPLST(3) = 'ASC'
      ENDIF
C
C Try all different types starting with guessed type
      REC80 = ' '
      GOTTYP = .FALSE.
      DO ITYP = 1, NTYP
        TYP = TYPLST(ITYP)
C
        IF ( TYP .EQ. 'ASC' ) THEN
          OPEN ( UNIT=LUNLUT, FILE=NAMLUT, STATUS='OLD', 
     &           IOSTAT=IOS, ERR=100 ) 
          REC80 = '!'
          DO WHILE ( REC80(1:1) .EQ. '!' ) 
            READ ( LUNLUT, '(A)', IOSTAT=IOS, ERR=100 ) REC80
          END DO
          READ ( REC80, *, ERR=100 ) RFMT
          GOTTYP = .TRUE.
C
        ELSE IF ( TYP .EQ. 'BIN' ) THEN    ! could interpret SVD LUT as .bin !
          OPEN ( UNIT=LUNLUT, FILE=NAMLUT, STATUS='OLD', 
     &           FORM='UNFORMATTED', IOSTAT=IOS, ERR=100 ) 
          REC80 = '!'
          DO WHILE ( REC80(1:1) .EQ. '!' ) 
            READ ( LUNLUT, IOSTAT=IOS, ERR=100 ) REC80
          END DO
          READ ( REC80, *, ERR=100 ) RFMT     
          GOTTYP = .TRUE.
C
        ELSE IF ( TYP .EQ. 'SVD' ) THEN
          OPEN ( UNIT=LUNLUT, FILE=NAMLUT, STATUS='OLD', 
     &           IOSTAT=IOS, ERR=100 ) 
          READ ( LUNLUT, '(A)', IOSTAT=IOS, ERR=100 ) REC80
          IF ( REC80(1:1) .EQ. '!' ) GOTO 100
          READ ( LUNLUT, '(A)', IOSTAT=IOS, ERR=100 ) REC80
          GOTTYP = ( REC80(1:1) .EQ. '#' ) 
C
        END IF

 100    CONTINUE           ! jump here if LUT type different to test
        CLOSE ( LUNLUT )
        IF ( GOTTYP ) THEN
          TYPLUT = TYP
          RETURN
        END IF
      END DO
C
C Cannot identify LUT type
      TYPLUT = ' '
C
      END
