      REAL FUNCTION VALATM ( HGT, FNC )
C
C VERSION
C     04FEB15 AD Use BRAKET to determine interpolation points
C                Assume HGT always within atmos.profile range
C     29DEC99 AD Original.
C
C DESCRIPTION
C     Function to interpolate value from atmospheric profiles.
C     Called by TANITR and TANCNV
C
      IMPLICIT NONE
C
C ARGUMENTS
      REAL        HGT      !  I  Altitude [km]
      CHARACTER*3 FNC      !  I  Function to be interpolated
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
C
C LOCAL VARIABLES
      INTEGER IATM         ! Lower vertical profile index
      INTEGER JATM         ! Upper vertical profile index
      REAL    DATM         ! Interpolation weight for IATM
      REAL    EATM         ! Interpolation weight for JATM
C
C DATA STATEMENTS
      DATA IATM / 1 / 
      SAVE IATM
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Update IATM index if required
      CALL BRAKET ( HGTATM, NATM, HGT, IATM )
C
C Only expect values of HGT within range of atmospheric profile
C Earlier version of this subroutine allowed for HGT>HGTATM with RFR=0?
C IATM could be 0 if HGT=HGTATM(1), so set to 1.
      IATM = MAX ( IATM, 1 )
      IF ( IATM .EQ. NATM ) STOP 'F-VALATM: Logical error#1'
C
      IF ( FNC .EQ. 'RFR' ) THEN
C
        JATM = IATM + 1
        EATM = ( HGT - HGTATM(IATM) ) / ( HGTATM(JATM) - HGTATM(IATM) ) 
        DATM = 1.0 - EATM
C Log Interpolation of Refractivity where values large enough
        IF ( RFRATM(JATM) .GT. ARGMIN ) THEN  ! Assume RFR(IATM)>RFR(JATM)
          VALATM = EXP ( DATM * LOG ( RFRATM(IATM) ) +
     &                   EATM * LOG ( RFRATM(JATM) )   )
        ELSE                                ! linear interpolation
          VALATM =  DATM * RFRATM(IATM) + EATM * RFRATM(JATM) 
        END IF
C
C Density Scale Height applies to each layer rather than level, so no interp.
      ELSE IF ( FNC .EQ. 'DSH' ) THEN
        VALATM = DSHATM(IATM)
C
      ELSE
        STOP 'F-VALATM: Logical Error#2'
      END IF
C
      END

