      REAL FUNCTION VALGLP ( LNP, PSI, FNC, IPRF )
C
C VERSION
C     01JAN15 AD Orginal.
C
C DESCRIPTION
C     Function interpolate value from (lnp,psi) atmospheric field.
C     Similar to VALGRA except ln(p) used as vertical coordinate.
C
      IMPLICIT NONE
C
C ARGUMENTS
      REAL        LNP  !  I  ln(pressure[mb])
      REAL        PSI  !  I  LOS angle [deg]
      CHARACTER*3 FNC  !  I  Function to be interpolated
      INTEGER     IPRF !  I  Profile# (defined if FNC = 'VMR', 'TVB' or 'QFN')
C
      EXTERNAL
     &  IDXINT ! Index of array element below given value, and interp. fraction
     &, VAL2DI ! Function interpolate value from 2D array
     &, VALINT ! Function to linearly interpolate value from array
      INTEGER IDXINT
      REAL VAL2DI, VALINT
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
C
C LOCAL VARIABLES
      INTEGER  IATM   ! Lower vertical profile index
      INTEGER  IGRA   ! Lower horizontal profile index
      REAL     DATM   ! Interpolation weight for IATM
      REAL     DGRA   ! Interpolation weight for IGRA
      REAL     HGT    ! Interpolated height for (lnp,psi)
      REAL     HGTI   ! Height of lnp at location IGRA
      REAL     HGTJ   ! Height of lnp at location IGRA+1
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Locate point in horizontal domain
      IGRA = IDXINT ( PSIGRA, NGRA, PSI, DGRA ) 
C
C Vertically interpolate at horizontal locations either side to find heights
C of pressure level
      HGTI = VALINT ( LNP, LNPGRA(1,IGRA), HGTATM, NATM, .FALSE. ) 
      HGTJ = VALINT ( LNP, LNPGRA(1,IGRA+1), HGTATM, NATM, .FALSE. )
C
C Horizontally interpolate to find height of pressure level at PSI
      HGT = DGRA * HGTJ + (1.0-DGRA) * HGTI
C
      IATM = IDXINT ( HGTATM, NATM, HGT, DATM )
C
      IF ( FNC .EQ. 'TVB' ) THEN
        VALGLP = VAL2DI ( TVBGRA(1,1,IPRF), MAXATM, IATM, DATM, IGRA,
     &                    DGRA, .FALSE. ) 
      ELSE IF ( FNC .EQ. 'QFN' ) THEN
        VALGLP = VAL2DI ( QFNGRA(1,1,IPRF), MAXATM, IATM, DATM, IGRA,
     &                    DGRA, .FALSE. ) 
      ELSE
        STOP 'F-VALGLP: Logical error'
      END IF
C
      END

