      REAL FUNCTION VALGRA ( HGT, PSI, FNC, IPRF )
C
C VERSION
C     01JAN15 AD Use IDXINT, VAL2DI for interpolation
C     23JUL03 AD Use Refractivity instead of Density for 'DSH'
C     17DEC01 AD Save DATM,EATM etc
C     24MAY01 AD Correction: avoid extrapolation low psi values.
C     31DEC99 AD Original.
C
C DESCRIPTION
C     Function interpolate value from 2D atmospheric field.
C
      IMPLICIT NONE
C
C ARGUMENTS
      REAL        HGT  !  I  Altitude [km]
      REAL        PSI  !  I  LOS angle [deg]
      CHARACTER*3 FNC  !  I  Function to be interpolated
      INTEGER     IPRF !  I  Profile# (defined if FNC = 'VMR', 'TVB' or 'QFN')
C
      EXTERNAL
     &  IDXINT ! Index of array element below given value, and interp. fraction
     &, VAL2DI ! Function interpolate value from 2D array
      INTEGER IDXINT
      REAL VAL2DI
C
C GLOBAL CONSTANTS
      INCLUDE 'idxcon.inc' ! HITRAN molecular indices
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'atmcom.inc' ! Atmospheric profile data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'gracom.inc' ! Atmospheric 2-D field data
C
C LOCAL VARIABLES
      INTEGER  IATM   ! Lower vertical profile index
      INTEGER  IGRA   ! Lower horizontal profile index
      LOGICAL  LOGINT ! T=linear interpolation, F=log interpolation
      REAL     DATM   ! Interpolation weight for IATM
      REAL     DGRA   ! Interpolation weight for IGRA
      REAL     HGTPRV ! Previous value of HGT
      REAL     PSIPRV ! Previous value of PSI       
C
C DATA STATEMENTS
      DATA IATM / 1 / 
      DATA IGRA / 1 /
      DATA DATM / 0.0 /
      DATA DGRA / 0.0 /
      DATA HGTPRV / -1.0E20 /
      DATA PSIPRV / -1.0E20 / 
      SAVE IATM, IGRA, DATM, DGRA, HGTPRV, PSIPRV
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Update IATM,DATM if required
      IF ( HGT .NE. HGTPRV ) THEN 
        IATM = IDXINT ( HGTATM, NATM, HGT, DATM )
        HGTPRV = HGT
      END IF
C
C Update IGRA,DGRA if required
      IF ( PSI .NE. PSIPRV ) THEN
        IGRA = IDXINT ( PSIGRA, NGRA, PSI, DGRA ) 
        PSIPRV = PSI
      END IF
C
      IF ( FNC .EQ. 'TEM' ) THEN
        VALGRA = VAL2DI ( TEMGRA, MAXATM, IATM, DATM, IGRA, DGRA, 
     &                    .FALSE. ) 
      ELSE IF ( FNC .EQ. 'RFR' ) THEN
        VALGRA = VAL2DI ( RFRGRA, MAXATM, IATM, DATM, IGRA, DGRA,
     &                    .TRUE. ) 
      ELSE IF ( FNC .EQ. 'PRE' ) THEN
        VALGRA = VAL2DI ( PREGRA, MAXATM, IATM, DATM, IGRA, DGRA, 
     &                    .TRUE. ) 
      ELSE IF ( FNC .EQ. 'DNS' ) THEN
        VALGRA = VAL2DI ( DNSGRA, MAXATM, IATM, DATM, IGRA, DGRA, 
     &                    .TRUE. ) 
      ELSE IF ( FNC .EQ. 'VMR' ) THEN
        LOGINT = .NOT. ( LINFLG .OR. IDXGAS(IPRF) .EQ. IDXAER )
        VALGRA = VAL2DI ( VMRGRA(1,1,IPRF), MAXATM, IATM, DATM, IGRA, 
     &                    DGRA, LOGINT ) 
      ELSE IF ( FNC .EQ. 'TVB' ) THEN
        VALGRA = VAL2DI ( TVBGRA(1,1,IPRF), MAXATM, IATM, DATM, IGRA,
     &                    DGRA, .FALSE. ) 
      ELSE IF ( FNC .EQ. 'QFN' ) THEN
        VALGRA = VAL2DI ( QFNGRA(1,1,IPRF), MAXATM, IATM, DATM, IGRA,
     &                    DGRA, .FALSE. ) 
C
      ELSE IF ( FNC .EQ. 'DSH' ) THEN              ! Density Scale Height (+ve)
C 23JUL03: Use refractivity gradient if possible (see also ATMAUX calculation)
        IF ( MIN ( RFRGRA(IATM+1,IGRA), RFRGRA(IATM+1,IGRA+1) ) 
     &         .GT. ARGMIN*1.0E6 ) THEN
          VALGRA = ( HGTATM(IATM+1) - HGTATM(IATM) ) /
     &   ( (1.0-DGRA) * LOG(RFRGRA(IATM,IGRA)/RFRGRA(IATM+1,IGRA)) +
     &           DGRA * LOG(RFRGRA(IATM,IGRA+1)/RFRGRA(IATM+1,IGRA+1)) )
        ELSE IF ( MIN ( DNSGRA(IATM+1,IGRA), DNSGRA(IATM+1,IGRA+1) ) 
     &        .GT. ARGMIN ) THEN
          VALGRA = ( HGTATM(IATM+1) - HGTATM(IATM) ) /
     &   ( (1.0-DGRA) * LOG(DNSGRA(IATM,IGRA)/DNSGRA(IATM+1,IGRA)) +
     &           DGRA * LOG(DNSGRA(IATM,IGRA+1)/DNSGRA(IATM+1,IGRA+1)) )
        ELSE
          VALGRA = 1.0E20
        END IF
C
      ELSE IF ( FNC .EQ. 'DRP' ) THEN                ! d(Refractivity)/d(Psi)
        IF ( NGRA .EQ. 1 ) THEN                   ! No horizontal gradient
          VALGRA = 0.0
        ELSE                  ! Since horiz.grad is +/-, don't do log interp.
          VALGRA = ( 
     &    (1.0-DATM) * ( RFRGRA(IATM,IGRA+1) - RFRGRA(IATM,IGRA) )+
     &          DATM * ( RFRGRA(IATM+1,IGRA+1) - RFRGRA(IATM+1,IGRA) ) )
     &             / ( PSIGRA(IGRA+1) - PSIGRA(IGRA) ) / DTORAD
        END IF
C
      ELSE
        STOP 'F-VALGRA: Logical Error'
      END IF
C
      END

