      SUBROUTINE WRTTAB ( FAIL, ERRMSG )
C
C VERSION
C     13JUL15 AD Set small k values to ZERLNK instead of LOG(ARGMIN)
C     12DEC14 AD Write ln(k) rather than k
C     16JAN14 AD New output format
C     31OCT97 AD Original.
C
C DESCRIPTION
C     Write RFM tabulated absorption coefficients.
C     Called by RFM for each widemesh interval if TAB flag selected.
C
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL      FAIL    !  O  Set TRUE if a fatal error occurs
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
C GLOBAL CONSTANTS
      INCLUDE 'phycon.inc' ! Physical and Mathematical constants
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'fincom.inc' ! Fine mesh data
      INCLUDE 'flgcom.inc' ! RFM option flags
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'outcom.inc' ! RFM output file data
      INCLUDE 'tabcom.inc' ! Table axes for tabulated absorb.coeffs.
C
C LOCAL CONSTANTS
      REAL ZERLNK          ! ln(k) value used for k < ARGMIN
        PARAMETER ( ZERLNK = -99.0 )
C
C LOCAL VARIABLES
      INTEGER       ICLC   ! Calculated path counter
      INTEGER       IFIN   ! Fine mesh grid-point counter
      INTEGER       IGAS   ! Counter for absorbers
      INTEGER       IOFF   ! Path offset index for different gases
      INTEGER       IOS    ! Value of IOSTAT saved for error messages.
      INTEGER       LUN    ! Local value of Logical Unit Number.
      DOUBLE PRECISION GHZFAC ! Factor to convert WNo to GHz if required
C
C EXECUTABLE CODE --------------------------------------------------------------
C
      IF ( GHZFLG ) THEN
        GHZFAC = VLIGHT * 1.0D-7         ! VLIGHT in phycon.inc
      ELSE
        GHZFAC = 1.0D0
      END IF
C
      DO ICLC = 1, NGAS * NATAB
        DO IFIN = 1, NFIN
          IF ( ABSFIN(IFIN,ICLC) .GE. ARGMIN ) THEN
            ABSFIN(IFIN,ICLC) = LOG ( ABSFIN(IFIN,ICLC) ) 
          ELSE
            ABSFIN(IFIN,ICLC) = ZERLNK
          END IF
        END DO
      END DO
C          
      DO IGAS = 1, NGAS
        LUN = LUNTAB + IGAS - 1 
        IOFF = ( IGAS - 1 ) * NATAB
        IF ( BINFLG ) THEN
          DO IFIN = IOUT1, IOUT2
            WRITE ( LUN, IOSTAT=IOS, ERR=900 ) WNOFIN(IFIN)*GHZFAC,
     &        ( ABSFIN(IFIN,ICLC), ICLC = IOFF+1, IOFF+NATAB )
          END DO
        ELSE
          DO IFIN = IOUT1, IOUT2
            WRITE ( LUN, *, IOSTAT=IOS, ERR=900 ) WNOFIN(IFIN)*GHZFAC,
     &        ( ABSFIN(IFIN,ICLC), ICLC = IOFF+1, IOFF+NATAB )
          END DO
        END IF
      END DO
C
      FAIL = .FALSE.
      RETURN
C
  900 FAIL = .TRUE.
      WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-WRTTAB: I/O failure on output file. IOSTAT=', IOS
C
      END
