      SUBROUTINE XSCBUF ( USEXSC, IXSC, IT1, IP1, NT, NP, MT, MP, 
     &                    RELOAD, REMOVE )
C
C VERSION
C     21NOV14 AD Original.
C 
C DESCRIPTION    
C     Handle local memory storage of multiple X/S datasets
C     Called by RFMXSC for each used X/S file.
C
C     It is assumed that data from multiple absorption cross-sections datasets
C     are stored externally sequentially in two arrays, T and P.
C     Just using the T array as an example
C     If USEXSC=T, then IXSC is a required dataset:
C       if marked as saved then just return index of 1st array element IT1,
C         together with length (NT) and currently filled size of T arrays (MT).
C       else 
C         if sufficient remaining space, then allocate space, adjusting IT1,etc
C         if insufficient space then
C           clear all stored arrays
C           allocate space starting at beginning of array
C       endif
C     If USEXSC=F, then IXSC is no longer a required dataset:
C       if IXSC currently saved
C         remove IXSC from list of pointers
C         return start location (IT1), no.pts (NT) and new total filled space 
C           (MT) (it is assumed that these points will be deleted from *XST,
C                 *XSP arrays arrays by the calling program)
C                  
      IMPLICIT NONE
      SAVE
C
C ARGUMENTS      
      LOGICAL USEXSC !  I  T=using this x/s dataset, F=not using this dataset
      INTEGER IXSC   !  I  Index of x/s dataset
      INTEGER IT1    !  O  Index of 1st point in *XST arrays for dataset
      INTEGER IP1    !  O  Index of 1st point in *XSP arrays for dataset
      INTEGER NT     !  O  No. of points in *XST arrays for dataset
      INTEGER NP     !  O  No. of points in *XSP arrays for dataset
      INTEGER MT     !  O  Total number of points in *XST buffer
      INTEGER MP     !  O  Total number of points in *XSP buffer
      LOGICAL RELOAD !  O  T=need to read in new x/s data, F=already stored 
      LOGICAL REMOVE !  O  T=need to remove points from buffer, F=no need
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
C
C COMMON VARIABLES
      INCLUDE 'xsccom.inc' ! X-section data 
C
C LOCAL VARIABLES
      INTEGER IOPXSC(MAXXSC) ! Offset for dataset in *XSP arrays
      INTEGER IOTXSC(MAXXSC) ! Offset for dataset in *XST arrays
      INTEGER JXSC           ! Counter for X/S datasets
      INTEGER MXSP           ! Max index of *XSP arrays currently used
      INTEGER MXST           ! Max index of *XST arrays currently used
      LOGICAL SAVXSC(MAXXSC) ! T=currently saved in buffer, F=not saved
C
C DATA STATEMENTS
      DATA IOPXSC / MAXXSC * 0 /
      DATA IOTXSC / MAXXSC * 0 /
      DATA MXSP / 0 /
      DATA MXST / 0 /
      DATA SAVXSC / MAXXSC * .FALSE. /
C
C EXECUTABLE CODE -------------------------------------------------------------
C
      IF ( USEXSC ) THEN
        REMOVE = .FALSE.
        RELOAD = .NOT. SAVXSC(IXSC)
C If data not currently saved, then check if enough space to add to buffer
        IF ( RELOAD ) THEN    
          IF ( MXST + NTXSC(IXSC) .GT. MAXXST .OR.
     &         MXSP + NPXSC(IXSC) .GT. MAXXSP ) THEN   ! out of space, so reset
            MXST = 0
            MXSP = 0
            DO JXSC = 1, NXSC
              SAVXSC(JXSC) = .FALSE.
            END DO
          END IF
C Set up buffer assumed this dataset will be now be loaded
          SAVXSC(IXSC) = .TRUE.
          IOTXSC(IXSC) = MXST
          IOPXSC(IXSC) = MXSP
          MXST = MXST + NTXSC(IXSC)
          MXSP = MXSP + NPXSC(IXSC)
        END IF
        IT1 = IOTXSC(IXSC) + 1
        IP1 = IOPXSC(IXSC) + 1
        NT = NTXSC(IXSC)
        NP = NPXSC(IXSC)
        MT = MXST
        MP = MXSP

C If dataset saved but no longer required then delete and move subsequent
C buffer data forwards in arrays
      ELSE IF ( SAVXSC(IXSC) ) THEN 
        RELOAD = .FALSE.
        REMOVE = .TRUE.
        NT = NTXSC(IXSC)
        NP = NPXSC(IXSC)
        DO JXSC = 1, NXSC
          IF ( IOTXSC(JXSC) .GT. IOTXSC(IXSC) )
     &      IOTXSC(JXSC) = IOTXSC(JXSC) - NT
          IF ( IOPXSC(JXSC) .GT. IOPXSC(IXSC) )
     &      IOPXSC(JXSC) = IOPXSC(JXSC) - NP
        END DO
        NTXSC(IXSC) = 0
        NPXSC(IXSC) = 0
        IT1 = IOTXSC(IXSC) + 1
        IP1 = IOPXSC(IXSC) + 1
        IOTXSC(IXSC) = 0
        IOPXSC(IXSC) = 0
        MXST = MXST - NT
        MXSP = MXSP - NP
        MT = MXST
        MP = MXSP
      END IF
C
      END
