      SUBROUTINE XSCCHK ( FAIL, ERRMSG )
C
C VERSION
C     21NOV14 AD Set WNOLIM as local variable instead of via DATA statement
C                    Remove xflcom.inc
C                Add warnings for MAXXST, MAXXSP array sizes
C     13JUN02 AD Only check for overlaps, not on whether files exist.
C     26APR00 AD Require some XSC data to be supplied for each gas
C     06SEP99 AD Check for index .GE. 50 rather than 51
C     10JUL98 AD Modify text of error message
C     22JAN98 AD (Standard F77) Put DATA statements *after* declarations
C     03MAR97 AD Version 3.
C     26FEB97 AD Change no X/S data from fatal to warning
C     16JAN97 AD Distinguish between fatal errors due to no X/S data for 
C                   gas, and no X/S data within required range
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Check reqd X/S species uniquely represented in X/Sec files
C     Called once by INPXSC.
C
      IMPLICIT NONE
C
C ARGUMENTS
      LOGICAL      FAIL    !  O  T = a fatal error has been detected
      CHARACTER*80 ERRMSG  !  O  Error message written if FAIL is TRUE
C
      EXTERNAL
     &  RFMLOG ! Write text message to RFM log file.
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'shpcon.inc' ! Line Shape codes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
      INCLUDE 'xsccom.inc' ! X/S data sets
C
C LOCAL VARIABLES
      INTEGER      IGAS    !  Counter for required gases
      INTEGER      ISPC    !  Counter for RFM spectral ranges
      INTEGER      IXSC    !  Counter for X/S data sets
      INTEGER      MAXP    !  Maximum value required for MAXXSP
      INTEGER      MAXT    !  Maximum value required for MAXXST
      INTEGER      NT      !  Number of *XST array elements required
      INTEGER      NP      !  Number of *XSP array elements required
      LOGICAL      ANYXSC  !  T = gas found in at least one X/S datasets
      CHARACTER*80 WRNMSG  !  Text for warning messages
      DOUBLE PRECISION WNO    ! Wavenumber [cm-1] for searching X/S datasets
      DOUBLE PRECISION WNOLIM ! Highest Wavenumber [cm-1] for gas so far
C
C EXECTUABLE CODE -------------------------------------------------------------
C
C For each gas, check through sorted list for any overlaps
      DO IGAS = 1, NGAS
        IF ( SHPGAS(IGAS) .EQ. SHPXSC ) THEN
          ANYXSC = .FALSE.
          WNOLIM = -1.0D0
          DO IXSC = 1, NXSC
            IF ( IGSXSC(IXSC) .EQ. IGAS ) THEN
              IF ( ANYXSC .AND. WN1XSC(IXSC) .LT. WNOLIM ) THEN
                FAIL = .TRUE.
                ERRMSG ='F-XSCCHK: Overlapping X/S files for Gas:'
     &            //CODGAS(IGAS)
                RETURN
              ELSE
                WNOLIM = WN2XSC(IXSC)
                ANYXSC = .TRUE.
              END IF
            END IF
          END DO
          IF ( .NOT. ANYXSC ) THEN
            WRNMSG ='W-XSCCHK: No X/S data within reqd range for Gas:'
     &        //CODGAS(IGAS)
            CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          END IF
        END IF
      END DO
C
C The following check is to work out the size of dimensions MAXXST, MAXXSP that
C would be required to store *all* X/S datasets required at any spectral point 
C in memory rather than re(read) from .xsc files each widemesh interval.
C If this can be done it saves a lot of I/O, hence faster execution.
      MAXT = 0
      MAXP = 0
      DO ISPC = 1, NSPC
        WNO = WNLSPC(ISPC)      ! current wno. for counting active X/S datasets
        WNOLIM = WNO            ! next wno.for which X/S is added or removed
        DO WHILE ( WNOLIM .LT. WNUSPC(ISPC) ) ! Count all active X/S datasets
          WNOLIM = WNUSPC(ISPC)               ! reset to end of spectral range
          NT = 0
          NP = 0
          DO IXSC = 1, NXSC
            IF ( WN1XSC(IXSC) .LE. WNO .AND. 
     &           WN2XSC(IXSC) .GE. WNO ) THEN   ! active at this WNO
              NT = NT + NTXSC(IXSC)
              NP = NP + NPXSC(IXSC)
              WNOLIM = MIN ( WN2XSC(IXSC), WNOLIM ) 
            ELSE IF ( WN1XSC(IXSC) .GT. WNO ) THEN
              WNOLIM = MIN ( WNOLIM, WN1XSC(IXSC) )
            END IF
          END DO
          MAXT = MAX ( NT, MAXT )
          MAXP = MAX ( NP, MAXP ) 
          WNO = WNOLIM+0.1
        END DO
      END DO
      IF ( MAXT .GT. MAXXST ) THEN
        WRITE ( WRNMSG, '(A,I10)' ) 'W-XSCCHK: Less I/O on .xsc files'//
     &    ' if MAXXST in rfmsiz.inc increased to', MAXT
        CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
      END IF
      IF ( MAXP .GT. MAXXSP ) THEN
        WRITE ( WRNMSG, '(A,I10)' ) 'W-XSCCHK: Less I/O on .xsc files'//
     &    ' if MAXXSP in rfmsiz.inc increased to', MAXP
        CALL RFMLOG ( WRNMSG, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
      END IF
C
      FAIL = .FALSE.
      END
