      SUBROUTINE XSCDEF ( LUNNXT, NAMDEF, FAIL, ERRMSG )
C
C VERSION
C     08JUL15 AD Add NAMLOG to list of EXTERNAL declarations
C     21NOV14 AD Simplify by using EXPNAM,CHKFIL,NAMLOG
C     20SEP12 AD Change NAMXSC from C*80 to C*200
C     21JUL03 AD Original.
C
C DESCRIPTION
C     Use default .xsc filename to find any missing files.
C     Called once by INPXSC if filename template found in *XSC section of 
C     driver table.
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNNXT ! I/O LUN for XSC File/next free LUN
      CHARACTER*(*) NAMDEF !  I  Default name of XSC file
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  CHKFIL ! Check if argument represents an existing filename
     &, EXPNAM ! Replace '*' in filename with given string
     &, NAMLOG ! Send text plus variable length filename to log file.
     &, RFMLOG ! Write text message to RFM log file.
     &, XSCFIL ! Open X-Section data file read from RFM driver table.
      LOGICAL CHKFIL
      CHARACTER*200 EXPNAM
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'shpcon.inc' ! Line-shape codes
C
C COMMON VARIABLES
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'xsccom.inc' ! X-section data
C
C LOCAL VARIABLES
      INTEGER       IGAS   ! Counter for absorbing species
      CHARACTER*200 NAMXSC ! Name of XSC file
C
C EXECUTABLE CODE -------------------------------------------------------------
C
C Send message to LOG file saying which file is about to be opened
      CALL RFMLOG ( 'I-XSCDEF: Checking default .xsc files',
     &              FAIL, ERRMSG )
      IF ( FAIL ) RETURN
C
      DO IGAS = 1, NGAS                            ! Loop over absorbers
        IF ( SHPGAS(IGAS) .EQ. SHPXSC .AND.
     &       .NOT. GASXSC(IGAS)             ) THEN ! no data loaded yet
          NAMXSC = EXPNAM ( NAMDEF, CODGAS(IGAS) )
          CALL NAMLOG ( 'I-XSCDEF: looking for file: ', NAMXSC,
     &                  FAIL, ERRMSG )
          IF ( FAIL ) RETURN
          IF ( CHKFIL ( NAMXSC ) ) THEN
C Check file is useful, and read in data
            CALL XSCFIL ( LUNNXT, NAMXSC, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          END IF
        ENDIF
      END DO
C Normal exit
      FAIL = .FALSE.
C
      END
