      SUBROUTINE XSCFIL ( LUNNXT, NAMXSC, FAIL, ERRMSG )
C
C VERSION
C     28JUL15 AD Bug#110 Fix ordering of IDSXSC
C     05FEB15 AD Change error messages 'F-FILXSC...' to 'F-XSCFIL...'
C                Use non-dummy variables for WNLXST,WNUXST in call REAXSC
C     21NOV14 AD Merged with subroutine FILXFL, use REAXSC instead of XFLHDR
C     05DEC00 AD Comment out READONLY
C     03MAR97 AD Version 3.
C     24DEC96 AD Add readonly to OPEN statement for VAX use
C     01OCT96 AD Version 2.
C     01SEP96 AD Version 1.
C
C DESCRIPTION
C     Open X-Section .xsc data file and check contents
C     Called by INPXSC for each file specified in *XSC section of driver table.
C     Treats .xsc files as containing arbitrary set of molecules in arbitrary
C     order of spectral ranges (eg as simple concatenation of .xsc files)
C     Note that X/S data only required within widemesh grid so test for range
C
      IMPLICIT NONE
C
C ARGUMENTS
      INTEGER       LUNNXT ! I/O LUN for XSC File/next free LUN
      CHARACTER*(*) NAMXSC !  I  Name of XSC file
      LOGICAL       FAIL   !  O  Set TRUE if a fatal error is detected
      CHARACTER*80  ERRMSG !  O  Error message returned if FAIL is TRUE
C
      EXTERNAL
     &  IDGNEW ! Convert old RFM index for .xsc data to new value
     &, OPNFIL ! Open ASCII input file, and skip/Log any initial comments.
     &, REAXSC ! Read dataset from .xsc file
     &, RFMLOG ! Write text message to RFM log file.
      INTEGER IDGNEW
C
C GLOBAL CONSTANTS
      INCLUDE 'rfmsiz.inc' ! RFM Array sizes
      INCLUDE 'shpcon.inc' ! Line-shape codes
C
C COMMON VARIABLES
      INCLUDE 'flgcom.inc' ! RFM option flags 
      INCLUDE 'gascom.inc' ! Molecular and isotope data
      INCLUDE 'spccom.inc' ! Spectral Range & Resolution data
      INCLUDE 'xsccom.inc' ! X-section data 
C
C LOCAL VARIABLES
      INTEGER     IDGAS    ! ID of first gas in forward pointer record
      INTEGER     IDGOLD   ! Old value of IDGAS read from file
      INTEGER     IDUMMY   ! Dummy integer
      INTEGER     IGAS     ! Gas counter
      INTEGER     IOS      ! Saved value of IOSTAT for error message
      INTEGER     ISET     ! Counter for datasets within .xsc file
      INTEGER     ISPC     ! Counter for RFM spectral ranges
      INTEGER IXSC, JXSC   ! Indices of X/S data sets
      INTEGER     NXSP     ! Total No.X/S data points in each X/S data set
      INTEGER     NXST     ! No. of (p,T) tables X/S data set 
      LOGICAL     EOF      ! T=reached end-of-file, F=not yet EOF
      LOGICAL     USEFIL   ! T=use data from this file, F=file not used
      LOGICAL     USEXSC   ! T=Use X/S data, F= don't use
      LOGICAL     WARN     ! T=warn if old index, F=don't warn
      REAL        RDUMMY   ! Dummy real number
      CHARACTER*100 HEADER ! Header Text for X/S data
      CHARACTER*80  MESSGE ! Text message for Log file
      DOUBLE PRECISION DWNILS ! Width to allow for ILS function (if any)
      DOUBLE PRECISION WNLXSC ! Min Wno [cm-1] for X/S dataset
      DOUBLE PRECISION WNLXST ! Min Wno [cm-1] for X/S (p,T) tabulation
      DOUBLE PRECISION WNUXSC ! Max Wno [cm-1] for X/S dataset
      DOUBLE PRECISION WNUXST ! Max Wno [cm-1] for X/S (p,T) tabulation
C
C EXECUTABLE CODE --------------------------------------------------------------
C
C Open file and print first record to log file
      CALL OPNFIL ( LUNNXT, NAMXSC, FAIL, ERRMSG ) 
      IF ( FAIL ) RETURN
C
      USEFIL = .FALSE.
      WARN = .TRUE.
      IF ( ILSFLG .OR. AVGFLG ) THEN
        DWNILS = 1.0D0       ! Allow extra width for ILS convolution
      ELSE
        DWNILS = 0.0D0
      END IF
C
C Find which molecules and wavenumber ranges are contained in file
      ISET = 1
      CALL REAXSC ( LUNNXT, ISET, 1, 1, EOF, IDGAS, WNLXSC, WNUXSC,
     &              NXSP, NXST, IDUMMY, RDUMMY, RDUMMY, WNLXST, WNUXST,
     &              RDUMMY, FAIL, ERRMSG )
        IF ( FAIL ) RETURN 
      DO WHILE ( .NOT. EOF ) 
C
C Convert to new RFM index (>100 for x/s files) if required 
        IF ( IDGAS .LT. 100 ) THEN 
          IDGOLD = IDGAS
          IDGAS = IDGNEW ( IDGOLD )
          IF ( IDGAS .GT. 100 .AND. WARN ) THEN ! successful conversion
            WARN = .FALSE.      ! just one warning per file
            WRITE ( MESSGE, '(A,I2,A,I3)' )
     &        'W-XSCFIL: File contains old molecular index=', IDGOLD,
     &        ' - assigning new index=', IDGAS
            CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
            IF ( FAIL ) RETURN
          END IF
        END IF
C
C Check that IDGAS is in the expected range for cross-section data
        IF ( IDGAS .LT. 100 .OR. IDGAS .GT. MAXMOL ) THEN
          WRITE ( ERRMSG, '(A,I11,A,I4)' )
     &      'F-XSCFIL: File contains Molec#ID=', IDGAS,
     &      ' out of valid range 100:', MAXMOL
          FAIL = .TRUE.
        END IF
C
C See if x/s molecule and spectral range are required by the RFM
        USEXSC = .FALSE.
        IGAS = IGSMOL(IDGAS)
        IF ( IGAS .GT. 0 ) THEN  ! this molecule is required by RFM
C
          IF ( SHPGAS(IGAS) .NE. SHPXSC ) 
     &      STOP 'F-XSCFIL: Logical error'
          GASXSC(IGAS) = .TRUE.  ! Flag that x/s file for molecule found,
C                                ! even if no data from file actually used
          DO ISPC = 1, NSPC
            IF ( WNLXSC .LE. WNUSPC(ISPC) + DWNILS .AND.
     &           WNUXSC .GE. WNLSPC(ISPC) - DWNILS       ) 
     &        USEXSC = .TRUE.    ! data required for at least one spect.range
          END DO
        END IF
C
C Data will be used 
        IF ( USEXSC ) THEN
          MESSGE = 'I-XSCFIL: Using x/s data: '//HEADER(1:50)
          CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
          IF ( FAIL ) RETURN
C
C Using this spectral range, so check relevant array sizes adequate
          FAIL = .TRUE.
          IF ( NXSC .EQ. MAXXSC ) THEN 
            ERRMSG = 'F-XSCFIL: No.X-Sec data arrays reqd > '//
     &        'MAXXSC in rfmsiz.inc'          
          ELSE IF ( NXST .GT. MAXXST ) THEN
            WRITE ( ERRMSG, '(A,I11,A,I11,A)' )
     &      'F-XSCFIL: No.X/S (p,T) tables =', NXST,
     &      ' > MAXXST =', MAXXST, ' in rfmsiz.inc'
          ELSE IF ( NXSP .GT. MAXXSP ) THEN
            WRITE ( ERRMSG, '(A,I11,A,I11,A)' )                        ! Bug#92
     &      'F-XSCFIL: No.X/S data pts =', NXSP, 
     &      ' > MAXXSP =', MAXXSP, ' in rfmsiz.inc' 
          ELSE
            FAIL = .FALSE.
          END IF
          IF ( FAIL ) RETURN
C
C Insert details into /XSCCOM/ list ordered by lower wavenumber
C Note that chkxsc.for will later check for any ambiguous overlaps
          JXSC = 1              ! index for insertion
          DO WHILE ( WN1XSC(JXSC) .LT. WNLXSC .AND. JXSC .LE. NXSC ) 
            JXSC = JXSC + 1
          END DO
          DO IXSC = NXSC, JXSC, -1        ! NXSC < MAXXSC already checked
            LUNXSC(IXSC+1) = LUNXSC(IXSC)
            IGSXSC(IXSC+1) = IGSXSC(IXSC)  
            NPXSC(IXSC+1) = NPXSC(IXSC)
            NTXSC(IXSC+1) = NTXSC(IXSC)
            WN1XSC(IXSC+1) = WN1XSC(IXSC)
            WN2XSC(IXSC+1) = WN2XSC(IXSC)
            IDSXSC(IXSC+1) = IDSXSC(IXSC)                  ! Bug#110
          END DO
          LUNXSC(JXSC) = LUNNXT 
          IGSXSC(JXSC) = IGAS
          NPXSC(JXSC) = NXSP
          NTXSC(JXSC) = NXST
          WN1XSC(JXSC) = WNLXSC
          WN2XSC(JXSC) = WNUXSC
          IDSXSC(JXSC) = ISET
          NXSC = NXSC + 1
C Since at least one spectral range required, mark this file as useful
          USEFIL = .TRUE.
        END IF
        ISET = ISET + 1
        CALL REAXSC ( LUNNXT, ISET, 1, 1, EOF, IDGAS, WNLXSC, WNUXSC,
     &              NXSP, NXST, IDUMMY, RDUMMY, RDUMMY, WNLXST, WNUXST,
     &              RDUMMY, FAIL, ERRMSG )
          IF ( FAIL ) RETURN 

      END DO
C
      IF ( USEFIL ) THEN      ! keep LUN open for this file
        REWIND ( LUNNXT, IOSTAT=IOS, ERR=900 ) 
        LUNNXT = LUNNXT + 1   ! set next free lun
      ELSE
        MESSGE = 
     &  'W-XSCFIL: Ignore X/S file, no reqd gases in reqd waveno.range'
        CALL RFMLOG ( MESSGE, FAIL, ERRMSG )
        IF ( FAIL ) RETURN
        CLOSE ( LUNNXT, IOSTAT=IOS, ERR=900 )
      END IF
C
      FAIL = .FALSE.
      RETURN
C
  900 FAIL = .TRUE.
      WRITE ( ERRMSG, '(A,I11)' ) 
     &  'F-XSCFIL: I/O failure on X/S file. IOSTAT=', IOS

      END

